@@ -1,7 +1,7 @@
 /*****************************************************************
  * drkonqi - The KDE Crash Handler
  *
- * $Id: backtrace.cpp,v 1.11 2000/11/04 14:42:41 faure Exp $
+ * $Id: backtrace.cpp,v 1.14 2001/12/29 16:55:12 mueller Exp $
  *
  * Copyright (C) 2000 Hans Petter Bieker <bieker@kde.org>
  *
@@ -28,10 +28,11 @@
  *****************************************************************/
 
 #include <qfile.h>
+#include <qregexp.h>
 
 #include <kprocess.h>
 #include <kdebug.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <ktempfile.h>
@@ -71,7 +72,7 @@ void BackTrace::start()
   QString exec = m_krashconf->tryExec();
   if ( !exec.isEmpty() && KStandardDirs::findExe(exec).isEmpty() )
   {
-    KMessageBox::error(0L,i18n("%1 not found. Check if it is installed, you need it to generate backtraces.\n"
+    KMessageBox::error(0L,i18n("%1 not found. Check if it is installed -- you need it to generate backtraces.\n"
                                "If you have another debugger, contact kde-devel@kde.org for help on how to set it up.").arg(exec));
     return;
   }
