@@ -1,7 +1,7 @@
 /*****************************************************************
  * drkonqi - The KDE Crash Handler
  *
- * $Id: main.cpp,v 1.23 2001/05/20 01:42:17 mhunter Exp $
+ * $Id: main.cpp,v 1.25 2002/03/19 18:54:32 ossi Exp $
  *
  * Copyright (C) 2000 Hans Petter Bieker <bieker@kde.org>
  *
@@ -32,7 +32,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <klocale.h>
@@ -76,6 +76,8 @@ int main( int argc, char* argv[] )
   KCmdLineArgs::init(argc, argv, &aboutData);
   KCmdLineArgs::addCmdLineOptions( options );
 
+  KApplication::disableAutoDcopRegistration();
+
   KApplication a;
   a.disableSessionManagement();
 
