@@ -1,7 +1,7 @@
 /*****************************************************************
  * drkonqi - The KDE Crash Handler
  *
- * $Id: toplevel.cpp,v 1.36 2001/05/20 01:42:17 mhunter Exp $
+ * $Id: toplevel.cpp,v 1.39 2002/01/04 05:29:40 firebaugh Exp $
  *
  * Copyright (C) 2000 Hans Petter Bieker <bieker@kde.org>
  *
@@ -36,7 +36,7 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kdebug.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kbugreport.h>
 #include <kmessagebox.h>
 #include <kprocess.h>
@@ -60,11 +60,8 @@ Toplevel :: Toplevel(const KrashConfig *krashconf, QWidget *parent, const char *
                  i18n("&Bug report"),
                  i18n("&Debugger")
                  ),
-    m_krashconf(krashconf), bugreport(0)
+    m_krashconf(krashconf), m_bugreport(0)
 {
-  NETWinInfo inf(qt_xdisplay(), winId(), qt_xrootwin(), NET::WMState);
-  inf.setState(NET::StaysOnTop, NET::StaysOnTop);
-
   QHBox *page = addHBoxPage(i18n("General"));
   page->setSpacing(20);
 
@@ -124,7 +121,7 @@ QString Toplevel :: generateText() const
 // starting bug report
 void Toplevel :: slotUser1()
 {
-  if (bugreport) return;
+  if (m_bugreport) return;
 
   int i = KMessageBox::No;
   if ( m_krashconf->pid() != 0 )
@@ -146,7 +143,7 @@ void Toplevel :: slotUser1()
 
     if (i == KMessageBox::Cancel) return;
 
-  bugreport = new DrKBugReport(0, true, m_krashconf->aboutData());
+  m_bugreport = new DrKBugReport(0, true, m_krashconf->aboutData());
 
   if (i == KMessageBox::Yes) {
     QApplication::setOverrideCursor ( waitCursor );
@@ -162,9 +159,9 @@ void Toplevel :: slotUser1()
     return;
   }
 
-  int result = bugreport->exec();
-  delete bugreport;
-  bugreport = 0;
+  int result = m_bugreport->exec();
+  delete m_bugreport;
+  m_bugreport = 0;
   if (result == KDialogBase::Accepted)
      close();
 }
@@ -185,13 +182,13 @@ void Toplevel :: slotBacktraceDone(const QString &str)
   QString buf = QString::fromLatin1
     ("\n\n\nHere is a backtrace generated by DrKonqi:\n") + str;
 
-  bugreport->setText(buf);
+  m_bugreport->setText(buf);
 
   QApplication::restoreOverrideCursor();
 
-  bugreport->exec();
-  delete bugreport;
-  bugreport = 0;
+  m_bugreport->exec();
+  delete m_bugreport;
+  m_bugreport = 0;
 }
 
 void Toplevel :: slotBacktraceSomeError()
@@ -201,8 +198,8 @@ void Toplevel :: slotBacktraceSomeError()
   KMessageBox::sorry(0, i18n("It was not possible to generate a backtrace."),
                      i18n("Backtrace not possible"));
 
-  bugreport->exec();
-  delete bugreport;
-  bugreport = 0;
+  m_bugreport->exec();
+  delete m_bugreport;
+  m_bugreport = 0;
 }
 
