@@ -15,13 +15,14 @@
 #include <qgrid.h>
 #include <qgroupbox.h>
 #include <qtabwidget.h>
+#include <qmultilineedit.h>
 
 #include "namevaluewidget.h"
 #include "attributes.h"
 #include "contactentry.h"
 #include "datepickerdialog.h"
 #include <klocale.h>
-#include <kapp.h> // for kapp->palette()
+#include <kapplication.h> // for kapp->palette()
 #include <kglobal.h>
 #include <kdebug.h>
 #include <kseparator.h>
@@ -86,6 +87,7 @@ void ContactDialog::setupTab1()
   QPushButton *pbFullName = new QPushButton( i18n( "&Full Name..." ), tab1 );
   leFullName = new ContactLineEdit( tab1, ".AUXCONTACT-N", ce );
   leFullName->setText( curName );
+  leFullName->setCursorPosition(0);
 
   connect( ce, SIGNAL( changed() ), this, SLOT( parseName() ));
   connect( pbFullName, SIGNAL( clicked()), this, SLOT( newNameDialog()));
@@ -100,12 +102,14 @@ void ContactDialog::setupTab1()
   QLabel *lJobTitle = new QLabel( i18n( "&Job title:" ), tab1 );
   QLineEdit *leJobTitle = new ContactLineEdit( tab1, "ROLE", ce );
   lJobTitle->setBuddy( leJobTitle );
+  leJobTitle->setCursorPosition(0);
   tab1lay->addWidget( lJobTitle, 0, 3 );
   tab1lay->addWidget( leJobTitle, 0, 4 );
 
   // Second row
   QLabel *lCompany = new QLabel( i18n( "&Company:" ), tab1 );
   QLineEdit *leCompany = new ContactLineEdit( tab1, "ORG", ce );
+  leCompany->setCursorPosition(0);
   lCompany->setBuddy( leCompany );
   curCompany = leCompany->text();
   connect( ce, SIGNAL( changed() ), this, SLOT( monitorCompany() ));
@@ -145,6 +149,7 @@ void ContactDialog::setupTab1()
   cbEmail->insertItem( i18n( "Email 2" ), "X-E-mail2" );
   cbEmail->insertItem( i18n( "Email 3" ), "X-E-mail3" );
   QLineEdit *leEmail = new ContactLineEdit( tab1, "EMAIL", ce );
+  leEmail->setCursorPosition(0);
   cbEmail->setBuddy( leEmail );
   tab1lay->addWidget( cbEmail, 3, 0 );
   tab1lay->addWidget( leEmail, 3, 1 );
@@ -156,6 +161,7 @@ void ContactDialog::setupTab1()
 
   QLabel *lWebPage = new QLabel( i18n( "&Web page:" ), tab1 );
   QLineEdit *leWebPage = new ContactLineEdit( tab1, "WEBPAGE", ce );
+  leWebPage->setCursorPosition(0);
   lWebPage->setBuddy( leWebPage );
   tab1lay->addWidget( lWebPage, 3, 3 );
   tab1lay->addWidget( leWebPage, 3, 4 );
@@ -199,8 +205,8 @@ void ContactDialog::setupTab1()
 
   // Perhaps the address "subfields" (city, postal, country) should be cleared
   // when this control loses focus. They aren't at the moment.
-  QMultiLineEdit *mleAddress = new ContactMultiLineEdit( tab1, "X-BusinessAddress", ce );
-  mleAddress->setWordWrap( QMultiLineEdit::WidgetWidth );
+  QTextEdit *mleAddress = new ContactMultiLineEdit( tab1, "X-BusinessAddress", ce );
+  mleAddress->setWordWrap( QTextEdit::WidgetWidth );
   cbAddress->setBuddy( mleAddress );
   tab1lay->addWidget( mleAddress, 5, 1 );
 
@@ -223,9 +229,13 @@ void ContactDialog::setupTab1()
 
   int iPhone[4];
   iPhone[0] = fieldPhone.findIndex( "X-BusinessPhone" );
+  if (iPhone[0] == -1) kdWarning() << "X-BusinessPhone field not found" << endl;
   iPhone[1] = fieldPhone.findIndex( "X-HomePhone" );
+  if (iPhone[1] == -1) kdWarning() << "X-HomePhone field not found" << endl;
   iPhone[2] = fieldPhone.findIndex( "X-BusinessFax" );
+  if (iPhone[2] == -1) kdWarning() << "X-BusinessFax field not found" << endl;
   iPhone[3] = fieldPhone.findIndex( "X-MobilePhone" );
+  if (iPhone[3] == -1) kdWarning() << "X-MobilePhone field not found" << endl;
 
   QGridLayout *layhGrid = new QGridLayout( numRows, 2 );
   layhGrid->setSpacing( 10 );
@@ -237,11 +247,14 @@ void ContactDialog::setupTab1()
     //      cbPhone->insertItem( i18n( sPhone[i] ), vPhone[i] );
     for( int i = 0; i < (int)namePhone.count(); ++i )
       cbPhone->insertItem(  namePhone[i], fieldPhone[i] );
-    cbPhone->setCurrentItem( iPhone[row] );
+    if ( iPhone[row] != -1 )
+        cbPhone->setCurrentItem( iPhone[row] );
     cbPhone->setMinimumSize( cbPhone->sizeHint() );
     layhGrid->addWidget( cbPhone, row, 0 );
 
-    QLineEdit *ed = new ContactLineEdit( hGrid, fieldPhone[iPhone[row]].ascii(), ce );
+    QCString fieldPhoneName = (iPhone[row] != -1) ? fieldPhone[iPhone[row]].ascii() : "X-NOTFOUND";
+    QLineEdit *ed = new ContactLineEdit( hGrid, fieldPhoneName, ce );
+    ed->setCursorPosition(0);
     ed->setMinimumSize( ed->sizeHint());
     cbPhone->setBuddy( ed );
     layhGrid->addWidget( ed, row ,1 );
@@ -261,7 +274,7 @@ void ContactDialog::setupTab1()
 //////////////////////
 // The Note group
   // Interestingly this doesn't have an equivalent in tab3
-  QMultiLineEdit *mleNotes = new ContactMultiLineEdit( tab1, "X-Notes", ce );
+  QTextEdit *mleNotes = new ContactMultiLineEdit( tab1, "X-Notes", ce );
   mleNotes->setWordWrap( QMultiLineEdit::WidgetWidth );
   mleNotes->setMinimumSize( mleNotes->sizeHint() );
   mleNotes->resize( mleNotes->sizeHint() );
@@ -400,16 +413,18 @@ void ContactDialog::setupTab3()
     lay3->addWidget( pbNew, 0 );
     lay3->addStretch( 1 );  // Fix the other widgets in place
     t3lay->addWidget( row3, 0);
-    tabs->addTab( tab3, i18n( "&All fields" ));
+    tabs->addTab( tab3, i18n( "&All Fields" ));
 }
 
 void ContactDialog::pickBirthDate()
 {
   DatePickerDialog* datePicker=new DatePickerDialog( i18n( "Select Birthday" ), this);
   datePicker->setDate(QDate::currentDate());
-  if(datePicker->exec())
-    ce->replace( "BDAY", new QString( datePicker->getDate().toString()));
+  if(datePicker->exec()) {
+    QString date = KGlobal::locale()->formatDate( datePicker->getDate() );
+    ce->replace( "BDAY", new QString( date ) );
     // ce autoDelete will clean it up
+  }
   delete datePicker;
 }
 
@@ -417,9 +432,11 @@ void ContactDialog::pickAnniversaryDate()
 {
   DatePickerDialog* datePicker=new DatePickerDialog( i18n( "Select Anniversary" ), this);
   datePicker->setDate(QDate::currentDate());
-  if(datePicker->exec())
-    ce->replace( "X-Anniversary", new QString( datePicker->getDate().toString()));
+  if(datePicker->exec()) {
+    QString date = KGlobal::locale()->formatDate( datePicker->getDate() );
+    ce->replace( "X-Anniversary", new QString( date ) );
     // ce autoDelete will clean it up
+  }
   delete datePicker;
 }
 
@@ -626,8 +643,8 @@ AddressDialog::AddressDialog( QWidget *parent,
     i18n( "Greece" ), i18n( "Greenland" ), i18n( "Grenada" ),
     i18n( "Guam" ), i18n( "Guatemala" ), i18n( "Guinea" ),
     i18n( "Guinea-Bissau" ), i18n( "Guyana" ), i18n( "Haiti" ),
-    i18n( "Holland" ), i18n( "Honduras" ), i18n( "Hong Kong" ),
-    i18n( "Hungary" ), i18n( "Iceland" ), i18n( "India" ), i18n( "Indonesia" ),
+    i18n( "Honduras" ), i18n( "Hong Kong" ), i18n( "Hungary" ), 
+    i18n( "Iceland" ), i18n( "India" ), i18n( "Indonesia" ),
     i18n( "Iran" ), i18n( "Iraq" ), i18n( "Ireland" ),
     i18n( "Israel" ), i18n( "Italy" ), i18n( "Ivory Coast" ),
     i18n( "Jamaica" ), i18n( "Japan" ), i18n( "Jordan" ),
@@ -731,15 +748,16 @@ AddressDialog::AddressDialog( QWidget *parent,
 
   QString country = KGlobal::locale()->country();
   // Try to guess the country the user is in depending
-  // on their preferred language.
-  // Imperfect but the best I could do.
-
+  // on their country code.
+  //
+  // This is ugly and should be changed for 3.1
+  
   QString GuessLanguage[] = {
-    "C", "en", "en_AU", "en_UK", "en_NZ", "en_ZA", "da",
-    "de", "el", "es", "fi", "fr", "he",
+    "C", "us", "au", "uk", "nz", "za", "dk",
+    "de", "gr", "es", "fi", "fr", "il",
     "hu", "hr", "is", "it", "ko", "nl",
-    "no", "pl", "pt", "pt_BR", "ro", "ru",
-    "sv", "tr", "zh_CN.GB2312", "zh_TW.Big5", "et",
+    "no", "pl", "pt", "br", "ro", "ru",
+    "se", "tr", "cn", "tw", "ee",
     ""
   };
   QCString GuessCountry[] = {
@@ -770,9 +788,9 @@ AddressDialog::AddressDialog( QWidget *parent,
 
   QFrame *tf = new QFrame( this );
   QVBoxLayout *lay1 = new QVBoxLayout( tf, 10 );
-  QPushButton *pbOk = new QPushButton( i18n("OK"), tf );
+  QPushButton *pbOk = new QPushButton( i18n("&OK"), tf );
   lay1->addWidget( pbOk, 0 );
-  QPushButton *pbCancel = new QPushButton( i18n("Cancel"), tf );
+  QPushButton *pbCancel = new QPushButton( i18n("&Cancel"), tf );
   lay1->addWidget( pbCancel, 0 );
   lay1->addStretch( 1 );  // Fix the other widgets in place
 
@@ -877,9 +895,9 @@ NameDialog::NameDialog( QWidget *parent, ContactEntry *ce, bool modal )
 
   QFrame *tf = new QFrame( this );
   QVBoxLayout *lay1 = new QVBoxLayout( tf, 10 );
-  QPushButton *pbOk = new QPushButton( i18n("OK"), tf );
+  QPushButton *pbOk = new QPushButton( i18n("&OK"), tf );
   lay1->addWidget( pbOk, 0 );
-  QPushButton *pbCancel = new QPushButton( i18n("Cancel"), tf );
+  QPushButton *pbCancel = new QPushButton( i18n("&Cancel"), tf );
   lay1->addWidget( pbCancel, 0 );
   lay1->addStretch( 1 );  // Fix the other widgets in place
 
