@@ -6,6 +6,29 @@
 
 #include "undo.h"
 
+StackBase::StackBase()
+{
+}
+
+void StackBase::push( Command *command )
+{
+  QPtrStack<Command>::push( command );
+  emit stackActionAvailable( true );
+}
+
+Command *StackBase::pop()
+{
+  Command *command = QPtrStack<Command>::pop();
+  emit stackActionAvailable( !isEmpty() );
+  return command;
+}
+
+void StackBase::clear()
+{
+  QPtrStack<Command>::clear();
+  emit stackActionAvailable( false );
+}
+
 UndoStack* UndoStack::instance_ = 0;
 
 UndoStack::UndoStack()
@@ -52,3 +75,6 @@ void RedoStack::redo()
   command->redo();
   UndoStack::instance()->push( command );
 }
+
+#include "undo.moc"
+
