@@ -17,7 +17,7 @@
 
 */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <kaboutdata.h>
@@ -28,6 +28,9 @@
 
 static const char* description=I18N_NOOP("KDE's application finder");
 
+static KCmdLineOptions options[] = {
+  { "dir <dir>", I18N_NOOP("Install .desktop files into directory <dir>"), 0 },
+  { 0, 0, 0} };
 
 int main(int argc, char *argv[])
 {
@@ -37,10 +40,12 @@ int main(int argc, char *argv[])
   aboutData.addAuthor("Matthias Hoelzer-Kluepfel",0, "hoelzer@kde.org");
 
   KCmdLineArgs::init( argc, argv, &aboutData );
+  KCmdLineArgs::addCmdLineOptions( options );
+  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
   KApplication app;
 
-  Scanner *dlg = new Scanner;
+  Scanner *dlg = new Scanner(args->getOption("dir"));
   app.setMainWidget(dlg);
 
   dlg->exec();
