@@ -22,7 +22,7 @@
 
 #include <kinstance.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 
