@@ -17,11 +17,11 @@
 
 */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kprogress.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kdesktopfile.h>
 #include <kiconloader.h>
@@ -32,15 +32,15 @@
 #include <qpushbutton.h>
 #include <qstringlist.h>
 #include <qtimer.h>
-
+#include <qmultilineedit.h>
 
 #include "scanner.h"
 #include "scanner.moc"
 #include "checker.h"
 
 
-Scanner::Scanner(QWidget *parent, const char *name)
-  : KDialog(parent,name,true)
+Scanner::Scanner(QString _destDir, QWidget *parent, const char *name)
+  : KDialog(parent,name,true), destDir(_destDir)
 {
   setCaption(i18n("KDE Application Finder"));
 
@@ -50,7 +50,7 @@ Scanner::Scanner(QWidget *parent, const char *name)
 			      "applications on your system and adds "
 			      "them to the KDE menu system. "
 			      "Click 'Scan' to begin."), this);
-  l->setAlignment(WordBreak);
+  l->setAlignment(AlignAuto);
 
   grid->addMultiCellWidget(l, 0,0, 0,1);
   grid->addRowSpacing(1, marginHint());
@@ -72,13 +72,21 @@ Scanner::Scanner(QWidget *parent, const char *name)
   l = new QLabel(i18n("Progress:"), this);
   grid->addMultiCellWidget(l, 5,5, 0,1);
 
-  _progress = new KProgress(KProgress::Horizontal, this);
+  _progress = new KProgress(this);
   grid->addMultiCellWidget(_progress, 6,6, 0,1);
   _progress->hide();
 
   _summary = new QLabel(i18n("Summary:"), this);
   grid->addMultiCellWidget(_summary, 7,7, 0,1);
 
+  _scanlog = new QLabel(i18n("Log Window:"), this);
+  grid->addMultiCellWidget(_scanlog, 8,8, 0,1);
+
+   _logview = new QMultiLineEdit(this);
+     _logview->setReadOnly(TRUE);
+     _logview->setMinimumSize(600, 250);
+  grid->addMultiCellWidget(_logview, 9,9,0,10);
+  
   grid->setRowStretch(20,1);
 
   _cancel1 = new QPushButton(i18n("&Cancel"), this);
@@ -92,7 +100,7 @@ Scanner::Scanner(QWidget *parent, const char *name)
   connect(kapp, SIGNAL(lastWindowClosed()), kapp, SLOT(quit()));
   connect(_cancel1, SIGNAL(clicked()), kapp, SLOT(quit()));
 
-  resize(450,250);
+  resize(750,550);
 }
 
 
@@ -134,9 +142,16 @@ void Scanner::scanOneFile()
       _progress->setValue(_progress->value()+1);
 
       // copy over the desktop file, if exists
-      if (checkDesktopFile(*first))
+      if (checkDesktopFile(*first,destDir))
+      {
 	found++;
 
+      QString loginf(i18n("Found: %1"));
+      QString loginf2(i18n("\tUsing: %1"));
+      _logview->append(loginf.arg(desktop.readName()));
+      _logview->append(loginf2.arg(desktop.readEntry("Exec")));
+      }
+
       // update summary
       QString sum(i18n("Summary: found %1 applications"));
       _summary->setText(sum.arg(found));
@@ -150,7 +165,7 @@ void Scanner::scanOneFile()
     }
 
   // decorate directories
-  decorateDirs();
+  decorateDirs(destDir);
 
   // stop scanning
   _scan->disconnect(this, SLOT(startScan()));
