@@ -30,6 +30,7 @@
 class KProgress;
 class QLabel;
 class QPushButton;
+class QMultiLineEdit;
 
 
 class Scanner : public KDialog
@@ -38,7 +39,7 @@ class Scanner : public KDialog
 
 public:
 
-  Scanner(QWidget *parent=0, const char *name=0);
+  Scanner(QString _destDir, QWidget *parent=0, const char *name=0);
   ~Scanner();
 
 
@@ -51,11 +52,14 @@ private slots:
 private:
 
   KProgress   *_progress;
-  QLabel      *_appIcon, *_appName, *_summary;
+  QLabel      *_appIcon, *_appName, *_summary, *_scanlog;
   QPushButton *_scan, *_cancel1;
   QStringList _templates;
+  QMultiLineEdit *_logview;
+
   int         found, count;
 
+  QString     destDir;
 };
 
 
