@@ -2,8 +2,8 @@
                           kateapp.h  -  description
                              -------------------
     begin                : Wed Jan 3 2001
-    copyright            : (C) 2001 by Christoph "Crossfire" Cullmann
-    email                : crossfire@babylon2k.de
+    copyright            : (C) 2001 by Christoph Cullmann
+    email                : cullmann@kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,14 +17,14 @@
 #ifndef __kate_app_h__
 #define __kate_app_h__
 
-#include "../main/katemain.h"
+#include "katemain.h"
 #include "kateappIface.h"
 #include "../interfaces/application.h"
 #include "../interfaces/mainwindow.h"
 #include "../interfaces/docmanager.h"
 #include "../interfaces/viewmanager.h"
 
-#include <qlist.h>
+#include <qptrlist.h>
 
 class KateApp : public Kate::Application, public KateAppDCOPIface
 {
@@ -39,21 +39,26 @@ class KateApp : public Kate::Application, public KateAppDCOPIface
 
     KatePluginManager *getPluginManager(){return pluginManager;};
 
-    void newMainWindow ();
+    class KateMainWindow *newMainWindow ();
     void removeMainWindow (KateMainWindow *mainWindow);
     uint mainWindowsCount ();
     virtual QString  isSingleInstance(){if (_singleInstance) return "true"; else return "false";};
+    virtual QString  isSDI(){if (_isSDI) return "true"; else return "false";};
+
+    void raiseCurrentMainWindow ();
 
     Kate::ViewManager *getViewManager ();
     Kate::DocManager *getDocManager ();
     Kate::MainWindow *getMainWindow ();
 
-  private:
+  public:
     bool _singleInstance;
+    bool _isSDI;
+
+  private:
     KateDocManager *docManager;
     KatePluginManager *pluginManager;
-
-    QList<KateMainWindow> mainWindows;
+    QPtrList<KateMainWindow> mainWindows;
 
   public:
     void openURL (const QString &name=0L);
