@@ -2,8 +2,8 @@
                           kateIface.h  -  description
                              -------------------
     begin                : Wed Jan 3 2001
-    copyright            : (C) 2001 by Christoph "Crossfire" Cullmann
-    email                : crossfire@babylon2k.de
+    copyright            : (C) 2001 by Christoph Cullmann
+    email                : cullmann@kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -25,6 +25,8 @@ class KateAppDCOPIface : virtual public DCOPObject
 
   k_dcop:
     virtual QString isSingleInstance()=0;
+    virtual QString isSDI()=0;
     virtual void openURL (const QString &name=0)=0;
+    virtual void raiseCurrentMainWindow ()=0;
 };
 #endif
