@@ -23,22 +23,22 @@
 
 #include <kconfig.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <krun.h>
 #include <kurl.h>
 #include <kinstance.h>
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 #include <kfiledialog.h>
 #include <knuminput.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 
 #include "kcmaccess.moc"
 
 
-KAccessConfig::KAccessConfig(QWidget *parent, const char *name)
-  : KCModule(parent, name)
+KAccessConfig::KAccessConfig(QWidget *parent, const char *)
+  : KCModule(parent, "kcmaccess")
 {
   QVBoxLayout *main = new QVBoxLayout(this, 0,0);
   QTabWidget *tab = new QTabWidget(this);
@@ -496,10 +496,12 @@ extern "C"
 {
   KCModule *create_access(QWidget *parent, const char *name)
   {
-    KGlobal::locale()->insertCatalogue("kcmaccess");
     return new KAccessConfig(parent, name);
   };
 
+  /* This one gets called by kcminit
+
+   */
   void init_access()
   {
     bool run=false;
@@ -515,8 +517,15 @@ extern "C"
     if (config->readBoolEntry("VisibleBell", false))
       run = true;
 
+    config->setGroup("Mouse");
+
+    if (config->readBoolEntry("MouseKeys", false))
+      run = true;
+
     delete config;
     if (run)
       kapp->startServiceByDesktopName("kaccess");
   }
 }
+
+
