@@ -36,6 +36,7 @@
 
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
+#include <qspinbox.h>
 #include <artsconfig.h>
 
 class KArtsModule : public KCModule
@@ -44,8 +45,8 @@ class KArtsModule : public KCModule
 
 public:
 
-  KArtsModule(QWidget *parent=0, const char *name=0);
-
+  KArtsModule(QWidget *parent=0, const char *name=0, const QStringList & = QStringList());
+  ~KArtsModule();
   void saveParams( void );
 
   void load();
@@ -53,7 +54,7 @@ public:
   void defaults();
 
   QString quickHelp() const;
-
+  const KAboutData* aboutData() const;
 private slots:
 
   void slotChanged();
@@ -62,29 +63,32 @@ private slots:
 
 private:
 
-  void updateWidgets(void);
+  void updateWidgets ();
   void calculateLatency();
-  void GetSettings( void );
+  void GetSettings ();
 
   QCheckBox *startServer, *startRealtime, *networkTransparent, *x11Comm,
-  			*fullDuplex, *customDevice, *customRate;
+  			*fullDuplex, *customDevice, *customRate, *autoSuspend, *displayMessage;
   QLineEdit *deviceName;
   QLineEdit *samplingRate;
+  QLineEdit *messageApplication;
+  QSpinBox *suspendTime;
   ArtsConfig *artsConfig;
   KConfig *config;
   int fragmentCount;
   int fragmentSize;
   bool configChanged;
 
-  void initAudioIOList();
   class AudioIOElement {
   public:
-    AudioIOElement(QString name, QString fullName)
-			: name(name), fullName(fullName) { }
-    QString name;
-	QString fullName;
+	  AudioIOElement(const QString &name, const QString &fullName)
+		  : name(name), fullName(fullName) {;}
+	  QString name;
+	  QString fullName;
   };
-  QList<AudioIOElement> audioIOList;
+
+  void initAudioIOList();
+  QPtrList<AudioIOElement> audioIOList;
 };
 
 
