@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: backgnd.cpp,v 1.30.2.2 2001/08/26 21:26:18 pfeiffer Exp $
+ * $Id: backgnd.cpp,v 1.49 2002/02/28 11:45:27 danimo Exp $
  *
  * This file is part of the KDE project, module kcmbackground.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -29,7 +29,6 @@
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
 #include <qcheckbox.h>
-#include <qradiobutton.h>
 #include <qpushbutton.h>
 #include <qdragobject.h>
 #include <qhbox.h>
@@ -39,19 +38,20 @@
 #include <qspinbox.h>
 #include <qhbuttongroup.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kpixmap.h>
 #include <dcopclient.h>
 #include <kimageio.h>
+#include <kgenericfactory.h>
 
 #include <bgdefaults.h>
 #include <bgsettings.h>
@@ -64,13 +64,8 @@
 #include <X11/Xlib.h>
 
 /**** DLL Interface ****/
-
-extern "C" {
-    KCModule *create_background(QWidget *parent, const char *name) {
-    KGlobal::locale()->insertCatalogue("kcmbackground");
-    return new KBackground(parent, name);
-    }
-}
+typedef KGenericFactory<KBackground, QWidget> KBackGndFactory;
+K_EXPORT_COMPONENT_FACTORY( kcm_background, KBackGndFactory("kcmbackground"));
 
 
 /**** KBGMonitor ****/
@@ -104,12 +99,17 @@ void KBGMonitor::dragEnterEvent(QDragEnterEvent *e)
 }
 
 /**** KBackground ****/
+KBackground::~KBackground( ){ 
+    delete m_pGlobals;
+    delete m_pConfig;
+}
 
-KBackground::KBackground(QWidget *parent, const char *name)
-    : KCModule(parent, name),
+KBackground::KBackground(QWidget *parent, const char *name, const QStringList &/* */)
+    : KCModule(KBackGndFactory::instance(), parent, name),
     m_Max( KWin::numberOfDesktops() ),
     m_Renderer( m_Max )
 {
+    kdDebug() << "KBackground\n";
     m_Renderer.setAutoDelete(true);
     KImageIO::registerFormats();
 
@@ -182,7 +182,12 @@ KBackground::KBackground(QWidget *parent, const char *name)
     grid->addWidget(lbl, 0, 0, Qt::AlignLeft);
     m_pBackgroundBox = new QComboBox(m_pTab1);
     connect(m_pBackgroundBox, SIGNAL(activated(int)), SLOT(slotBGMode(int)));
-    connect(m_pBackgroundBox->listBox(),SIGNAL(highlighted ( int  )), SLOT(slotBGMode(int)));
+
+// this is dog slow on remote X systems and in addition it breaks the standard combobox
+// behaviour which allows you to highlight items but abort the popup listbox by
+// clicking outside the popup, not changing the current combobox item. (Simon)
+//    connect(m_pBackgroundBox->listBox(),SIGNAL(highlighted ( int  )), SLOT(slotBGMode(int)));
+
     lbl->setBuddy(m_pBackgroundBox);
     grid->addWidget(m_pBackgroundBox, 0, 1);
     QWhatsThis::add( m_pBackgroundBox, i18n("You can select the manner in which"
@@ -236,7 +241,7 @@ KBackground::KBackground(QWidget *parent, const char *name)
     m_WallpaperType->setFrameStyle( QFrame::NoFrame );
     QWhatsThis::add( m_WallpaperType, i18n("If you check this option, you can choose"
 					   " a set of graphic files to be used as wallpaper, one at a time, for an"
-					   " interval ranging from 5 minutes to 4 hours. You can also choose to have"
+					   " interval ranging from 1 minute to 4 hours. You can also choose to have"
 					   " the graphics selected at random or in the order you specified them.") );
     connect( m_WallpaperType, SIGNAL(clicked(int)), SLOT(slotWallpaperType(int)) );
     grid->addMultiCellWidget( m_WallpaperType, 0, 0, 0, 2 );
@@ -337,7 +342,7 @@ KBackground::KBackground(QWidget *parent, const char *name)
 					      " reverse the background and wallpaper layers by checking this option.") );
 
     m_pCBLimit = new QCheckBox(i18n("&Limit Pixmap Cache"), m_pTab3);
-    QWhatsThis::add( m_pCBLimit, i18n( "Checking this box limits the amount of memory that KDE will use to save pixmap (raster graphics). It is advisable to do this, especially if you do not have alot of memory." ) );
+    QWhatsThis::add( m_pCBLimit, i18n( "Checking this box limits the amount of memory that KDE will use to save pixmap (raster graphics). It is advisable to do this, especially if you do not have a lot of memory." ) );
     grid->addMultiCellWidget(m_pCBLimit, 2, 2, 0, 1);
     connect(m_pCBLimit, SIGNAL(toggled(bool)), SLOT(slotLimitCache(bool)));
     hbox = new QHBoxLayout();
@@ -408,18 +413,19 @@ void KBackground::init()
 
     // Wallpapers
     QStringList lst = m_pDirs->findAllResources("wallpaper", "*", false, true);
+    lst.sort();
     for (i=0; i<(int)lst.count(); i++) {
         int n = lst[i].findRev('/');
         QString s = lst[i].mid(n+1);
         m_pWallpaperBox->insertItem(s);
         m_Wallpaper[s] = i;
     }
-
     // Wallpaper tilings: again they must match the ones from bgrender.cc
     m_pArrangementBox->insertItem(i18n("Centered"));
     m_pArrangementBox->insertItem(i18n("Tiled"));
     m_pArrangementBox->insertItem(i18n("Center Tiled"));
     m_pArrangementBox->insertItem(i18n("Centered Maxpect"));
+    m_pArrangementBox->insertItem(i18n("Tiled Maxpect"));
     m_pArrangementBox->insertItem(i18n("Scaled"));
     m_pArrangementBox->insertItem(i18n("Centered Auto Fit"));
 }
@@ -472,7 +478,7 @@ void KBackground::apply()
     // Wallpaper mode
     if ( r->wallpaperMode() == KBackgroundSettings::NoWallpaper )
 	m_WallpaperType->setButton( 0 );
-    else if ( r->multiWallpaperMode() == KBackgroundSettings::NoMulti )
+    else if ( r->multiWallpaperMode() == KBackgroundSettings::NoMulti || r->multiWallpaperMode() == KBackgroundSettings::NoMultiRandom )
 	m_WallpaperType->setButton( 1 );
     else
 	m_WallpaperType->setButton( 2 );
@@ -511,7 +517,7 @@ void KBackground::apply()
             (r->blendMode() < KBackgroundSettings::IntensityBlending) ? false : true);
 
         // Multi mode
-        if (r->multiWallpaperMode() == KBackgroundSettings::NoMulti)
+        if (r->multiWallpaperMode() == KBackgroundSettings::NoMulti || r->multiWallpaperMode() == KBackgroundSettings::NoMultiRandom)
         {
             m_pWallpaperBox->setEnabled(true);
             m_pBrowseBut->setEnabled(true);
@@ -807,7 +813,8 @@ void KBackground::slotImageDropped(QString uri)
     KBackgroundRenderer *r = m_Renderer[desk];
 
     if ( r->wallpaperMode() == KBackgroundSettings::NoWallpaper ||
-	 r->multiWallpaperMode() != KBackgroundSettings::NoMulti ) {
+	 r->multiWallpaperMode() == KBackgroundSettings::InOrder ||
+	 r->multiWallpaperMode() == KBackgroundSettings::Random) {
 	m_WallpaperType->setButton( 1 );
 	slotWallpaperType( 1 );
     }
@@ -883,7 +890,11 @@ void KBackground::slotWallpaperType( int type )
 
     r->stop();
     r->setWallpaperMode(mode);
-    r->setMultiWallpaperMode(multi ? 1 : 0);
+	if ( r -> multiWallpaperMode() == KBackgroundSettings::Random || r -> multiWallpaperMode() == KBackgroundSettings::NoMultiRandom ) {
+        r->setMultiWallpaperMode(multi ? KBackgroundSettings::Random : KBackgroundSettings::NoMultiRandom);
+	} else {
+	    r->setMultiWallpaperMode(multi ? KBackgroundSettings::InOrder : KBackgroundSettings::NoMulti);
+	}
     r->start();
     emit changed(true);
 }
@@ -914,7 +925,7 @@ void KBackground::slotBrowseWallpaper()
 
     KURL url = KFileDialog::getImageOpenURL(
                           KGlobal::dirs()->findDirs("wallpaper", "").first(), 
-					    0, i18n("Select Wallpaper"));
+                          0, i18n("Select Wallpaper"));
 
     if (url.isEmpty())
         return;
