@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgdialogs.cpp,v 1.15 2001/08/01 00:36:54 faure Exp $
+ * $Id: bgdialogs.cpp,v 1.21 2002/03/24 02:45:47 pfeiffer Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -24,12 +24,14 @@
 #include <qmap.h>
 #include <qvbox.h>
 #include <qdragobject.h>
+#include <qpainter.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kdebug.h>
+#include <kimageio.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kbuttonbox.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
@@ -95,7 +97,7 @@ KProgramSelectDialog::KProgramSelectDialog(QWidget *parent, char *name)
     layout->addLayout(vbox, 1, 1);
 }
 
-	
+
 /*
  * Set the current program.
  */
@@ -167,8 +169,8 @@ void KProgramSelectDialog::slotRemove()
     KBackgroundProgram prog(m_Current);
     if (prog.isGlobal()) {
 	KMessageBox::sorry(this,
-		i18n("Unable to remove the program! The program is global\n"
-		"and can only be removed by the System Administrator.\n"),
+		i18n("Unable to remove the program! The program is global "
+		"and can only be removed by the System Administrator."),
 		i18n("Cannot remove program"));
 	return;
     }
@@ -396,7 +398,7 @@ KPatternSelectDialog::KPatternSelectDialog(QWidget *parent, char *name)
     layout->addLayout(vbox, 1, 1);
 }
 
-	
+
 /*
  * Set the current pattern.
  */
@@ -477,8 +479,8 @@ void KPatternSelectDialog::slotRemove()
     KBackgroundPattern pat(m_Current);
     if (pat.isGlobal()) {
 	KMessageBox::sorry(this,
-		i18n("Unable to remove the pattern! The pattern is global\n"
-		"and can only be removed by the System Administrator.\n"),
+		i18n("Unable to remove the pattern! The pattern is global "
+		"and can only be removed by the System Administrator."),
 		i18n("Cannot remove pattern"));
 	return;
     }
@@ -516,7 +518,8 @@ void KPatternSelectDialog::slotModify()
 
 void KPatternSelectDialog::slotItemClicked(QListViewItem *item)
 {
-    m_Current = item->text(1);
+    if ( item )
+        m_Current = item->text(1);
     kdDebug() << "current: " << m_Current << endl;
 }
 
@@ -580,7 +583,7 @@ KPatternEditDialog::KPatternEditDialog(QString pattern, QWidget *parent,
 
 void KPatternEditDialog::slotBrowse()
 {
-    KURL url = KFileDialog::getOpenURL();
+    KURL url = KFileDialog::getImageOpenURL();
     if (url.isEmpty())
 	return;
 
@@ -699,16 +702,17 @@ KMultiWallpaperDialog::KMultiWallpaperDialog(KBackgroundSettings *setts,
     vbox->addWidget(hbox);
     QPushButton *pbut = new QPushButton(i18n("&Add..."), hbox);
     connect(pbut, SIGNAL(clicked()), SLOT(slotAdd()));
-    pbut = new QPushButton(i18n("&Remove"), hbox);
-    connect(pbut, SIGNAL(clicked()), SLOT(slotRemove()));
+    pbutRemove = new QPushButton(i18n("&Remove"), hbox);
+    pbutRemove->setEnabled(m_pListBox->count()>0);
+    connect(pbutRemove, SIGNAL(clicked()), SLOT(slotRemove()));
 }
 
 
 void KMultiWallpaperDialog::slotAdd()
 {
-    KFileDialog fileDialog(KGlobal::dirs()->findDirs("wallpaper", "").first(), 
-			   QString::null, this, 
-			   "", true);
+    KFileDialog fileDialog(KGlobal::dirs()->findDirs("wallpaper", "").first(),
+			   KImageIO::pattern(), this,
+			   0L, true);
 
     fileDialog.setCaption(i18n("Select"));
     KFile::Mode mode = static_cast<KFile::Mode> (KFile::Files |
@@ -722,6 +726,7 @@ void KMultiWallpaperDialog::slotAdd()
 	return;
 
     m_pListBox->insertStringList(files);
+    pbutRemove->setEnabled(true);
 }
 
 
@@ -731,6 +736,7 @@ void KMultiWallpaperDialog::slotRemove()
     if (item == -1)
 	return;
     m_pListBox->removeItem(item);
+    pbutRemove->setEnabled(m_pListBox->count()>0);
 }
 
 
