@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgrender.cc,v 1.13.2.1 2001/08/26 19:01:01 pfeiffer Exp $
+ * $Id: bgrender.cc,v 1.24 2002/01/10 00:43:28 pfeiffer Exp $
  *
  * This file is part of the KDE project, module kdesktop.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -21,16 +21,18 @@
 #include <qfileinfo.h>
 #include <qdir.h>
 #include <qtimer.h>
+#include <qpainter.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kdebug.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kpixmap.h>
 #include <kpixmapeffect.h>
 #include <kimageeffect.h>
 #include <kprocess.h>
 #include <kimageio.h>
+#include <kpixmapio.h>
 #include <ktempfile.h>
 
 #include <bgdefaults.h>
@@ -58,13 +60,16 @@ KBackgroundRenderer::KBackgroundRenderer(int desk, KConfig *config)
 	else
 	    configname.sprintf("kdesktop-screen-%drc", screen_number);
 
-	m_pConfig = new KConfig(configname);
-    } else
+	m_pConfig = new KConfig(configname, false, true);
+        m_bDeleteConfig = true;
+    } else {
 	m_pConfig = config;
+        m_bDeleteConfig = false;
+    }
 
     m_pDirs = KGlobal::dirs();
     m_rSize = m_Size = QApplication::desktop()->size();
-    m_pBackground = 0L; m_pImage = 0L;
+    m_pBackground = 0L; m_pImage = 0L; m_pPixmap = 0L;
     m_pProc = 0L;
     m_Tempfile = 0L;
     m_bPreview = false;
@@ -79,6 +84,8 @@ KBackgroundRenderer::~KBackgroundRenderer()
 {
     cleanup();
     delete m_Tempfile; m_Tempfile = 0;
+    if( m_bDeleteConfig )
+        delete m_pConfig;
 }
 
 
@@ -169,11 +176,21 @@ int KBackgroundRenderer::doBackground(bool quit)
 
     int retval = Done;
     QString file;
+    
+    static unsigned int tileWidth = 0;
+    static unsigned int tileHeight = 0;
+    if( tileWidth == 0 )
+    // some dithering may be needed even with bpb==16, so don't use tileWidth==1
+    // with tileWidth>2, repainting the desktop causes nasty effect (XFree86 4.1.0 )
+        if( XQueryBestTile( qt_xdisplay(), qt_xrootwin(), 2, 2,
+            &tileWidth, &tileHeight ) != Success )
+            tileWidth = tileHeight = 2; // some defaults
 
     switch (bgmode) {
 
     case Flat:
-	m_pBackground->create(10, 10, 32);
+        // this can be tiled correctly without problems
+	m_pBackground->create( tileWidth, tileHeight, 32);
         m_pBackground->fill(colorA().rgb());
         break;
 
@@ -208,6 +225,7 @@ int KBackgroundRenderer::doBackground(bool quit)
 	if (file.isEmpty())
 	    break;
 
+        delete m_pProc;
         m_pProc = new KShellProcess;
         *m_pProc << file;
         connect(m_pProc, SIGNAL(processExited(KProcess *)),
@@ -219,7 +237,9 @@ int KBackgroundRenderer::doBackground(bool quit)
     case HorizontalGradient:
     {
 	QSize size = m_Size;
-	size.setHeight(30);
+        // on <16bpp displays the gradient sucks when tiled because of dithering
+        if( optimize())
+	    size.setHeight( tileHeight );
 	*m_pBackground = KImageEffect::gradient(size, colorA(), colorB(),
 		KImageEffect::HorizontalGradient, 0);
         break;
@@ -227,7 +247,9 @@ int KBackgroundRenderer::doBackground(bool quit)
     case VerticalGradient:
     {
 	QSize size = m_Size;
-	size.setWidth(30);
+        // on <16bpp displays the gradient sucks when tiled because of dithering
+        if( optimize())
+	    size.setWidth( tileWidth );
         *m_pBackground = KImageEffect::gradient(size, colorA(), colorB(),
 		KImageEffect::VerticalGradient, 0);
         break;
@@ -265,7 +287,6 @@ int KBackgroundRenderer::doWallpaper(bool quit)
         return Done;
 
     int wpmode = wallpaperMode();
-    int blmode = blendMode();
 
     bool bTile = m_bTile;
     if (wpmode != NoWallpaper)
@@ -305,7 +326,7 @@ int KBackgroundRenderer::doWallpaper(bool quit)
 wp_out:
 
     if (m_pBackground->isNull()) {
-	m_pBackground->create(10, 10, 32);
+	m_pBackground->create(8, 8, 32);
 	m_pBackground->fill(colorA().rgb());
     }
 
@@ -343,21 +364,112 @@ wp_out:
             }
             // fall through
 	case CentredMaxpect:
-            double sx = (double) w / ww;
-            double sy = (double) h / wh;
-            if (sx > sy) {
-                ww = (int)(sy * ww);
-                wh = h;
-            } else {
-                wh = (int)(sx * wh);
-                ww = w;
+            {
+              double sx = (double) w / ww;
+              double sy = (double) h / wh;
+              if (sx > sy) {
+                  ww = (int)(sy * ww);
+                  wh = h;
+              } else {
+                  wh = (int)(sx * wh);
+                  ww = w;
+              }
+              wp = wp.smoothScale(ww, wh);
+	      d.setRect((w - ww) / 2, (h - wh) / 2, ww, wh);
+	      break;
+            }
+	case TiledMaxpect:
+            {
+              double sx = (double) w / ww;
+              double sy = (double) h / wh;
+              if (sx > sy) {
+                  ww = (int)(sy * ww);
+                  wh = h;
+              } else {
+                  wh = (int)(sx * wh);
+                  ww = w;
+              }
+              wp = wp.smoothScale(ww, wh);
+	      d.setRect(0, 0, w, h);
+	      break;
             }
-            wp = wp.smoothScale(ww, wh);
-	    d.setRect((w - ww) / 2, (h - wh) / 2, ww, wh);
-	    break;
     }
 
+    wallpaperBlend( d, wp, ww, wh );
+    
+    if (retval == Done)
+        m_State |= WallpaperDone;
 
+    return retval;
+}
+
+extern bool qt_use_xrender; // in Qt ( qapplication_x11.cpp )
+
+void KBackgroundRenderer::wallpaperBlend( const QRect& d, QImage& wp, int ww, int wh )
+{
+    if( blendMode() == NoBlending && ( qt_use_xrender || !wp.hasAlphaBuffer())) {
+        fastWallpaperBlend( d, wp, ww, wh );
+    }
+    else {
+        fullWallpaperBlend( d, wp, ww, wh );
+    }
+}
+
+// works only for NoBlending and no alpha in wallpaper
+// but is much faster than QImage fidling
+void KBackgroundRenderer::fastWallpaperBlend( const QRect& d, QImage& wp, int ww, int wh )
+{
+    *m_pImage = QImage();
+    // copy background to m_pPixmap
+    if( wallpaperMode() == NoWallpaper && optimize()) {
+        // if there's no wallpaper, no need to tile the pixmap to the size of desktop, as X does
+        // that automatically and using a smaller pixmap should save some memory
+        m_pPixmap->convertFromImage( *m_pBackground );
+        return;
+    }
+    else if( wallpaperMode() == Tiled && !wp.hasAlphaBuffer() && optimize() && !m_bPreview ) {
+    // tiles will be tiled by X automatically
+        if( useShm()) {
+            KPixmapIO io;
+            *m_pPixmap = io.convertToPixmap( wp );
+        }
+        else
+            m_pPixmap->convertFromImage( wp );
+        return;
+    }
+    else if (m_pBackground->size() == m_Size)
+        m_pPixmap->convertFromImage( *m_pBackground );
+    else {
+        *m_pPixmap = QPixmap( m_Size );
+        QPainter p( m_pPixmap );
+        QPixmap pm;
+        pm.convertFromImage( *m_pBackground );
+        p.drawTiledPixmap( 0, 0, m_Size.width(), m_Size.height(), pm );
+    }
+
+    // paint/alpha-blend wallpaper to destination rectangle of m_pPixmap
+    if (d.isValid()) {
+        QPixmap wp_pixmap;
+        if( useShm() && !wp.hasAlphaBuffer()) {
+            KPixmapIO io;
+            wp_pixmap = io.convertToPixmap( wp );
+        }
+        else
+            wp_pixmap.convertFromImage( wp );
+        for (int y = d.top(); y < d.bottom(); y += wh) {
+	    for (int x = d.left(); x < d.right(); x += ww) {
+		bitBlt( m_pPixmap, x, y, &wp_pixmap, 0, 0, ww, wh );
+	    }
+	}
+    }
+}
+
+
+void KBackgroundRenderer::fullWallpaperBlend( const QRect& d, QImage& wp, int ww, int wh )
+{
+    *m_pPixmap = QPixmap();
+    int w = m_Size.width();	// desktop width/height
+    int h = m_Size.height();
     // copy background to m_pImage
     if (m_pBackground->size() == m_Size) {
 	*m_pImage = m_pBackground->copy();
@@ -381,10 +493,10 @@ wp_out:
 
 
     // blend whole desktop
-    if (wpmode != NoWallpaper) {
+    if ( wallpaperMode() != NoWallpaper) {
       int bal = blendBalance();
 
-      switch( blmode ) {
+      switch( blendMode() ) {
       case HorizontalBlending:
 	KImageEffect::blend( *m_pImage, *m_pBackground,
 			     KImageEffect::HorizontalGradient,
@@ -436,15 +548,8 @@ wp_out:
 	break;
       }
     }
-
-    if (retval == Done)
-        m_State |= WallpaperDone;
-
-    return retval;
 }
 
-
-
 /* Alpha blend an area from <src> with offset <soffs> to rectangle <dr> of <dst>
  * Default offset is QPoint(0, 0).
  */
@@ -496,6 +601,8 @@ void KBackgroundRenderer::start()
 	m_pBackground = new QImage();
     if (m_pImage == 0L)
 	m_pImage = new QImage();
+    if (m_pPixmap == 0L)
+	m_pPixmap = new QPixmap();
 
     m_State = Rendering;
     m_pTimer->start(0, true);
@@ -559,6 +666,7 @@ void KBackgroundRenderer::cleanup()
 {
     delete m_pBackground; m_pBackground = 0L;
     delete m_pImage; m_pImage = 0L;
+    delete m_pPixmap; m_pPixmap = 0L;
     delete m_pProc; m_pProc = 0L;
     m_State = 0;
 }
@@ -581,10 +689,32 @@ void KBackgroundRenderer::setTile(bool tile)
 }
 
 
+QPixmap *KBackgroundRenderer::pixmap()
+{
+    if (m_State & AllDone) {
+        if( m_pPixmap->isNull())
+            m_pPixmap->convertFromImage( *m_pImage );
+        return m_pPixmap;
+    }
+    return 0L;
+}
+
 QImage *KBackgroundRenderer::image()
 {
-    if (m_State & AllDone)
+    if (m_State & AllDone) {
+        if( m_pImage->isNull()) {
+            if( m_pPixmap->size() != m_Size ) {
+                QPainter p( m_pPixmap );
+                QPixmap pm( m_Size ); // the pixmap may be smaller, so tile it
+                pm.convertFromImage( *m_pBackground );
+                p.drawTiledPixmap( 0, 0, m_Size.width(), m_Size.height(), pm );
+                *m_pImage = pm.convertToImage();
+            }
+            else
+                *m_pImage = m_pPixmap->convertToImage();
+        }
         return m_pImage;
+    }
     return 0L;
 }
 
@@ -593,6 +723,7 @@ void KBackgroundRenderer::load(int desk, bool reparseConfig)
 {
     if (m_State & Rendering)
         stop();
+
     cleanup();
     m_bPreview = false;
     m_bTile = false;
