@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgsettings.h,v 1.4 2001/03/15 09:16:04 lunakl Exp $
+ * $Id: bgsettings.h,v 1.8 2002/02/12 10:39:17 faure Exp $
  *
  * This file is part of the KDE project, module kdesktop.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -158,7 +158,7 @@ public:
     QColor colorB() const { return m_ColorB; }
 
     void setProgram(QString program);
-    void setPattern(QString pattern);
+    void setPatternName(QString pattern);
 
     enum BackgroundMode {
 	Flat, Pattern, Program,
@@ -188,7 +188,7 @@ public:
     QString wallpaper() const { return m_Wallpaper; }
 
     enum WallpaperMode {
-	NoWallpaper, Centred, Tiled, CenterTiled, CentredMaxpect,
+	NoWallpaper, Centred, Tiled, CenterTiled, CentredMaxpect, TiledMaxpect,
 	Scaled, CentredAutoFit, lastWallpaperMode
     };
     void setWallpaperMode(int mode);
@@ -201,10 +201,20 @@ public:
     int wallpaperChangeInterval() const { return m_Interval; }
 
     enum MultiMode {
-	NoMulti, InOrder, Random
+	NoMulti, InOrder, Random, NoMultiRandom
     };
     void setMultiWallpaperMode(int mode);
     int multiWallpaperMode() const { return m_MultiMode; }
+    
+    enum MinOptDepth {
+        AlwaysOpt, Opt16bpp, Opt15bpp, NeverOpt };
+        
+    void setMinOptimizationDepth( int mode );
+    int minOptimizationDepth() const { return m_MinOptimizationDepth; }
+    bool optimize() const;
+    
+    void setUseShm( bool use );
+    bool useShm() const { return m_bShm; }
 
     void changeWallpaper(bool init=false);
     void updateWallpaperFiles();
@@ -236,6 +246,8 @@ private:
     int m_BlendMode, defBlendMode;
     int m_BlendBalance, defBlendBalance;
     bool m_ReverseBlending, defReverseBlending;
+    int m_MinOptimizationDepth;
+    bool m_bShm;
 
     int m_MultiMode, defMultiMode;
     int m_Interval, m_LastChange;
