@@ -20,25 +20,29 @@
  */
 #include <unistd.h>
 
-#include <qtabwidget.h>
 #include <qlabel.h>
 #include <qlayout.h>
 
 #include <dcopclient.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kcmodule.h>
+#include <kgenericfactory.h>
 
 #include "main.h"
 #include "main.moc"
 
 #include "tzone.h"
 #include "dtime.h"
+#include <kaboutdata.h>
 
-KclockModule::KclockModule(QWidget *parent, const char *name)
-  : KCModule(parent, name)
+typedef KGenericFactory<KclockModule, QWidget> KlockModuleFactory;
+K_EXPORT_COMPONENT_FACTORY( kcm_clock, KlockModuleFactory("kcmkclock"));
+
+KclockModule::KclockModule(QWidget *parent, const char *name, const QStringList &)
+  : KCModule(KlockModuleFactory::instance(), parent, name)
 {
+//qWarning("new");
   QVBoxLayout *layout = new QVBoxLayout(this);
 
   dtime = new Dtime(this);
@@ -61,8 +65,9 @@ KclockModule::KclockModule(QWidget *parent, const char *name)
 
 void KclockModule::save()
 {
-  tzone->save();
+//  The order here is important
   dtime->save();
+  tzone->save();
 
     // restart kicker to sync up the time
     if (!kapp->dcopClient()->isAttached())
@@ -90,18 +95,22 @@ QString KclockModule::quickHelp() const
     " administrator.");
 }
 
+const KAboutData* KclockModule::aboutData() const
+{
+   KAboutData *about =
+   new KAboutData(I18N_NOOP("kcmclock"), I18N_NOOP("KDE Clock Control Module"),
+                  0, 0, KAboutData::License_GPL,
+                  I18N_NOOP("(c) 1996 - 2001 Luca Montecchiani"));
+ 
+   about->addAuthor("Luca Montecchiani", I18N_NOOP("Original author"), "m.luca@usa.net");
+	about->addAuthor("Paul Campbell", I18N_NOOP("Current Maintainer"), "paul@taniwha.com");
+ 
+   return about;
+}
+
 void KclockModule::moduleChanged(bool state)
 {
   emit changed(state);
 }
 
-extern "C"
-{
-  KCModule *create_clock(QWidget *parent, const char *name)
-  {
-    KGlobal::locale()->insertCatalogue("kcmkclock");
-    return new KclockModule(parent, name);
-  }
-}
-
 
