@@ -21,6 +21,7 @@
 class QSlider;
 class QComboBox;
 class QPushButton;
+class QCheckBox;
 class QResizeEvent;
 class KLineEdit;
 class QPalette;
@@ -28,6 +29,7 @@ class KListBox;
 class KColorButton;
 class KConfig;
 class KStdDirs;
+class KColorSchemeList;
 
 /**
  * The Desktop/Colors tab in kcontrol.
@@ -37,7 +39,7 @@ class KColorScheme: public KCModule
     Q_OBJECT
 
 public:
-    KColorScheme(QWidget *parent, const char *name);
+    KColorScheme(QWidget *parent, const char *name, const QStringList &);
     ~KColorScheme();
 
     virtual void load();
@@ -57,6 +59,7 @@ private slots:
     void slotWidgetColor(int);
     void slotColorForWidget(int, const QColor &);
     void slotPreviewScheme(int);
+    void slotChanged();
 
 private:
     void setColorName( const QString &name, int id );
@@ -75,11 +78,13 @@ private:
     QComboBox *wcCombo;
     QPushButton *addBt, *removeBt;
     KListBox *sList;
-    QStringList sFileList;
+    KColorSchemeList *mSchemeList;
     QString sCurrentScheme;
 
     KColorButton *colorButton;
     WidgetCanvas *cs;
+    
+    QCheckBox *cbExportColors;
 };
 
 
@@ -94,6 +99,9 @@ public:
     SaveScm(QWidget *parent, const char *name, const QString &def);
 	
     KLineEdit* nameLine;
+
+private slots:
+    void slotTextChanged(const QString & _text);
 };
 
 #endif
