@@ -2,24 +2,20 @@
 
 
 #include <qlayout.h>
-#include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
-#include <qlineedit.h>
-#include <qstylesheet.h>
 #include <qtextbrowser.h>
-#include <qcolor.h>
 #include <qcombobox.h>
 
 
-#include <kglobal.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kconfig.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcolorbutton.h>
 #include <kfontdialog.h>
 #include <kurlrequester.h>
+#include <kgenericfactory.h>
 
 #include "cssconfig.h"
 #include "template.h"
@@ -28,14 +24,16 @@
 
 #include "kcmcss.h"
 
+typedef KGenericFactory<CSSConfig, QWidget> CSSFactory;
+K_EXPORT_COMPONENT_FACTORY( kcm_css, CSSFactory("kcmcss") );
 
-CSSConfig::CSSConfig(QWidget *parent, const char *name)
-  : KCModule(parent, name)
+CSSConfig::CSSConfig(QWidget *parent, const char *name, const QStringList &)
+  : KCModule(CSSFactory::instance(), parent, name)
 {
   dialog = new CSSConfigDialog(this);
 
   QStringList fonts;
-  KFontChooser::getFontList(fonts, false);
+  KFontChooser::getFontList(fonts, 0);
   dialog->fontFamily->insertStringList(fonts);
 
   connect(dialog->useDefault, SIGNAL(clicked()),
@@ -391,7 +389,9 @@ void CSSConfig::preview()
   PreviewDialog *dlg = new PreviewDialog(this, 0, true);
   QColorGroup clgrp = dlg->preview->colorGroup();
   clgrp.setColor(QColorGroup::Base, back);
+#if QT_VERSION < 300
   dlg->preview->setPaperColorGroup(clgrp);
+#endif
   dlg->preview->viewport()->setFont(QFont("helvetica", bfs));
 
   dlg->exec();
@@ -400,15 +400,5 @@ void CSSConfig::preview()
 }
 
 
-extern "C" {
-
-  KCModule *create_kcmcss(QWidget *parent, const char *name)
-  {
-    KGlobal::locale()->insertCatalogue("kcmcss");
-    return new CSSConfig(parent, name);
-  }
-
-}
-
 #include "kcmcss.moc"
 
