@@ -35,13 +35,13 @@
 
 #include <dcopclient.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kconfig.h>
 #include <ksimpleconfig.h>
 #include <ktrader.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 
 #include "ikwsopts.h"
@@ -77,8 +77,8 @@ private:
     SearchProvider *m_provider;
 };
 
-InternetKeywordsOptions::InternetKeywordsOptions(QWidget *parent, const char *name)
-                        :KCModule(parent, name)
+InternetKeywordsOptions::InternetKeywordsOptions(KInstance *instance, QWidget *parent, const char *name)
+                        :KCModule(instance, parent, name)
 {
     QVBoxLayout *lay = new QVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
     lay->setAutoAdd( true );
@@ -103,7 +103,7 @@ InternetKeywordsOptions::InternetKeywordsOptions(QWidget *parent, const char *na
     lb_searchFallback->setBuddy(cmb_searchFallback);
     connect(cmb_searchFallback, SIGNAL(activated(const QString &)), this, SLOT(moduleChanged()));
     QString wtstr = i18n("Allows you to select a search provider that will be used in case what you "
-                         "typed is not an <em>Internet Keyword</em>.  Select \"None\" if you do not "
+                         "typed is not an <em>Internet Keyword</em>. Select \"None\" if you do not "
                          "want to do a search in this case, and you will get a directory listing of "
                          "relevant keywords.");
     QWhatsThis::add(lb_searchFallback, wtstr);
@@ -139,7 +139,8 @@ InternetKeywordsOptions::InternetKeywordsOptions(QWidget *parent, const char *na
            this, SLOT(updateSearchProvider()));
     connect(lv_searchProviders, SIGNAL(doubleClicked(QListViewItem *)),
            this, SLOT(changeSearchProvider()));
-
+    connect(lv_searchProviders, SIGNAL(returnPressed(QListViewItem *)),
+           this, SLOT(changeSearchProvider()));
     w_grid->addMultiCellWidget(lv_searchProviders, 1, 2, 0, 0);
 
     QVBox* vbox = new QVBox( gb_search );
