@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: energy.cpp,v 1.11.2.1 2001/08/16 01:17:14 neil Exp $
+ * $Id: energy.cpp,v 1.15 2002/01/23 21:51:22 coolo Exp $
  *
  * This file is part of the KDE project, module kcontrol.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -18,6 +18,10 @@
 
 #include <config.h>
 
+#if !defined(QT_CLEAN_NAMESPACE)
+#define QT_CLEAN_NAMESPACE
+#endif
+
 #include <qglobal.h>
 #include <qcheckbox.h>
 #include <qlayout.h>
@@ -27,7 +31,7 @@
 
 #include <kglobal.h>
 #include <kconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <knuminput.h>
 #include <klocale.h>
@@ -73,8 +77,7 @@ static const int DFLT_OFF   = 60;
 extern "C" {
 
     KCModule *create_energy(QWidget *parent, char *name) {
-    KGlobal::locale()->insertCatalogue("kcmenergy");
-    return new KEnergy(parent, name);
+	return new KEnergy(parent, "kcmenergy");
     }
 
     void init_energy() {
