@@ -18,7 +18,7 @@
 #include "filegroupdetails.h"
 #include "typeslistitem.h"
 #include <qlayout.h>
-#include <qbuttongroup.h>
+#include <qvbuttongroup.h>
 #include <qradiobutton.h>
 #include <qwhatsthis.h>
 #include <kdialog.h>
@@ -31,15 +31,13 @@ FileGroupDetails::FileGroupDetails(QWidget *parent, const char *name )
   QVBoxLayout *secondLayout = new QVBoxLayout(parentWidget, KDialog::marginHint(),
                                               KDialog::spacingHint());
 
-  m_autoEmbed = new QButtonGroup( i18n("Left click action"), parentWidget );
+  m_autoEmbed = new QVButtonGroup( i18n("Left click action"), parentWidget );
+  m_autoEmbed->layout()->setSpacing( KDialog::spacingHint() );
   secondLayout->addWidget( m_autoEmbed, 1 );
   secondLayout->addWidget( new QWidget( parentWidget ), 100 );
-  QVBoxLayout *bgLay = new QVBoxLayout(m_autoEmbed, KDialog::marginHint(),
-                                       KDialog::spacingHint());
-  bgLay->addSpacing(10);
   // The order of those three items is very important. If you change it, fix typeslistitem.cpp !
-  bgLay->addWidget( new QRadioButton( i18n("Show file in embedded viewer"), m_autoEmbed ) );
-  bgLay->addWidget( new QRadioButton( i18n("Show file in separate viewer"), m_autoEmbed ) );
+  new QRadioButton( i18n("Show file in embedded viewer"), m_autoEmbed );
+  new QRadioButton( i18n("Show file in separate viewer"), m_autoEmbed );
   connect(m_autoEmbed, SIGNAL( clicked( int ) ), SLOT( slotAutoEmbedClicked( int ) ));
 
   QWhatsThis::add( m_autoEmbed, i18n("Here you can configure what the Konqueror file manager"
@@ -52,7 +50,7 @@ FileGroupDetails::FileGroupDetails(QWidget *parent, const char *name )
 
 void FileGroupDetails::setTypeItem( TypesListItem * item )
 {
-  ASSERT( item->isMeta() );
+  Q_ASSERT( item->isMeta() );
   m_item = item;
   m_autoEmbed->setButton( item ? item->autoEmbed() : -1 );
 }
