@@ -1,27 +1,13 @@
-#include <qstringlist.h>
-#include <qpushbutton.h>
-#include <qbuttongroup.h>
+#include <qvbuttongroup.h>
 #include <qradiobutton.h>
 #include <qlayout.h>
-#include <qgroupbox.h>
-#include <qlistbox.h>
 #include <qwhatsthis.h>
-#include <qlabel.h>
 
-#include <kbuttonbox.h>
 #include <kdebug.h>
-#include <kdialog.h>
 #include <kicondialog.h>
-#include <kiconloader.h>
 #include <klineedit.h>
 #include <klineeditdlg.h>
 #include <klocale.h>
-#include <kopenwith.h>
-#include <kmimetype.h>
-#include <krun.h>
-#include <kservice.h>
-#include <kservicetype.h>
-#include <kuserprofile.h>
 
 #include "kservicelistwidget.h"
 #include "filetypedetails.h"
@@ -108,21 +94,22 @@ FileTypeDetails::FileTypeDetails( QWidget * parent, const char * name )
   QVBoxLayout *secondLayout = new QVBoxLayout(secondWidget, KDialog::marginHint(),
                                        KDialog::spacingHint());
 
-  m_autoEmbed = new QButtonGroup( i18n("Left click action"), secondWidget );
+  m_autoEmbed = new QVButtonGroup( i18n("Left click action"), secondWidget );
+  m_autoEmbed->layout()->setSpacing( KDialog::spacingHint() );
   secondLayout->addWidget( m_autoEmbed, 1 );
-  QVBoxLayout *bgLay = new QVBoxLayout(m_autoEmbed, KDialog::marginHint(),
-                                       KDialog::spacingHint());
-  bgLay->addSpacing(10);
+
+  m_autoEmbed->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)0, m_autoEmbed->sizePolicy().hasHeightForWidth() ) );
+
   // The order of those three items is very important. If you change it, fix typeslistitem.cpp !
-  bgLay->addWidget( new QRadioButton( i18n("Show file in embedded viewer"), m_autoEmbed ) );
-  bgLay->addWidget( new QRadioButton( i18n("Show file in separate viewer"), m_autoEmbed ) );
-  bgLay->addWidget( new QRadioButton( i18n("Use group settings"), m_autoEmbed ) );
+  new QRadioButton( i18n("Show file in embedded viewer"), m_autoEmbed );
+  new QRadioButton( i18n("Show file in separate viewer"), m_autoEmbed );
+  m_rbGroupSettings = new QRadioButton( i18n("Use settings for '%1' group"), m_autoEmbed );
   connect(m_autoEmbed, SIGNAL( clicked( int ) ), SLOT( slotAutoEmbedClicked( int ) ));
 
   QWhatsThis::add( m_autoEmbed, i18n("Here you can configure what the Konqueror file manager"
     " will do when you click on a file of this type. Konqueror can display the file in"
-    " an embedded viewer or start up a separate application. If set to 'Use group settings',"
-    " Konqueror will behave according to the settings of the group this type belongs to,"
+    " an embedded viewer or start up a separate application. If set to 'Use settings for G group',"
+    " Konqueror will behave according to the settings of the group G this type belongs to,"
     " for instance 'image' if the current file type is image/png.") );
 
   secondLayout->addSpacing(10);
@@ -136,6 +123,11 @@ FileTypeDetails::FileTypeDetails( QWidget * parent, const char * name )
   addTab( secondWidget, i18n("&Embedding") );
 }
 
+void FileTypeDetails::updateRemoveButton()
+{
+    removeExtButton->setEnabled(extensionLB->count()>0);
+}
+
 void FileTypeDetails::updateIcon(QString icon)
 {
   if (!m_item)
@@ -168,7 +160,7 @@ void FileTypeDetails::addExtension()
       QStringList patt = m_item->patterns();
       patt += m.text();
       m_item->setPatterns(patt);
-
+      updateRemoveButton();
       emit changed(true);
     }
   }
@@ -184,7 +176,7 @@ void FileTypeDetails::removeExtension()
   patt.remove(extensionLB->text(extensionLB->currentItem()));
   m_item->setPatterns(patt);
   extensionLB->removeItem(extensionLB->currentItem());
-
+  updateRemoveButton();
   emit changed(true);
 }
 
@@ -204,6 +196,8 @@ void FileTypeDetails::setTypeItem( TypesListItem * tlitem )
   else
     iconButton->resetIcon();
   description->setText(tlitem ? tlitem->comment() : QString::null);
+  if ( tlitem )
+    m_rbGroupSettings->setText( i18n("Use settings for '%1' group").arg( tlitem->majorType() ) );
   extensionLB->clear();
   addExtButton->setEnabled(true);
   removeExtButton->setEnabled(false);
