@@ -3,17 +3,23 @@
 
 #include <qstring.h>
 #include <qstringlist.h>
-#include <qcombobox.h>
 #include <kdialog.h>
-#include <klineedit.h>
 
+class KLineEdit;
+class QComboBox;
+
+/**
+ * A dialog for creating a new file type, with
+ * a combobox for choosing the group and a line-edit
+ * for entering the name of the file type
+ */
 class NewTypeDialog : public KDialog
 {
 public:
   NewTypeDialog(QStringList groups, QWidget *parent = 0, 
 		const char *name = 0);
-  QString group() const { return groupCombo->currentText(); }
-  QString text() const { return typeEd->text(); }
+  QString group() const;
+  QString text() const;
 private:
   KLineEdit *typeEd;
   QComboBox *groupCombo;
