@@ -19,7 +19,7 @@ class FontUseItem : public QObject
   Q_OBJECT
 
 public:
-    FontUseItem(QWidget * parent, QLabel * prvw, QString n, QString grp, QString key, QString rc, QFont default_fnt, QString default_charset, bool fixed = false);
+    FontUseItem(QWidget * parent, QLabel * prvw, QString n, QString grp, QString key, QString rc, QFont default_fnt, bool fixed = false);
 
     QString fontString(QFont rFont);
 
@@ -27,6 +27,7 @@ public:
     void writeFont();
     void setDefault();
     void setFont(const QFont &fnt ) { _font = fnt; }
+    void applyFontDiff(const QFont &fnt, int fontDiffFlags);
 
     QFont font() { return _font; }
     const QString& rcFile() { return _rcfile; }
@@ -50,9 +51,7 @@ private:
     QString _rcgroup;
     QString _rckey;
     QFont _font;
-    QString _charset;
     QFont _default;
-    QString _defaultCharset;
     bool fixed;
 };
 
@@ -65,7 +64,7 @@ class KFonts : public KCModule
     Q_OBJECT
 
 public:
-    KFonts(QWidget *parent, const char *name);
+    KFonts(QWidget *parent, const char *name, const QStringList &);
     ~KFonts();
 
     virtual void load();
@@ -80,14 +79,14 @@ signals:
 
 protected slots:
     void fontChanged();
+    void slotApplyFontDiff(); 
     void slotUseAntiAliasing();
 
 private:
     bool _changed;
     bool useAA, useAA_original;
-    bool defaultCharset;
     QCheckBox *cbAA;
-    QList <FontUseItem> fontUseList;
+    QPtrList <FontUseItem> fontUseList;
 };
 
 #endif
