@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: icons.cpp,v 1.8 2001/01/11 23:44:16 waba Exp $
+ * $Id: icons.cpp,v 1.21 2002/03/09 13:28:05 mlaurent Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -12,35 +12,21 @@
  */
 
 #include <stdlib.h>
-#include <qwidget.h>
 #include <qlayout.h>
-#include <qstring.h>
-#include <qstringlist.h>
 #include <qlabel.h>
-#include <qlistbox.h>
 #include <qlistview.h>                                                                     
 #include <qgroupbox.h>
 #include <qcombobox.h>
-#include <qpushbutton.h>
 #include <qslider.h>
 #include <qcheckbox.h>
-#include <qlabel.h>
-#include <qtabwidget.h>
-#include <qiconview.h>
 
-#include <kapp.h>
 #include <kdebug.h>
 #include <kconfig.h>
-#include <kwin.h>
-#include <kglobal.h>
-#include <kstddirs.h>
 #include <kiconeffect.h>
-#include <kicontheme.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kipc.h>
-#include <kcolordlg.h>
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 #include <kseparator.h>
 
 #include <icons.h>
@@ -68,8 +54,7 @@ KIconConfig::KIconConfig(QWidget *parent, const char *name)
     connect(mpUsageList, SIGNAL(highlighted(int)), SLOT(slotUsage(int)));
     g_vlay->addWidget(mpUsageList);
 
-    KSeparator *sep = new KSeparator( this );
-    sep->setOrientation( QFrame::HLine );
+    KSeparator *sep = new KSeparator( KSeparator::HLine, this );
     top->addWidget(sep, 1, 1);
     // Preview at (2,0) - (2, 1) 
     QGridLayout *g_lay = new QGridLayout(4, 3, KDialog::marginHint(), 0);
@@ -96,19 +81,19 @@ KIconConfig::KIconConfig(QWidget *parent, const char *name)
     // Size
     QLabel *lbl = new QLabel(i18n("Size:"), m_pTab1);
     lbl->setFixedSize(lbl->sizeHint());
-    grid->addWidget(lbl, 0, 0, Qt::AlignLeft);                                                  
+    grid->addWidget(lbl, 0, 0, Qt::AlignLeft);
     mpSizeBox = new QComboBox(m_pTab1);
     connect(mpSizeBox, SIGNAL(activated(int)), SLOT(slotSize(int)));
     lbl->setBuddy(mpSizeBox);
-    grid->addWidget(mpSizeBox, 0, 1, Qt::AlignLeft);                                                    
+    grid->addWidget(mpSizeBox, 0, 1, Qt::AlignLeft);
 
-    mpDPCheck = new QCheckBox(i18n("Double sized pixels"), m_pTab1);
+    mpDPCheck = new QCheckBox(i18n("Double-sized pixels"), m_pTab1);
     connect(mpDPCheck, SIGNAL(toggled(bool)), SLOT(slotDPCheck(bool)));
-    grid->addWidget(mpDPCheck, 1, 0, Qt::AlignLeft);
+    grid->addMultiCellWidget(mpDPCheck, 1, 1, 0, 1, Qt::AlignLeft);
 
-    mpAlphaBCheck = new QCheckBox(i18n("Blend alpha channel"), m_pTab1);
-    connect(mpAlphaBCheck, SIGNAL(toggled(bool)), SLOT(slotAlphaBCheck(bool)));
-    grid->addWidget(mpAlphaBCheck, 2, 0, Qt::AlignLeft);
+    mpAnimatedCheck = new QCheckBox(i18n("Animate icons"), m_pTab1);
+    connect(mpAnimatedCheck, SIGNAL(toggled(bool)), SLOT(slotAnimatedCheck(bool)));
+    grid->addMultiCellWidget(mpAnimatedCheck, 2, 2, 0, 1, Qt::AlignLeft);
 
     top->activate();
 
@@ -118,6 +103,11 @@ KIconConfig::KIconConfig(QWidget *parent, const char *name)
     preview();
 }
 
+KIconConfig::~KIconConfig()
+{
+  delete mpEffect;
+}
+
 QPushButton *KIconConfig::addPreviewIcon(int i, const QString &str, QWidget *parent, QGridLayout *lay)
 {
     QLabel *lab = new QLabel(str, parent);
@@ -142,7 +132,7 @@ void KIconConfig::init()
 	mbChanged[i] = false;
 
     // Fill list/checkboxen
-    mpUsageList->insertItem(i18n("Desktop / FileManager"));
+    mpUsageList->insertItem(i18n("Desktop / File Manager"));
     mpUsageList->insertItem(i18n("Toolbar"));
     mpUsageList->insertItem(i18n("Main Toolbar"));
     mpUsageList->insertItem(i18n("Small Icons"));
@@ -175,24 +165,47 @@ void KIconConfig::initDefaults()
     mDefaultEffect[1].color = QColor(169,156,255);
     mDefaultEffect[2].color = QColor(34,202,0);
 
-    int i;
+    KIcon::Group i;
     QStringList::ConstIterator it;
-    for(it=mGroups.begin(), i=0; it!=mGroups.end(); it++, i++)
+    for(it=mGroups.begin(), i=KIcon::FirstGroup; it!=mGroups.end(); it++, i++)
     {
 	mbDP[i] = false;
-	mbAlphaB[i] = false;
 	mbChanged[i] = true;
+	mbAnimated[i] = false;
 	mSizes[i] = mpTheme->defaultSize(i);
 
 	mEffects[i][0] = mDefaultEffect[0];
 	mEffects[i][1] = mDefaultEffect[1];
 	mEffects[i][2] = mDefaultEffect[2];
     }
+    // Animate desktop icons by default
+    int group = mGroups.findIndex( "Desktop" );
+    if ( group != -1 )
+        mbAnimated[group] = true;
+
+    // This is the new default in KDE 2.2, in sync with the kiconeffect of kdelibs Nolden 2001/06/11
+    int activeState = mStates.findIndex( "Active" );
+    if ( activeState != -1 )
+    {
+        int group = mGroups.findIndex( "Desktop" );
+        if ( group != -1 )
+        {
+            mEffects[ group ][ activeState ].type = KIconEffect::ToGamma;
+            mEffects[ group ][ activeState ].value = 0.7;
+        }
+
+        group = mGroups.findIndex( "Panel" );
+        if ( group != -1 )
+        {
+            mEffects[ group ][ activeState ].type = KIconEffect::ToGamma;
+            mEffects[ group ][ activeState ].value = 0.7;
+        }
+    }
 }
 
 void KIconConfig::read()
 {
-    for (int i=0; i<KIcon::LastGroup; i++)
+    for (KIcon::Group i=KIcon::FirstGroup; i<KIcon::LastGroup; i++)
 	mAvSizes[i] = mpTheme->querySizes(i);
 
     mTheme = mpTheme->current();
@@ -209,7 +222,7 @@ void KIconConfig::read()
 	mpConfig->setGroup(*it + "Icons");
 	mSizes[i] = mpConfig->readNumEntry("Size", mSizes[i]);
 	mbDP[i] = mpConfig->readBoolEntry("DoublePixels", mbDP[i]);
-	mbAlphaB[i] = mpConfig->readBoolEntry("AlphaBlending", mbAlphaB[i]);
+	mbAnimated[i] = mpConfig->readBoolEntry("Animated", mbAnimated[i]);
 
 	for (it2=mStates.begin(), j=0; it2!=mStates.end(); it2++, j++)
 	{
@@ -237,7 +250,7 @@ void KIconConfig::apply()
 {
     mpUsageList->setCurrentItem(mUsage);
 
-    int delta = 1000, dw, index = -1, size, i;
+    int delta = 1000, dw, index = -1, size = 0, i;
     QValueList<int>::Iterator it;
     mpSizeBox->clear();
     for (it=mAvSizes[mUsage].begin(), i=0; it!=mAvSizes[mUsage].end(); it++, i++)
@@ -258,7 +271,7 @@ void KIconConfig::apply()
 	mSizes[mUsage] = size; // best or exact match
     }
     mpDPCheck->setChecked(mbDP[mUsage]);
-    mpAlphaBCheck->setChecked(mbAlphaB[mUsage]);
+    mpAnimatedCheck->setChecked(mbAnimated[mUsage]);
 }
 
 void KIconConfig::preview(int i)
@@ -295,6 +308,7 @@ void KIconConfig::load()
     emit changed(false);
     for (int i=0; i<KIcon::LastGroup; i++)
 	mbChanged[i] = false;
+    preview();
 }
 
 
@@ -307,7 +321,7 @@ void KIconConfig::save()
 	mpConfig->setGroup(*it + "Icons");
 	mpConfig->writeEntry("Size", mSizes[i], true, true);
 	mpConfig->writeEntry("DoublePixels", mbDP[i], true, true);
-	mpConfig->writeEntry("AlphaBlending", mbAlphaB[i], true, true);
+	mpConfig->writeEntry("Animated", mbAnimated[i], true, true);
 	for (it2=mStates.begin(), j=0; it2!=mStates.end(); it2++, j++)
 	{
 	    QString tmp;
@@ -335,6 +349,7 @@ void KIconConfig::save()
             mpConfig->writeEntry(*it2 + "SemiTransparent", mEffects[i][j].transparant, true, true);
 	}
     }
+
     mpConfig->sync();
 
     emit changed(false);
@@ -365,14 +380,15 @@ void KIconConfig::slotUsage(int index)
     {
         mpSizeBox->setEnabled(false);
         mpDPCheck->setEnabled(false);
-	mpAlphaBCheck->setEnabled(true);
+	mpAnimatedCheck->setEnabled(false);
     } 
     else
     {
         mpSizeBox->setEnabled(true);
         mpDPCheck->setEnabled(true);
-	mpAlphaBCheck->setEnabled( (mUsage==KIcon::Desktop)? true : false);
+	mpAnimatedCheck->setEnabled( mUsage==KIcon::Desktop );
     }
+
     apply();
     preview();
 }
@@ -422,13 +438,9 @@ void KIconConfig::slotDPCheck(bool check)
     mbChanged[mUsage] = true;
 }
 
-void KIconConfig::slotAlphaBCheck(bool check)
+void KIconConfig::slotAnimatedCheck(bool check)
 {
-    mbAlphaB[mUsage] = check;
- // XXX Should warning the user that this change will only
- // take effect when restarting KDE.
-
- //    preview();
+    mbAnimated[mUsage] = check;
     emit changed(true);
     mbChanged[mUsage] = true;
 }
@@ -508,6 +520,11 @@ KIconEffectSetupDialog::KIconEffectSetupDialog(const Effect &effect,
     preview();
 }
 
+KIconEffectSetupDialog::~KIconEffectSetupDialog()
+{
+  delete mpEffect;
+}
+
 void KIconEffectSetupDialog::init()
 {
     mpEffectBox->setCurrentItem(mEffect.type);
