@@ -19,28 +19,14 @@
  */
 
 #include <qlayout.h>
-#include <qvbox.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
-#include <qcheckbox.h>
 #include <qlabel.h>
-#include <qdict.h>
-#include <qstring.h>
-#include <qcstring.h>
-#include <qlistview.h>
-#include <qfile.h>
-#include <qpushbutton.h>
-#include <qgroupbox.h>
-#include <ksimpleconfig.h>
-#include <kglobal.h>
-#include <kstddirs.h>
+#include <klistview.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kurlrequester.h>
-#include <kicontheme.h>
 #include <kipc.h>
 #undef Unsorted
 #include <kfiledialog.h>
-#include <kapp.h>
 #include <kdebug.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -48,6 +34,7 @@
 #include <kio/job.h>
 
 #include "iconthemes.h"
+#include <kiconloader.h>
 
 IconThemesConfig::IconThemesConfig(QWidget *parent, const char *name)
   : KCModule(parent, name)
@@ -74,14 +61,13 @@ IconThemesConfig::IconThemesConfig(QWidget *parent, const char *name)
   lh2->addStretch(10);
 
 
-  m_iconThemes=new QListView(this,"IconThemeList");
+  m_iconThemes=new KListView(this,"IconThemeList");
   m_iconThemes->addColumn(i18n("Name"));
   m_iconThemes->addColumn(i18n("Description"));
   m_iconThemes->setAllColumnsShowFocus( true );
   connect(m_iconThemes,SIGNAL(selectionChanged(QListViewItem *)),
 		SLOT(themeSelected(QListViewItem *)));
 
-
   m_themeRequester=new KURLRequester(this,"themeRequester");
 //  m_themeRequester->fileDialog()->setMode( KFile::File | KFile::ExistingOnly );
 
@@ -106,6 +92,7 @@ IconThemesConfig::IconThemesConfig(QWidget *parent, const char *name)
   m_defaultTheme=iconThemeItem(KIconTheme::current());
 //  m_iconThemes->setCurrentItem(m_defaultTheme);
   m_iconThemes->setSelected(m_defaultTheme, true);
+  updateRemoveButton();
 
   load();
 
@@ -155,11 +142,6 @@ void IconThemesConfig::loadThemes()
 
 }
 
-void IconThemesConfig::configChanged()
-{
-  emit changed(true);
-}
-
 void IconThemesConfig::installNewTheme()
 {
   if (m_themeRequester->url().isEmpty()) return;
@@ -186,20 +168,25 @@ void IconThemesConfig::installNewTheme()
   QListViewItem *item=iconThemeItem(KIconTheme::current());
 //  m_iconThemes->setCurrentItem(item);
   m_iconThemes->setSelected(item, true);
+  updateRemoveButton();
 }
 
 void IconThemesConfig::removeSelectedTheme()
 {
+  QListViewItem *selected = m_iconThemes->selectedItem();
+  if (!selected)
+     return;
+
   QString question=i18n("Are you sure you want to remove the %1 icon theme ?"
         "\nThis will delete the files installed by this theme").
-	arg(m_iconThemes->currentItem()->text(0));
+	arg(selected->text(0));
 
-  bool deletingCurrentTheme=(m_iconThemes->currentItem()==iconThemeItem(KIconTheme::current()));
+  bool deletingCurrentTheme=(selected==iconThemeItem(KIconTheme::current()));
 
   int r=KMessageBox::questionYesNo(this,question,i18n("Confirmation"));
   if (r!=KMessageBox::Yes) return;
 
-  KIconTheme icontheme(m_themeNames[m_iconThemes->currentItem()->text(0)]);
+  KIconTheme icontheme(m_themeNames[selected->text(0)]);
 
   unlink(QFile::encodeName(icontheme.dir()+"/index.desktop").data());
 
@@ -211,28 +198,40 @@ void IconThemesConfig::removeSelectedTheme()
 
   loadThemes();
 
-
   QListViewItem *item=0L;
   //Fallback to hicolor if we've deleted the current theme
-  if (deletingCurrentTheme) item=iconThemeItem("hicolor");
-  else item=iconThemeItem(KIconTheme::current());
-
+  if (!deletingCurrentTheme)
+     item=iconThemeItem(KIconTheme::current());
+  if (!item)
+     item=iconThemeItem("hicolor");
 //  m_iconThemes->setCurrentItem(item);
+
   m_iconThemes->setSelected(item, true);
+  updateRemoveButton();
 
   if (deletingCurrentTheme) // Change the configuration
     save();
 }
 
+void IconThemesConfig::updateRemoveButton()
+{
+  QListViewItem *selected = m_iconThemes->selectedItem();
+  bool enabled = false;
+  if (selected)
+  {
+    QString dirName(m_themeNames[selected->text(0)]);
+    enabled = ( dirName != "hicolor" );
+  }
+  m_removeButton->setEnabled(enabled);
+}
+
 void IconThemesConfig::themeSelected(QListViewItem *item)
 {
   QString dirName(m_themeNames[item->text(0)]);
   KIconTheme icontheme(dirName);
   if (!icontheme.isValid()) kdDebug() << "notvalid\n";
 
-  if ( dirName=="hicolor" || dirName=="locolor" )
-    m_removeButton->setEnabled(false);
-  else m_removeButton->setEnabled(true);
+  updateRemoveButton();
 
   KIcon icon=icontheme.iconPath("exec.png",
 	icontheme.defaultSize(KIcon::Desktop),KIcon::MatchBest);
@@ -247,28 +246,34 @@ void IconThemesConfig::themeSelected(QListViewItem *item)
   kdDebug() << icon.path<< "\n";
   m_previewDocument->setPixmap(QPixmap(icon.path));
   emit changed(true);
+  m_bChanged = true;
 }
 
 void IconThemesConfig::load()
 {
   emit changed(false);
+  m_bChanged = false;
 }
 
 void IconThemesConfig::save()
 {
+  if (!m_bChanged)
+     return;
+  QListViewItem *selected = m_iconThemes->selectedItem();
+  if (!selected)
+     return;
 
   KSimpleConfig *config = new KSimpleConfig("kdeglobals", false);
 
   config->setGroup("Icons");
 
-  config->writeEntry("Theme", m_themeNames[
-	m_iconThemes->selectedItem()->text(0)]);
+  config->writeEntry("Theme", m_themeNames[selected->text(0)]);
 
-  KIconTheme icontheme(m_themeNames[m_iconThemes->selectedItem()->text(0)]);
+  KIconTheme icontheme(m_themeNames[selected->text(0)]);
 
-  const char *groups[] = { "Desktop", "Toolbar", "MainToolbar", "Small", 0L };
+  const char * const groups[] = { "Desktop", "Toolbar", "MainToolbar", "Small", 0L };
 
-  for (int i=0; i<KIcon::LastGroup; i++)
+  for (KIcon::Group i=KIcon::FirstGroup; i<KIcon::LastGroup; i++)
   {
     if (groups[i] == 0L)
       break;
@@ -283,7 +288,7 @@ void IconThemesConfig::save()
   {
     KIPC::sendMessageAll(KIPC::IconChanged, i);
   }
-
+  m_bChanged = false;
 }
 
 void IconThemesConfig::defaults()
@@ -292,8 +297,10 @@ void IconThemesConfig::defaults()
 
 //  m_iconThemes->setCurrentItem(m_defaultTheme);
   m_iconThemes->setSelected(m_defaultTheme,true);
+  updateRemoveButton();
 
   emit changed(true);
+  m_bChanged = true;
 }
 
 #include "iconthemes.moc"
