@@ -1,10 +1,10 @@
 /*
-	$Id: info.cpp,v 1.45 2001/02/08 19:31:44 waba Exp $
+	$Id: info.cpp,v 1.54 2002/02/16 09:00:45 deller Exp $
 
 	Main Widget for showing system-dependent information.
 	(But all functions in THIS FILE should be system independent !)
 
-	(C) 1998-1999 by Helge Deller (deller@gmx.de)
+	(C) 1998-2002 by Helge Deller <deller@gmx.de>
 
 	** main.cpp includes this file ! **
 
@@ -33,10 +33,7 @@
 #include <qwhatsthis.h>
 #include <qlayout.h>
 
-#include <kapp.h>
-#include <kglobal.h>
 #include <kglobalsettings.h>
-#include <kcharsets.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include "info.h"		/* include the forward declares... */
@@ -191,7 +188,7 @@ static QListViewItem* XServer_fill_screen_info( QListViewItem *lBox, QListViewIt
     last = new QListViewItem(item, last, i18n("Default Number of Colormap Cells"),
 		Value((int)DisplayCells(dpy, scr)));
     last = new QListViewItem(item, last, i18n("Preallocated Pixels"),
-		i18n("black %1, White %2")
+		i18n("Black %1, White %2")
 		.arg(KGlobal::locale()->formatNumber(BlackPixel(dpy,scr), 0))
 		.arg(KGlobal::locale()->formatNumber(WhitePixel(dpy,scr), 0)));
 
@@ -276,6 +273,16 @@ bool GetInfo_XServer_Generic( QListView *lBox )
 	if (i==0) item->setOpen(true);
     }
 
+    last = new QListViewItem( next, last, i18n("Supported Extensions") );
+    item = last;
+
+    int extCount;
+    char **extensions = XListExtensions( dpy, &extCount );
+    for ( i = 0; i < extCount; i++ ) {
+       item = new QListViewItem( last, item, QString( extensions[i] ) );
+    }
+    XFreeExtensionList( extensions );
+
     pmf = XListPixmapFormats(dpy, &n);
     last = item = new QListViewItem(next, last, i18n("Supported Pixmap Formats"));
     if (pmf) {
@@ -308,7 +315,6 @@ bool GetInfo_XServer_Generic( QListView *lBox )
     last = new QListViewItem(next, last, i18n("Image Byte Order"),
 		Order(ImageByteOrder(dpy)));
 
-
     XCloseDisplay (dpy);
     return true;
 }
@@ -321,10 +327,6 @@ bool GetInfo_XServer_Generic( QListView *lBox )
 ***************************************************************************
 */
 
-#include <qlayout.h>
-#include <qcollection.h>
-#include <qwidget.h>
-#include <qwidgetlist.h>
 
 
 void KInfoListWidget::load()
@@ -362,12 +364,18 @@ void KInfoListWidget::load()
         NoInfoText->setText(ErrorString);
         widgetStack->raiseWidget(NoInfoText);
     }
+
+    emit changed(false);
 }
 
 
 QString KInfoListWidget::quickHelp() const
 {
-  return i18n( "<h1>System Information</h1>All the information modules return information about a certain aspect of your computer hardware or your operating system. Not all modules are available on all hardware architectures and/or operating systems." );
+  return i18n("<h1>System Information</h1>"
+	" All the information modules return information about a certain"
+	" aspect of your computer hardware or your operating system."
+	" Not all modules are available on all hardware architectures"
+	" and/or operating systems." );
 }
 
 
@@ -376,7 +384,7 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, const c
     : KCModule(parent, name),
       title(_title)
 {
-    setButtons(Help);
+    setButtons(KCModule::Help);
     getlistbox 	= _getlistbox;
     GetInfo_ErrorString = 0;
     QHBoxLayout *layout = new QHBoxLayout(this, 10);
@@ -390,11 +398,55 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, const c
     QWhatsThis::add( lBox, i18n( "This list displays system information on the selected category." ) );
     NoInfoText  = new QLabel(widgetStack);
     widgetStack->addWidget(NoInfoText, 1);
-    NoInfoText->setAlignment(AlignCenter); //  | WordBreak);
+    NoInfoText->setAlignment(AlignCenter | WordBreak);
     widgetStack->raiseWidget(NoInfoText);
     load();
 }
 
+
+const KAboutData* KInfoListWidget::aboutData() const
+{
+
+    KAboutData *about =
+    new KAboutData(I18N_NOOP("kcminfo"),
+		I18N_NOOP("KDE Panel System Information Control Module"),
+		0, 0, KAboutData::License_GPL,
+		I18N_NOOP("(c) 1998 - 2002 Helge Deller"));
+
+    about->addAuthor("Helge Deller", 0, "deller@gmx.de");
+
+    return about;
+}
+
+
+/* Helper-function to read output from an external program */
+static int GetInfo_ReadfromPipe( QListView *lBox, const char *FileName, bool WithEmptyLines = true )
+{
+    FILE *pipe;
+    QTextStream *t;
+    QListViewItem* olditem = 0;
+    QString s;
+  
+    if ((pipe = popen(FileName, "r")) == NULL) {
+	pclose(pipe);
+	return 0;
+    }
+
+    t = new QTextStream(pipe, IO_ReadOnly);
+
+    while (!t->eof()) {
+	s = t->readLine();
+	if (!WithEmptyLines && s.length()==0)
+		continue;
+       	olditem = new QListViewItem(lBox, olditem, s);
+    }
+  
+    delete t; 
+    pclose(pipe);
+  
+    return (lBox->childCount());
+}
+
 /*
 ***************************************************************************
 **  Include system-specific code					 **
@@ -403,7 +455,7 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, const c
 
 #ifdef __linux__
 #include "info_linux.cpp"
-#elif sgi || sun
+#elif sgi
 #include "info_sgi.cpp"
 #elif __FreeBSD__
 #include "info_fbsd.cpp"
@@ -413,6 +465,8 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, const c
 #include "info_netbsd.cpp"
 #elif __OpenBSD__
 #include "info_openbsd.cpp"
+#elif defined(__svr4__) && defined(sun)
+#include "info_solaris.cpp"
 #elif __svr4__
 #include "info_svr4.cpp"
 #elif _AIX
