@@ -3,7 +3,7 @@
  *
  *  prints memory-information and shows a graphical display.
  *
- *  Copyright (c) 1999-2001 Helge Deller <deller@gmx.de>
+ *  Copyright (c) 1999-2002 Helge Deller <deller@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,14 +20,14 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *
- *  $Id: memory.cpp,v 1.35.2.1 2001/08/21 13:32:34 mueller Exp $ 
+ *  $Id: memory.cpp,v 1.43 2002/03/05 21:35:39 deller Exp $ 
  */
 
 #include <sys/param.h>		/* for BSD */
 
-#include <qtabbar.h>
 #include <qlayout.h>
 #include <qpainter.h>
+#include <qpixmap.h>
 
 #include <klocale.h>
 #include <kglobal.h>
@@ -241,6 +241,28 @@ KMemoryWidget::~KMemoryWidget()
 }
 
 
+QString KMemoryWidget::quickHelp() const
+{
+  return i18n("<h1>Memory Information</h1>"
+	" This display shows you the current memory usage of your system."
+	" The values are updated on a regular basis and give you an"
+	" overview of the physical and virtual used memory." );
+}
+
+
+const KAboutData* KMemoryWidget::aboutData() const
+{
+
+    KAboutData *about =
+    new KAboutData(I18N_NOOP("kcminfo"),
+		I18N_NOOP("KDE Panel Memory Information Control Module"),
+		0, 0, KAboutData::License_GPL,
+		I18N_NOOP("(c) 1998 - 2002 Helge Deller"));
+
+    about->addAuthor("Helge Deller", 0, "deller@gmx.de");
+    return about;
+}
+
 /* Graphical Memory Display */
 bool KMemoryWidget::Display_Graph(int widgetindex,
 				int count,
@@ -252,7 +274,11 @@ bool KMemoryWidget::Display_Graph(int widgetindex,
     QWidget *graph = Graph[widgetindex];
     int width = graph->width();
     int height = graph->height();
-    QPainter paint(graph);
+    QPixmap pm(width, height);
+    QPainter paint;
+
+    paint.begin(&pm, this);
+
     QPen pen(QColor(0, 0, 0));
 
     if (! ZERO_IF_NO_INFO(total)) {
@@ -261,12 +287,14 @@ bool KMemoryWidget::Display_Graph(int widgetindex,
 	paint.setPen(pen);
 	paint.drawRect(graph->rect());
 	GraphLabel[widgetindex]->setText(Not_Available_Text);
+	paint.end();
+	bitBlt(graph, 0, 0, &pm);
 	return false;
     }
 
     int startline = height-2;
     int	percent, localheight;
-    t_memsize last_used;
+    t_memsize last_used = 0;
     
     while (count--) {
 	last_used = *used;
@@ -286,10 +314,11 @@ bool KMemoryWidget::Display_Graph(int widgetindex,
 	if (localheight>0) {
 		paint.fillRect(1, startline, width-2, -localheight, *color);
 
-    		if (localheight >= SPACING)
-			paint.drawText(0, startline, width, -localheight,
+    		if (localheight >= SPACING) {
+			paint.drawText(0, startline-localheight, width, localheight,
 				AlignCenter | WordBreak, 
 				QString("%1 %2%").arg(*text).arg(percent));
+		}
     	}
 	
 	startline -= localheight;
@@ -303,6 +332,9 @@ bool KMemoryWidget::Display_Graph(int widgetindex,
     paint.setPen(pen);
     paint.drawRect(graph->rect());
     
+    paint.end();
+    bitBlt(graph, 0, 0, &pm);
+
     GraphLabel[widgetindex]->setText(i18n("%1 free").arg(format_MB(last_used)));
  
     return true;
