@@ -1,4 +1,4 @@
-// $Id: memory_fbsd.cpp,v 1.11 2000/07/14 00:47:53 bhughes Exp $
+// $Id: memory_fbsd.cpp,v 1.12 2001/05/27 16:19:53 deller Exp $
 
 #include <sys/types.h>
 #include <sys/sysctl.h>
@@ -32,6 +32,9 @@ void KMemoryWidget::update()
     mib[0] = CTL_VM;
     mib[1] = VM_METER;
     
+#warning "FIXME: Memory_Info[CACHED_MEM]"
+    Memory_Info[CACHED_MEM] = NO_MEMORY_INFO;
+    
     len = sizeof(vmem);
     
     if (sysctl(mib, 2, &vmem, &len, NULL, 0) == 0) 
