@@ -32,7 +32,7 @@
 #include "global.h"
 #include "modules.h"
 #include "proxywidget.h"
-#include <qobjcoll.h>
+#include <qobjectlist.h>
 #include <qaccel.h>
 
 DockContainer::DockContainer(QWidget *parent)
@@ -54,45 +54,53 @@ DockContainer::~DockContainer()
 
 void DockContainer::setBaseWidget(QWidget *widget)
 {
+  delete _basew;
+  _basew = 0;
   if (!widget) return;
 
   _basew = widget;
-  _basew->reparent(this, 0 , QPoint(0,0), true);
+  _basew->reparent(this, 0, QPoint(0,0), true);
 
-  // "inherit" the minimum size
-  setMinimumSize( _basew->minimumSize() );
-  resize(_basew->sizeHint());
+  _basew->resize( size() );
   emit newModule(widget->caption(), "", "");
+  updateGeometry();
 }
 
-void DockContainer::dockModule(ConfigModule *module)
+QSize DockContainer::minimumSizeHint() const
 {
-  if (module == _module) return;
+    if (_module)
+	return _module->module()->minimumSizeHint();
+    if ( _basew )
+	return _basew->minimumSizeHint().expandedTo( _basew->minimumSize() );
+    return QWidget::minimumSizeHint();
+}
+
+bool DockContainer::dockModule(ConfigModule *module)
+{
+  if (module == _module) return true;
 
   if (_module && _module->isChanged())
     {
-      
-      int res = KMessageBox::warningYesNo(this,
+
+      int res = KMessageBox::warningYesNoCancel(this,
 module ?
-i18n("There are unsaved changes in the "
-     "active module.\n"
-     "Do you want to apply the changes "
-     "before running\n"
+i18n("There are unsaved changes in the active module.\n"
+     "Do you want to apply the changes before running "
      "the new module or forget the changes?") :
-i18n("There are unsaved changes in the "
-     "active module.\n"
-     "Do you want to apply the changes "
-     "before exiting\n"
+i18n("There are unsaved changes in the active module.\n"
+     "Do you want to apply the changes before exiting "
      "the Control Center or forget the changes?"),
-                                          i18n("Unsaved changes"),
+                                          i18n("Unsaved Changes"),
                                           i18n("&Apply"),
                                           i18n("&Forget"));
       if (res == KMessageBox::Yes)
         _module->module()->applyClicked();
+      if (res == KMessageBox::Cancel)
+        return false;
     }
 
   deleteModule();
-  if (!module) return;
+  if (!module) return true;
 
   _busy->raise();
   _busy->show();
@@ -114,8 +122,6 @@ i18n("There are unsaved changes in the "
 
       widget->reparent(this, 0 , QPoint(0,0), false);
       widget->resize(size());
-      // "inherit" the minimum size
-      setMinimumSize( widget->minimumSize() );
 
       emit newModule(widget->caption(), module->docPath(), widget->quickHelp());
       QApplication::restoreOverrideCursor();
@@ -129,15 +135,9 @@ i18n("There are unsaved changes in the "
   }
   _busy->hide();
 
-  QObjectList * l = topLevelWidget()->queryList( "QAccel" );
-  QObjectListIt it( *l );             // iterate over the buttons
-  QObject * obj;
-  while ( (obj=it.current()) != 0 ) { // for each found object...
-      ++it;
-      ((QAccel*)obj)->repairEventFilter();
-  }
-  delete l;                           // delete the list, not the objects
-
+  KCGlobal::repairAccels( topLevelWidget() );
+  updateGeometry();
+  return true;
 }
 
 void DockContainer::removeModule()
@@ -146,12 +146,12 @@ void DockContainer::removeModule()
 
   resizeEvent(0L);
 
-  setMinimumSize( _basew->minimumSize() );
-
   if (_basew)
-	emit newModule(_basew->caption(), "", "");
+      emit newModule(_basew->caption(), "", "");
   else
-	emit newModule("", "", "");
+      emit newModule("", "", "");
+
+  updateGeometry();
 }
 
 void DockContainer::deleteModule()
@@ -170,7 +170,7 @@ void DockContainer::resizeEvent(QResizeEvent *)
 	  _module->module()->resize(size());
 	  _basew->hide();
 	}
-  else
+  else if (_basew)
 	{
 	  _basew->resize(size());
 	  _basew->show();
