@@ -36,7 +36,11 @@ public:
   void setBaseWidget(QWidget *widget);
   QWidget *baseWidget() { return _basew; }
   
-  void dockModule(ConfigModule *module);
+  bool dockModule(ConfigModule *module);
+
+  QSize minimumSizeHint() const;
+
+  QSize sizeHint() const { return minimumSizeHint(); }
 
 public slots:
   void removeModule();
