@@ -23,7 +23,7 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kprocess.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #include <qpushbutton.h>
 
