@@ -20,8 +20,9 @@
 */
 
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kwin.h>
+#include <global.h>
 
 #include "kcdialog.h"
 #include "kcdialog.moc"
@@ -32,8 +33,8 @@ KCDialog::KCDialog(KCModule *client, int b, const QString &docpath, QWidget *par
                 (b & KCModule::Help ? Help : 0) |
                 (b & KCModule::Default ? User1 : 0) |
                 (b & KCModule::Apply ? (Ok | Apply | Cancel) : Close),
-                (b & KCModule::Apply ? Ok : Close), 
-                true, i18n("Use &Defaults")),
+                (b & KCModule::Apply ? Ok : Close),
+                true, i18n("&Defaults")),
     DCOPObject("dialog"),
     _client(client)
 {
@@ -44,6 +45,8 @@ KCDialog::KCDialog(KCModule *client, int b, const QString &docpath, QWidget *par
     setHelp( docpath, QString::null );
 
     enableButton(Apply, false);
+
+    KCGlobal::repairAccels( topLevelWidget() );
 }
 
 void KCDialog::slotUser1()
