@@ -24,11 +24,11 @@
 
 #include <dcopclient.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kcmdlineargs.h>
 #include <kservice.h>
 #include <kdesktopfile.h>
@@ -36,6 +36,7 @@
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <klibloader.h>
+#include <kaboutdata.h>
 
 #include "kcdialog.h"
 #include "kecdialog.h"
@@ -45,11 +46,14 @@
 #include "kcmshell.h"
 #include "proxywidget.h"
 
+#include "version.h"
+
 static KCmdLineOptions options[] =
 {
     { "list", I18N_NOOP("List all possible modules"), 0},
     { "+module", I18N_NOOP("Configuration module to open."), 0 },
     { "embed <id>", I18N_NOOP("Window ID to embed into."), 0 },
+    { "silent", I18N_NOOP("Do not display main window."), 0 },
     KCmdLineLastOption
 };
 
@@ -59,7 +63,7 @@ static QString locateModule(const QCString module)
     //QStringList files;
     if (module[0] == '/')
     {
-        kdDebug() << "Full path given to kcmshell - not supported yet" << endl;
+        kdDebug(1208) << "Full path given to kcmshell - not supported yet" << endl;
         // (because of KService::findServiceByDesktopPath)
         //files.append(args->arg(0));
     }
@@ -83,7 +87,7 @@ static QString locateModule(const QCString module)
     return path;
 }
 
-void 
+void
 kcmApplication::setDCOPName(const QCString &dcopName)
 {
     m_dcopName = "kcmshell_"+dcopName;
@@ -95,6 +99,7 @@ kcmApplication::isRunning()
 {
     if (dcopClient()->appId() == m_dcopName)
        return false; // We are the one and only.
+    dcopClient()->attach(); // Reregister as anonymous
 
     dcopClient()->setNotifications(true);
 
@@ -127,12 +132,15 @@ kcmApplication::slotAppExit(const QCString &appId)
 int main(int _argc, char *_argv[])
 {
     KAboutData aboutData( "kcmshell", I18N_NOOP("KDE Control Module"),
-                          "2.0",
+                          KCONTROL_VERSION,
                           I18N_NOOP("A tool to start single KDE control modules"),
                           KAboutData::License_GPL,
-                          "(c) 1999-2000, The KDE Developers");
+                          "(c) 1999-2001, The KDE Developers");
+
+    aboutData.addAuthor("Daniel Molkentin", I18N_NOOP("Current Maintainer"), "molkentin@kde.org");
     aboutData.addAuthor("Matthias Hoelzer-Kluepfel",0, "hoelzer@kde.org");
     aboutData.addAuthor("Matthias Elter",0, "elter@kde.org");
+    aboutData.addAuthor("Matthias Ettrich",0, "ettrich@kde.org");
 
     KCmdLineArgs::init(_argc, _argv, &aboutData);
     KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
@@ -154,6 +162,8 @@ int main(int _argc, char *_argv[])
 
             if (KDesktopFile::isDesktopFile(*it)) {
                 KDesktopFile file(*it, true);
+                if (file.readEntry("Hidden") == "true")
+                    continue;
                 QString module = *it;
                 if (module.startsWith(KCGlobal::baseGroup()))
                     module = module.mid(KCGlobal::baseGroup().length());
@@ -179,6 +189,9 @@ int main(int _argc, char *_argv[])
 		    (*descriptions.at(i)).local8Bit().data());
         }
 
+#if defined(QT_THREAD_SUPPORT)
+	app.unlock();
+#endif
         return 0;
     }
 
@@ -197,7 +210,12 @@ int main(int _argc, char *_argv[])
 
         QString path = locateModule(args->arg(0));
         if (path.isEmpty())
+	{
+#if defined(QT_THREAD_SUPPORT)
+	   app.unlock();
+#endif
            return 0;
+	}
 
         // load the module
         ModuleInfo info(path);
@@ -208,42 +226,51 @@ int main(int _argc, char *_argv[])
             // create the dialog
             QCString embedStr = args->getOption("embed");
             bool embed = false;
-            int id;
-            if (!embedStr.isEmpty()) 
+            int id = -1;
+            if (!embedStr.isEmpty())
                id = embedStr.toInt(&embed);
-            
-            if (!embed)
-            {
-               KCDialog * dlg = new KCDialog(module, module->buttons(), info.docPath(), 0, 0, true );
-               dlg->setCaption(info.name());
+            if (!args->isSet("silent")) {
+             if (!embed)
+             {
+                KCDialog * dlg = new KCDialog(module, module->buttons(), info.docPath(), 0, 0, true );
+                dlg->setCaption(info.name());
 
-               // Needed for modules that use d'n'd (not really the right
-               // solution for this though, I guess)
-               dlg->setAcceptDrops(true);
-	   
-               // run the dialog
-               dlg->exec();
-               delete dlg;
-            }
-            // if we are going to be embedded, embed
-            else
-            {
-               QWidget *dlg = new ProxyWidget(module, info.name(), "kcmshell", false);
-               // Needed for modules that use d'n'd (not really the right
-               // solution for this though, I guess)
-               dlg->setAcceptDrops(true);
+                // Needed for modules that use d'n'd (not really the right
+                // solution for this though, I guess)
+                dlg->setAcceptDrops(true);
 
-               QXEmbed::embedClientIntoWindow(dlg, id);
-               kapp->exec();
-               delete dlg;
+                // run the dialog
+                dlg->exec();
+                delete dlg;
+             }
+             // if we are going to be embedded, embed
+             else
+             {
+                QWidget *dlg = new ProxyWidget(module, info.name(), "kcmshell", false);
+                // Needed for modules that use d'n'd (not really the right
+                // solution for this though, I guess)
+                dlg->setAcceptDrops(true);
+
+                QXEmbed::embedClientIntoWindow(dlg, id);
+                kapp->exec();
+                delete dlg;
+             }
+            } else {
+             //Silent
+             kapp->exec();
             }
             ModuleLoader::unloadModule(info);
             return 0;
         }
 
-        KMessageBox::error(0,
-                           i18n("There was an error loading the module.\nThe diagnostics is:\n%1")
-                           .arg(KLibLoader::self()->lastErrorMessage()));
+        KMessageBox::detailedError(0,
+                           i18n("There was an error loading the module."),i18n("<qt><p>The diagnostics is:<br>%1"
+                                "<p>Possible reasons:</p><ul><li>An error occurred during your last "
+                                "KDE upgrade leaving an orphaned control module<li>You have old third party "
+                                "modules lying around.</ul><p>Check these points carefully and try to remove "
+                                "the module mentioned in the error message. If this fails, consider contacting "
+                                "your distributor or packager.</p></qt>")
+                                   .arg(KLibLoader::self()->lastErrorMessage()));
         return 0;
     }
 
