@@ -21,11 +21,12 @@
 #include <qstringlist.h>
 #include <qfile.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klibloader.h>
+#include <kparts/componentfactory.h>
 
 #include <stdlib.h>
 
@@ -33,6 +34,35 @@
 #include "global.h"
 #include "modloader.h"
 
+static KCModule *load(const ModuleInfo &mod, const QString &libname, KLibLoader *loader)
+{
+    // attempt to load KDE3 modules (new loader)
+    
+    KCModule *module = KParts::ComponentFactory::createInstanceFromLibrary<KCModule>(QFile::encodeName(libname.arg(mod.library())));
+    if (module)
+	return module;
+    
+    // else do a fallback
+    kdDebug() << "Unable to load module using ComponentFactory! Falling back to old loader." << endl;
+    
+    KLibrary *lib = loader->library(QFile::encodeName(libname.arg(mod.library())));
+    if (lib) {
+	// get the create_ function
+	QString factory("create_%1");
+	void *create = lib->symbol(QFile::encodeName(factory.arg(mod.handle())));
+	
+	if (create)
+	    {
+		// create the module
+		KCModule* (*func)(QWidget *, const char *);
+		func = (KCModule* (*)(QWidget *, const char *)) create;
+		return  func(0, 0);
+	    }
+    }
+    return 0;
+}
+
+
 KCModule *ModuleLoader::loadModule(const ModuleInfo &mod, bool withfallback)
 {
   /*
@@ -55,27 +85,14 @@ KCModule *ModuleLoader::loadModule(const ModuleInfo &mod, bool withfallback)
 
       KLibLoader *loader = KLibLoader::self();
 
-      // try to load the library
-      QString libname("libkcm_%1");
-      KLibrary *lib = loader->library(QFile::encodeName(libname.arg(mod.library())));
-      if (lib)
-	{
-	  // get the create_ function
-	  QString factory("create_%1");
-	  void *create = lib->symbol(QFile::encodeName(factory.arg(mod.handle())));
-
-	  if (create)
-	    {
-	      // create the module
-	      KCModule* (*func)(QWidget *, const char *);
-	      func = (KCModule* (*)(QWidget *, const char *)) create;
-	      return  func(0,"");
-	    }
-	}
+       KCModule *module = load(mod, "kcm_%1", loader);
+       if (!module)
+	   module = load(mod, "libkcm_%1", loader);
+       if (module)
+	   return module;
     }
     else
       kdWarning() << "Module " << mod.fileName() << " doesn't specify a library!" << endl;
-
   /*
    * Ok, we could not load the library.
    * Try to run it as an executable.
@@ -84,6 +101,8 @@ KCModule *ModuleLoader::loadModule(const ModuleInfo &mod, bool withfallback)
    * (startService calls kcmshell which calls modloader which calls startService...)
    *
    */
+
+
   if(withfallback)
       kapp->startServiceByDesktopPath(mod.fileName(), QString::null);
   return 0;
@@ -99,4 +118,7 @@ void ModuleLoader::unloadModule(const ModuleInfo &mod)
   // try to unload the library
   QString libname("libkcm_%1");
   loader->unloadLibrary(QFile::encodeName(libname.arg(mod.library())));
+
+  libname = "kcm_%1";
+  loader->unloadLibrary(QFile::encodeName(libname.arg(mod.library())));
 }
