@@ -24,9 +24,8 @@
 #include <qwidget.h>
 #include <qlabel.h>
 #include <qlayout.h>
-
-
-#include <kapp.h>
+#include <qvbox.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kservicegroup.h>
@@ -35,13 +34,12 @@
 #include <kprocess.h>
 #include <qxembed.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 
 #include "modules.h"
 #include "modules.moc"
 #include "global.h"
-#include "utils.h"
 #include "proxywidget.h"
 #include "modloader.h"
 #include "kcrootonly.h"
@@ -49,12 +47,12 @@
 #include <X11/Xlib.h>
 
 
-template class QList<ConfigModule>;
+template class QPtrList<ConfigModule>;
 
 
 ConfigModule::ConfigModule(QString desktopFile)
   : ModuleInfo(desktopFile), _changed(false), _module(0), _embedWidget(0),
-    _rootProcess(0), _embedLayout(0)
+    _rootProcess(0), _embedLayout(0), _embedFrame(0)
 {
 }
 
@@ -71,11 +69,11 @@ ProxyWidget *ConfigModule::module()
   bool run_as_root = needsRootPrivileges() && (getuid() != 0);
 
   KCModule *modWidget = 0;
-  
-  if (run_as_root && !hasReadOnlyMode())
+
+  if (run_as_root && isHiddenByDefault())
      modWidget = new KCRootOnly(0, "root_only");
   else
-     modWidget = ModuleLoader::loadModule(*this);
+      modWidget = ModuleLoader::loadModule(*this);
 
   if (modWidget)
     {
@@ -102,6 +100,8 @@ void ConfigModule::deleteClient()
 
   delete _embedWidget;
   _embedWidget = 0;
+  delete _embedFrame;
+  _embedFrame = 0;
   kapp->syncX();
 
   delete _module;
@@ -142,10 +142,18 @@ void ConfigModule::runAsRoot()
   // create an embed widget that will embed the
   // kcmshell running as root
   _embedLayout = new QVBoxLayout(_module->parentWidget());
-  _embedWidget = new QXEmbed(_module->parentWidget());
-  _embedLayout->addWidget(_embedWidget,1);
+  _embedFrame = new QVBox( _module->parentWidget() );
+  _embedFrame->setFrameStyle( QFrame::Box | QFrame::Raised );
+  QPalette pal( red );
+  pal.setColor( QColorGroup::Background, 
+		_module->parentWidget()->colorGroup().background() );
+  _embedFrame->setPalette( pal );
+  _embedFrame->setLineWidth( 2 );
+  _embedFrame->setMidLineWidth( 2 );
+  _embedLayout->addWidget(_embedFrame,1);
+  _embedWidget = new QXEmbed(_embedFrame );
   _module->hide();
-  _embedWidget->show();
+  _embedFrame->show();
   QLabel *_busy = new QLabel(i18n("<big>Loading ...</big>"), _embedWidget);
   _busy->setAlignment(AlignCenter);
   _busy->setTextFormat(RichText);
@@ -169,14 +177,18 @@ void ConfigModule::runAsRoot()
     {
       _rootProcess = new KProcess;
       *_rootProcess << kdesu;
+      *_rootProcess << "--nonewdcop";
       // We have to disable the keep-password feature because
-      // in that case the modules is started through kdesud and kdesu 
-      // returns before the module is running and that doesn't work. 
+      // in that case the modules is started through kdesud and kdesu
+      // returns before the module is running and that doesn't work.
       // We also don't have a way to close the module in that case.
       *_rootProcess << "--n"; // Don't keep password.
-      if (kdeshell)
-        *_rootProcess << "kcmshell";
-      *_rootProcess << QString("%1 --embed %2").arg(cmd).arg(_embedWidget->winId());
+      if (kdeshell) {
+         *_rootProcess << QString("kcmshell %1 --embed %2").arg(cmd).arg(_embedWidget->winId());
+      }
+      else {
+         *_rootProcess << QString("%1 --embed %2").arg(cmd).arg(_embedWidget->winId());
+      }
 
       connect(_rootProcess, SIGNAL(processExited(KProcess*)), this, SLOT(rootExited(KProcess*)));
 
@@ -186,7 +198,7 @@ void ConfigModule::runAsRoot()
     }
 
   // clean up in case of failure
-  delete _embedWidget;
+  delete _embedFrame;
   _embedWidget = 0;
   delete _embedLayout;
   _embedLayout = 0;
@@ -224,6 +236,7 @@ ConfigModuleList::ConfigModuleList()
 
 const KAboutData *ConfigModule::aboutData() const
 {
+  if (!_module) return 0;
   return _module->aboutData();
 }
 
@@ -238,7 +251,7 @@ void ConfigModuleList::readDesktopEntriesRecursive(const QString &path)
 
   if (!group || !group->isValid()) return;
 
-  KServiceGroup::List list = group->entries();
+  KServiceGroup::List list = group->entries(true);
 
   for( KServiceGroup::List::ConstIterator it = list.begin();
        it != list.end(); it++)
