@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: backgnd.cpp,v 1.15 2001/06/11 02:21:54 rahn Exp $
+ * $Id: backgnd.cpp,v 1.20 2002/03/24 03:45:19 pfeiffer Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -24,35 +24,21 @@
 #include <sys/types.h>
 
 
-#include <qobject.h>
 #include <qlayout.h>
-#include <qstring.h>
-#include <qstringlist.h>
 #include <qlabel.h>
-#include <qlistbox.h>
-#include <qgroupbox.h>
 #include <qcombobox.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
 #include <qcheckbox.h>
-#include <qpushbutton.h>
 #include <qdragobject.h>
-#include <qhbox.h>
-#include <qevent.h>
 #include <qwhatsthis.h>
 #include <qtabwidget.h>
 
-#include <kapp.h>
 #include <kdebug.h>
-#include <kglobal.h>
-#include <kstddirs.h>
-#include <kiconloader.h>
-#include <kcolorbtn.h>
+#include <kstandarddirs.h>
+#include <kcolorbutton.h>
 #include <klocale.h>
 #include <kfiledialog.h>
 #include <kpixmap.h>
 #include <dcopclient.h>
-#include <ksimpleconfig.h>
 #include <kmessagebox.h>
 
 #include <bgdefaults.h>
@@ -62,15 +48,7 @@
 #include <backgnd.h>
 
 
-extern KSimpleConfig *c;
-
-/**** DLL Interface ****/
-
-extern "C" {
-    KCModule *create_background(QWidget *parent, const char *name) {
-    return new KBackground(parent, name);
-    }
-}
+extern KSimpleConfig *config;
 
 
 /**** KBGMonitor ****/
@@ -98,7 +76,7 @@ void KBGMonitor::dragEnterEvent(QDragEnterEvent *e)
 /**** KBackground ****/
 
 KBackground::KBackground(QWidget *parent, const char *name)
-    : KCModule(parent, name)
+    : QWidget(parent, name)
 {
     QString wtstr;
     m_pDirs = KGlobal::dirs();
@@ -117,7 +95,7 @@ KBackground::KBackground(QWidget *parent, const char *name)
     QLabel *lbl = new QLabel(this);
     lbl->setPixmap(locate("data", "kcontrol/pics/monitor.png"));
     lbl->setFixedSize(lbl->sizeHint());
-    top->addWidget(lbl, 0,0); // 0,1, AlignCenter);
+    top->addMultiCellWidget(lbl, 0,0, 0,2, AlignCenter);
     m_pMonitor = new KBGMonitor(lbl);
     m_pMonitor->setGeometry(23, 14, 151, 115);
     connect(m_pMonitor, SIGNAL(imageDropped(QString)), SLOT(slotImageDropped(QString)));
@@ -264,7 +242,7 @@ KBackground::KBackground(QWidget *parent, const char *name)
     m_pCBMulti->hide();
     m_pMSetupBut->hide();
 
-    m_Renderer = new KBackgroundRenderer(0, c);
+    m_Renderer = new KBackgroundRenderer(0, config);
     connect(m_Renderer, SIGNAL(imageDone(int)), SLOT(slotPreviewDone(int)));
 
     init();
@@ -349,52 +327,52 @@ void KBackground::apply()
     m_pColor1But->setColor(r->colorA());
     m_pColor2But->setColor(r->colorB());
     switch (r->backgroundMode()) {
-    case KBackgroundSettings::Program:
-    m_pColor1But->setEnabled(false);
-    m_pColor2But->setEnabled(false);
-    m_pBGSetupBut->setEnabled(true);
-    break;
-    case KBackgroundSettings::Flat:
-    m_pColor1But->setEnabled(true);
-    m_pColor2But->setEnabled(false);
-    m_pBGSetupBut->setEnabled(false);
-    break;
-    case KBackgroundSettings::Pattern:
-    m_pColor1But->setEnabled(true);
-    m_pColor2But->setEnabled(true);
-    m_pBGSetupBut->setEnabled(true);
-    break;
-    default:
-    m_pColor1But->setEnabled(true);
-    m_pColor2But->setEnabled(true);
-    m_pBGSetupBut->setEnabled(false);
-    break;
+        case KBackgroundSettings::Program:
+            m_pColor1But->setEnabled(false);
+            m_pColor2But->setEnabled(false);
+            m_pBGSetupBut->setEnabled(true);
+            break;
+        case KBackgroundSettings::Flat:
+            m_pColor1But->setEnabled(true);
+            m_pColor2But->setEnabled(false);
+            m_pBGSetupBut->setEnabled(false);
+            break;
+        case KBackgroundSettings::Pattern:
+            m_pColor1But->setEnabled(true);
+            m_pColor2But->setEnabled(true);
+            m_pBGSetupBut->setEnabled(true);
+            break;
+        default:
+            m_pColor1But->setEnabled(true);
+            m_pColor2But->setEnabled(true);
+            m_pBGSetupBut->setEnabled(false);
+            break;
     }
 
     // Wallpaper mode
     QString wp = r->wallpaper();
     if (wp.isEmpty())
-    wp = QString(" ");
+        wp = QString(" ");
     if (!m_Wallpaper.contains(wp)) {
-    int count = m_Wallpaper.count();
-    m_Wallpaper[wp] = count;
-    m_pWallpaperBox->insertItem(wp);
-    m_pWallpaperBox->setCurrentItem(count);
+        int count = m_Wallpaper.count();
+        m_Wallpaper[wp] = count;
+        m_pWallpaperBox->insertItem(wp);
+        m_pWallpaperBox->setCurrentItem(count);
     }
     m_pWallpaperBox->setCurrentItem(m_Wallpaper[wp]);
     m_pArrangementBox->setCurrentItem(r->wallpaperMode());
 
     // Multi mode
     if (r->multiWallpaperMode() == KBackgroundSettings::NoMulti) {
-    m_pCBMulti->setChecked(false);
-    m_pWallpaperBox->setEnabled(true);
-    m_pBrowseBut->setEnabled(true);
-    m_pMSetupBut->setEnabled(false);
+        m_pCBMulti->setChecked(false);
+        m_pWallpaperBox->setEnabled(true);
+        m_pBrowseBut->setEnabled(true);
+        m_pMSetupBut->setEnabled(false);
     } else {
-    m_pCBMulti->setChecked(true);
-    m_pWallpaperBox->setEnabled(false);
-    m_pBrowseBut->setEnabled(false);
-    m_pMSetupBut->setEnabled(true);
+        m_pCBMulti->setChecked(true);
+        m_pWallpaperBox->setEnabled(false);
+        m_pBrowseBut->setEnabled(false);
+        m_pMSetupBut->setEnabled(true);
     }
 
     // Start preview render
@@ -470,7 +448,7 @@ void KBackground::slotBGSetup()
     dlg.setCurrent(cur);
     if ((dlg.exec() == QDialog::Accepted) && !dlg.pattern().isEmpty()) {
         r->stop();
-        r->setPattern(dlg.pattern());
+        r->setPatternName(dlg.pattern());
         r->start();
         emit changed(true);
     }
@@ -588,7 +566,7 @@ void KBackground::slotBrowseWallpaper()
     if (url.isEmpty())
     return;
     if (!url.isLocalFile()) {
-      KMessageBox::sorry(this, i18n("Currently are only local wallpapers allowed."));
+      KMessageBox::sorry(this, i18n("Currently only local wallpapers are allowed."));
       return;
     }
     QString file = url.path();
