@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: backgnd.h,v 1.3 2000/08/04 10:09:38 faure Exp $
+ * $Id: backgnd.h,v 1.6 2002/01/25 10:17:25 hausmann Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -19,7 +19,6 @@
 #include <qevent.h>
 #include <qwidget.h>
 
-#include <kcmodule.h>
 #include <bgdefaults.h>
 
 class QCheckBox;
@@ -33,10 +32,8 @@ class QTabWidget;
 
 class KColorButton;
 class KBackgroundRenderer;
-class KConfig;
 class KStandardDirs;
 
-
 /**
  * This class handles drops on the preview monitor.
  */
@@ -64,12 +61,12 @@ protected:
 /**
  * The Desktop/Background tab in kcontrol.
  */
-class KBackground: public KCModule
+class KBackground: public QWidget
 {
     Q_OBJECT
 
 public:
-    KBackground(QWidget *parent, const char *name);
+    KBackground(QWidget *parent=0, const char *name=0);
 
     virtual void load();
     virtual void save();
