@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgdialogs.cpp,v 1.6 2001/06/09 23:43:20 mhunter Exp $
+ * $Id: bgdialogs.cpp,v 1.13 2002/03/24 02:51:51 pfeiffer Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -9,30 +9,22 @@
  * License. See the file "COPYING" for the exact licensing terms.
  */
 
-#include <qstring.h>
-#include <qstringlist.h>
 #include <qlayout.h>
 #include <qlistview.h>
-#include <qpushbutton.h>
 #include <qlabel.h>
-#include <qpixmap.h>
-#include <qlineedit.h>
-#include <qlistbox.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
-#include <qframe.h>
-#include <qmap.h>
 #include <qvbox.h>
 #include <qdragobject.h>
+#include <qpainter.h>
 
-#include <kapp.h>
-#include <kglobal.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kstddirs.h>
-#include <kbuttonbox.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
+#include <kurlrequester.h>
+#include <klineedit.h>
 
 #include <bgdialogs.h>
 #include <bgrender.h>
@@ -78,24 +70,35 @@ KProgramSelectDialog::KProgramSelectDialog(QWidget *parent, char *name)
     connect(m_ListView, SIGNAL(doubleClicked(QListViewItem *)),
 	    SLOT(slotItemDoubleClicked(QListViewItem *)));
 
+    connect(m_ListView, SIGNAL(selectionChanged()),
+            SLOT(slotSelectionChanged()));
+
     // Add/Remove/Modify buttons
     QVBoxLayout *vbox = new QVBoxLayout(spacingHint());
     QPushButton *but = new QPushButton(i18n("&Add..."), page);
     vbox->addWidget(but);
     connect(but, SIGNAL(clicked()), SLOT(slotAdd()));
-    but = new QPushButton(i18n("&Remove"), page);
-    vbox->addWidget(but);
-    connect(but, SIGNAL(clicked()), SLOT(slotRemove()));
-    but = new QPushButton(i18n("&Modify..."), page);
-    vbox->addWidget(but);
-    connect(but, SIGNAL(clicked()), SLOT(slotModify()));
+
+    removeBut = new QPushButton(i18n("&Remove"), page);
+    vbox->addWidget(removeBut);
+    connect(removeBut, SIGNAL(clicked()), SLOT(slotRemove()));
+    modifyBut = new QPushButton(i18n("&Modify..."), page);
+    vbox->addWidget(modifyBut);
+    connect(modifyBut, SIGNAL(clicked()), SLOT(slotModify()));
 
     vbox->addStretch(1);
 
     layout->addLayout(vbox, 1, 1);
+    slotSelectionChanged();
+}
+
+void KProgramSelectDialog::slotSelectionChanged()
+{
+    bool state=m_ListView->currentItem();
+    removeBut->setEnabled(state);
+    modifyBut->setEnabled(state);
 }
 
-	
 /*
  * Set the current program.
  */
@@ -167,8 +170,8 @@ void KProgramSelectDialog::slotRemove()
     KBackgroundProgram prog(m_Current);
     if (prog.isGlobal()) {
 	KMessageBox::sorry(this,
-		i18n("Unable to remove the program! The program is global\n"
-		"and can only be removed by the System Administrator.\n"),
+		i18n("Unable to remove the program! The program is global "
+		"and can only be removed by the System Administrator."),
 		i18n("Cannot remove program"));
 	return;
     }
@@ -180,6 +183,8 @@ void KProgramSelectDialog::slotRemove()
     prog.remove();
     updateItem(m_Current);
     m_Current = QString::null;
+    removeBut->setEnabled(false);
+    modifyBut->setEnabled(false);
 }
 
 
@@ -216,7 +221,8 @@ void KProgramSelectDialog::slotItemDoubleClicked(QListViewItem *item)
     if ( item )
     {
         m_Current = item->text(1);
-        accept();
+        slotModify();
+        //accept();
     }
 }
 
@@ -258,7 +264,7 @@ KProgramEditDialog::KProgramEditDialog(QString program, QWidget *parent, char *n
 
     lbl = new QLabel(i18n("&Executable:"), frame);
     grid->addWidget(lbl, 4, 0);
-    m_ExecEdit = new QLineEdit(frame);
+    m_ExecEdit = new KURLRequester(frame);
     lbl->setBuddy(m_ExecEdit);
     grid->addWidget(m_ExecEdit, 4, 1);
 
@@ -288,7 +294,7 @@ KProgramEditDialog::KProgramEditDialog(QString program, QWidget *parent, char *n
     m_NameEdit->setText(m_Program);
     KBackgroundProgram prog(m_Program);
     m_CommentEdit->setText(prog.comment());
-    m_ExecEdit->setText(prog.executable());
+    m_ExecEdit->lineEdit()->setText(prog.executable());
     m_CommandEdit->setText(prog.command());
     m_PreviewEdit->setText(prog.previewCommand());
     m_RefreshEdit->setValue(prog.refresh());
@@ -318,7 +324,7 @@ void KProgramEditDialog::slotOk()
 	    return;
     }
 
-    if (m_ExecEdit->text().isEmpty()) {
+    if (m_ExecEdit->lineEdit()->text().isEmpty()) {
 	KMessageBox::sorry(this, i18n("You did not fill in the `Executable' field.\n"
 		"This is a required field."));
 	return;
@@ -330,7 +336,7 @@ void KProgramEditDialog::slotOk()
     }
 
     prog.setComment(m_CommentEdit->text());
-    prog.setExecutable(m_ExecEdit->text());
+    prog.setExecutable(m_ExecEdit->lineEdit()->text());
     prog.setCommand(m_CommandEdit->text());
     prog.setPreviewCommand(m_PreviewEdit->text());
     prog.setRefresh(m_RefreshEdit->value());
@@ -396,7 +402,7 @@ KPatternSelectDialog::KPatternSelectDialog(QWidget *parent, char *name)
     layout->addLayout(vbox, 1, 1);
 }
 
-	
+
 /*
  * Set the current pattern.
  */
@@ -477,7 +483,7 @@ void KPatternSelectDialog::slotRemove()
     KBackgroundPattern pat(m_Current);
     if (pat.isGlobal()) {
 	KMessageBox::sorry(this,
-		i18n("Unable to remove the pattern! The pattern is global\n"
+		i18n("Unable to remove the pattern! The pattern is global "
 		"and can only be removed by the System Administrator.\n"),
 		i18n("Cannot remove pattern"));
 	return;
@@ -516,7 +522,8 @@ void KPatternSelectDialog::slotModify()
 
 void KPatternSelectDialog::slotItemClicked(QListViewItem *item)
 {
-    m_Current = item->text(1);
+    if ( item )
+        m_Current = item->text(1);
     kdDebug() << "current: " << m_Current << endl;
 }
 
