@@ -22,7 +22,7 @@
 #ifndef __KDMCONV_H__
 #define __KDMCONV_H__
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qimage.h>
 #include <qgroupbox.h>
@@ -37,10 +37,8 @@
 
 #include <pwd.h>
 
-#include <kcmodule.h>
 
-
-class KDMConvenienceWidget : public KCModule
+class KDMConvenienceWidget : public QWidget
 {
 	Q_OBJECT
 
@@ -51,6 +49,9 @@ public:
         void save();
 	void defaults();
 
+signals:
+	void changed( bool state );
+
 private slots:
         void addShowUser(const QString &user);
         void removeShowUser(const QString &user);
