@@ -21,67 +21,68 @@
 #include <sys/types.h>
 
 
+#include <qpushbutton.h>
+#include <qapplication.h>
 #include <qcombobox.h>
 #include <qlayout.h>
 #include <qgroupbox.h>
+#include <qhgroupbox.h>
+#include <qvgroupbox.h>
 #include <qlabel.h>
 #include <qwhatsthis.h>
 
 #include <ksimpleconfig.h>
 #include <klocale.h>
-#include <kstddirs.h>
-#include "kdm-font.moc"
+#include <kstandarddirs.h>
+
+#include "kdm-font.h"
 
 
-extern KSimpleConfig *c;
+extern KSimpleConfig *config;
 
 KDMFontWidget::KDMFontWidget(QWidget *parent, const char *name)
-  : KCModule(parent, name)
+  : QWidget(parent, name)
 {
-  QGroupBox *tGroup = new QGroupBox(i18n("Select fonts"), this);
-  QGroupBox *bGroup = new QGroupBox(i18n("Example"), this);
-
-  QWhatsThis::add( bGroup, i18n("Shows a preview of the selected font.") );
-
-  QPushButton *fontbtn = new QPushButton(i18n("C&hange font..."), tGroup);
-  connect(fontbtn, SIGNAL(clicked()), SLOT(slotGetFont()));
-  fontbtn->setFixedSize(fontbtn->sizeHint());
-
-  QWhatsThis::add( fontbtn, i18n("Click here to change the selected font.") );
+  QGroupBox *tGroup = new QHGroupBox(i18n("Select fonts"), this);
 
   fontcombo = new QComboBox( FALSE, tGroup );
-  connect(fontcombo, SIGNAL(highlighted(int)), SLOT(slotSetFont(int)));
   fontcombo->insertItem(i18n("Greeting"), 0);
   fontcombo->insertItem(i18n("Fail"), 1);
   fontcombo->insertItem(i18n("Standard"), 2);
   fontcombo->setFixedSize(fontcombo->sizeHint());
+  connect(fontcombo, SIGNAL(highlighted(int)), SLOT(slotSetFont(int)));
 
   QWhatsThis::add( fontcombo, i18n("Here you can select the font you want to change."
     " KDM knows three fonts: <ul><li><em>Greeting:</em> used to display KDM's greeting"
     " string (see \"Appearance\" tab)</li><li><em>Fail:</em> used to display a message"
     " when a person fails to login</li><li><em>Standard:</em> used for the rest of the text</li></ul>") );
 
+  QPushButton *fontbtn = new QPushButton(i18n("C&hange Font..."), tGroup);
+  fontbtn->setFixedSize(fontbtn->sizeHint());
+  connect(fontbtn, SIGNAL(clicked()), SLOT(slotGetFont()));
+
+  QWhatsThis::add( fontbtn, i18n("Click here to change the selected font.") );
+
+  tGroup->addSpace(0);
+
+  QGroupBox *bGroup = new QVGroupBox(i18n("Example"), this);
+  QWhatsThis::add( bGroup, i18n("Shows a preview of the selected font.") );
   fontlabel = new QLabel( bGroup );
   fontlabel->setFrameStyle(QFrame::WinPanel|QFrame::Sunken);
+  fontlabel->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
+
+
+  QGroupBox *mGroup = new QVGroupBox(i18n("Miscellaneous"), this);
+  aacb = new QCheckBox (i18n("Use Anti-Aliasing for fonts"), mGroup);
+  QWhatsThis::add( aacb, i18n("If you check this box and your X-Server has the Xft extension, "
+	"fonts will be antialiased (smoothed) in the login dialog.") );
+  connect(aacb, SIGNAL(toggled ( bool )),this,SLOT(configChanged()));
 
   QBoxLayout *ml = new QVBoxLayout(this, 10);
-
-  QBoxLayout *tLayout = new QVBoxLayout(tGroup, 10);
-  QBoxLayout *bLayout = new QVBoxLayout(bGroup, 10);
-  tLayout->addSpacing(tGroup->fontMetrics().height());
-  bLayout->addSpacing(bGroup->fontMetrics().height());
-
-  QBoxLayout *tLayout2 = new QHBoxLayout();
-  tLayout->addLayout(tLayout2, 1);
-  tLayout2->addWidget(fontbtn);
-  tLayout2->addWidget(fontcombo);
-  tLayout2->addStretch();
-
-  bLayout->addWidget(fontlabel);
-
   ml->addWidget(tGroup);
-  ml->addWidget(bGroup, 3);
-  ml->addStretch(2);
+  ml->addWidget(bGroup, 1);
+  ml->addWidget(mGroup);
+  ml->addStretch(1);
 
   load();
   slotSetFont(0);
@@ -90,18 +91,25 @@ KDMFontWidget::KDMFontWidget(QWidget *parent, const char *name)
     {
       fontbtn->setEnabled(false);
       fontcombo->setEnabled(false);
+      aacb->setEnabled(false);
     }
 }
 
+void KDMFontWidget::configChanged()
+{
+    emit changed(true);
+}
+
 
 void KDMFontWidget::save()
 {
-  c->setGroup("X-*-Greeter");
+  config->setGroup("X-*-Greeter");
 
   // write font
-  c->writeEntry("StdFont", stdfont);
-  c->writeEntry("GreetFont", greetfont);
-  c->writeEntry("FailFont", failfont);
+  config->writeEntry("StdFont", stdfont);
+  config->writeEntry("GreetFont", greetfont);
+  config->writeEntry("FailFont", failfont);
+  config->writeEntry("AntiAliasing", aacb->isChecked());
 }
 
 
@@ -117,14 +125,16 @@ void KDMFontWidget::load()
 {
   set_def();
 
-  c->setGroup("X-*-Greeter");
+  config->setGroup("X-*-Greeter");
 
   // Read the fonts
-  stdfont = c->readFontEntry("StdFont", &stdfont);
-  failfont = c->readFontEntry("FailFont", &failfont);
-  greetfont = c->readFontEntry("GreetFont", &greetfont);
+  stdfont = config->readFontEntry("StdFont", &stdfont);
+  failfont = config->readFontEntry("FailFont", &failfont);
+  greetfont = config->readFontEntry("GreetFont", &greetfont);
 
   slotSetFont(fontcombo->currentItem());
+
+  aacb->setChecked(config->readBoolEntry("AntiAliasing"));
 }
 
 
@@ -132,6 +142,7 @@ void KDMFontWidget::defaults()
 {
   set_def();
   slotSetFont(fontcombo->currentItem());
+  aacb->setChecked(false);
 }
 
 
@@ -141,6 +152,7 @@ void KDMFontWidget::slotGetFont()
 
   KFontDialog *fontdlg = new KFontDialog(0, 0, TRUE, 0L);
   QApplication::restoreOverrideCursor( );
+  QFont tmpfont;
   fontdlg->getFont(tmpfont);
   switch (fontcombo->currentItem())
   {
@@ -158,30 +170,32 @@ void KDMFontWidget::slotGetFont()
   //fontlabel->setFixedSize(fontlabel->sizeHint());
   delete fontdlg;
 
-  emit KCModule::changed(true);
+  emit changed(true);
 }
 
 
 void KDMFontWidget::slotSetFont(int id)
 {
   QApplication::setOverrideCursor( waitCursor );
+  QFont *tmpfont;
   switch (id)
   {
     case 0:
-      tmpfont = greetfont;
+      tmpfont = &greetfont;
       fontlabel->setText(i18n("Greeting font"));
       break;
     case 1:
-      tmpfont = failfont;
+      tmpfont = &failfont;
       fontlabel->setText(i18n("Fail font"));
       break;
-    case 2:
-      tmpfont = stdfont;
+    default:
+      tmpfont = &stdfont;
       fontlabel->setText(i18n("Standard font"));
       break;
   }
-  fontlabel->setFont(tmpfont);
+  fontlabel->setFont(*tmpfont);
   //fontlabel->adjustSize();
   QApplication::restoreOverrideCursor( );
 }
 
+#include "kdm-font.moc"
