@@ -20,13 +20,13 @@
 #ifndef __KDMFONT_H__
 #define __KDMFONT_H__
 
-
+#include <qcheckbox.h>
 
 #include <kfontdialog.h>
-#include <kcmodule.h>
+#include <qwidget.h>
 
 
-class KDMFontWidget : public KCModule
+class KDMFontWidget : public QWidget
 {
 	Q_OBJECT
 
@@ -38,6 +38,11 @@ public:
 	void defaults();
 	void set_def();
 
+signals:
+	void changed( bool state );
+
+protected slots:
+    void configChanged();
 
 private slots:
         void slotGetFont();
@@ -45,11 +50,10 @@ private slots:
 
 
 private:
-        KIconLoader *iconloader;
-        QFont        tmpfont, stdfont, greetfont, failfont;
-        QLabel       *fontlabel;
-	QComboBox    *fontcombo;
-
+        QFont		stdfont, greetfont, failfont;
+        QLabel		*fontlabel;
+	QComboBox	*fontcombo;
+	QCheckBox	*aacb;
 };
 
 
