@@ -20,92 +20,86 @@
 #include <unistd.h>
 #include <sys/types.h>
 
-
-#include <qdragobject.h>
+#include <qdir.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qtooltip.h>
 #include <qvalidator.h>
 #include <qwhatsthis.h>
 #include <qvgroupbox.h>
-#include <qstringlist.h>
 
-#include <kapp.h>
 #include <ksimpleconfig.h>
-#include <kicondialog.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
-#include <kglobal.h>
-#include <kstddirs.h>
-#include <kimageio.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
-#include "kdm-users.moc"
+
+#include "kdm-users.h"
 
 
-extern KSimpleConfig *c;
+extern KSimpleConfig *config;
 
 KDMUsersWidget::KDMUsersWidget(QWidget *parent, const char *name, QStringList *show_users)
-    : KCModule(parent, name)
+    : QWidget(parent, name)
 {
-    m_userPixDir = KGlobal::dirs()->resourceDirs("data").last() + "kdm/pics/users/";
+    // We assume that $kde_datadir/kdm exists, but better check for pics/ and pics/users,
+    // and create them if necessary.
+    m_userPixDir = KGlobal::dirs()->resourceDirs("data").last() + "kdm/pics/";
+    QDir testDir( m_userPixDir );
+    if ( !testDir.exists() && !testDir.mkdir( testDir.absPath() ) )
+    {
+        KMessageBox::sorry(this, i18n("Couldn't create directory %1").arg(testDir.absPath()));
+        m_userPixDir += "users/"; // doesn't exist, then...
+    } else
+    {
+        m_userPixDir += "users/";
+        if ( !testDir.exists() )
+            if ( !testDir.mkdir( testDir.absPath() ) )
+                KMessageBox::sorry(this, i18n("Couldn't create directory %1").arg(testDir.absPath()));
+    }
+
     m_defaultText = i18n("<default>");
 
     QString wtstr;
-    QHBoxLayout *main = new QHBoxLayout(this, 10);
-    QGridLayout *rLayout = new QGridLayout(main, 4, 3, 10);
 
     QLabel *a_label = new QLabel(i18n("&Remaining users"), this);
-    rLayout->addWidget(a_label, 0, 0);
 
     QLabel *s_label = new QLabel(i18n("S&elected users"), this);
-    rLayout->addWidget(s_label, 0, 2);
 
     QLabel *n_label = new QLabel(i18n("No-sho&w users"), this);
-    rLayout->addWidget(n_label, 4, 2);
-
-    QPushButton *all_to_no, *all_to_usr, *no_to_all, *usr_to_all;
 
     QSize sz(40, 20);
 
-    all_to_usr = new QPushButton( ">>", this );
+    QPushButton *all_to_usr = new QPushButton( ">>", this );
     all_to_usr->setFixedSize( sz );
-    rLayout->addWidget(all_to_usr, 1, 1);
     connect( all_to_usr, SIGNAL( clicked() ), SLOT( slotAllToUsr() ) );
-    connect( all_to_usr, SIGNAL(clicked()), this, SLOT(slotChanged()));
+    connect( all_to_usr, SIGNAL(clicked()), SLOT(slotChanged()));
     QWhatsThis::add( all_to_usr, i18n("Click here to add the highlighted user on the left to"
       " the list of selected users on the right, i.e. users that should in any case be shown in KDM's user list.") );
 
-    usr_to_all = new QPushButton( "<<", this );
-    rLayout->addWidget(usr_to_all, 2, 1);
+    QPushButton *usr_to_all = new QPushButton( "<<", this );
     usr_to_all->setFixedSize( sz );
     connect( usr_to_all, SIGNAL( clicked() ), SLOT( slotUsrToAll() ) );
-    connect( usr_to_all, SIGNAL(clicked()), this, SLOT(slotChanged()));
+    connect( usr_to_all, SIGNAL(clicked()), SLOT(slotChanged()));
     QWhatsThis::add( usr_to_all, i18n("Click here to remove the highlighted user from the list"
       " of selected users."));
 
-    rLayout->setRowStretch(3, 1);
-
-    all_to_no  = new QPushButton( ">>", this );
-    rLayout->addWidget(all_to_no, 5, 1);
+    QPushButton *all_to_no = new QPushButton( ">>", this );
     all_to_no->setFixedSize( sz );
     connect( all_to_no, SIGNAL( clicked() ), SLOT( slotAllToNo() ) );
-    connect( all_to_no, SIGNAL(clicked()), this, SLOT(slotChanged()));
+    connect( all_to_no, SIGNAL(clicked()), SLOT(slotChanged()));
     QWhatsThis::add( all_to_no, i18n("Click here to add the highlighted user on the left to the list"
       " of users explicitly not shown by KDM.") );
 
-    no_to_all = new QPushButton( "<<", this );
-    rLayout->addWidget(no_to_all, 6, 1);
+    QPushButton *no_to_all = new QPushButton( "<<", this );
     no_to_all->setFixedSize( sz );
     connect( no_to_all, SIGNAL( clicked() ), SLOT( slotNoToAll() ) );
-    connect( no_to_all, SIGNAL(clicked()), this, SLOT(slotChanged()));
+    connect( no_to_all, SIGNAL(clicked()), SLOT(slotChanged()));
     QWhatsThis::add( no_to_all, i18n("Click here to remove the highlighted user from the list"
       " of users explicitly not shown by KDM.") );
 
-    rLayout->setRowStretch(7, 1);
-
     remuserlb = new KListBox(this);
     a_label->setBuddy(remuserlb);
-    rLayout->addMultiCellWidget(remuserlb, 1, 7, 0, 0);
     wtstr = i18n("This is the list of users for which no explicit show policy has been set,"
       " i.e. they will only be shown by KDM if \"Show users\" is \"all but no-show\".");
     QWhatsThis::add( remuserlb, wtstr );
@@ -113,16 +107,14 @@ KDMUsersWidget::KDMUsersWidget(QWidget *parent, const char *name, QStringList *s
 
     userlb = new KListBox(this);
     s_label->setBuddy(userlb);
-    rLayout->addMultiCellWidget(userlb, 1, 3, 2, 2);
     wtstr = i18n("This is the list of users KDM will show in its login dialog in any case.");
     QWhatsThis::add( userlb, wtstr );
     QWhatsThis::add( s_label, wtstr );
 
     nouserlb = new KListBox(this);
     n_label->setBuddy(nouserlb);
-    rLayout->addMultiCellWidget(nouserlb, 5, 7, 2, 2);
     wtstr = i18n("This is the list of users KDM will not show in its login dialog."
-      " Users (except for root) with a user ID less than the one specified in the \"Hide UIDs below\" field will not be shown, too.");
+      " Users (except for root) with a user ID less than the one specified in the \"Hide UIDs\" fields will not be shown, too.");
     QWhatsThis::add( nouserlb, wtstr );
     QWhatsThis::add( n_label, wtstr );
 
@@ -133,22 +125,19 @@ KDMUsersWidget::KDMUsersWidget(QWidget *parent, const char *name, QStringList *s
     connect( nouserlb, SIGNAL( highlighted( const QString & ) ),
              SLOT( slotUserSelected( const QString & ) ) );
 
-    QVBoxLayout *lLayout = new QVBoxLayout(main, 10);
-    lLayout->addSpacing(20);
-
     userlabel = new QLabel(" ", this );
     userlabel->setAlignment(AlignCenter);
-    lLayout->addWidget(userlabel);
 
     userbutton = new KIconButton(this);
     userbutton->setAcceptDrops(true);
     userbutton->installEventFilter(this); // for drag and drop
     userbutton->setFixedSize(80, 80);
-    connect(userbutton, SIGNAL(iconChanged(QString)), SLOT(slotUserPixChanged(QString)));
-    connect(userbutton, SIGNAL(iconChanged(QString)), this, SLOT(slotChanged()));
+    connect(userbutton, SIGNAL(iconChanged(QString)),
+	    SLOT(slotUserPixChanged(QString)));
+    connect(userbutton, SIGNAL(iconChanged(QString)),
+	    SLOT(slotChanged()));
 
     QToolTip::add(userbutton, i18n("Click or drop an image here"));
-    lLayout->addWidget(userbutton);
     wtstr = i18n("Here you can see the username of the currently selected user and the"
       " image assigned to this user. Click on the image button to select from a list"
       " of images or drag and drop your own image onto the button (e.g. from Konqueror).");
@@ -156,8 +145,8 @@ KDMUsersWidget::KDMUsersWidget(QWidget *parent, const char *name, QStringList *s
     QWhatsThis::add( userbutton, wtstr );
 
     usrGroup = new QButtonGroup(5, Qt::Vertical, i18n("Show users"),  this );
-    connect(usrGroup, SIGNAL(clicked(int)), this, SLOT(slotShowUsers(int)));
-    connect(usrGroup, SIGNAL(clicked(int)), this, SLOT(slotChanged()));
+    connect(usrGroup, SIGNAL(clicked(int)), SLOT(slotShowUsers(int)));
+    connect(usrGroup, SIGNAL(clicked(int)), SLOT(slotChanged()));
     rbnoneusr = new QRadioButton(i18n("&None"), usrGroup );
     QWhatsThis::add(rbnoneusr, i18n("If this option is selected, KDM will not show any users."
       " If one of the alternative radio buttons is selected, KDM will show a list of users in its"
@@ -169,28 +158,55 @@ KDMUsersWidget::KDMUsersWidget(QWidget *parent, const char *name, QStringList *s
     rballusr = new QRadioButton( i18n("A&ll but no-show"), usrGroup );
     QWhatsThis::add( rballusr, i18n("If this option is selected, KDM will show all users but those"
       " who are listed in the \"no-show users\" listbox or have user ID less then the one specified"
-      " in the \"Hide UIDs below\" field (except root)."));
+      " in the \"Hide UIDs\" fields (except root)."));
     cbusrsrt = new QCheckBox(i18n("Sor&t users"), usrGroup);
-    connect(cbusrsrt, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+    connect(cbusrsrt, SIGNAL(toggled(bool)), SLOT(slotChanged()));
     QWhatsThis::add(cbusrsrt, i18n("This option tells KDM to alphabetically sort the users"
       " shown in its login dialog.") );
-    lLayout->addWidget( usrGroup );
 
-    minGroup = new QVGroupBox( i18n("Hide U&IDs below"), this );
-    QWhatsThis::add( minGroup, i18n("In \"All but no-show\"-mode all users with a user ID less than"
-      " this number are hidden. Note, that the root user is not affected by this and must be"
+    minGroup = new QGroupBox( 2, Horizontal, i18n("Hide U&IDs"), this );
+    QWhatsThis::add( minGroup, i18n("In \"All but no-show\"-mode all users with a user ID less/greater than"
+      " these numbers are hidden. Note, that the root user is not affected by this and must be"
       " explicitly listed in \"No-show users\" to be hidden."));
-    leminuid = new QLineEdit(minGroup);
-    leminuid->setSizePolicy(
-	QSizePolicy (QSizePolicy::Minimum, QSizePolicy::Preferred));
+    QSizePolicy sp_ign_fix(QSizePolicy::Ignored, QSizePolicy::Fixed);
     QValidator *valid = new QIntValidator(0, 999999, minGroup);
+    QLabel *minlab = new QLabel (i18n("below"), minGroup);
+    leminuid = new QLineEdit(minGroup);
+    connect(leminuid,SIGNAL(textChanged ( const QString & )),this,SLOT(slotChanged()));
+    minlab->setBuddy(leminuid);
+    leminuid->setSizePolicy(sp_ign_fix);
     leminuid->setValidator(valid);
-    lLayout->addWidget( minGroup );
+    QLabel *maxlab = new QLabel (i18n("above"), minGroup);
+    lemaxuid = new QLineEdit(minGroup);
+    maxlab->setBuddy(lemaxuid);
+    lemaxuid->setSizePolicy(sp_ign_fix);
+    lemaxuid->setValidator(valid);
+    connect(lemaxuid,SIGNAL(textChanged ( const QString & )),this,SLOT(slotChanged()));
 
-//    shwGroup = new QButtonGroup( 1, Qt::Vertical, this );
-//    lLayout->addWidget( shwGroup );
+    QHBoxLayout *main = new QHBoxLayout(this, 10);
 
-    lLayout->addStretch( 1 );
+    QGridLayout *lLayout = new QGridLayout(main, 4, 3, 10);
+    lLayout->addWidget(a_label, 0, 0);
+    lLayout->addWidget(s_label, 0, 2);
+    lLayout->addWidget(n_label, 4, 2);
+    lLayout->addWidget(all_to_usr, 1, 1);
+    lLayout->addWidget(usr_to_all, 2, 1);
+    lLayout->setRowStretch(3, 1);
+    lLayout->addWidget(all_to_no, 5, 1);
+    lLayout->addWidget(no_to_all, 6, 1);
+    lLayout->setRowStretch(7, 1);
+    lLayout->addMultiCellWidget(remuserlb, 1, 7, 0, 0);
+    lLayout->addMultiCellWidget(userlb, 1, 3, 2, 2);
+    lLayout->addMultiCellWidget(nouserlb, 5, 7, 2, 2);
+    main->setStretchFactor(lLayout, 1);
+
+    QVBoxLayout *rLayout = new QVBoxLayout( main, 10 );
+    rLayout->addSpacing( 20 );
+    rLayout->addWidget( userlabel, 0, AlignHCenter );
+    rLayout->addWidget( userbutton, 0, AlignHCenter );
+    rLayout->addWidget( usrGroup );
+    rLayout->addWidget( minGroup );
+    rLayout->addStretch( 1 );
 
     load(show_users);
 
@@ -202,6 +218,7 @@ KDMUsersWidget::KDMUsersWidget(QWidget *parent, const char *name, QStringList *s
 	rballusr->setEnabled(false);
 	cbusrsrt->setEnabled(false);
 	leminuid->setReadOnly(true);
+	lemaxuid->setReadOnly(true);
 	userbutton->setEnabled(false);
 	remuserlb->setEnabled(false);
 	nouserlb->setEnabled(false);
@@ -365,12 +382,12 @@ void KDMUsersWidget::slotUserSelected(const QString &user)
 
 void KDMUsersWidget::save()
 {
-    c->setGroup("X-*-Greeter");
+    config->setGroup("X-*-Greeter");
 
-    c->writeEntry( "SortUsers", cbusrsrt->isChecked() );
+    config->writeEntry( "SortUsers", cbusrsrt->isChecked() );
 
-    c->writeEntry( "ShowUsers", 
-	rballusr->isChecked() ? "All" :
+    config->writeEntry( "ShowUsers",
+	rballusr->isChecked() ? "NotHidden" :
 	rbselusr->isChecked() ? "Selected" : "None");
 
     QString nousrstr;
@@ -378,16 +395,17 @@ void KDMUsersWidget::save()
         nousrstr.append(nouserlb->text(i));
         nousrstr.append(",");
     }
-    c->writeEntry( "NoUsers", nousrstr );
+    config->writeEntry( "HiddenUsers", nousrstr );
 
     QString usrstr;
     for(uint i = 0, j = userlb->count(); i < j; i++) {
         usrstr.append(userlb->text(i));
         usrstr.append(",");
     }
-    c->writeEntry( "Users", usrstr );
+    config->writeEntry( "SelectedUsers", usrstr );
 
-    c->writeEntry( "MinShowUID", leminuid->text());
+    config->writeEntry( "MinShowUID", leminuid->text());
+    config->writeEntry( "MaxShowUID", lemaxuid->text());
 }
 
 #define CHECK_STRING( x) (x != 0 && x[0] != 0)
@@ -397,28 +415,27 @@ void KDMUsersWidget::load(QStringList *show_users)
     iconloader = KGlobal::iconLoader();
     QString str;
 
-    c->setGroup("X-*-Greeter");
+    config->setGroup("X-*-Greeter");
 
     // Read users from kdmrc and /etc/passwd
-    QStringList users = c->readListEntry( "Users");
+    QStringList users = config->readListEntry( "SelectedUsers");
     userlb->clear();
-    userlb->insertStringList(users);
+    for (QStringList::ConstIterator it = users.begin(), et = users.end();
+	 it != et; ++it)
+	if (getpwnam((*it).local8Bit()))
+	    userlb->insertItem(*it);
 
-    QStringList no_users = c->readListEntry( "NoUsers");
+    QStringList no_users = config->readListEntry( "HiddenUsers");
     nouserlb->clear();
     nouserlb->insertStringList(no_users);
 
     QStringList rem_users;
 
     struct passwd *ps;
-    for( setpwent(); (ps = getpwent()) != 0; ) {
-        if( CHECK_STRING(ps->pw_dir) && CHECK_STRING(ps->pw_shell) &&
-            ( no_users.contains( ps->pw_name) == 0)
-	) {
-	    // kapp->processEvents(50) makes layout calculation to fail
-	    // do we really need them here?
-            //  kapp->processEvents(50);
-
+    for (setpwent(); (ps = getpwent()) != 0; ) {
+        if (CHECK_STRING(ps->pw_dir) && CHECK_STRING(ps->pw_shell) &&
+            !no_users.contains( ps->pw_name))
+	{
 	    // "Convenience" tab -> Auto-login-able users
     	    show_users->append( QString::fromLocal8Bit(ps->pw_name));
 
@@ -434,11 +451,12 @@ void KDMUsersWidget::load(QStringList *show_users)
     remuserlb->clear();
     remuserlb->insertStringList(rem_users);
 
-    cbusrsrt->setChecked(c->readBoolEntry("SortUsers", true));
+    cbusrsrt->setChecked(config->readBoolEntry("SortUsers", true));
 
-    leminuid->setText(c->readEntry("MinShowUID", "0"));
+    leminuid->setText(config->readEntry("MinShowUID", "0"));
+    lemaxuid->setText(config->readEntry("MaxShowUID", "65535"));
 
-    QString su = c->readEntry( "ShowUsers");
+    QString su = config->readEntry( "ShowUsers");
     if (su == QString::fromLatin1("None")) {
 	rbnoneusr->setChecked(true);
 	slotShowUsers(0);
@@ -462,10 +480,13 @@ void KDMUsersWidget::defaults()
     rballusr->setChecked(true);
     slotShowUsers(2);
     leminuid->setText("0");
+    lemaxuid->setText("65535");
 }
 
 
 void KDMUsersWidget::slotChanged()
 {
-  emit KCModule::changed(true);
+  emit changed(true);
 }
+
+#include "kdm-users.moc"
