@@ -20,7 +20,7 @@
 #ifndef __KDMUSERS_H__
 #define __KDMUSERS_H__
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qlineedit.h>
 #include <qstring.h>
 #include <qimage.h>
@@ -35,10 +35,10 @@
 
 #include <pwd.h>
 
-#include <kcmodule.h>
+#include <qwidget.h>
 
 
-class KDMUsersWidget : public KCModule
+class KDMUsersWidget : public QWidget
 {
 	Q_OBJECT
 
@@ -51,6 +51,9 @@ public:
 
 	bool eventFilter(QObject *o, QEvent *e);
 
+signals:
+	void changed( bool state );
+
 protected:
 	void userButtonDragEnterEvent(QDragEnterEvent *e);
 	void userButtonDropEvent(QDropEvent *e);
@@ -74,7 +77,7 @@ private:
 	KIconLoader	*iconloader;
 	QButtonGroup	*usrGroup, *shwGroup;
 	QGroupBox	*minGroup;
-	QLineEdit	*leminuid;
+	QLineEdit	*leminuid, *lemaxuid;
 	QRadioButton	*rbnoneusr, *rbselusr, *rballusr;
 	QCheckBox	*cbusrsrt;
 	KIconButton	*userbutton;
