@@ -23,10 +23,17 @@
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
 #include <qvalidator.h>
+#include <qtoolbutton.h>
+#include <qdir.h>
+#include <qlistview.h>
+#include <qtooltip.h>
 
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
+#include <kdesktopfile.h>
+#include <kstandarddirs.h>
+#include <kiconloader.h>
 
 #include "menutab_impl.h"
 #include "menutab_impl.moc"
@@ -39,13 +46,11 @@ MenuTab::MenuTab( QWidget *parent, const char* name )
   : MenuTabBase (parent, name)
 {
     // connections
-    connect(m_clearCache, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(m_clearSlider, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(m_clearSpinBox, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+    connect(m_showPixmap, SIGNAL(clicked()), SIGNAL(changed()));
     connect(m_hiddenFiles, SIGNAL(clicked()), SIGNAL(changed()));
     connect(m_maxSlider, SIGNAL(valueChanged(int)), SIGNAL(changed()));
     connect(m_maxSpinBox, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(m_mergeLocations, SIGNAL(clicked()), SIGNAL(changed()));
+    connect(m_detailedEntries, SIGNAL(clicked()), SIGNAL(changed()));
     connect(m_showBookmarks, SIGNAL(clicked()), SIGNAL(changed()));
     connect(m_showRecent, SIGNAL(clicked()), SIGNAL(changed()));
     connect(m_showQuickBrowser, SIGNAL(clicked()), SIGNAL(changed()));
@@ -54,19 +59,13 @@ MenuTab::MenuTab( QWidget *parent, const char* name )
     m_pRecentOrderGroup->setRadioButtonExclusive(true);
     connect(m_pRecentOrderGroup, SIGNAL(clicked(int)), SIGNAL(changed()));
 
+    connect(m_addMenuBtn, SIGNAL(clicked()), SLOT(slotAddMenuClicked()));
+    connect(m_removeMenuBtn, SIGNAL(clicked()), SLOT(slotRemoveMenuClicked()));\
+    connect(m_availableMenus,SIGNAL(selectionChanged ()),SLOT(slotSelectionChanged()));
+
+    connect(m_selectedMenus,SIGNAL(selectionChanged ()),SLOT(slotSelectionChanged()));
 
     // whats this help
-    QWhatsThis::add(m_clearCache, i18n("The panel can cache information about menu entries instead "
-                                       "of reading it from disk every time you browse the menus. "
-                                       "This makes the panel menus react faster. "
-                                       "However, you might want to turn this off if you're short on memory."));
-
-    QString clearstr = i18n("If menu caching is turned on, you can set a delay after which "
-                            "the cache will be cleared.");
-
-    QWhatsThis::add(m_clearSlider, clearstr);
-    QWhatsThis::add(m_clearSpinBox, clearstr);
-
     QWhatsThis::add(m_hiddenFiles, i18n("If this option is enabled, hidden files (i.e. files beginning "
                                         "with a dot) will be shown in the QuickBrowser menus."));
 
@@ -78,13 +77,7 @@ MenuTab::MenuTab( QWidget *parent, const char* name )
     QWhatsThis::add(m_maxSlider, maxstr);
     QWhatsThis::add(m_maxSpinBox, maxstr);
 
-    QWhatsThis::add(m_mergeLocations, i18n("KDE can support several different locations "
-                                           "on the system for storing program "
-                                           "information, including (but not limited to) "
-                                           "a system-wide and a personal directory. "
-                                           "Enabling this option makes the KDE panel "
-                                           "merge these different locations into a "
-                                           "single logical tree of programs."));
+    QWhatsThis::add(m_detailedEntries, i18n("Toggle menu entry details."));
 
     QWhatsThis::add(m_showBookmarks, i18n("Enabling this option will make the panel show "
                                           "a bookmarks menu in your KDE menu"));
@@ -100,7 +93,18 @@ MenuTab::MenuTab( QWidget *parent, const char* name )
                                              "You can also add a Quick Browser "
                                              "as a panel button, using the panel context menu."));
 
+    QToolTip::add(m_addMenuBtn, i18n("Add selected item"));
+    QToolTip::add(m_removeMenuBtn, i18n("Remove selected item"));
+    QWhatsThis::add(m_availableMenus, i18n("The list of available dynamic menus that can be "
+                                           "plugged into the KDE menu. Use the buttons to add "
+                                           "or remove items."));
+    QWhatsThis::add(m_selectedMenus, i18n("The list of selected dynamic menus that will be added "
+                                          "to the KDE menu. Use the buttons to add or remove items. "));
+
     load();
+    //at the beginning we didn't select a item
+    m_addMenuBtn->setEnabled(false);
+    m_removeMenuBtn->setEnabled(false);
 }
 
 void MenuTab::load()
@@ -112,19 +116,16 @@ void MenuTab::load()
         configname.sprintf("kicker-screen-%drc", kickerconfig_screen_number);
     KConfig *c = new KConfig(configname, false, false);
 
-    c->setGroup("menus");
+    c->setGroup("KMenu");
 
-    bool cc = c->readBoolEntry("ClearMenuCache", true);
-    m_clearCache->setChecked(cc);
-    m_clearSlider->setValue(c->readNumEntry("MenuCacheTime", 60000) / 1000);
-    m_clearSlider->setEnabled(cc);
-    m_clearSpinBox->setValue(c->readNumEntry("MenuCacheTime", 60000) / 1000);
-    m_clearSpinBox->setEnabled(cc);
+    m_showPixmap->setChecked(c->readBoolEntry("UseSidePixmap", true));
+
+    c->setGroup("menus");
 
     m_maxSlider->setValue(c->readNumEntry("MaxEntries2", 30));
     m_maxSpinBox->setValue(c->readNumEntry("MaxEntries2", 30));
 
-    m_mergeLocations->setChecked(c->readBoolEntry("MergeKDEDirs", true));
+    m_detailedEntries->setChecked(c->readBoolEntry("DetailedMenuEntries", true));
     m_showBookmarks->setChecked(c->readBoolEntry("UseBookmarks", true));
     m_showRecent->setChecked(c->readBoolEntry("UseRecent", true));
     m_showQuickBrowser->setChecked(c->readBoolEntry("UseBrowser", true));
@@ -138,6 +139,29 @@ void MenuTab::load()
         m_pRecent->setChecked(true);
     else
         m_pOften->setChecked(true);
+
+    m_availableMenus->clear();
+    m_selectedMenus->clear();
+    QStringList ext = c->readListEntry("Extensions");
+    QListView *lv(0);
+    QStringList dirs = KGlobal::dirs()->findDirs("data", "kicker/menuext");
+    for (QStringList::ConstIterator dit=dirs.begin(); dit!=dirs.end(); ++dit)
+    {
+        QDir d(*dit, "*.desktop");
+        QStringList av = d.entryList();
+        QListViewItem *item(0);
+        for (QStringList::ConstIterator it=av.begin(); it!=av.end(); ++it)
+        {
+            KDesktopFile df(d.absFilePath(*it), true);
+            if (qFind(ext.begin(), ext.end(), *it) == ext.end())
+                lv = m_availableMenus;
+            else
+                lv = m_selectedMenus;
+            item = new QListViewItem(lv, item, df.readName(), *it);
+            item->setPixmap(0, SmallIcon(df.readIcon()));
+        }
+    }
+
     delete c;
 }
 
@@ -150,12 +174,15 @@ void MenuTab::save()
         configname.sprintf("kicker-screen-%drc", kickerconfig_screen_number);
     KConfig *c = new KConfig(configname, false, false);
 
+
+    c->setGroup("KMenu");
+
+    c->writeEntry("UseSidePixmap", m_showPixmap->isChecked());
+
     c->setGroup("menus");
 
-    c->writeEntry("ClearMenuCache", m_clearCache->isChecked());
-    c->writeEntry("MenuCacheTime", m_clearSlider->value() * 1000);
     c->writeEntry("MaxEntries2", m_maxSlider->value());
-    c->writeEntry("MergeKDEDirs", m_mergeLocations->isChecked());
+    c->writeEntry("DetailedMenuEntries", m_detailedEntries->isChecked());
     c->writeEntry("UseBookmarks", m_showBookmarks->isChecked());
     c->writeEntry("UseRecent", m_showRecent->isChecked());
     c->writeEntry("UseBrowser", m_showQuickBrowser->isChecked());
@@ -165,6 +192,15 @@ void MenuTab::save()
     bool bRecentVsOften = m_pRecent->isChecked();
     c->writeEntry("RecentVsOften", bRecentVsOften);
 
+    QStringList ext;
+    QListViewItem *item = m_selectedMenus->firstChild();
+    while (item)
+    {
+        ext << item->text(1);
+        item = item->nextSibling();
+    }
+    c->writeEntry("Extensions", ext);
+
     c->sync();
 
     delete c;
@@ -172,14 +208,10 @@ void MenuTab::save()
 
 void MenuTab::defaults()
 {
-  m_clearCache->setChecked(true);
-  m_clearSlider->setValue(60);
-  m_clearSlider->setEnabled(true);
-  m_clearSpinBox->setValue(60);
-  m_clearSpinBox->setEnabled(true);
+  m_showPixmap->setChecked(true);
   m_maxSlider->setValue(30);
   m_maxSpinBox->setValue(30);
-  m_mergeLocations->setChecked(true);
+  m_detailedEntries->setChecked(true);
   m_showRecent->setChecked(true);
   m_showQuickBrowser->setChecked(true);
   m_hiddenFiles->setChecked(false);
@@ -188,3 +220,40 @@ void MenuTab::defaults()
   m_pOften->setChecked(true);
   m_num2ShowSpinBox->setValue(5);
 }
+
+void MenuTab::slotAddMenuClicked()
+{
+    QListViewItem *item = m_availableMenus->currentItem();
+    if (item)
+    {
+        QListViewItem *newItem = new QListViewItem(m_selectedMenus, m_selectedMenus->lastItem(), item->text(0), item->text(1));
+        if (item->pixmap(0))
+            newItem->setPixmap(0, *(item->pixmap(0)));
+        delete item;
+
+        emit changed();
+    }
+}
+
+void MenuTab::slotRemoveMenuClicked()
+{
+    QListViewItem *item = m_selectedMenus->currentItem();
+    if (item)
+    {
+        QListViewItem *newItem = new QListViewItem(m_availableMenus, m_availableMenus->lastItem(), item->text(0), item->text(1));
+        if (item->pixmap(0))
+            newItem->setPixmap(0, *(item->pixmap(0)));
+        delete item;
+
+        emit changed();
+    }
+}
+
+void MenuTab::slotSelectionChanged()
+{
+    QListViewItem *item = m_selectedMenus->currentItem();
+    m_removeMenuBtn->setEnabled(item);
+
+    item=m_availableMenus->currentItem();
+    m_addMenuBtn->setEnabled(item);
+}
