@@ -33,6 +33,11 @@ public:
 
 signals:
     void changed();
+
+protected slots:
+    void slotAddMenuClicked();
+    void slotRemoveMenuClicked();
+    void slotSelectionChanged();
 };
 
 #endif
