@@ -7,12 +7,9 @@
 #include <qtabwidget.h>
 
 #include <klocale.h>
-#include <kapp.h>
-#include <kbuttonbox.h>
+#include <kapplication.h>
 #include <kmessagebox.h>
-#include <kprocess.h>
 #include <kdebug.h>
-#include <ksimpleconfig.h>
 #include <dcopclient.h>
 
 #include "kcookiesmain.h"
@@ -29,7 +26,7 @@ KCookiesMain::KCookiesMain(QWidget *parent, const char *name)
         if (KApplication::startServiceByDesktopName("kcookiejar", QStringList(), &error ))
         {
           kdDebug(7103) << "kcm_kio: error starting KCookiejar: " << error << "\n" << endl;
-          KMessageBox::sorry(0, i18n("This control module could not start the cookie server process\n"
+          KMessageBox::sorry(0, i18n("This control module could not start the cookie server process.\n"
                                      "It will not be possible to manage received cookies"));
           managerOK = false;
         }
@@ -83,7 +80,7 @@ void KCookiesMain::moduleChanged()
 QString KCookiesMain::quickHelp() const
 {
   return i18n("<h1>Cookies</h1> Cookies contain information that Konqueror"
-    " (or other KDE applications using the http protocol) stores on your"
+    " (or other KDE applications using the HTTP protocol) stores on your"
     " computer, initiated by a remote Internet server. This means that"
     " a web server can store information about you and your browsing activities"
     " on your machine for later use. You might consider this an invasion of"
