@@ -82,8 +82,8 @@ private slots:
 
 private:
     bool getCookieDetails(CookieProp *cookie);
-    bool checkCookiejarStatus();
     void clearCookieDetails();
+    bool checkCookiejarStatus();
 
     QLineEdit* le_name;
     QLineEdit* le_value;
@@ -98,11 +98,11 @@ private:
     QPushButton* btn_reload;
     QPushButton* btn_deleteAll;
 
-    DCOPClient* m_dcopClient;
+    DCOPClient* dcop;
     bool m_bDeleteAll;
 
     QStringList deletedDomains;
-    typedef QList<CookieProp> CookiePropList;
+    typedef QPtrList<CookieProp> CookiePropList;
     QDict<CookiePropList> deletedCookies;
 };
 
