@@ -2,14 +2,14 @@
 // code adapted from other option dialogs
 
 #ifndef __KSMBOPTDLG_H
-#define __KSMBOPTDLG_H "$Id: ksmboptdlg.h,v 1.8 2000/07/17 15:33:35 kalle Exp $"
+#define __KSMBOPTDLG_H "$Id: ksmboptdlg.h,v 1.9 2001/09/12 11:53:41 mlaurent Exp $"
 
 #include <qwidget.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qhbuttongroup.h>
 #include <qradiobutton.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qlistbox.h>
 
 #include <kcmodule.h>
@@ -85,7 +85,7 @@ private:
 		Item(const QString &e, const QString& h, const QString& l, const QString& p);
 	};
 	friend class Item;
-	QList<Item> bindings;
+	QPtrList<Item> bindings;
 };
 
 #endif // __KSMBOPTDLG_H
