@@ -1,5 +1,5 @@
 /*
-    $Id: events.cpp,v 1.10 2001/01/14 21:57:41 pfeiffer Exp $
+    $Id: events.cpp,v 1.11 2001/10/23 22:50:35 mueller Exp $
 
     Copyright (C) 2000 Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -20,13 +20,11 @@
 
 */
 
-#include <qstringlist.h>
 
 #include <kconfig.h>
 #include <kdebug.h>
-#include <kglobal.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include "events.h"
 
