@@ -1,5 +1,5 @@
 /*
-    $Id: knotify.cpp,v 1.43 2001/02/05 06:42:23 waba Exp $
+    $Id: knotify.cpp,v 1.53 2002/02/19 17:27:52 coolo Exp $
 
     Copyright (C) 2000 Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -20,39 +20,39 @@
 
 */
 
-#include <qdir.h>
-#include <qglobal.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qpushbutton.h>
-#include <qsplitter.h>
+#include <qslider.h>
 #include <qtimer.h>
 #include <qvgroupbox.h>
 
 #include <kaboutdata.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaudioplayer.h>
 #include <kcursor.h>
 #include <kdebug.h>
-#include <kdialog.h>
 #include <kfiledialog.h>
-#include <kglobal.h>
 #include <kiconloader.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <knotifyclient.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kurlcompletion.h>
 #include <kurlrequester.h>
+#include <kgenericfactory.h>
 
 #include "knotify.h"
+#include <dcopclient.h>
 #include "knotify.moc"
 
 static const int COL_FILENAME = 1;
 
-KNotifyWidget::KNotifyWidget(QWidget *parent, const char *name):
-    KCModule(parent, name)
+typedef KGenericFactory<KNotifyWidget, QWidget> NotifyFactory;
+K_EXPORT_COMPONENT_FACTORY( kcm_knotify, NotifyFactory("kcmnotify") );
+
+KNotifyWidget::KNotifyWidget(QWidget *parent, const char *name, const QStringList & ):
+    KCModule(NotifyFactory::instance(), parent, name)
 {
     updating = true;
     currentItem = 0L;
@@ -101,6 +101,18 @@ KNotifyWidget::KNotifyWidget(QWidget *parent, const char *name):
     connect( reqExternal, SIGNAL( textChanged( const QString& )),
 	     SLOT( changed() ));
 
+    hbox = new QHBox( box );
+    hbox->setSpacing( KDialog::spacingHint() );
+    l = new QLabel( i18n( "&Volume: " ), hbox );
+    volumeSlider = new QSlider( hbox );
+    volumeSlider->setOrientation( Horizontal );
+    volumeSlider->setRange( 0, 100 );
+    connect( volumeSlider, SIGNAL( valueChanged( int ) ), SLOT( changed() ) );
+    l->setBuddy( volumeSlider );
+
+    soundButton = new QPushButton( box );
+    // this is configured in updateView
+
     m_events = new Events();
     qApp->processEvents(); // let's show up
 
@@ -126,6 +138,7 @@ void KNotifyWidget::updateView()
     QListViewItem *appItem = 0L;
     KNListViewItem *eItem  = 0L;
     KNEvent *e;
+    bool soundsDisabled = true;
 
     QPixmap icon = SmallIcon("idea");
 
@@ -137,6 +150,8 @@ void KNotifyWidget::updateView()
 
 	KNEventListIterator it2( *(*it)->eventList() );
 	while( (e = it2.current()) ) {
+	    if(e->presentation & KNotifyClient::Sound) soundsDisabled = false;
+
 	    eItem = new KNListViewItem( appItem, eItem, e );
 	    eItem->setPixmap( 0, icon );
 
@@ -147,6 +162,18 @@ void KNotifyWidget::updateView()
 	++it;
     }
     updating = save_updating;
+
+	soundButton->disconnect(this);
+	if(soundsDisabled)
+	{
+		soundButton->setText( i18n("&Enable All Sounds") );
+		connect(soundButton, SIGNAL(clicked()), this, SLOT(enableAllSounds()));
+	}
+	else
+	{
+		soundButton->setText( i18n("&Disable All Sounds") );
+		connect(soundButton, SIGNAL(clicked()), this, SLOT(disableAllSounds()));
+	}
 }
 
 
@@ -214,6 +241,8 @@ void KNotifyWidget::load()
     cbExternal->setChecked( kc->readBoolEntry( "Use external player", false ));
     reqExternal->setURL( kc->readEntry( "External player" ));
     reqExternal->setEnabled( cbExternal->isChecked() );
+    volumeSlider->setValue( kc->readNumEntry( "Volume", 100 ) );
+    static_cast<QHBox *>( volumeSlider->parent() )->setEnabled( !cbExternal->isChecked() );
     delete kc;
 
     requester->clear();
@@ -236,6 +265,7 @@ void KNotifyWidget::save()
     kc->setGroup( "Misc" );
     kc->writeEntry( "External player", reqExternal->url() );
     kc->writeEntry( "Use external player", cbExternal->isChecked() );
+    kc->writeEntry( "Volume", volumeSlider->value() );
     kc->sync();
     delete kc;
 	
@@ -283,6 +313,7 @@ void KNotifyWidget::externalClicked( bool on )
     if ( on )
 	reqExternal->setFocus();
     reqExternal->setEnabled( on );
+    static_cast<QHBox *>( volumeSlider->parent() )->setEnabled( !on );
     changed();
 }
 
@@ -290,13 +321,13 @@ QString KNotifyWidget::quickHelp() const
 {
     return i18n("<h1>System Notifications</h1>"
 		"KDE allows for a great deal of control over how you "
-		"will be notified when certain events occur.  There are "
+		"will be notified when certain events occur. There are "
 		"several choices as to how you are notified:"
 		"<ul><li>As the application was originally designed."
 		"<li>With a beep or other noise."
 		"<li>Via a popup dialog box with additional information."
 		"<li>By recording the event in a logfile without "
-		"any additional visual or auditory alert."
+		"any additional visual or audible alert."
 		"</ul>");
 }
 
@@ -323,6 +354,8 @@ void KNotifyWidget::slotRequesterClicked( KURLRequester *requester )
     static bool init = true;
     if ( !init )
 	return;
+
+    init = false;
     
     // find the first "sound"-resource that contains files
     QStringList soundDirs = KGlobal::dirs()->resourceDirs( "sound" );
@@ -343,7 +376,32 @@ void KNotifyWidget::slotRequesterClicked( KURLRequester *requester )
     }
 }
 
+void KNotifyWidget::disableAllSounds()
+{
+	for(KNApplicationListIterator app(m_events->apps()); app.current(); ++app)
+	{
+		for(KNEventListIterator event(*(*app)->eventList()); event.current(); ++event)
+		{
+			(*event)->presentation &= ~KNotifyClient::Sound;
+		}
+	}
+	updateView();
+	changed();
+}
 
+void KNotifyWidget::enableAllSounds()
+{
+	for(KNApplicationListIterator app(m_events->apps()); app.current(); ++app)
+	{
+		for(KNEventListIterator event(*(*app)->eventList()); event.current(); ++event)
+		{
+			if(!(*event)->soundfile.isNull())
+				(*event)->presentation |= KNotifyClient::Sound;
+		}
+	}
+	updateView();
+	changed();
+}
 ///////////////////////////////////////////////////////////////////
 
 /**
