@@ -1,5 +1,5 @@
 /*
-    $Id: knotify.h,v 1.17 2001/04/20 00:30:40 malte Exp $
+    $Id: knotify.h,v 1.20 2002/01/30 01:49:35 neil Exp $
 
     Copyright (C) Charles Samuels <charles@altair.dhs.org>
                   2000 Carsten Pfeiffer <pfeiffer@kde.org>
@@ -29,6 +29,7 @@
 #include <qlistview.h>
 #include <qstring.h>
 #include <qtooltip.h>
+#include <qpushbutton.h>
 
 #include <kcmodule.h>
 
@@ -44,7 +45,7 @@ class KNotifyWidget : public KCModule
     Q_OBJECT
 
 public:
-    KNotifyWidget(QWidget *parent, const char *name);
+    KNotifyWidget(QWidget *parent, const char *name, const QStringList &);
     virtual ~KNotifyWidget();
 
     void defaults();
@@ -54,6 +55,8 @@ public:
 
 public slots:
     virtual void load();
+    void disableAllSounds();
+    void enableAllSounds();
 
 private slots:
     void slotRequesterClicked( KURLRequester * );
@@ -70,7 +73,7 @@ private:
     QCheckBox *cbExternal;
     QListView *view;
     KURLRequester *requester, *reqExternal;
-    QPushButton *playButton;
+    QPushButton *playButton, *soundButton;
     QSlider *volumeSlider;
     Events *m_events;
     KNCheckListItem *currentItem;
