@@ -23,7 +23,6 @@
 #include <qwhatsthis.h>
 #include <qslider.h>
 
-#include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdialog.h>
@@ -37,8 +36,7 @@ extern "C"
 {
   KCModule *create_virtualdesktops(QWidget *parent, const char *name)
   {
-    KGlobal::locale()->insertCatalogue("kcmkonq");
-    return new KDesktopConfig(parent, name);
+    return new KDesktopConfig(parent, "kcmkonq");
   };
 }
 
@@ -48,7 +46,7 @@ extern "C"
 // asking why I did not implement a more intelligent/smaller GUI.
 
 KDesktopConfig::KDesktopConfig(QWidget *parent, const char *name)
-  : KCModule(parent, name)
+  : KCModule(parent, "kcmkonq")
 {
   QVBoxLayout *layout = new QVBoxLayout(this,
                     KDialog::marginHint(),
@@ -61,7 +59,7 @@ KDesktopConfig::KDesktopConfig(QWidget *parent, const char *name)
                      KDialog::marginHint(),
                      KDialog::spacingHint());
 
-  QLabel *label = new QLabel(i18n("&Number of Desktops: "), number_group);
+  QLabel *label = new QLabel(i18n("N&umber of Desktops: "), number_group);
   _numLabel = new QLabel("4", number_group);
   _numSlider = new QSlider(1, 16, 1, 4, Horizontal, number_group);
   connect(_numSlider, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
@@ -89,8 +87,8 @@ KDesktopConfig::KDesktopConfig(QWidget *parent, const char *name)
 
   for(int i = 0; i < 8; i++)
     {
-      _nameLabel[i] = new QLabel(i18n("Desktop%1:").arg(i+1), name_group);
-      _nameLabel[i+8] = new QLabel(i18n("Desktop%1:").arg(i+8+1), name_group);
+      _nameLabel[i] = new QLabel(i18n("Desktop %1:").arg(i+1), name_group);
+      _nameLabel[i+8] = new QLabel(i18n("Desktop %1:").arg(i+8+1), name_group);
       _nameInput[i] = new KLineEdit(name_group);
       _nameInput[i+8] = new KLineEdit(name_group);
       QWhatsThis::add( _nameLabel[i], i18n( "Here you can enter the name for desktop %1" ).arg( i+1 ) );
