@@ -17,18 +17,11 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <qbuttongroup.h>
 #include <qcheckbox.h>
-#include <qcolor.h>
-#include <qcombobox.h>
-#include <qspinbox.h>
 #include <qlabel.h>
 #include <qlayout.h>//CT - 12Nov1998
-#include <qradiobutton.h>
 #include <qwhatsthis.h>
-#include <kglobal.h>
 #include <kglobalsettings.h>
-#include <kdialog.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kcolorbutton.h>
@@ -40,11 +33,12 @@
 #include <konq_defaults.h> // include default values directly from konqueror
 #include <klocale.h>
 #include <kfontdialog.h>
+#include <kfontcombo.h>
 
 //-----------------------------------------------------------------------------
 
 KonqFontOptions::KonqFontOptions(KConfig *config, QString group, bool desktop, QWidget *parent, const char *name)
-    : KCModule( parent, name ), g_pConfig(config), groupname(group), m_bDesktop(desktop)
+    : KCModule( parent, "kcmkonq" ), g_pConfig(config), groupname(group), m_bDesktop(desktop)
 {
     QLabel *label;
     QString wtstr;
@@ -58,10 +52,10 @@ KonqFontOptions::KonqFontOptions(KConfig *config, QString group, bool desktop, Q
     lay->setColStretch(LASTCOLUMN,10);
 
     row++;
-    label = new QLabel( i18n("Standard Font"), this );
-    lay->addWidget(label,row,0);
 
-    m_pStandard = new QComboBox( false, this );
+    m_pStandard = new KFontCombo( this );
+    label = new QLabel( m_pStandard, i18n("&Standard Font:"), this );
+    lay->addWidget(label,row,0);
     lay->addMultiCellWidget(m_pStandard,row,row,1,1);
 
     wtstr = i18n("This is the font used to display text in Konqueror windows.");
@@ -69,18 +63,14 @@ KonqFontOptions::KonqFontOptions(KConfig *config, QString group, bool desktop, Q
     QWhatsThis::add( m_pStandard, wtstr );
 
     row++;
-    KFontChooser::getFontList(standardFonts, false);
-    m_pStandard->insertStringList( standardFonts );
     connect( m_pStandard, SIGNAL( activated(const QString&) ),
              SLOT( slotStandardFont(const QString&) ) );
     connect( m_pStandard, SIGNAL( activated(const QString&) ),
              SLOT(changed() ) );
 
-
-    label = new QLabel( i18n("Font Size"), this );
-    lay->addWidget(label,row,0);
-
     m_pSize = new QSpinBox( 4,18,1,this );
+    label = new QLabel( m_pSize, i18n("Font Si&ze:"), this );
+    lay->addWidget(label,row,0);
     lay->addMultiCellWidget(m_pSize,row,row,1,1);
 
     connect( m_pSize, SIGNAL( valueChanged(int) ),
@@ -93,10 +83,9 @@ KonqFontOptions::KonqFontOptions(KConfig *config, QString group, bool desktop, Q
 
     //
 #define COLOR_BUTTON_COL 1
-    label = new QLabel( i18n("Normal Text Color:"), this );
-    lay->addWidget(label,row,0);
-
     m_pNormalText = new KColorButton( normalTextColor, this );
+    label = new QLabel( m_pNormalText, i18n("Normal Te&xt Color:"), this );
+    lay->addWidget(label,row,0);
     lay->addWidget(m_pNormalText,row,COLOR_BUTTON_COL,Qt::AlignLeft);
 
     wtstr = i18n("This is the color used to display text in Konqueror windows.");
@@ -267,13 +256,7 @@ void KonqFontOptions::updateGUI()
     if ( stdName.isEmpty() )
         stdName = KGlobalSettings::generalFont().family();
 
-    QStringList::Iterator sit = standardFonts.begin();
-    int i;
-    for ( i = 0; sit != standardFonts.end(); ++sit, i++ )
-    {
-        if ( stdName == (*sit) )
-            m_pStandard->setCurrentItem( i );
-    }
+    m_pStandard->setCurrentFont( stdName );
     m_pSize->setValue( fSize );
 }
 
