@@ -14,30 +14,31 @@
 
 #include <config.h>
 
-#include <qdir.h>
-#include <dcopclient.h>
-#include <kapp.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kglobalsettings.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kio/global.h>
-#include <kio/job.h>
-#include <kmessagebox.h>
-#include <kstddirs.h>
-#include <kipc.h>
-#include <ktrader.h>
-#include <kseparator.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
+#include <qdir.h>
+#include <qgrid.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlineedit.h>
+#include <qvgroupbox.h>
 #include <qwhatsthis.h>
-#include <qtl.h>
-#include <qlistview.h>
-#include <assert.h>
+
+#include <kapplication.h>
+#include <kconfig.h>
+#include <kdebug.h>
+#include <kdialog.h>
+#include <kglobalsettings.h>
+#include <klistview.h>
+#include <klocale.h>
+#include <kipc.h>
+#include <kmessagebox.h>
+#include <ktrader.h>
+#include <kseparator.h>
+#include <kstandarddirs.h>
+#include <kurlrequester.h>
+
+#include <dcopclient.h>
+#include <kio/job.h>
 
 #include "rootopts.h"
 
@@ -80,22 +81,28 @@ private:
 
 static const char * s_choices[6] = { "", "WindowListMenu", "DesktopMenu", "AppMenu", "CustomMenu1", "CustomMenu2" };
 
-KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
-    : KCModule( parent, name ), g_pConfig(config)
+KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char * )
+    : KCModule( parent, "kcmkonq" ), g_pConfig(config)
 {
   QLabel * tmpLabel;
-#define RO_LASTROW 15   // 4 cb, 1 listview, 1 line, 3 combo, 1 line, 4 paths + last row
+
+#define RO_LASTROW 2   // 2 GroupBoxes + last row = 3 rows. But it starts at 0 ;)
 #define RO_LASTCOL 2
   int row = 0;
-  QGridLayout *lay = new QGridLayout(this, RO_LASTROW+1, RO_LASTCOL+1, 10);
+  QGridLayout *lay = new QGridLayout(this, RO_LASTROW+1, RO_LASTCOL+1, KDialog::spacingHint());
   QString strMouseButton1, strMouseButton3, strButtonTxt1, strButtonTxt3;
   bool leftHandedMouse;
 
-  lay->setRowStretch(RO_LASTROW,10); // last line grows
+  lay->setRowStretch(RO_LASTROW, 10); // last line grows
 
+  /*
   lay->setColStretch(0,0);
   lay->setColStretch(1,0);
   lay->setColStretch(2,10);
+  */
+
+  QGroupBox *groupBox = new QVGroupBox(i18n("Misc Options"), this);
+  lay->addWidget(groupBox, 0, 0);
 
   /*
    * The text on this form depends on the mouse setting, which can be right
@@ -104,19 +111,31 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
    */
   leftHandedMouse = ( KGlobalSettings::mouseSettings().handed == KGlobalSettings::KMouseSettings::LeftHanded);
 
-  VertAlignBox = new QCheckBox(i18n("Align Icons &Vertically on Desktop"), this);
-  lay->addMultiCellWidget(VertAlignBox, row, row, 0, 0);
-  connect(VertAlignBox, SIGNAL(clicked()), this, SLOT(changed()));
-  QWhatsThis::add( VertAlignBox, i18n("Check this option if you want the icons"
+
+  menuBarBox = new QCheckBox(i18n("Enable Desktop &Menu"), groupBox);
+  connect(menuBarBox, SIGNAL(clicked()), this, SLOT(changed()));
+  QWhatsThis::add( menuBarBox, i18n("Check this option if you want the"
+                                    " desktop popup menus to appear at the top of the screen in the style"
+                                    " of Macintosh. This setting is independent of the global top-level"
+                                    " menu setting that applies to KDE applications.") );
+
+  iconsEnabledBox = new QCheckBox(i18n("Enable &Icons on Desktop"), groupBox);
+  connect(iconsEnabledBox, SIGNAL(clicked()), this, SLOT(enableChanged()));
+  QWhatsThis::add( iconsEnabledBox, i18n("Uncheck this option if you do not want to have icons on the desktop."
+                                      " Without icons the desktop will be somewhat faster but you will no"
+                                      " longer be able to drag files to the desktop." ) );
+
+
+  vertAlignBox = new QCheckBox(i18n("Align Icons &Vertically on Desktop"), groupBox);
+  connect(vertAlignBox, SIGNAL(clicked()), this, SLOT(changed()));
+  QWhatsThis::add( vertAlignBox, i18n("Check this option if you want the icons"
                                       " on the desktop to be aligned vertically (in columns). If you leave this"
                                       " option unchecked, desktop icons are aligned horizontally.<p>"
                                       " Note that you can drag icons wherever you want to on the desktop. When"
                                       " you choose \"Arrange Icons\" from the Desktop menu, icons will be"
                                       " arranged horizontally or vertically.") );
 
-  row++;
-  showHiddenBox = new QCheckBox(i18n("Show &Hidden Files on Desktop"), this);
-  lay->addMultiCellWidget(showHiddenBox, row, row, 0, 0);
+  showHiddenBox = new QCheckBox(i18n("Show H&idden Files on Desktop"), groupBox);
   connect(showHiddenBox, SIGNAL(clicked()), this, SLOT(changed()));
   QWhatsThis::add( showHiddenBox, i18n("If you check this option, any files"
                                        " in your desktop directory that begin with a period (.) will be shown."
@@ -128,45 +147,32 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
                                        " You should not change or delete these files unless you know what you"
                                        " are doing!") );
 
-  row++;
-  menuBarBox = new QCheckBox(i18n("Enable Desktop &Menu"), this);
-  lay->addMultiCellWidget(menuBarBox, row, row, 0, 0);
-  connect(menuBarBox, SIGNAL(clicked()), this, SLOT(changed()));
-  QWhatsThis::add( menuBarBox, i18n("Check this option if you want the"
-                                    " desktop popup menus to appear on the top of the screen in the style"
-                                    " of Macintosh.  This setting is independent of the global top-level"
-                                    " menu setting that applies to KDE applications.") );
-
-  row++;
-  vrootBox = new QCheckBox(i18n("Support Programs in Desktop Window"), this);
-  lay->addMultiCellWidget(vrootBox, row, row, 0, 0);
+  vrootBox = new QCheckBox(i18n("Pr&ograms in Desktop Window"), groupBox);
   connect(vrootBox, SIGNAL(clicked()), this, SLOT(changed()));
   QWhatsThis::add( vrootBox, i18n("Check this option if you want to"
                                     " run X11 programs that draw into the desktop such as xsnow, xpenguin or"
                                     " xmountain. If you have problems with applications like netscape that check"
                                     " the root window for running instances, disable this option.") );
 
-  row++;
-  lay->setRowStretch( row, 10 );
-  previewListView = new QListView( this );
+  previewListView = new KListView( this );
+  previewListView->setFullWidth(true);
   previewListView->addColumn( i18n("Show Previews for:") );
-  lay->addMultiCellWidget( previewListView, row - 4, row, 1, RO_LASTCOL );
   QWhatsThis::add(previewListView, i18n("Select for which types of files you want to"
                                         " enable preview images"));
 
-  row++;
-  KSeparator * hLine2 = new KSeparator(KSeparator::HLine, this);
-  lay->addMultiCellWidget(hLine2, row, row, 0, RO_LASTCOL);
+  lay->addWidget(previewListView, row, RO_LASTCOL);
 
   row++;
-  tmpLabel = new QLabel( i18n("Clicks on the desktop"), this );
-  lay->addMultiCellWidget( tmpLabel, row, row, 0, RO_LASTCOL );
+  groupBox = new QVGroupBox( i18n("Clicks on the desktop"), this );
+  lay->addMultiCellWidget( groupBox, row, row, 0, RO_LASTCOL );
 
-  strMouseButton1 = i18n("Left Button");
+  QGrid * grid = new QGrid(2, groupBox);
+
+  strMouseButton1 = i18n("Left Button:");
   strButtonTxt1 = i18n( "You can choose what happens when"
    " you click the left button of your pointing device on the desktop:");
 
-  strMouseButton3 = i18n("Right Button");
+  strMouseButton3 = i18n("Right Button:");
   strButtonTxt3 = i18n( "You can choose what happens when"
    " you click the right button of your pointing device on the desktop:");
 
@@ -176,12 +182,9 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
      qSwap(strButtonTxt1, strButtonTxt3);
   }
 
-  row++;
-  tmpLabel = new QLabel( strMouseButton1, this );
-  lay->addWidget( tmpLabel, row, 0 );
-  leftComboBox = new QComboBox( this );
+  tmpLabel = new QLabel( strMouseButton1, grid );
+  leftComboBox = new QComboBox( grid );
   tmpLabel->setBuddy( leftComboBox );
-  lay->addWidget( leftComboBox, row, 1 );
   fillMenuCombo( leftComboBox );
   connect(leftComboBox, SIGNAL(activated(int)), this, SLOT(changed()));
   QString wtstr = strButtonTxt1 +
@@ -201,12 +204,9 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   QWhatsThis::add( tmpLabel, wtstr );
   QWhatsThis::add( leftComboBox, wtstr );
 
-  row++;
-  tmpLabel = new QLabel( i18n("Middle button"), this );
-  lay->addWidget( tmpLabel, row, 0 );
-  middleComboBox = new QComboBox( this );
+  tmpLabel = new QLabel( i18n("Middle Button:"), grid );
+  middleComboBox = new QComboBox( grid );
   tmpLabel->setBuddy( middleComboBox );
-  lay->addWidget( middleComboBox, row, 1 );
   fillMenuCombo( middleComboBox );
   connect(middleComboBox, SIGNAL(activated(int)), this, SLOT(changed()));
   wtstr = i18n("You can choose what happens when"
@@ -227,12 +227,9 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   QWhatsThis::add( tmpLabel, wtstr );
   QWhatsThis::add( middleComboBox, wtstr );
 
-  row++;
-  tmpLabel = new QLabel( strMouseButton3, this );
-  lay->addWidget( tmpLabel, row, 0 );
-  rightComboBox = new QComboBox( this );
+  tmpLabel = new QLabel( strMouseButton3, grid );
+  rightComboBox = new QComboBox( grid );
   tmpLabel->setBuddy( rightComboBox );
-  lay->addWidget( rightComboBox, row, 1 );
   fillMenuCombo( rightComboBox );
   connect(rightComboBox, SIGNAL(activated(int)), this, SLOT(changed()));
   wtstr = strButtonTxt3 +
@@ -252,75 +249,15 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   QWhatsThis::add( tmpLabel, wtstr );
   QWhatsThis::add( rightComboBox, wtstr );
 
-  // Desktop Paths
-
-  row++;
-  KSeparator* hLine = new KSeparator(KSeparator::HLine, this);
-  lay->addMultiCellWidget(hLine, row, row, 0, RO_LASTCOL);
-
-  row++;
-  tmpLabel = new QLabel(i18n("Desktop &path:"), this);
-  lay->addWidget(tmpLabel, row, 0);
-  leDesktop = new QLineEdit(this);
-  tmpLabel->setBuddy( leDesktop );
-  lay->addMultiCellWidget(leDesktop, row, row, 1, RO_LASTCOL);
-  connect(leDesktop, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
-  QWhatsThis::add( leDesktop, i18n("This directory contains all the files"
-                                   " which you see on your desktop. You can change the location of this"
-                                   " directory if you want to, and the contents will move automatically"
-                                   " to the new location as well.") );
-
-  row++;
-  tmpLabel = new QLabel(i18n("&Trash path:"), this);
-  lay->addWidget(tmpLabel, row, 0);
-  leTrash = new QLineEdit(this);
-  tmpLabel->setBuddy( leTrash );
-  lay->addMultiCellWidget(leTrash, row, row, 1, RO_LASTCOL);
-  connect(leTrash, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
-  wtstr = i18n("This directory contains deleted files (until"
-               " you empty the trashcan). You can change the location of this"
-               " directory if you want to, and the contents will move automatically"
-               " to the new location as well.");
-  QWhatsThis::add( tmpLabel, wtstr );
-  QWhatsThis::add( leTrash, wtstr );
-
-  row++;
-  tmpLabel = new QLabel(i18n("&Autostart path:"), this);
-  lay->addWidget(tmpLabel, row, 0);
-  leAutostart = new QLineEdit(this);
-  tmpLabel->setBuddy( leAutostart );
-  lay->addMultiCellWidget(leAutostart, row, row, 1, RO_LASTCOL);
-  connect(leAutostart, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
-  wtstr = i18n("This directory contains applications or"
-               " links to applications (shortcuts) that you want to have started"
-               " automatically whenever KDE starts. You can change the location of this"
-               " directory if you want to, and the contents will move automatically"
-               " to the new location as well.");
-  QWhatsThis::add( tmpLabel, wtstr );
-  QWhatsThis::add( leAutostart, wtstr );
-
-  row++;
-  tmpLabel = new QLabel(i18n("&Documents path:"), this);
-  lay->addWidget(tmpLabel, row, 0);
-  leDocument = new QLineEdit(this);
-  tmpLabel->setBuddy( leDocument );
-  lay->addMultiCellWidget(leDocument, row, row, 1, RO_LASTCOL);
-  connect(leDocument, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
-  wtstr = i18n("This directory will be used by default to "
-               "load or save documents from or to.");
-  QWhatsThis::add( tmpLabel, wtstr );
-  QWhatsThis::add( leDocument, wtstr );
-
   // -- Bottom --
-  assert( row == RO_LASTROW-1 ); // if it fails here, check the row++ and RO_LASTROW above
-  lay->activate();
+  Q_ASSERT( row == RO_LASTROW-1 ); // if it fails here, check the row++ and RO_LASTROW above
 
   load();
 }
 
 void KRootOptions::fillMenuCombo( QComboBox * combo )
 {
-  combo->insertItem( i18n("No action") );
+  combo->insertItem( i18n("No Action") );
   combo->insertItem( i18n("Window List Menu") );
   combo->insertItem( i18n("Desktop Menu") );
   combo->insertItem( i18n("Application Menu") );
@@ -334,7 +271,7 @@ void KRootOptions::load()
     bool bShowHidden = g_pConfig->readBoolEntry("ShowHidden", DEFAULT_SHOW_HIDDEN_ROOT_ICONS);
     showHiddenBox->setChecked(bShowHidden);
     bool bVertAlign = g_pConfig->readNumEntry("VertAlign", DEFAULT_VERT_ALIGN);
-    VertAlignBox->setChecked(bVertAlign);
+    vertAlignBox->setChecked(bVertAlign);
     KTrader::OfferList plugins = KTrader::self()->query("ThumbCreator");
     previewListView->clear();
     QStringList previews = g_pConfig->readListEntry("Preview");
@@ -347,6 +284,8 @@ void KRootOptions::load()
     menuBarBox->setChecked(bMenuBar);
     g_pConfig->setGroup( "General" );
     vrootBox->setChecked( g_pConfig->readBoolEntry( "SetVRoot", false ) );
+    iconsEnabledBox->setChecked( g_pConfig->readBoolEntry( "Enabled", true ) );
+
     //
     g_pConfig->setGroup( "Mouse Buttons" );
     QString s;
@@ -363,17 +302,13 @@ void KRootOptions::load()
       if (s == s_choices[c])
       { rightComboBox->setCurrentItem( c ); break; }
 
-    // Desktop Paths
-    leDesktop->setText( KGlobalSettings::desktopPath() );
-    leTrash->setText( KGlobalSettings::trashPath() );
-    leAutostart->setText( KGlobalSettings::autostartPath() );
-    leDocument->setText( KGlobalSettings::documentPath() );
+    enableChanged();
 }
 
 void KRootOptions::defaults()
 {
     showHiddenBox->setChecked(DEFAULT_SHOW_HIDDEN_ROOT_ICONS);
-    VertAlignBox->setChecked(true);
+    vertAlignBox->setChecked(true);
     for (QListViewItem *item = previewListView->firstChild(); item; item = item->nextSibling())
         static_cast<KRootOptPreviewItem *>(item)->setOn(false);
     menuBarBox->setChecked(false);
@@ -381,19 +316,16 @@ void KRootOptions::defaults()
     leftComboBox->setCurrentItem( NOTHING );
     middleComboBox->setCurrentItem( WINDOWLISTMENU );
     rightComboBox->setCurrentItem( DESKTOPMENU );
-
-    // Desktop Paths - keep defaults in sync with kglobalsettings.cpp
-    leDesktop->setText( QDir::homeDirPath() + "/Desktop/" );
-    leTrash->setText( QDir::homeDirPath() + "/Desktop/" + i18n("Trash") + '/' );
-    leAutostart->setText( KGlobal::dirs()->localkdedir() + "Autostart/" );
-    leDocument->setText( QDir::homeDirPath() );
+    iconsEnabledBox->setChecked(true);
+    enableChanged();
 }
 
+
 void KRootOptions::save()
 {
     g_pConfig->setGroup( "Desktop Icons" );
     g_pConfig->writeEntry("ShowHidden", showHiddenBox->isChecked());
-    g_pConfig->writeEntry("VertAlign",VertAlignBox->isChecked());
+    g_pConfig->writeEntry("VertAlign",vertAlignBox->isChecked());
     QStringList previews;
     for ( KRootOptPreviewItem *item = static_cast<KRootOptPreviewItem *>( previewListView->firstChild() );
           item;
@@ -410,6 +342,142 @@ void KRootOptions::save()
 
     g_pConfig->setGroup( "General" );
     g_pConfig->writeEntry( "SetVRoot", vrootBox->isChecked() );
+    g_pConfig->writeEntry( "Enabled", iconsEnabledBox->isChecked() );
+
+    g_pConfig->sync();
+}
+
+void KRootOptions::enableChanged()
+{
+    bool enabled = iconsEnabledBox->isChecked();
+    showHiddenBox->setEnabled(enabled);
+    vertAlignBox->setEnabled(enabled);
+    previewListView->setEnabled(enabled);
+    vrootBox->setEnabled(enabled);
+
+    changed();
+}
+
+void KRootOptions::changed()
+{
+  emit KCModule::changed(true);
+}
+
+
+QString KRootOptions::quickHelp() const
+{
+  return i18n("<h1>Desktop</h1>\n"
+    "This module allows you to choose various options\n"
+    "for your desktop, including the way in which icons are arranged and\n"
+    "the pop-up menus associated with clicks of the middle and right mouse\n"
+    "buttons on the desktop.\n"
+    "Use the \"Whats This?\" (Shift+F1) to get help on specific options.");
+}
+
+DesktopPathConfig::DesktopPathConfig(QWidget *parent, const char * )
+    : KCModule( parent, "kcmkonq" )
+{
+  QLabel * tmpLabel;
+
+#undef RO_LASTROW
+#undef RO_LASTCOL
+#define RO_LASTROW 5   // 4 paths + last row
+#define RO_LASTCOL 2
+
+  int row = 0;
+  QGridLayout *lay = new QGridLayout(this, RO_LASTROW+1, RO_LASTCOL+1, 10);
+
+  lay->setRowStretch(RO_LASTROW,10); // last line grows
+
+  lay->setColStretch(0,0);
+  lay->setColStretch(1,0);
+  lay->setColStretch(2,10);
+
+  // Desktop Paths
+  row++;
+  tmpLabel = new QLabel(i18n("Des&ktop path:"), this);
+  lay->addWidget(tmpLabel, row, 0);
+  urDesktop = new KURLRequester(this);
+  urDesktop->setMode( KFile::Directory );
+  tmpLabel->setBuddy( urDesktop );
+  lay->addMultiCellWidget(urDesktop, row, row, 1, RO_LASTCOL);
+  connect(urDesktop, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+  QWhatsThis::add( urDesktop, i18n("This directory contains all the files"
+                                   " which you see on your desktop. You can change the location of this"
+                                   " directory if you want to, and the contents will move automatically"
+                                   " to the new location as well.") );
+
+  row++;
+  tmpLabel = new QLabel(i18n("&Trash path:"), this);
+  lay->addWidget(tmpLabel, row, 0);
+  urTrash = new KURLRequester(this);
+  urTrash->setMode( KFile::Directory );
+  tmpLabel->setBuddy( urTrash );
+  lay->addMultiCellWidget(urTrash, row, row, 1, RO_LASTCOL);
+  connect(urTrash, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+  QString wtstr = i18n("This directory contains deleted files (until"
+               " you empty the trashcan). You can change the location of this"
+               " directory if you want to, and the contents will move automatically"
+               " to the new location as well.");
+  QWhatsThis::add( tmpLabel, wtstr );
+  QWhatsThis::add( urTrash, wtstr );
+
+  row++;
+  tmpLabel = new QLabel(i18n("A&utostart path:"), this);
+  lay->addWidget(tmpLabel, row, 0);
+  urAutostart = new KURLRequester(this);
+  urAutostart->setMode( KFile::Directory );
+  tmpLabel->setBuddy( urAutostart );
+  lay->addMultiCellWidget(urAutostart, row, row, 1, RO_LASTCOL);
+  connect(urAutostart, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+  wtstr = i18n("This directory contains applications or"
+               " links to applications (shortcuts) that you want to have started"
+               " automatically whenever KDE starts. You can change the location of this"
+               " directory if you want to, and the contents will move automatically"
+               " to the new location as well.");
+  QWhatsThis::add( tmpLabel, wtstr );
+  QWhatsThis::add( urAutostart, wtstr );
+
+  row++;
+  tmpLabel = new QLabel(i18n("D&ocuments path:"), this);
+  lay->addWidget(tmpLabel, row, 0);
+  urDocument = new KURLRequester(this);
+  urDocument->setMode( KFile::Directory );
+  tmpLabel->setBuddy( urDocument );
+  lay->addMultiCellWidget(urDocument, row, row, 1, RO_LASTCOL);
+  connect(urDocument, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+  wtstr = i18n("This directory will be used by default to "
+               "load or save documents from or to.");
+  QWhatsThis::add( tmpLabel, wtstr );
+  QWhatsThis::add( urDocument, wtstr );
+
+  // -- Bottom --
+  Q_ASSERT( row == RO_LASTROW-1 ); // if it fails here, check the row++ and RO_LASTROW above
+
+  load();
+}
+
+void DesktopPathConfig::load()
+{
+    // Desktop Paths
+    urDesktop->setURL( KGlobalSettings::desktopPath() );
+    urTrash->setURL( KGlobalSettings::trashPath() );
+    urAutostart->setURL( KGlobalSettings::autostartPath() );
+    urDocument->setURL( KGlobalSettings::documentPath() );
+    changed();
+}
+
+void DesktopPathConfig::defaults()
+{
+    // Desktop Paths - keep defaults in sync with kglobalsettings.cpp
+    urDesktop->setURL( QDir::homeDirPath() + "/Desktop/" );
+    urTrash->setURL( QDir::homeDirPath() + "/Desktop/" + i18n("Trash") + '/' );
+    urAutostart->setURL( KGlobal::dirs()->localkdedir() + "Autostart/" );
+    urDocument->setURL( QDir::homeDirPath() );
+}
+
+void DesktopPathConfig::save()
+{
     KConfig *config = KGlobal::config();
     KConfigGroupSaver cgs( config, "Paths" );
 
@@ -420,22 +488,22 @@ void KRootOptions::save()
     KURL desktopURL;
     desktopURL.setPath( KGlobalSettings::desktopPath() );
     KURL newDesktopURL;
-    newDesktopURL.setPath(leDesktop->text());
+    newDesktopURL.setPath(urDesktop->url());
 
     KURL trashURL;
     trashURL.setPath( KGlobalSettings::trashPath() );
     KURL newTrashURL;
-    newTrashURL.setPath(leTrash->text());
+    newTrashURL.setPath(urTrash->url());
 
     KURL autostartURL;
     autostartURL.setPath( KGlobalSettings::autostartPath() );
     KURL newAutostartURL;
-    newAutostartURL.setPath(leAutostart->text());
+    newAutostartURL.setPath(urAutostart->url());
 
     KURL documentURL;
     documentURL.setPath( KGlobalSettings::documentPath() );
     KURL newDocumentURL;
-    newDocumentURL.setPath(leDocument->text());
+    newDocumentURL.setPath(urDocument->url());
 
     if ( !newDesktopURL.cmp( desktopURL, true ) )
     {
@@ -454,7 +522,7 @@ void KRootOptions::save()
             if ( newTrashURL.cmp( trashURL, true ) )
             {
                 // Hack. It could be in a subdir inside desktop. Hmmm... Argl.
-                leTrash->setText( leDesktop->text() + trashURL.fileName() );
+                urTrash->setURL( urDesktop->url() + trashURL.fileName() );
                 kdDebug() << "The trash is moved with the desktop" << endl;
                 trashMoved = true;
             }
@@ -462,11 +530,11 @@ void KRootOptions::save()
             else
             {
                 KURL futureTrashURL;
-                futureTrashURL.setPath( leDesktop->text() + trashURL.fileName() );
+                futureTrashURL.setPath( urDesktop->url() + trashURL.fileName() );
                 if ( newTrashURL.cmp( futureTrashURL, true ) )
                     trashMoved = true; // The trash moves with the desktop
                 else
-                    trashMoved = moveDir( KGlobalSettings::trashPath(), leTrash->text(), i18n("Trash") );
+                    trashMoved = moveDir( KGlobalSettings::trashPath(), urTrash->url(), i18n("Trash") );
             }
         }
 
@@ -478,7 +546,7 @@ void KRootOptions::save()
             if ( newAutostartURL.cmp( autostartURL, true ) )
             {
                 // Hack. It could be in a subdir inside desktop. Hmmm... Argl.
-                leAutostart->setText( leDesktop->text() + "Autostart/" );
+                urAutostart->setURL( urDesktop->url() + "Autostart/" );
                 kdDebug() << "Autostart is moved with the desktop" << endl;
                 autostartMoved = true;
             }
@@ -486,17 +554,18 @@ void KRootOptions::save()
             else
             {
                 KURL futureAutostartURL;
-                futureAutostartURL.setPath( leDesktop->text() + "Autostart/" );
+                futureAutostartURL.setPath( urDesktop->url() + "Autostart/" );
                 if ( newAutostartURL.cmp( futureAutostartURL, true ) )
                     autostartMoved = true;
                 else
-                    autostartMoved = moveDir( KGlobalSettings::autostartPath(), leAutostart->text(), i18n("Autostart") );
+                    autostartMoved = moveDir( KGlobalSettings::autostartPath(), urAutostart->url(), i18n("Autostart") );
             }
         }
 
-        if ( moveDir( KGlobalSettings::desktopPath(), leDesktop->text(), i18n("Desktop") ) )
+        if ( moveDir( KGlobalSettings::desktopPath(), urDesktop->url(), i18n("Desktop") ) )
         {
-            config->writeEntry( "Desktop", leDesktop->text(), true, true );
+//            config->writeEntry( "Desktop", urDesktop->url());
+            config->writePathEntry( "Desktop", urDesktop->url(), true, true );
             pathChanged = true;
         }
     }
@@ -504,10 +573,11 @@ void KRootOptions::save()
     if ( !newTrashURL.cmp( trashURL, true ) )
     {
         if (!trashMoved)
-            trashMoved = moveDir( KGlobalSettings::trashPath(), leTrash->text(), i18n("Trash") );
+            trashMoved = moveDir( KGlobalSettings::trashPath(), urTrash->url(), i18n("Trash") );
         if (trashMoved)
         {
-            config->writeEntry( "Trash", leTrash->text(), true, true );
+//            config->writeEntry( "Trash", urTrash->url());
+            config->writePathEntry( "Trash", urTrash->url(), true, true );
             pathChanged = true;
         }
     }
@@ -515,31 +585,32 @@ void KRootOptions::save()
     if ( !newAutostartURL.cmp( autostartURL, true ) )
     {
         if (!autostartMoved)
-            autostartMoved = moveDir( KGlobalSettings::autostartPath(), leAutostart->text(), i18n("Autostart") );
+            autostartMoved = moveDir( KGlobalSettings::autostartPath(), urAutostart->url(), i18n("Autostart") );
         if (autostartMoved)
         {
-            config->writeEntry( "Autostart", leAutostart->text(), true, true );
+//            config->writeEntry( "Autostart", Autostart->url());
+            config->writePathEntry( "Autostart", urAutostart->url(), true, true );
             pathChanged = true;
         }
     }
 
     if ( !newDocumentURL.cmp( documentURL, true ) )
     {
-        config->writeEntry( "Documents", leDocument->text(), true, true );
+//        config->writeEntry( "Documents", urDocument->url());
+        config->writePathEntry( "Documents", urDocument->url(), true, true );
         pathChanged = true;
     }
 
     config->sync();
-    g_pConfig->sync();
 
     if (pathChanged)
     {
-        kdDebug() << "KRootOptions::save sending message SettingsChanged" << endl;
+        kdDebug() << "DesktopPathConfig::save sending message SettingsChanged" << endl;
         KIPC::sendMessageAll(KIPC::SettingsChanged, KApplication::SETTINGS_PATHS);
     }
 }
 
-bool KRootOptions::moveDir( const KURL & src, const KURL & dest, const QString & type )
+bool DesktopPathConfig::moveDir( const KURL & src, const KURL & dest, const QString & type )
 {
     if (!src.isLocalFile() || !dest.isLocalFile())
         return true;
@@ -554,11 +625,11 @@ bool KRootOptions::moveDir( const KURL & src, const KURL & dest, const QString &
         // wait for job
         qApp->enter_loop();
     }
-    kdDebug() << "KRootOptions::slotResult returning " << m_ok << endl;
+    kdDebug() << "DesktopPathConfig::slotResult returning " << m_ok << endl;
     return m_ok;
 }
 
-void KRootOptions::slotResult( KIO::Job * job )
+void DesktopPathConfig::slotResult( KIO::Job * job )
 {
     if (job->error())
     {
@@ -572,20 +643,17 @@ void KRootOptions::slotResult( KIO::Job * job )
     qApp->exit_loop();
 }
 
-
-void KRootOptions::changed()
+void DesktopPathConfig::changed()
 {
   emit KCModule::changed(true);
 }
 
 
-QString KRootOptions::quickHelp() const
+QString DesktopPathConfig::quickHelp() const
 {
   return i18n("<h1>Desktop</h1>\n"
-    "This module allows you to choose various options\n"
-    "for your desktop, including the way in which icons are arranged, the\n"
-    "location of your desktop directory, and the pop-up menus associated\n"
-    "with clicks of the middle and right mouse buttons on the desktop.\n"
+    "This module allows you to choose where files on your desktop\n"
+    "are being stored.\n"
     "Use the \"Whats This?\" (Shift+F1) to get help on specific options.");
 }
 
