@@ -11,8 +11,7 @@
 #include <qstrlist.h>
 #include <qcheckbox.h>
 #include <qlineedit.h>
-
-#include <kcmodule.h>
+#include <qcombobox.h>
 
 
 //-----------------------------------------------------------------------------
@@ -26,10 +25,10 @@
 
 #include <qstring.h>
 #include <kconfig.h>
-class KURLRequester;
 class QRadioButton;
+class KIntNumInput;
 
-class KMiscHTMLOptions : public KCModule
+class KMiscHTMLOptions : public QWidget
 {
     Q_OBJECT
 
@@ -39,21 +38,23 @@ public:
     virtual void save();
     virtual void defaults();
 
+signals:
+    void changed( bool state );
 private slots:
-    void slotOpenFileDialog( KURLRequester * );
     void changed();
 
 private:
     KConfig* m_pConfig;
     QString  m_groupname;
 
-    QRadioButton *m_pUnderlineRadio[3];
+    QComboBox* m_pUnderlineCombo;
+    QComboBox* m_pAnimationsCombo;
     QCheckBox* cbCursor;
     QCheckBox* m_pAutoLoadImagesCheckBox;
-    QCheckBox* m_pEnableFaviconCheckBox;
-
-    QCheckBox* userSheet;
-    KURLRequester* userSheetLocation;
+    QCheckBox* m_pAutoRedirectCheckBox;
+    QCheckBox* m_pBackRightClick;
+    QCheckBox* m_pFormCompletionCheckBox;
+    KIntNumInput* m_pMaxFormCompletionItems;
 };
 
 #endif
