@@ -48,7 +48,7 @@
 
 KJavaOptions::KJavaOptions( KConfig* config, QString group,
                             QWidget *parent, const char *name )
-    : KCModule( parent, name ),
+    : QWidget( parent, name ),
       m_pConfig( config ),
       m_groupname( group )
 {
@@ -81,18 +81,19 @@ KJavaOptions::KJavaOptions( KConfig* config, QString group,
     domainSpecificLV->addColumn(i18n("Host/Domain"));
     domainSpecificLV->addColumn(i18n("Policy"), 100);
     connect(domainSpecificLV,SIGNAL(doubleClicked ( QListViewItem * )), this, SLOT( changePressed() ) );
+    connect(domainSpecificLV,SIGNAL(returnPressed ( QListViewItem * )), this, SLOT( changePressed() ) );
 
     domainSpecificGBLayout->addMultiCellWidget( domainSpecificLV, 0, 5, 0, 0 );
 
-    QPushButton* addDomainPB = new QPushButton( i18n("&Add..."), domainSpecificGB );
+    QPushButton* addDomainPB = new QPushButton( i18n("Add..."), domainSpecificGB );
     domainSpecificGBLayout->addWidget( addDomainPB, 0, 1 );
     connect( addDomainPB, SIGNAL(clicked()), SLOT( addPressed() ) );
 
-    QPushButton* changeDomainPB = new QPushButton( i18n("&Change..."), domainSpecificGB );
+    QPushButton* changeDomainPB = new QPushButton( i18n("Change..."), domainSpecificGB );
     domainSpecificGBLayout->addWidget( changeDomainPB, 1, 1 );
     connect( changeDomainPB, SIGNAL( clicked() ), this, SLOT( changePressed() ) );
 
-    QPushButton* deleteDomainPB = new QPushButton( i18n("&Delete"), domainSpecificGB );
+    QPushButton* deleteDomainPB = new QPushButton( i18n("Delete"), domainSpecificGB );
     domainSpecificGBLayout->addWidget( deleteDomainPB, 2, 1 );
     connect( deleteDomainPB, SIGNAL( clicked() ), this, SLOT( deletePressed() ) );
 
@@ -100,11 +101,13 @@ KJavaOptions::KJavaOptions( KConfig* config, QString group,
     domainSpecificGBLayout->addWidget( importDomainPB, 3, 1 );
     connect( importDomainPB, SIGNAL( clicked() ), this, SLOT( importPressed() ) );
     importDomainPB->setEnabled( false );
+    importDomainPB->hide();
 
     QPushButton* exportDomainPB = new QPushButton( i18n("&Export..."), domainSpecificGB );
     domainSpecificGBLayout->addWidget( exportDomainPB, 4, 1 );
     connect( exportDomainPB, SIGNAL( clicked() ), this, SLOT( exportPressed() ) );
     exportDomainPB->setEnabled( false );
+    exportDomainPB->hide();
 
     QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
     domainSpecificGBLayout->addItem( spacer, 5, 1 );
@@ -131,6 +134,7 @@ KJavaOptions::KJavaOptions( KConfig* config, QString group,
     serverTimeoutSB = new KIntNumInput( secondsHB );
     serverTimeoutSB->setRange( 0, 1000, 5 );
     serverTimeoutSB->setLabel( i18n("Applet Server Timeout (seconds)"), AlignLeft );
+    connect(serverTimeoutSB, SIGNAL(valueChanged(int)),this,SLOT(changed()));
 
     QHBox* pathHB = new QHBox( javartGB );
     pathHB->setSpacing( 10 );
@@ -167,16 +171,16 @@ KJavaOptions::KJavaOptions( KConfig* config, QString group,
     QWhatsThis::add( deleteDomainPB, i18n("Click on this button to change the policy for the "
                                           "host or domain selected in the list box.") );
     QWhatsThis::add( importDomainPB, i18n("Click this button to choose the file that contains "
-                                          "the Java policies.  These policies will be merged "
-                                          "with the exisiting ones.  Duplicate entries are ignored.") );
+                                          "the Java policies. These policies will be merged "
+                                          "with the exisiting ones. Duplicate entries are ignored.") );
     QWhatsThis::add( exportDomainPB, i18n("Click this button to save the Java policy to a zipped "
-                                          "file.  The file, named <b>java_policy.tgz</b>, will be "
+                                          "file. The file, named <b>java_policy.tgz</b>, will be "
                                           "saved to a location of your choice." ) );
     QWhatsThis::add( domainSpecificGB, i18n("Here you can set specific Java policies for any particular "
                                             "host or domain. To add a new policy, simply click the <i>Add...</i> "
                                             "button and supply the necessary information requested by the "
                                             "dialog box. To change an existing policy, click on the <i>Change...</i> "
-                                            "button and choose the new policy from the policy dialog box.  Clicking "
+                                            "button and choose the new policy from the policy dialog box. Clicking "
                                             "on the <i>Delete</i> button will remove the selected policy causing the default "
                                             "policy setting to be used for that domain. The <i>Import</i> and <i>Export</i> "
                                             "button allows you to easily share your policies with other people by allowing "
@@ -189,25 +193,26 @@ KJavaOptions::KJavaOptions( KConfig* config, QString group,
     QWhatsThis::add( javaSecurityManagerCB, i18n( "Enabling the security manager will cause the jvm to run with a Security "
                                                   "Manager in place. This will keep applets from being able to read and "
                                                   "write to your file system, creating arbitrary sockets, and other actions "
-                                                  "which could be used to compromise your system.  Disable this option at your "
-                                                  "own risk.  You can modify your $HOME/.java.policy file with the Java "
+                                                  "which could be used to compromise your system. Disable this option at your "
+                                                  "own risk. You can modify your $HOME/.java.policy file with the Java "
                                                   "policytool utility to give code downloaded from certain sites more "
                                                   "permissions." ) );
 
-    QWhatsThis::add( pathED, i18n("Enter the path to the java executable.  If you want to use the jre in "
-                                  "your path, simply leave it as 'java'.  If you need to use a different jre, "
-                                  "enter the path to the java executable (for example, /usr/lib/jdk/bin/java), "
-                                  "or the path to the directory that contains 'bin/java' (for example, /opt/IBMJava2-13).") );
+    QWhatsThis::add( pathED, i18n("Enter the path to the java executable. If you want to use the jre in "
+                                  "your path, simply leave it as 'java'. If you need to use a different jre, "
+                                  "enter the path to the java executable (e.g. /usr/lib/jdk/bin/java), "
+                                  "or the path to the directory that contains 'bin/java' (e.g. /opt/IBMJava2-13).") );
 
     QWhatsThis::add( addArgED, i18n("If you want special arguments to be passed to the virtual machine, enter them here.") );
 
-    QWhatsThis::add( serverTimeoutSB, i18n("When all the applets have been destroyed, the applet server should shut down.  "
-                                           "However, starting the jvm takes a lot of time.  If you would like to "
+    QString shutdown = i18n("When all the applets have been destroyed, the applet server should shut down. "
+                                           "However, starting the jvm takes a lot of time. If you would like to "
                                            "keep the java process running while you are "
-                                           "browsing, you can set the timeout value to what you would like.  To keep "
-                                           "the java process running for the whole time the konqueror process is, "
-                                           "leave the Shutdown Applet Server checkbox unchecked.") );
-
+                                           "browsing, you can set the timeout value to whatever you like. To keep "
+                                           "the java process running for the whole time that the konqueror process is, "
+                                           "leave the Shutdown Applet Server checkbox unchecked.");
+    QWhatsThis::add( serverTimeoutSB, shutdown);
+    QWhatsThis::add( enableShutdownCB, shutdown);
     // Finally do the loading
     load();
 }
@@ -251,7 +256,7 @@ void KJavaOptions::defaults()
     javaSecurityManagerCB->setChecked( true );
     pathED->lineEdit()->setText( "java" );
     addArgED->setText( "" );
-
+    enableShutdownCB->setChecked(true);
     toggleJavaControls();
 }
 
@@ -284,7 +289,7 @@ void KJavaOptions::save()
 
 void KJavaOptions::changed()
 {
-    emit KCModule::changed(true);
+    emit changed(true);
 }
 
 
