@@ -49,19 +49,26 @@
 
 KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget *parent,
 										const char *name ) :
-  KCModule( parent, name ), m_pConfig( config ), m_groupname( group )
+  QWidget( parent, name ), m_pConfig( config ), m_groupname( group )
 {
   QVBoxLayout* toplevel = new QVBoxLayout( this, 10, 5 );
 
   // the global checkbox
   QVGroupBox* globalGB = new QVGroupBox( i18n( "Global Settings" ), this );
   toplevel->addWidget( globalGB );
+
   enableJavaScriptGloballyCB = new QCheckBox( i18n( "Enable Java&Script globally" ), globalGB );
   QWhatsThis::add( enableJavaScriptGloballyCB, i18n("Enables the execution of scripts written in ECMA-Script "
         "(also known as JavaScript) that can be contained in HTML pages. Be aware that JavaScript support "
         "is not yet finished. Note that, as with any browser, enabling scripting languages can be a security problem.") );
   connect( enableJavaScriptGloballyCB, SIGNAL( clicked() ), this, SLOT( changed() ) );
 
+//  enableJavaScriptDebugCB = new QCheckBox( i18n( "Enable Debu&gging" ), globalGB );
+//  QWhatsThis::add( enableJavaScriptDebugCB, i18n("Enables the reporting of errors that occur when JavaScript "
+//        "code is executed, and allows the use of the JavaScript debugger to trace through code execution. "
+//        "Note that this has a small performance impact and is mainly only useful for developers.") );
+//  connect( enableJavaScriptDebugCB, SIGNAL( clicked() ), this, SLOT( changed() ) );
+
   // the domain-specific listview (copied and modified from Cookies configuration)
   QGroupBox* domainSpecificGB = new QGroupBox( i18n( "Domain-specific" ), this );
   domainSpecificGB->setColumnLayout(0, Qt::Vertical );
@@ -83,21 +90,23 @@ KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget
   QWhatsThis::add( domainSpecificLV, wtstr );
   QWhatsThis::add( domainSpecificGB, wtstr );
   connect(domainSpecificLV,SIGNAL(doubleClicked ( QListViewItem * )), this, SLOT( changePressed() ) );
+  connect(domainSpecificLV,SIGNAL(returnPressed ( QListViewItem * )), this, SLOT( changePressed() ) );
+
 
   domainSpecificGBLayout->addMultiCellWidget( domainSpecificLV, 0, 5, 0, 0 );
-  QPushButton* addDomainPB = new QPushButton( i18n("&Add..."), domainSpecificGB );
+  QPushButton* addDomainPB = new QPushButton( i18n("Add..."), domainSpecificGB );
   domainSpecificGBLayout->addWidget( addDomainPB, 0, 1 );
   QWhatsThis::add( addDomainPB, i18n("Click on this button to manually add a host or domain "
                                      "specific policy.") );
   connect( addDomainPB, SIGNAL(clicked()), SLOT( addPressed() ) );
 
-  QPushButton* changeDomainPB = new QPushButton( i18n("&Change..."), domainSpecificGB );
+  QPushButton* changeDomainPB = new QPushButton( i18n("Change..."), domainSpecificGB );
   domainSpecificGBLayout->addWidget( changeDomainPB, 1, 1 );
   QWhatsThis::add( changeDomainPB, i18n("Click on this button to change the policy for the "
                                         "host or domain selected in the list box.") );
   connect( changeDomainPB, SIGNAL( clicked() ), this, SLOT( changePressed() ) );
 
-  QPushButton* deleteDomainPB = new QPushButton( i18n("&Delete"), domainSpecificGB );
+  QPushButton* deleteDomainPB = new QPushButton( i18n("Delete"), domainSpecificGB );
   domainSpecificGBLayout->addWidget( deleteDomainPB, 2, 1 );
   QWhatsThis::add( deleteDomainPB, i18n("Click on this button to change the policy for the "
                                         "host or domain selected in the list box.") );
@@ -106,19 +115,21 @@ KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget
   QPushButton* importDomainPB = new QPushButton( i18n("&Import..."), domainSpecificGB );
   domainSpecificGBLayout->addWidget( importDomainPB, 3, 1 );
   QWhatsThis::add( importDomainPB, i18n("Click this button to choose the file that contains "
-                                        "the JavaScript policies.  These policies will be merged "
-                                        "with the exisiting ones.  Duplicate entries are ignored.") );
+                                        "the JavaScript policies. These policies will be merged "
+                                        "with the existing ones. Duplicate entries are ignored.") );
   connect( importDomainPB, SIGNAL( clicked() ), this, SLOT( importPressed() ) );
   importDomainPB->setEnabled( false );
+  importDomainPB->hide();
 
   QPushButton* exportDomainPB = new QPushButton( i18n("&Export..."), domainSpecificGB );
   domainSpecificGBLayout->addWidget( exportDomainPB, 4, 1 );
   QWhatsThis::add( exportDomainPB, i18n("Click this button to save the JavaScript policy to a zipped "
-                                        "file.  The file, named <b>javascript_policy.tgz</b>, will be "
+                                        "file. The file, named <b>javascript_policy.tgz</b>, will be "
                                         "saved to a location of your choice." ) );
 
   connect( exportDomainPB, SIGNAL( clicked() ), this, SLOT( exportPressed() ) );
   exportDomainPB->setEnabled( false );
+  exportDomainPB->hide();
 
   QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
   domainSpecificGBLayout->addItem( spacer, 5, 1 );
@@ -128,17 +139,21 @@ KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget
                                           "host or domain. To add a new policy, simply click the <i>Add...</i> "
                                           "button and supply the necessary information requested by the "
                                           "dialog box. To change an existing policy, click on the <i>Change...</i> "
-                                          "button and choose the new policy from the policy dialog box.  Clicking "
+                                          "button and choose the new policy from the policy dialog box. Clicking "
                                           "on the <i>Delete</i> button will remove the selected policy causing the default "
                                           "policy setting to be used for that domain. The <i>Import</i> and <i>Export</i> "
                                           "button allows you to easily share your policies with other people by allowing "
                                           "you to save and retrive them from a zipped file.") );
 
-  js_popup      = new QButtonGroup(3, Horizontal, i18n( "JavaScript web popups policy" ), this);
+  js_popup      = new QButtonGroup(4, Horizontal, i18n( "JavaScript web popups policy" ), this);
   js_popup->setExclusive(TRUE);
-  js_popupAllow = new QRadioButton(i18n( "Allow" ), js_popup);
-  js_popupAsk   = new QRadioButton(i18n( "Ask" ), js_popup);
-  js_popupDeny  = new QRadioButton(i18n( "Deny" ), js_popup);
+  QRadioButton* js_popupAllow = new QRadioButton(i18n( "Allow" ), js_popup);
+  QRadioButton* js_popupAsk   = new QRadioButton(i18n( "Ask" ), js_popup);
+  QRadioButton* js_popupDeny  = new QRadioButton(i18n( "Deny" ), js_popup);
+  QRadioButton* js_popupSmart = new QRadioButton(i18n( "Smart" ), js_popup);
+  QWhatsThis::add( js_popupSmart,
+                   i18n("If you choose the 'Smart' option, window.open will be disabled unless "
+                        "it is being activated from a mouse click or a keyboard operation.") );
   toplevel->addWidget(js_popup);
   QWhatsThis::add( js_popup,
                    i18n("If you disable this, Konqueror will stop interpreting the <i>window.open()</i> "
@@ -175,7 +190,8 @@ void KJavaScriptOptions::load()
         updateDomainList(m_pConfig->readListEntry("JavaScriptDomainAdvice") );
 
     // *** apply to GUI ***
-    enableJavaScriptGloballyCB->setChecked( m_pConfig->readBoolEntry("EnableJavaScript") );
+    enableJavaScriptGloballyCB->setChecked( m_pConfig->readBoolEntry("EnableJavaScript",true));
+//    enableJavaScriptDebugCB->setChecked( m_pConfig->readBoolEntry("EnableJavaScriptDebug",false));
     js_popup->setButton( m_pConfig->readUnsignedNumEntry("WindowOpenPolicy", 0) );
 
   // enableDebugOutputCB->setChecked( m_pConfig->readBoolEntry("EnableJSDebugOutput") );
@@ -183,7 +199,8 @@ void KJavaScriptOptions::load()
 
 void KJavaScriptOptions::defaults()
 {
-  enableJavaScriptGloballyCB->setChecked( false );
+  enableJavaScriptGloballyCB->setChecked( true );
+//  enableJavaScriptDebugCB->setChecked( false );
   js_popup->setButton(0);
  // enableDebugOutputCB->setChecked( false );
 }
@@ -192,6 +209,7 @@ void KJavaScriptOptions::save()
 {
     m_pConfig->setGroup(m_groupname);
     m_pConfig->writeEntry( "EnableJavaScript", enableJavaScriptGloballyCB->isChecked() );
+//    m_pConfig->writeEntry( "EnableJavaScriptDebug", enableJavaScriptDebugCB->isChecked() );
 
     int js_policy = 0;
     if ( js_popup->selected() )
@@ -219,7 +237,7 @@ void KJavaScriptOptions::save()
 
 void KJavaScriptOptions::changed()
 {
-  emit KCModule::changed(true);
+  emit changed(true);
 }
 
 void KJavaScriptOptions::addPressed()
