@@ -10,7 +10,7 @@
 #ifndef __JSOPTS_H__
 #define __JSOPTS_H__
 
-#include <kcmodule.h>
+#include <qwidget.h>
 #include <qmap.h>
 
 class KColorButton;
@@ -23,8 +23,9 @@ class QLineEdit;
 class QListViewItem;
 class QRadioButton;
 class QSpinBox;
+class QButtonGroup;
 
-class KJavaScriptOptions : public KCModule
+class KJavaScriptOptions : public QWidget
 {
   Q_OBJECT
 public:
@@ -34,6 +35,9 @@ public:
   virtual void save();
   virtual void defaults();
 
+signals:
+  void changed( bool state );
+
 private slots:
   void changed();
   void importPressed();
@@ -49,11 +53,8 @@ private:
   KConfig *m_pConfig;
   QString m_groupname;
   QCheckBox *enableJavaScriptGloballyCB;
-  QCheckBox *disableWindowOpenCB;
-//  QCheckBox *enableDebugOutputCB;
-
-  //bool bJavaScriptGlobal;
-
+  QCheckBox *enableJavaScriptDebugCB;
+  QButtonGroup *js_popup;
   KListView* domainSpecificLV;
   QMap<QListViewItem*, int> javaScriptDomainPolicy;
 };
