@@ -9,7 +9,6 @@
 #include <qcheckbox.h>
 #include <qstring.h>
 
-#include <kcmodule.h>
 #include <kconfig.h>
 
 
@@ -17,7 +16,7 @@
 *  Dialog for configuring HTTP Options like charset and language negotiation
 *  and assuming that file got from HTTP is HTML if no Content-Type is given
 */
-class KHTTPOptions : public KCModule
+class KHTTPOptions : public QWidget
 {
 Q_OBJECT
   public:
@@ -27,6 +26,9 @@ Q_OBJECT
     virtual void save();
     virtual void defaults();
 
+signals:
+    void changed( bool state );
+
   private:
 
     KConfig *m_pConfig;
@@ -40,9 +42,6 @@ Q_OBJECT
     QLabel *lb_charsets;	
     QLineEdit *le_charsets;	
 
-    // Assume HTML if mime type is not known
-    QCheckBox *cb_assumeHTML;
-
     QString defaultCharsets;
 
 private slots:
