@@ -1,14 +1,9 @@
 // (c) 2001, Daniel Naber, based on javaopts.cpp
 
-#include <qcheckbox.h>
-#include <qcombobox.h>
 #include <qlayout.h>
 #include <qwhatsthis.h>
 #include <qvgroupbox.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
 #include <kconfig.h>
-#include <kmessagebox.h>
 #include <kdebug.h>
 #include <X11/Xlib.h>
 
@@ -17,14 +12,12 @@
 
 #include <konq_defaults.h> // include default values directly from konqueror
 #include <klocale.h>
-#include <khtml_settings.h>
-#include <khtmldefaults.h>
 
 #include "pluginopts.moc"
 
 KPluginOptions::KPluginOptions( KConfig* config, QString group, QWidget *parent,
                             const char *name )
-    : KCModule( parent, name ),
+    : QWidget( parent, name ),
       m_pConfig( config ),
       m_groupname( group )
 {
@@ -35,9 +28,10 @@ KPluginOptions::KPluginOptions( KConfig* config, QString group, QWidget *parent,
      **************************************************************************/
     QVGroupBox* globalGB = new QVGroupBox( i18n( "Global Settings" ), this );
     toplevel->addWidget( globalGB );
-    enablePluginsGloballyCB = new QCheckBox( i18n( "Enable &Plugins globally" ), globalGB );
+    enablePluginsGloballyCB = new QCheckBox( i18n( "Enable Plugins globally" ), globalGB );
     connect( enablePluginsGloballyCB, SIGNAL( clicked() ), this, SLOT( changed() ) );
-
+    QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
+    toplevel->addItem( spacer );
 
     /***************************************************************************
      ********************** WhatsThis? items ***********************************
@@ -74,5 +68,5 @@ void KPluginOptions::save()
 
 void KPluginOptions::changed()
 {
-    emit KCModule::changed(true);
+    emit changed(true);
 }
