@@ -31,7 +31,8 @@ class QCheckBox;
 class QComboBox;
 class QLineEdit;
 
-class KLocaleAdvanced;
+class KIntNumInput;
+class KLocale;
 class KLanguageCombo;
 
 class KLocaleConfigMoney : public QWidget
@@ -39,54 +40,56 @@ class KLocaleConfigMoney : public QWidget
   Q_OBJECT
 
 public:
-  KLocaleConfigMoney( KLocaleAdvanced *_locale, QWidget *parent=0, const char *name=0);
-  ~KLocaleConfigMoney( );
+  KLocaleConfigMoney(KLocale *locale, QWidget *parent=0, const char *name=0);
+  virtual ~KLocaleConfigMoney();
 
-  void load();
   void save();
-  void defaults();
 
 public slots:
-  void reset();
-  void reTranslate();
+  /**
+   * Loads all settings from the current locale into the current widget.
+   */
+  void slotLocaleChanged();
+  /**
+   * Retranslate all objects owned by this object using the current locale.
+   */
+  void slotTranslate();
+
+signals:
+  void localeChanged();
 
 private slots:
   // Money
   void slotMonCurSymChanged(const QString &t);
   void slotMonDecSymChanged(const QString &t);
   void slotMonThoSepChanged(const QString &t);
-  void slotMonFraDigChanged(const QString &t);
+  void slotMonFraDigChanged(int value);
   void slotMonPosPreCurSymChanged();
   void slotMonNegPreCurSymChanged();
   void slotMonPosMonSignPosChanged(int i);
   void slotMonNegMonSignPosChanged(int i);
 
-signals:
-  void translate();
-  void resample();
-
 private:
-  KLocaleAdvanced *locale;
-  KLocaleSample *sample;
+  KLocale *m_locale;
 
   // Money
-  QLabel *labMonCurSym;
-  QLineEdit *edMonCurSym;
-  QLabel *labMonDecSym;
-  QLineEdit *edMonDecSym;
-  QLabel *labMonThoSep;
-  QLineEdit *edMonThoSep;
-  QLabel *labMonFraDig;
-  QLineEdit *edMonFraDig;
+  QLabel *m_labMonCurSym;
+  QLineEdit *m_edMonCurSym;
+  QLabel *m_labMonDecSym;
+  QLineEdit *m_edMonDecSym;
+  QLabel *m_labMonThoSep;
+  QLineEdit *m_edMonThoSep;
+  QLabel *m_labMonFraDig;
+  KIntNumInput * m_inMonFraDig;
 
-  QLabel *labMonPosPreCurSym;
-  QCheckBox *chMonPosPreCurSym;
-  QLabel *labMonNegPreCurSym;
-  QCheckBox *chMonNegPreCurSym;
-  QLabel *labMonPosMonSignPos;
-  QComboBox *cmbMonPosMonSignPos;
-  QLabel *labMonNegMonSignPos;
-  QComboBox *cmbMonNegMonSignPos;
+  QLabel *m_labMonPosPreCurSym;
+  QCheckBox *m_chMonPosPreCurSym;
+  QLabel *m_labMonNegPreCurSym;
+  QCheckBox *m_chMonNegPreCurSym;
+  QLabel *m_labMonPosMonSignPos;
+  QComboBox *m_cmbMonPosMonSignPos;
+  QLabel *m_labMonNegMonSignPos;
+  QComboBox *m_cmbMonNegMonSignPos;
 };
 
 #endif
