@@ -8,18 +8,19 @@
 #include <qlayout.h>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
+#include <qvbuttongroup.h>
 #include <qstring.h>
 #include <qspinbox.h>
 #include <qlabel.h>
 #include <qwhatsthis.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kcmodule.h>
 #include <kpassdlg.h>
+#include <kgenericfactory.h>
 
 #include <kdesu/defaults.h>
 #include <kdesu/client.h>
@@ -29,23 +30,21 @@
 /**
  * DLL interface.
  */
-extern "C" {
-    KCModule *create_passwords(QWidget *parent, const char *name) {
-    KGlobal::locale()->insertCatalogue("passwords");
-    return new KPasswordConfig(parent, name);
-    }
-}
+typedef KGenericFactory<KPasswordConfig, QWidget > PassFactory;
+K_EXPORT_COMPONENT_FACTORY (kcm_passwords, PassFactory("passwords") );
+
 
 
 /**** KPasswordConfig ****/
 
-KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name)
-    : KCModule(parent, name)
+KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name, const QStringList &)
+    : KCModule(PassFactory::instance(), parent, name)
 {
     QVBoxLayout *top = new QVBoxLayout(this, 10, 10);
 
     // Echo mode
-    m_EMGroup = new QButtonGroup(i18n("Echo characters as"), this);
+    m_EMGroup = new QVButtonGroup(i18n("Echo characters as"), this);
+    m_EMGroup->layout()->setSpacing( KDialog::spacingHint() );
     QWhatsThis::add( m_EMGroup,  i18n("You can select the type of visual feedback given"
       " when you enter a password in kdesu. Choose one of the following options:<p>"
       " <ul><li><em>1 star:</em> each character you type is shown as an asterisk (*) symbol.</li>"
@@ -53,14 +52,9 @@ KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name)
       " <li><em>no echo:</em> there is no visual feedback at all, so nothing on your screen"
       " shows how many characters are in your password.</li></ul>"));
     top->addWidget(m_EMGroup);
-    QVBoxLayout *vbox = new QVBoxLayout(m_EMGroup, 10, 10);
-    vbox->addSpacing(10);
-    QRadioButton *rb = new QRadioButton(i18n("1 star"), m_EMGroup);
-    vbox->addWidget(rb, 0, AlignLeft);
-    rb = new QRadioButton(i18n("3 stars"), m_EMGroup);
-    vbox->addWidget(rb, 0, AlignLeft);
-    rb = new QRadioButton(i18n("no echo"), m_EMGroup);
-    vbox->addWidget(rb, 0, AlignLeft);
+    new QRadioButton(i18n("1 star"), m_EMGroup);
+    new QRadioButton(i18n("3 stars"), m_EMGroup);
+    new QRadioButton(i18n("no echo"), m_EMGroup);
     connect(m_EMGroup, SIGNAL(clicked(int)), SLOT(slotEchoMode(int)));
 
     // Keep password
@@ -72,7 +66,7 @@ KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name)
        " Please <em>do not</em> use this option if you are working in an insecure environment,"
        " for example, on a workstation that is located in a publicly accessible area.<p>"
        " This option does not affect passwords explicitly set in other applications, for example,"
-       " your e-mail account password in KMail.") );
+       " your email account password in KMail.") );
     connect(m_KeepBut, SIGNAL(toggled(bool)), SLOT(slotKeep(bool)));
     top->addWidget(m_KeepBut);
     QHBoxLayout *hbox = new QHBoxLayout();
@@ -91,6 +85,9 @@ KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name)
     m_TimeoutEdit->setSteps(5, 10);
     m_TimeoutEdit->setSuffix(i18n(" minutes"));
     m_TimeoutEdit->setFixedSize(m_TimeoutEdit->sizeHint());
+
+    connect(m_TimeoutEdit,SIGNAL(valueChanged ( int )),this,SLOT(configChanged()));
+
     hbox->addWidget(m_TimeoutEdit);
     hbox->addStretch();
 
