@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwords.h,v 1.2 2000/04/09 21:31:45 jschenck Exp $
+ * $Id: passwords.h,v 1.5 2001/12/28 02:32:22 zecke Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -21,7 +21,7 @@ class KPasswordConfig : public KCModule
     Q_OBJECT
 
 public:
-    KPasswordConfig(QWidget *parent=0, const char *name=0);
+    KPasswordConfig(QWidget *parent=0, const char *name=0, const QStringList &list=QStringList());
     ~KPasswordConfig();
 
     virtual void load();
@@ -30,7 +30,7 @@ public:
 
     void apply();
     int buttons();
-    QString quickHelp();
+    QString quickHelp() const;
 
 signals:
     void changed(bool);
@@ -39,7 +39,7 @@ private slots:
 
     void slotEchoMode(int);
     void slotKeep(bool);
-
+    void configChanged(){emit changed(true);}
 private:
     QButtonGroup *m_EMGroup;
     QCheckBox *m_KeepBut;
