@@ -24,14 +24,19 @@
 #include <qtabwidget.h>
 #include <kglobal.h>
 #include <qlayout.h>
-#include <kconfig.h>
 
 #include <kcmodule.h>
+#include <kgenericfactory.h>
+
+class SambaContainer; // damn forward declaration :( but I want the factory first zecke
+
+typedef KGenericFactory<SambaContainer, QWidget > SambaFactory;
+K_EXPORT_COMPONENT_FACTORY (kcm_samba, SambaFactory("kcmsamba") );
 
 class SambaContainer:public KCModule
 {
    public:
-      SambaContainer(QWidget *parent=0, const char * name=0);
+      SambaContainer(QWidget *parent=0, const char * name=0, const QStringList &list = QStringList() );
       virtual ~SambaContainer();
       virtual void loadSettings();
       virtual void saveSettings();
@@ -48,8 +53,8 @@ class SambaContainer:public KCModule
       StatisticsView statisticsView;
 };
 
-SambaContainer::SambaContainer(QWidget *parent, const char* name)
-:KCModule(parent,name)
+SambaContainer::SambaContainer(QWidget *parent, const char* name, const QStringList&)
+:KCModule(SambaFactory::instance(), parent,name)
 ,layout(this)
 ,config("kcmsambarc",false,true)
 ,tabs(this)
@@ -110,12 +115,3 @@ QString SambaContainer::quickHelp() const
 }
 
 
-extern "C"
-{
-
-  KCModule *create_samba(QWidget *parent, const char *name)
-  {
-    KGlobal::locale()->insertCatalogue("kcmsamba");
-    return new SambaContainer(parent, name);
-  }
-}
