@@ -1,6 +1,6 @@
 /*
  *  kcmsmserver.cpp
- *  Copyright (c) 2000 Oswald Buddenhagen <ob6@inf.tu-dresden.de>
+ *  Copyright (c) 2000,2002 Oswald Buddenhagen <ossi@kde.org>
  *
  *  based on kcmtaskbar.cpp
  *  Copyright (c) 2000 Kurt Granroth <granroth@kde.org>
@@ -21,18 +21,23 @@
 #include <qlayout.h>
 
 #include <dcopclient.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kdialog.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <qcheckbox.h>
+#include <qradiobutton.h>
+#include <kgenericfactory.h>
 
 #include "kcmsmserver.h"
 #include "smserverconfigimpl.h"
 
-SMServerConfig::SMServerConfig( QWidget *parent, const char* name )
-  : KCModule (parent, name)
+typedef KGenericFactory<SMServerConfig, QWidget > SMSFactory;
+K_EXPORT_COMPONENT_FACTORY (kcm_smserver, SMSFactory("kcmsmserver") );
+
+SMServerConfig::SMServerConfig( QWidget *parent, const char* name, const QStringList & )
+  : KCModule (SMSFactory::instance(), parent, name)
 {
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     dialog = new SMServerConfigImpl(this);
@@ -59,6 +64,17 @@ void SMServerConfig::load()
   c->setGroup("General");
   dialog->confirmLogoutCheck->setChecked(c->readBoolEntry("confirmLogout", true));
   dialog->saveSessionCheck->setChecked(c->readBoolEntry("saveSession", true));
+  switch (c->readNumEntry("shutdownType", int(KApplication::ShutdownTypeNone))) {
+  case int(KApplication::ShutdownTypeHalt):
+    dialog->haltRadio->setChecked(true);
+    break;
+  case int(KApplication::ShutdownTypeReboot):
+    dialog->rebootRadio->setChecked(true);
+    break;
+  default:
+    dialog->logoutRadio->setChecked(true);
+    break;
+  }
   delete c;
 
   emit changed(false);
@@ -70,6 +86,12 @@ void SMServerConfig::save()
   c->setGroup("General");
   c->writeEntry( "saveSession", dialog->saveSessionCheck->isChecked());
   c->writeEntry( "confirmLogout", dialog->confirmLogoutCheck->isChecked());
+  c->writeEntry( "shutdownType",
+                 dialog->haltRadio->isChecked() ?
+                   int(KApplication::ShutdownTypeHalt) :
+                   dialog->rebootRadio->isChecked() ?
+                     int(KApplication::ShutdownTypeReboot) :
+                     int(KApplication::ShutdownTypeNone));
   c->sync();
   delete c;
 
@@ -80,6 +102,7 @@ void SMServerConfig::defaults()
 {
   dialog->saveSessionCheck->setChecked(true);
   dialog->confirmLogoutCheck->setChecked(true);
+  dialog->logoutRadio->setChecked(true);
 
   emit changed(true);
 }
@@ -89,17 +112,10 @@ QString SMServerConfig::quickHelp() const
   return i18n("<h1>Session Manager</h1>"
     " You can configure the session manager here."
     " This includes options such as whether or not the session exit (logout)"
-    " should be confirmed and if the previous session should be restored"
-    " when logging in.");
+    " should be confirmed, whether the session should be saved when exiting"
+    " and whether the computer should be automatically shut down after session"
+    " exit by default.");
 }
 
-extern "C"
-{
-  KCModule *create_smserver(QWidget *parent, const char *name)
-  {
-    KGlobal::locale()->insertCatalogue("kcmsmserver");
-    return new SMServerConfig(parent, name);
-  };
-}
 #include "kcmsmserver.moc"
 
