@@ -30,7 +30,7 @@ class TaskbarConfig : public KCModule
     Q_OBJECT
 
 public:
-    TaskbarConfig( QWidget *parent=0, const char* name=0 );
+    TaskbarConfig( QWidget *parent=0, const char* name=0 , const QStringList &list = QStringList() );
     virtual ~TaskbarConfig();
 
     void load();
@@ -38,11 +38,25 @@ public:
     void defaults();
 
     QString quickHelp() const;
+    const KAboutData* aboutData() const;    
 
 protected slots:
     void configChanged();
-
+    void slotUpdateComboBox();
+    
 private:
+    enum Action {
+        ShowTaskList = 0,
+        ShowOperationsMenu,
+        ActivateRaiseOrIconify,
+        Activate,
+        Raise,
+        Lower,
+        Iconify };
+    static Action buttonAction( ButtonState button, const QString& actionName = QString::null );
+    static QString buttonAction( int action );
+    static const QStringList& actionList();
+    static QStringList i18nActionList();
     TaskbarConfigUI *ui;
 };
 
