@@ -33,22 +33,21 @@
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qfileinfo.h>
-#include <kapp.h>
-#include <qdir.h>
+#include <kapplication.h>
 #include <qpixmap.h>
 #include <qbitmap.h>
 #include <qpainter.h>
 #include <qwindowdefs.h>
 #include <qimage.h>
+#include <qregexp.h>
 #include <dcopclient.h>
 
-#include <kapp.h>
 #include <kconfigbackend.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdesktopfile.h>
 #include <kicontheme.h>
 #include <kipc.h>
@@ -217,7 +216,7 @@ bool Theme::load(const QString &aPath, QString &error)
 {
   QString cmd, str;
   QFileInfo finfo(aPath);
-  int rc, num, i;
+  int rc, i;
 
   assert(!aPath.isEmpty());
 
@@ -911,10 +910,10 @@ void Theme::applyIcons()
 
   KIconTheme icontheme(theme);
 
-  const char *groups[] = { "Desktop", "Toolbar", "MainToolbar", "Small", 0L };
+  const char * const groups[] = { "Desktop", "Toolbar", "MainToolbar", "Small", 0L };
 
   KSimpleConfig *config = new KSimpleConfig("kdeglobals", false);
-  for (int i=0; i<KIcon::LastGroup; i++)
+  for (KIcon::Group i=KIcon::FirstGroup; i<KIcon::LastGroup; i++)
   {
     if (groups[i] == 0L)
       break;
@@ -1270,8 +1269,12 @@ void Theme::runKrdb(void) const
   KSimpleConfig cfg("kcmdisplayrc", true);
 
   cfg.setGroup("X11");
-  if (cfg.readBoolEntry("useResourceManager", true))
-    system("krdb");
+  if (cfg.readBoolEntry("useResourceManager", true)) {
+    QString exe = locate("exe", "krdb");
+    if (exe.isEmpty())
+      exe = "krdb";
+    system(exe.local8Bit());
+  }
 }
 
 
