@@ -30,7 +30,7 @@ class USBViewer : public KCModule
 
 public:
 
-  USBViewer(QWidget *parent = 0L, const char *name = 0L);
+  USBViewer(QWidget *parent = 0L, const char *name = 0L, const QStringList &list=QStringList() );
   virtual ~USBViewer();
 
   void load();
@@ -39,6 +39,8 @@ public:
   
   int buttons();
   QString quickHelp() const;
+  const KAboutData* aboutData() const;
+
 
 
 protected slots:
