@@ -21,7 +21,7 @@
 #include <kconfig.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 
 KAbstractDebugDialog::KAbstractDebugDialog( QWidget *parent, const char *name, bool modal )
