@@ -22,7 +22,7 @@
 
 #include <kabstractdebugdialog.h>
 #include <qcheckbox.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 /**
  * Control debug output of KDE applications
@@ -30,7 +30,7 @@
  * class, but allows to set debug output on or off to several areas much more easily.
  *
  * @author David Faure <faure@kde.org>
- * @version $Id: klistdebugdialog.h,v 1.1 2000/04/08 12:46:38 faure Exp $
+ * @version $Id: klistdebugdialog.h,v 1.4 2002/01/25 11:24:05 blackie Exp $
  */
 class KListDebugDialog : public KAbstractDebugDialog
 {
@@ -40,11 +40,17 @@ public:
   KListDebugDialog( QStringList areaList, QWidget *parent=0, const char *name=0, bool modal=true );
   virtual ~KListDebugDialog() {}
 
+  void activateArea( QCString area, bool activate );
+
   virtual void save();
 
+protected slots:
+  void selectAll();
+  void deSelectAll();
+
 private:
   void load();
-  QList<QCheckBox> boxes;
+  QPtrList<QCheckBox> boxes;
 };
 
 #endif
