@@ -21,11 +21,11 @@
 #include "klistdebugdialog.h"
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <qtextstream.h>
 #include <klocale.h>
 #include <kdebug.h>
-#include <kuniqueapp.h>
+#include <kuniqueapplication.h>
 #include <kconfig.h>
 
 #include <qfile.h>
@@ -46,8 +46,9 @@ QStringList readAreaList()
     QString data;
 
     QTextStream *ts = new QTextStream(&file);
+    ts->setEncoding( QTextStream::Latin1 );
     while (!ts->eof()) {
-      data = ts->readLine(); //.simplifyWhiteSpace();
+      data = ts->readLine().simplifyWhiteSpace();
 
       int pos = data.find("#");
       if ( pos != -1 )
@@ -68,7 +69,7 @@ QStringList readAreaList()
 
 static KCmdLineOptions options[] =
 {
-  { "fullmode", I18N_NOOP("Show the full-fledged dialog instead of the default list dialog."), 0 },
+  { "fullmode", I18N_NOOP("Show the fully-fledged dialog instead of the default list dialog."), 0 },
   { "on <area>", /*I18N_NOOP TODO*/ "Turn area on", 0 },
   { "off <area>", /*I18N_NOOP TODO*/ "Turn area off", 0 },
   { 0, 0, 0 }
