@@ -29,7 +29,7 @@ class KListBox;
 
 class FaxAB : public KDialog
 {
-	Q_OBJECT;
+	Q_OBJECT
 public:
 	FaxAB(QWidget *parent = 0, const char *name = 0);
 	bool isValid();
