@@ -22,8 +22,11 @@
 #include "kdeprintfax.h"
 #include "defcmds.h"
 
-#include <qmultilineedit.h>
+#include <qtextedit.h>
 #include <qfile.h>
+#include <qregexp.h>
+#include <qpushbutton.h>
+#include <qlayout.h>
 
 #include <kprocess.h>
 #include <kglobal.h>
@@ -31,11 +34,15 @@
 #include <klocale.h>
 #include <kdialogbase.h>
 #include <kmimetype.h>
-#include <kstddirs.h>
-#include <kapp.h>
+#include <kstandarddirs.h>
+#include <kapplication.h>
+#include <kwin.h>
+#include <kemailsettings.h>
 
 #include <stdlib.h>
 
+#define quote(x) KShellProcess::quote(x)
+
 FaxCtrl::FaxCtrl(QObject *parent, const char *name)
 : QObject(parent, name)
 {
@@ -44,10 +51,12 @@ FaxCtrl::FaxCtrl(QObject *parent, const char *name)
 	connect(m_process, SIGNAL(receivedStderr(KProcess*,char*,int)), SLOT(slotReceivedStdout(KProcess*,char*,int)));
 	connect(m_process, SIGNAL(processExited(KProcess*)), SLOT(slotProcessExited(KProcess*)));
 	connect(this, SIGNAL(faxSent(bool)), SLOT(cleanTempFiles()));
+	m_logview = 0;
 }
 
 FaxCtrl::~FaxCtrl()
 {
+	slotCloseLog();
 	delete m_process;
 }
 
@@ -61,23 +70,28 @@ bool FaxCtrl::send(KdeprintFax *f)
 	QString	v;
 	// settings
 	conf->setGroup("Fax");
-	m_command.replace(QRegExp("%dev"), conf->readEntry("Device", "modem"));
+	m_command.replace(QRegExp("%dev"), quote(conf->readEntry("Device", "modem")));
 	v = conf->readEntry("Server");
 	if (v.isEmpty()) v = getenv("FAXSERVER");
 	if (v.isEmpty()) v = QString::fromLatin1("localhost");
-	m_command.replace(QRegExp("%server"), v);
+	m_command.replace(QRegExp("%server"), quote(v));
 	m_command.replace(QRegExp("%page"), conf->readEntry("Page", "a4"));
 	v = conf->readEntry("Resolution", "High");
 	m_command.replace(QRegExp("%res"), (v == "High" ? "" : "-l"));
 	conf->setGroup("Personal");
-	m_command.replace(QRegExp("%user"), conf->readEntry("Name", getenv("USER")));
-	m_command.replace(QRegExp("%from"), conf->readEntry("Number", ""));
+	m_command.replace(QRegExp("%user"), quote(conf->readEntry("Name", getenv("USER"))));
+	m_command.replace(QRegExp("%from"), quote(conf->readEntry("Number", "")));
+	if (m_command.find("%email") != -1)
+	{
+		KEMailSettings	e;
+		m_command.replace(QRegExp("'?%email'?"), quote(e.getSetting(KEMailSettings::EmailAddress)));
+	}
 
 	// arguments
-	m_command.replace(QRegExp("%number"), f->number());
-	m_command.replace(QRegExp("%name"), f->name());
-	m_command.replace(QRegExp("%comment"), f->comment());
-	m_command.replace(QRegExp("%enterprise"), f->enterprise());
+	m_command.replace(QRegExp("%number"), quote(f->number()));
+	m_command.replace(QRegExp("%name"), quote(f->name()));
+	m_command.replace(QRegExp("%comment"), quote(f->comment()));
+	m_command.replace(QRegExp("%enterprise"), quote(f->enterprise()));
 
 	m_log = QString::null;
 	m_filteredfiles.clear();
@@ -125,14 +139,21 @@ QString FaxCtrl::faxCommand()
 	KConfig	*conf = KGlobal::config();
 	conf->setGroup("System");
 	QString	sys = conf->readEntry("System", "efax");
-	if (sys == "hylafax") return conf->readEntry("HylaFax", hylafax_default_cmd);
-	else return conf->readEntry("EFax", hylafax_default_cmd);
+	QString cmd;
+	if (sys == "hylafax") cmd = conf->readEntry("HylaFax", hylafax_default_cmd);
+	else cmd = conf->readEntry("EFax", efax_default_cmd);
+	if (cmd.startsWith("%exe_"))
+		cmd = defaultCommand(cmd);
+	return cmd;
 }
 
 void FaxCtrl::sendFax()
 {
 	// files
-	m_command.replace(QRegExp("%files"), m_filteredfiles.join(" "));
+	QString	filestr;
+	for (QStringList::ConstIterator it=m_filteredfiles.begin(); it!=m_filteredfiles.end(); ++it)
+		filestr += (quote(*it)+" ");
+	m_command.replace(QRegExp("%files"), filestr);
 
 	m_process->clearArguments();
 	*m_process << m_command;
@@ -180,19 +201,41 @@ bool FaxCtrl::abort()
 
 void FaxCtrl::viewLog(QWidget *parent)
 {
-	KDialogBase	dlg(parent, 0, true, i18n("Log message"), KDialogBase::Close, KDialogBase::Close);
-	QMultiLineEdit	*m_edit = new QMultiLineEdit(&dlg);
-	m_edit->setText(m_log);
-	m_edit->setWordWrap(QMultiLineEdit::WidgetWidth);
-	m_edit->setReadOnly(true);
-	dlg.setMainWidget(m_edit);
-	dlg.resize(450, 300);
-	dlg.exec();
+	if (!m_logview)
+	{
+		QWidget	*topView = new QWidget(0, "LogView", WType_TopLevel|WStyle_DialogBorder);
+		m_logview = new QTextEdit(topView);
+		m_logview->setReadOnly(true);
+		QPushButton	*m_clear = new QPushButton(i18n("C&lear"), topView);
+		QPushButton	*m_close = new QPushButton(i18n("&Close"), topView);
+		m_close->setDefault(true);
+		connect(m_clear, SIGNAL(clicked()), SLOT(slotClearLog()));
+		connect(m_close, SIGNAL(clicked()), SLOT(slotCloseLog()));
+
+		QVBoxLayout	*l0 = new QVBoxLayout(topView, 10, 10);
+		l0->addWidget(m_logview);
+		QHBoxLayout	*l1 = new QHBoxLayout(0, 0, 10);
+		l0->addLayout(l1);
+		l1->addStretch(1);
+		l1->addWidget(m_clear);
+		l1->addWidget(m_close);
+
+		m_logview->setText(m_log);
+
+		topView->resize(450, 350);
+		topView->show();
+	}
+	else
+	{
+		KWin::setActiveWindow(m_logview->parentWidget()->winId());
+	}
 }
 
 void FaxCtrl::addLog(const QString& s)
 {
-	m_log.append(s).append("\n");
+	m_log.append(s);
+	if (m_logview)
+		m_logview->append(s);
 }
 
 QString FaxCtrl::faxSystem()
@@ -211,4 +254,20 @@ void FaxCtrl::cleanTempFiles()
 	m_tempfiles.clear();
 }
 
+void FaxCtrl::slotClearLog()
+{
+	m_log = QString::null;
+	if (m_logview)
+		m_logview->clear();
+}
+
+void FaxCtrl::slotCloseLog()
+{
+	if (m_logview)
+	{
+		delete m_logview->parentWidget();
+		m_logview = 0;
+	}
+}
+
 #include "faxctrl.moc"
