@@ -21,14 +21,17 @@
 #define KJOBVIEWER_H
 
 #include <kuniqueapp.h>
+#include <kdeprint/kpreloadobject.h>
+#include <qdict.h>
 
-class KSystemTray;
 class KMJobViewer;
-class QTimer;
+class KMTimer;
+class JobTray;
 
-class KJobViewerApp : public KUniqueApplication
+class KJobViewerApp : public KUniqueApplication, public KPReloadObject
 {
 	Q_OBJECT
+	friend class JobTray;
 public:
 	KJobViewerApp();
 	virtual ~KJobViewerApp();
@@ -37,15 +40,18 @@ public:
 
 protected:
 	void initialize();
+	void reload();
 
 protected slots:
-	void slotJobsShown();
+	void slotJobsShown(KMJobViewer*, bool);
 	void slotTimer();
+	void slotPrinterChanged(KMJobViewer*, const QString&);
+	void slotViewerDestroyed(KMJobViewer*);
 
 private:
-	KMJobViewer	*m_view;
-	KSystemTray	*m_tray;
-	QTimer		*m_timer;
+	QDict<KMJobViewer>	m_views;
+	JobTray	*m_tray;
+	KMTimer	*m_timer;
 };
 
 #endif
