@@ -32,13 +32,15 @@ public:
 
 	void listDir(const KURL& url);
 	void get(const KURL& url);
+	void stat(const KURL& url);
 
 private:
 	void listRoot();
-	void createRootEntry(KIO::UDSEntry& entry);
 	void showClassInfo(KMPrinter*);
 	void showPrinterInfo(KMPrinter*);
 	void showSpecialInfo(KMPrinter*);
+	void showData(const QString&);
+	QString locateData(const QString&);
 
 	bool loadTemplate(const QString& filename, QString& buffer);
 };
