@@ -30,16 +30,13 @@
 #include <unistd.h>
 #include <kcolordrag.h>
 
-#include <qdragobject.h>
-#include <qrect.h>
 #include <qdir.h>
 
 #include <netwm.h>
 #include <dcopclient.h>
-#include <kapp.h>
 #include <kcursor.h>
 #include <kdebug.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kimageio.h>
 #include <kipc.h>
 #include <klocale.h>
@@ -47,15 +44,17 @@
 #include <kprocess.h>
 #include <ksycoca.h>
 #include <ktempfile.h>
-#include <kurl.h>
 #include <kmessagebox.h>
 #include <kglobalaccel.h>
 #include <kwinmodule.h>
 #include <krun.h>
-#include <ksimpleconfig.h>
 #include <kwin.h>
 #include <kglobalsettings.h>
 #include <kpopupmenu.h>
+#include <kapplication.h>
+// Create the equivalent of KAccelBase::connectItem
+// and then remove this include and fix reconnects in initRoot() -- ellis
+//#include <kaccelbase.h>
 
 // root window hack
 #include <X11/X.h>
@@ -64,6 +63,25 @@
 #include <X11/Xatom.h>
 // ----
 
+class KRootWidget : public QObject
+{
+public:
+   KRootWidget() : QObject() {
+     kapp->desktop()->installEventFilter(this);
+   }
+   
+   bool eventFilter ( QObject *, QEvent * e )
+   {
+     if (e->type() == QEvent::MouseButtonPress)
+     { 
+       QMouseEvent *me = (QMouseEvent *) e;
+       KRootWm::self()->mousePressed( me->globalPos(), me->button() );
+       return true;
+     }
+     return false; // Don't filter.
+   }
+};
+
 // -----------------------------------------------------------------------------
 #define DEFAULT_DELETEACTION 1
 
@@ -71,7 +89,7 @@
 extern int kdesktop_screen_number;
 
 KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
-    QWidget( 0L, "desktop", WResizeNoErase | (x_root_hack ? (WStyle_Customize | WStyle_NoBorder) : 0) ),
+    QWidget( 0L, "desktop", WResizeNoErase | ( x_root_hack ? (WStyle_Customize | WStyle_NoBorder) : 0) ),
     // those two WStyle_ break kdesktop when the root-hack isn't used (no Dnd)
 
     DCOPObject( "KDesktopIface" ), startup_id( NULL )
@@ -79,6 +97,7 @@ KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
   m_bAutoStart = auto_start;
   m_bWaitForKded = wait_for_kded;
   m_miniCli = 0; // created on demand
+  m_show_iconview = false;
   keys = 0; // created later
   KGlobal::locale()->insertCatalogue("kdesktop");
   KGlobal::locale()->insertCatalogue("libkonq"); // needed for apps using libkonq
@@ -124,53 +143,110 @@ KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
           this, SLOT(slotSettingsChanged(int)));
   kapp->addKipcEventMask(KIPC::SettingsChanged);
 
+  kapp->addKipcEventMask(KIPC::IconChanged);
+  connect(kapp, SIGNAL(iconChanged(int)), this, SLOT(slotIconChanged(int)));
+
   connect(KSycoca::self(), SIGNAL(databaseChanged()),
           this, SLOT(slotDatabaseChanged()));
 
-  m_pIconView = new KDIconView( this, 0 );
-  connect( m_pIconView, SIGNAL( imageDropEvent( QDropEvent * ) ),
-           this, SLOT( handleImageDropEvent( QDropEvent * ) ) );
-  connect( m_pIconView, SIGNAL( colorDropEvent( QDropEvent * ) ),
-           this, SLOT( handleColorDropEvent( QDropEvent * ) ) );
-  connect( m_pIconView, SIGNAL( newWallpaper( const KURL & ) ),
-           this, SLOT( slotNewWallpaper( const KURL & ) ) );
-
-  // All the QScrollView/QWidget-specific stuff should go here, so that we can use
-  // another qscrollview/widget instead of the iconview and use the same code
-  m_pIconView->setVScrollBarMode( QScrollView::AlwaysOff );
-  m_pIconView->setHScrollBarMode( QScrollView::AlwaysOff );
-  m_pIconView->setDragAutoScroll( false );
-  m_pIconView->setFrameStyle( QFrame::NoFrame );
-  m_pIconView->setBackgroundMode( NoBackground );
-  m_pIconView->viewport()->setBackgroundMode( NoBackground );
-  m_pIconView->setFocusPolicy( StrongFocus );
-  m_pIconView->viewport()->setFocusPolicy( StrongFocus );
-  m_pIconView->setGeometry( geometry() );
-
-  // Geert Jansen: backgroundmanager belongs here
-  // TODO tell KBackgroundManager if we change widget()
-  bgMgr = new KBackgroundManager( widget(), m_pKwinmodule );
-  connect( bgMgr, SIGNAL( initDone()), SLOT( backgroundInitDone()));
-
-  //kdDebug(1204) << "KDesktop constructor -> workAreaChanged" << endl;
-  workAreaChanged();
+  m_pIconView = 0;
+  m_pRootWidget = 0;
+  bgMgr = 0;
+  initRoot();
 
   QTimer::singleShot(0, this, SLOT( slotStart() ));
 }
 
+void
+KDesktop::initRoot()
+{
+  KConfigGroup configGroup(KGlobal::config(), "General");
+  m_bDesktopEnabled = configGroup.readBoolEntry("Enabled", true);
+  if (!m_bDesktopEnabled && !m_pRootWidget)
+  {
+     hide();
+     delete bgMgr;
+     bgMgr = 0;
+     if ( m_pIconView )
+        m_pIconView->slotSaveIconPositions();
+     delete m_pIconView;
+     m_pIconView = 0;
+     Display *dpy = qt_xdisplay();
+     Window root = RootWindow(dpy, kdesktop_screen_number);
+     XSelectInput(dpy, root, ButtonPressMask | PropertyChangeMask | StructureNotifyMask);
+     m_pRootWidget = new KRootWidget;
+     // Geert Jansen: backgroundmanager belongs here
+     // TODO tell KBackgroundManager if we change widget()
+     bgMgr = new KBackgroundManager( m_pIconView, m_pKwinmodule );
+     connect( bgMgr, SIGNAL( initDone()), SLOT( backgroundInitDone()));
+     if (!m_bInit)
+     {
+        delete KRootWm::self();
+        KRootWm* krootwm = new KRootWm( this ); // handler for root menu (used by kdesktop on RMB click)
+        keys->setSlot("Lock Screen", krootwm, SLOT(slotLock()));
+        keys->updateConnections();
+     }
+  }
+  else if (m_bDesktopEnabled && !m_pIconView)
+  {
+     delete bgMgr;
+     bgMgr = 0;
+     delete m_pRootWidget;
+     m_pRootWidget = 0;
+     m_pIconView = new KDIconView( this, 0 );
+     connect( m_pIconView, SIGNAL( imageDropEvent( QDropEvent * ) ),
+              this, SLOT( handleImageDropEvent( QDropEvent * ) ) );
+     connect( m_pIconView, SIGNAL( colorDropEvent( QDropEvent * ) ),
+              this, SLOT( handleColorDropEvent( QDropEvent * ) ) );
+     connect( m_pIconView, SIGNAL( newWallpaper( const KURL & ) ),
+              this, SLOT( slotNewWallpaper( const KURL & ) ) );
+
+     // All the QScrollView/QWidget-specific stuff should go here, so that we can use
+     // another qscrollview/widget instead of the iconview and use the same code
+     m_pIconView->setVScrollBarMode( QScrollView::AlwaysOff );
+     m_pIconView->setHScrollBarMode( QScrollView::AlwaysOff );
+     m_pIconView->setDragAutoScroll( false );
+     m_pIconView->setFrameStyle( QFrame::NoFrame );
+     m_pIconView->viewport()->setBackgroundMode( X11ParentRelative );
+     m_pIconView->setFocusPolicy( StrongFocus );
+     m_pIconView->viewport()->setFocusPolicy( StrongFocus );
+     m_pIconView->setGeometry( geometry() );
+     if (m_show_iconview)
+         m_pIconView->show();
+
+     // Geert Jansen: backgroundmanager belongs here
+     // TODO tell KBackgroundManager if we change widget()
+     bgMgr = new KBackgroundManager( m_pIconView, m_pKwinmodule );
+     connect( bgMgr, SIGNAL( initDone()), SLOT( backgroundInitDone()));
+
+     //kdDebug(1204) << "KDesktop constructor -> workAreaChanged" << endl;
+     workAreaChanged();
+     if (!m_bInit)
+     {
+        m_pIconView->initConfig( m_bInit );
+        m_pIconView->start();
+        delete KRootWm::self();
+        KRootWm* krootwm = new KRootWm( this ); // handler for root menu (used by kdesktop on RMB click)
+        keys->setSlot("Lock Screen", krootwm, SLOT(slotLock()));
+        keys->updateConnections();
+     }
+   }
+}
+
 void
 KDesktop::backgroundInitDone()
 {
-  //kdDebug(1204) << "KDesktop::backgroundInitDone" << endl;
-  show();
-  const QPixmap *bg = backgroundPixmap();
-  if ( bg )
-  {
-     // Set the root window background now too.
-     // This is entirely so that when the window manager starts
-     // background flashing is kept to a minimum.
-     kapp->desktop()->setBackgroundPixmap( *bg );
-  }
+    //kdDebug(1204) << "KDesktop::backgroundInitDone" << endl;
+
+    // avoid flicker
+    if (m_bDesktopEnabled)
+    {
+       const QPixmap *bg = QApplication::desktop()->screen()->backgroundPixmap();
+       if ( bg )
+          m_pIconView->setErasePixmap( *bg );
+
+       show();
+    }
 }
 
 void
@@ -186,27 +262,24 @@ KDesktop::slotStart()
 
   initConfig();
 
-  // We need to be visible in order to insert icons, even if the background isn't ready yet...
-  show();
+  if (m_bDesktopEnabled)
+  {
+     // We need to be visible in order to insert icons, even if the background isn't ready yet...
+     show();
+  }
 
   // Now we may react to configuration changes
   m_bInit = false;
 
-  m_pIconView->start();
+  if (m_pIconView)
+     m_pIconView->start();
 
   // Global keys
-  keys = new KGlobalAccel;
+  keys = new KGlobalAccel( this );
 #include "kdesktopbindings.cpp"
-  keys->connectItem("Execute command", this, SLOT(slotExecuteCommand()));
-  keys->connectItem("Show taskmanager", this, SLOT(slotShowTaskManager()));
-  keys->connectItem("Show window list", this, SLOT(slotShowWindowList()));
-  keys->connectItem("Logout", this, SLOT(slotLogout()));
-  keys->connectItem("Logout without Confirmation", this, SLOT(slotLogoutWithoutConfirmation()));
-
-  KRootWm* krootwm = new KRootWm( this ); // handler for root menu (used by kdesktop on RMB click)
-  keys->connectItem("Lock screen", krootwm, SLOT( slotLock()));
 
   keys->readSettings();
+  keys->updateConnections();
 
   if ( m_bAutoStart )
   {
@@ -240,7 +313,6 @@ KDesktop::~KDesktop()
 {
   delete m_miniCli;
   delete bgMgr;
-  delete keys;
   delete startup_id;
 }
 
@@ -248,10 +320,14 @@ KDesktop::~KDesktop()
 
 void KDesktop::initConfig()
 {
-    m_pIconView->initConfig( m_bInit );
+    if (m_pIconView)
+       m_pIconView->initConfig( m_bInit );
 
     if ( keys )
-         keys->readSettings();
+    {
+        keys->readSettings();
+        keys->updateConnections();
+    }
 
     KConfig c( "klaunchrc", true );
     c.setGroup( "FeedbackStyle" );
@@ -308,7 +384,7 @@ void KDesktop::popupExecuteCommand()
   if ( m_miniCli->isVisible() ) {
       m_miniCli->raise();
   } else {
-      KDesktopWidget *desktop = KApplication::desktop();
+      QDesktopWidget *desktop = KApplication::desktop();
       QRect rect = desktop->screenGeometry(desktop->screenNumber(QCursor::pos()));
       m_miniCli->move(rect.x() + (rect.width() - m_miniCli->width())/2,
                       rect.y() + (rect.height() - m_miniCli->height())/2);
@@ -320,14 +396,14 @@ void KDesktop::popupExecuteCommand()
 void KDesktop::slotShowWindowList()
 {
      KWin::setActiveWindow( winId() );
-     KRootWm::getRootWm()->slotWindowList();
+     KRootWm::self()->slotWindowList();
 }
 
 void KDesktop::slotShowTaskManager()
 {
     kdDebug(1204) << "Launching KSysGuard..." << endl;
     KProcess* p = new KProcess;
-    CHECK_PTR(p);
+    Q_CHECK_PTR(p);
 
     *p << "ksysguard";
     *p << "--showprocesses";
@@ -341,47 +417,53 @@ void KDesktop::slotShowTaskManager()
 
 void KDesktop::rearrangeIcons()
 {
-    m_pIconView->rearrangeIcons();
+    if (m_pIconView)
+        m_pIconView->rearrangeIcons();
 }
 
 void KDesktop::lineupIcons()
 {
-    m_pIconView->lineupIcons();
+    if (m_pIconView)
+        m_pIconView->lineupIcons();
 }
 
 void KDesktop::selectAll()
 {
-    m_pIconView->selectAll( true );
+    if (m_pIconView)
+        m_pIconView->selectAll( true );
 }
 
 void KDesktop::unselectAll()
 {
-    m_pIconView->selectAll( false );
+    if (m_pIconView)
+        m_pIconView->selectAll( false );
 }
 
 QStringList KDesktop::selectedURLs()
 {
-    return m_pIconView->selectedURLs();
+    if (m_pIconView)
+        return m_pIconView->selectedURLs();
+    return QStringList();
 }
 
 void KDesktop::refreshIcons()
 {
-    m_pIconView->refreshIcons();
+    if (m_pIconView)
+        m_pIconView->refreshIcons();
 }
 
 KActionCollection * KDesktop::actionCollection()
 {
+    if (!m_pIconView)
+       return 0;
     return m_pIconView->actionCollection();
 }
 
 KURL KDesktop::url() const
 {
-    return m_pIconView->url();
-}
-
-QWidget * KDesktop::widget() const
-{
-     return m_pIconView;
+    if (m_pIconView)
+        return m_pIconView->url();
+    return KURL();
 }
 
 // -----------------------------------------------------------------------------
@@ -400,9 +482,13 @@ void KDesktop::configure()
     // Otherwise, start() will call initConfig anyway
     if (!m_bInit)
     {
+       initRoot();
        initConfig();
-       KRootWm::getRootWm()->initConfig();
+       KRootWm::self()->initConfig();
     }
+
+    keys->readSettings();
+    keys->updateConnections();
 }
 
 void KDesktop::slotSettingsChanged(int category)
@@ -411,7 +497,24 @@ void KDesktop::slotSettingsChanged(int category)
     if (category == KApplication::SETTINGS_PATHS)
     {
         kdDebug(1204) << "KDesktop::slotSettingsChanged SETTINGS_PATHS" << endl;
-        m_pIconView->recheckDesktopURL();
+        if (m_pIconView)
+            m_pIconView->recheckDesktopURL();
+    }
+    else if (category == KApplication::SETTINGS_SHORTCUTS)
+    {
+        kdDebug(1204) << "KDesktop::slotSettingsChanged SETTINGS_SHORTCUTS" << endl;
+        keys->readSettings();
+        keys->updateConnections();
+    }
+}
+
+void KDesktop::slotIconChanged(int group)
+{
+    if ( group == KIcon::Desktop )
+    {
+        kdDebug(1204) << "KDesktop::slotIconChanged" << endl;
+        refreshIcons();
+        refresh();
     }
 }
 
@@ -420,7 +523,7 @@ void KDesktop::slotDatabaseChanged()
     //kdDebug(1204) << "KDesktop::slotDatabaseChanged" << endl;
     if (m_bInit) // kded is done, now we can "start" for real
         slotStart();
-    if (KSycoca::isChanged("mimetypes"))
+    if (m_pIconView && KSycoca::isChanged("mimetypes"))
         m_pIconView->refreshMimeTypes();
 }
 
@@ -442,6 +545,9 @@ void KDesktop::refresh()
 
 void KDesktop::slotSetVRoot()
 {
+    if (!m_pIconView)
+        return;
+
     if (KWin::info(winId()).mappingState == NET::Withdrawn) {
         QTimer::singleShot(100, this, SLOT(slotSetVRoot()));
         return;
@@ -449,7 +555,7 @@ void KDesktop::slotSetVRoot()
 
     unsigned long rw = RootWindowOfScreen(ScreenOfDisplay(qt_xdisplay(), qt_xscreen()));
     unsigned long vroot_data[1] = { m_pIconView->viewport()->winId() };
-    Atom vroot = XInternAtom(qt_xdisplay(), "__SWM_VROOT", False);
+    static Atom vroot = XInternAtom(qt_xdisplay(), "__SWM_VROOT", False);
 
     Window rootReturn, parentReturn, *children;
     unsigned int numChildren;
@@ -475,7 +581,8 @@ void KDesktop::slotSetVRoot()
 
 void KDesktop::slotShutdown()
 {
-    m_pIconView->slotSaveIconPositions();
+    if ( m_pIconView )
+        m_pIconView->slotSaveIconPositions();
     if ( m_miniCli )
         m_miniCli->saveConfig();
 }
@@ -495,8 +602,11 @@ void KDesktop::workAreaChanged()
 
 void KDesktop::updateWorkArea()
 {
-    QRect wr( kwinModule()->workArea( kwinModule()->currentDesktop() ) );
-    m_pIconView->updateWorkArea( wr );
+    if (m_pIconView)
+    {
+        QRect wr( kwinModule()->workArea( kwinModule()->currentDesktop() ) );
+        m_pIconView->updateWorkArea( wr );
+    }
 }
 
 void KDesktop::handleColorDropEvent(QDropEvent * e)
@@ -542,25 +652,59 @@ void KDesktop::slotNewWallpaper(const KURL &url)
     bgMgr->setWallpaper(tmpFile);
 }
 
+// for dcop interface backward compatibility
 void KDesktop::logout()
 {
-    if( !kapp->requestShutDown() )
+    logout( KApplication::ShutdownConfirmDefault,
+            KApplication::ShutdownTypeNone );
+}
+
+void KDesktop::logout( KApplication::ShutdownConfirm confirm, 
+                       KApplication::ShutdownType sdtype )
+{
+    if( !kapp->requestShutDown( confirm, sdtype ) )
         // this i18n string is also in kicker/applets/run/runapplet
-        KMessageBox::error( this, i18n("Could not logout properly.  The session manager cannot\n"
-                                        "be contacted.  You can try to force a shutdown by pressing\n"
-                                        "the CTRL, ALT and BACKSPACE keys at the same time.  Note\n"
-                                        "however that your current session will not be saved with a\n"
+        KMessageBox::error( this, i18n("Could not logout properly.\nThe session manager cannot "
+                                        "be contacted. You can try to force a shutdown by pressing "
+                                        "the CTRL, ALT and BACKSPACE keys at the same time. Note "
+                                        "however that your current session will not be saved with a "
                                         "forced shutdown." ) );
 }
 
 void KDesktop::slotLogout()
 {
-    logout();
+    logout( KApplication::ShutdownConfirmDefault,
+            KApplication::ShutdownTypeNone );
 }
 
-void KDesktop::slotLogoutWithoutConfirmation()
+void KDesktop::slotLogoutNoCnf()
 {
-    kapp->requestShutDown( true );
+    logout( KApplication::ShutdownConfirmNo,
+            KApplication::ShutdownTypeNone );
+}
+
+void KDesktop::slotHalt()
+{
+    logout( KApplication::ShutdownConfirmDefault,
+            KApplication::ShutdownTypeHalt );
+}
+
+void KDesktop::slotHaltNoCnf()
+{
+    logout( KApplication::ShutdownConfirmNo,
+            KApplication::ShutdownTypeHalt );
+}
+
+void KDesktop::slotReboot()
+{
+    logout( KApplication::ShutdownConfirmDefault,
+            KApplication::ShutdownTypeReboot );
+}
+
+void KDesktop::slotRebootNoCnf()
+{
+    logout( KApplication::ShutdownConfirmNo,
+            KApplication::ShutdownTypeReboot );
 }
 
 void KDesktop::setVRoot( bool enable )
@@ -577,4 +721,24 @@ void KDesktop::setVRoot( bool enable )
     slotSetVRoot();
 }
 
+void KDesktop::setIconsEnabled( bool enable )
+{
+    if ( enable == m_bDesktopEnabled )
+        return;
+
+    m_bDesktopEnabled = enable;
+    kdDebug(1204) << "setIcons " << enable << endl;
+    KConfig * config = KGlobal::config();
+    KConfigGroupSaver gs( config, "General" );
+    config->writeEntry( "Enabled", m_bDesktopEnabled );
+    config->sync();
+    if (!enable) {
+        delete m_pIconView;
+        m_pIconView = 0;
+        m_show_iconview = false;
+    } else
+        m_show_iconview = true;
+    configure();
+}
+
 #include "desktop.moc"
