@@ -1,9 +1,7 @@
 #include <unistd.h>
 
 
-#include <kapp.h>
 #include <ksimpleconfig.h>
-#include <kstddirs.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 
@@ -11,23 +9,22 @@
 
 
 #include "bgrender.h"
-#include "kdmdesktop.h"
 #include "kdmdesktop.moc"
 
 #include <config.h>
+#include <stdlib.h>
 
 static const char *description = 
 	I18N_NOOP("Fancy desktop background for kdm");
 
-static const char *version = "v1.3";
+static const char *version = "v1.4";
 
 
 
 MyApplication::MyApplication()
   : KApplication(), 
     renderer(0, new KSimpleConfig( 
-	KGlobal::dirs()->resourceDirs("config").last() + 
-	QString::fromLatin1("kdmrc") ))
+	QString::fromLatin1 (KDE_CONFDIR "/kdm/kdmrc") ))
 {
   connect(&renderer, SIGNAL(imageDone(int)), this, SLOT(renderDone()));
   renderer.start();
@@ -36,8 +33,7 @@ MyApplication::MyApplication()
 
 void MyApplication::renderDone()
 {
-  QPixmap pm;
-  pm.convertFromImage(*renderer.image());
+  QPixmap pm = *renderer.pixmap();
   desktop()->setBackgroundPixmap(pm);
   desktop()->repaint(true);
   quit();
@@ -46,6 +42,9 @@ void MyApplication::renderDone()
 
 int main(int argc, char *argv[])
 {
+  setenv("HOME", "/tmp", 1);	/* for QSettings */
+  KApplication::disableAutoDcopRegistration();
+
   KLocale::setMainCatalogue("kdesktop");
   KCmdLineArgs::init(argc, argv, "kdmdesktop", description, version);
 
