@@ -12,41 +12,32 @@
 #include <string.h>
 #include <errno.h>
 
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlayout.h>
-#include <qtimer.h>
 #include <qvbox.h>
-#include <qslider.h>
-#include <qwhatsthis.h>
-#include <qcstring.h>
+#include <qlabel.h>
 #include <qbitmap.h>
+#include <qslider.h>
+#include <qlayout.h>
+#include <qcheckbox.h>
+#include <qwhatsthis.h>
 
-#include <kdialog.h>
 #include <klocale.h>
-#include <kconfig.h>
-#include <kiconloader.h>
-#include <kbuttonbox.h>
 #include <kmessagebox.h>
-#include <kmimetype.h>
-#include <kservice.h>
 #include <kprocess.h>
 #include <kcombobox.h>
-#include <kcompletion.h>
-#include <knuminput.h>
 #include <klineedit.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kpassdlg.h>
 #include <krun.h>
 #include <kwin.h>
-#include <kdesu/stub.h>
 #include <kdesu/su.h>
-#include <kstddirs.h>
-
-#include <konq_faviconmgr.h>
-
+#include <kstandarddirs.h>
+#include <kconfig.h>
+#include <kiconloader.h>
+#include <kpushbutton.h>
+#include <kguiitem.h>
+#include <kstdguiitem.h>
+#include <kmimetype.h>
 #include "minicli.moc"
 
 #define KDESU_ERR strerror(errno)
@@ -57,13 +48,11 @@
         KWin::setState( winId(), NET::StaysOnTop );
 
 Minicli::Minicli( QWidget *parent, const char *name)
-        :QDialog( parent, name )
+        :KDialog( parent, name )
 {
     m_filterData = new KURIFilterData();
-    m_strCWD = QString::null;
     m_IconName = QString::null;
     m_FocusWidget = 0;
-    m_favIconMgr = new KonqFavIconMgr( this );
     loadGUI();
     KWin::setState( winId(), NET::StaysOnTop );
 }
@@ -76,89 +65,75 @@ Minicli::~Minicli()
 
 void Minicli::loadGUI()
 {
-    QVBoxLayout* vbox = new QVBoxLayout( this );
-    setIcon( SmallIcon("run") );
-
-    setCaption( i18n("Run Command") );
+    QVBoxLayout* vbox = new QVBoxLayout( this, KDialog::marginHint(),
+                                         KDialog::spacingHint() );
     vbox->setResizeMode( QLayout::Fixed );
-
-    vbox->setSpacing( KDialog::spacingHint() );
-    vbox->setMargin( KDialog::marginHint() );
+    KWin::setIcons( winId(), DesktopIcon("run"), SmallIcon("run") );
+    setCaption( i18n("Run Command") );
 
     QHBox *hBox = new QHBox( this );
-    CHECK_PTR(hBox);
     vbox->addWidget( hBox );
     hBox->setSpacing( KDialog::marginHint() );
 
     m_runIcon = new QLabel( hBox );
-    CHECK_PTR(m_runIcon);
     m_runIcon->setPixmap(DesktopIcon("go"));
     m_runIcon->setFixedSize(m_runIcon->sizeHint());
 
-    QLabel *label = new QLabel( i18n("Enter the name of the application you want\n"
+    QLabel *label = new QLabel( i18n("Enter the name of the application you want "
                                      "to run or the URL you want to view."), hBox);
-    CHECK_PTR(label);
+    label->setAlignment( Qt::WordBreak );
     hBox = new QHBox( this );
     vbox->addWidget( hBox );
-    CHECK_PTR(hBox);
     hBox->setSpacing( KDialog::marginHint() );
 
     label = new QLabel(i18n("Co&mmand:"), hBox);
-    CHECK_PTR(label);
     label->setFixedSize(label->sizeHint());
 
     m_runCombo = new KHistoryCombo( hBox );
-    QWhatsThis::add(m_runCombo, i18n("Enter the command or url you wish to run here."));
-    CHECK_PTR(m_runCombo);
+    QWhatsThis::add(m_runCombo, i18n("Enter the command you wish to execute or the address "
+                                     "of the resource you want to open. This can be a remote URL "
+                                     "like \"www.kde.org\" or a local one like \"~/.kderc\""));
     connect( m_runCombo, SIGNAL( textChanged( const QString& ) ),
-	     SLOT( slotCmdChanged( const QString& ) ) );
-    connect( m_runCombo, SIGNAL( activated( const QString& ) ), m_runCombo,
-	     SLOT( addToHistory( const QString& ) ) );
+             SLOT( slotCmdChanged( const QString& ) ) );
     label->setBuddy(m_runCombo);
-    // Stop the combobox from growing and growing and...(DA)
-    m_runCombo->setFixedWidth( int(0.85 * sizeHint().width()) );
-
+    m_runCombo->setFixedWidth( m_runCombo->fontMetrics().width('W') * 23 );
     m_parseTimer = new QTimer(this);
-    CHECK_PTR(m_parseTimer);
     connect(m_parseTimer, SIGNAL(timeout()), SLOT(slotParseTimer()));
 
     mbAdvanced = false;
     mpAdvanced = new MinicliAdvanced(this);
     mpAdvanced->hide();
-    // Prevents the items in this group box from
-    // receiving focus.
     mpAdvanced->setEnabled( false );
     vbox->addWidget(mpAdvanced, AlignLeft);
+    vbox->addSpacing( KDialog::spacingHint() );
 
-    hBox = new QHBox(this);
-    CHECK_PTR(hBox);
-    vbox->addWidget( hBox );
-    hBox->setSpacing( KDialog::marginHint() );
+    QWidget* btnBox = new QWidget( this );
+    QBoxLayout* bbLay = new QHBoxLayout( btnBox );
+    bbLay->setSpacing( KDialog::spacingHint() );
 
-    KButtonBox *bbox = new KButtonBox(hBox);
-    CHECK_PTR(bbox);
-    mpAdvButton = bbox->addButton(i18n("&Options >>"), false);
-    CHECK_PTR(mpAdvButton);
-    connect(mpAdvButton, SIGNAL(clicked()), SLOT(slotAdvanced()));
-    bbox->addStretch();
-    QPushButton *runButton = bbox->addButton(i18n("&Run"), false);
-    CHECK_PTR(runButton);
-    runButton->setDefault( true );
-    connect(runButton, SIGNAL(clicked()), this, SLOT(accept()));
+    m_btnOptions = new KPushButton( KGuiItem( i18n( "&Options >>" ),
+                                    "configure" ), btnBox );
+    bbLay->addWidget( m_btnOptions );
+    connect( m_btnOptions, SIGNAL(clicked()), SLOT(slotAdvanced()) );
+    bbLay->addStretch( 1 );
 
-    QPushButton *cancelButton = bbox->addButton(i18n("&Cancel"), false);
-    CHECK_PTR(cancelButton);
-    connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
+    btnRun = new KPushButton( KGuiItem( i18n( "&Run" ), "run" ), btnBox );
+    bbLay->addWidget( btnRun );
+    btnRun->setDefault( true );
+    connect( btnRun, SIGNAL(clicked()), this, SLOT(accept()) );
 
-    bbox->layout();
-    move( QApplication::desktop()->width()/2 - width()/2,
-          QApplication::desktop()->height()/2 - height()/2);
+    m_btnCancel = new KPushButton( KStdGuiItem::cancel(), btnBox );
+    bbLay->addWidget( m_btnCancel );
+    connect(m_btnCancel, SIGNAL(clicked()), this, SLOT(reject()));
+    vbox->addWidget( btnBox );
 
-    // Create the completion object just before
-    // loading new stuff into it.
     loadConfig();
-    m_runCombo->setFocus();
     m_runCombo->clearEdit();
+    m_runCombo->setFocus();
+    btnRun->setEnabled(!m_runCombo->currentText().isEmpty());
+
+    // Very important, to get the size right before showing
+    vbox->activate();
 }
 
 void Minicli::loadConfig()
@@ -188,48 +163,15 @@ void Minicli::saveConfig()
     config->sync();
 }
 
-bool Minicli::setCWD( const QString& )
-{
-/*
-    QDir d( cwd );
-    if( d.exists() )
-    {
-        m_strCWD = cwd;
-        if( m_strCWD.at(0) != '/' )
-            m_strCWD += '/';
-        return true;
-    }
-*/
-    return false;
-}
-
-void Minicli::keyPressEvent(QKeyEvent *kev)
-{
-    int a = ((QKeyEvent*)kev)->ascii();
-    // EOF, ESC
-    if (a == 4 || a == 27)
-    {
-        kev->accept();
-    	reject();
-        return;
-    }
-    if (kev->key() == Key_Return || kev->key() == Key_Enter)
-    {
-        kev->accept();
-        accept();
-        return;
-    }
-    kev->ignore();
-}
-
 void Minicli::accept()
 {
+//    qDebug("***** contents: %s", m_runCombo->currentText().latin1());
+//    kdDebug() << kdBacktrace() << endl;
     int ret = run_command();
-    // If incorrect but with a positive return
-    // value simply return so that the user can
-    // try again...
     if( ret > 0 )
         return;
+
+    m_runCombo->addToHistory( m_runCombo->currentText() );
     reset();
     QDialog::accept();
     saveConfig();
@@ -254,6 +196,17 @@ void Minicli::reset()
     m_FocusWidget = 0;
 }
 
+void Minicli::keyPressEvent( QKeyEvent* e )
+{
+  if ( e->key() == Qt::Key_Escape )
+  {
+    e->accept();
+    m_btnCancel->animateClick();
+    return;
+  }
+  QDialog::keyPressEvent( e );
+}
+
 int Minicli::run_command()
 {
     kapp->propagateSessionManager();
@@ -266,16 +219,10 @@ int Minicli::run_command()
         slotParseTimer();
     }
 
-    // Okay lets get the actual data.
-    // But get it from the combo, not from m_filterData,
-    // because in the filter we only put the first 'word' (David)
-    //
-    // Not anymore! The shortURI filter plugin now has basic support
-    // for splitting an executable and associated command line options
-    // and arguments. See KURIFilterData::argsAndOptions() (DA)
-    QString cmd = (m_filterData->uri().isLocalFile() ? m_filterData->uri().path():m_filterData->uri().url());
+    KConfigGroupSaver gs(KGlobal::config(), "General");
+    QString terminal = KGlobal::config()->readEntry("TerminalApplication", "konsole");
 
-    // Nothing interesting. Quit!
+    QString cmd = (m_filterData->uri().isLocalFile() ? m_filterData->uri().path():m_filterData->uri().url());
     if ( m_runCombo->currentText().isEmpty() )
     {
         return 1;  // Ignore
@@ -336,8 +283,10 @@ int Minicli::run_command()
         QCString command = cmd.local8Bit();
         if( m_filterData->hasArgsAndOptions() )
             command += m_filterData->argsAndOptions().local8Bit();
+  
         if (mpAdvanced->terminal())
-            command.prepend("konsole -e /bin/sh -c ");
+            command = terminal.local8Bit() + QCString(" -e /bin/sh -c \"") + command + "\"";
+
         proc.setCommand(command);
         if (proc.checkInstall(mpAdvanced->password()) < 0)
         {
@@ -360,8 +309,8 @@ int Minicli::run_command()
         QString exec;
         if (mpAdvanced->terminal())
         {
-            exec = QString::fromLatin1("konsole");
-            cmd = QString::fromLatin1("konsole -e ") + cmd;
+	    exec = terminal;
+            cmd = terminal + QString::fromLatin1(" -e ") + cmd;
             if( m_filterData->hasArgsAndOptions() )
                 cmd += m_filterData->argsAndOptions();
         }
@@ -384,19 +333,17 @@ int Minicli::run_command()
                     exec = cmd;
                     if( m_filterData->hasArgsAndOptions() )
                         cmd += m_filterData->argsAndOptions();
-                    kdDebug(1207) << "Command to execute: " << cmd << endl;
-                    kdDebug(1207) << "Executable name: " << exec << endl;
+                    //kdDebug(1207) << "Command to execute: " << cmd << endl;
+                    //kdDebug(1207) << "Executable name: " << exec << endl;
                     break;
                 }
                 case KURIFilterData::UNKNOWN:
                 case KURIFilterData::ERROR:
                 default:
                     MSGBOX_WRAPPER(
-                    KMessageBox::sorry( this, i18n("<qt>Could not run <b>%1</b>.<br/>"
-                                                   "The specified command or URL was "
-                                                   "not found!</qt>").arg( cmd ));
+                    KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
+                                                   "Could not run the specified command!").arg( cmd ));
                     )
-                    m_runCombo->removeFromHistory( m_runCombo->currentText() );
                     return 1;
             }
         }
@@ -407,10 +354,9 @@ int Minicli::run_command()
         else
         {
             MSGBOX_WRAPPER(
-            KMessageBox::sorry( this, i18n("<qt>Could not run <b>%1</b>.<br/>"
-                                            "The specified command does not exist!</qt>").arg( cmd ) );
+            KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
+                                           "The specified command does not exist!").arg( cmd ) );
             )
-            m_runCombo->removeFromHistory( m_runCombo->currentText() );
             return 1; // Let the user try again...
         }
     }
@@ -419,6 +365,10 @@ int Minicli::run_command()
 
 void Minicli::slotCmdChanged( const QString& )
 {
+    bool state=m_runCombo->currentText().isEmpty();
+    btnRun->setEnabled(!state);
+    if(state)
+        return;
     m_parseTimer->start(250, true);
 }
 
@@ -428,8 +378,8 @@ void Minicli::slotAdvanced()
     if (mbAdvanced)
     {
         mpAdvanced->show();
-    	mpAdvButton->setText(i18n("&Options <<"));
-    	mpAdvanced->setMaximumSize(1000, 1000);
+        m_btnOptions->setText(i18n("&Options <<"));
+        mpAdvanced->setMaximumSize(1000, 1000);
         mpAdvanced->setEnabled( true );
         // Set the focus back to the widget
         // that had it to begin with, i.e. do
@@ -443,7 +393,7 @@ void Minicli::slotAdvanced()
     else
     {
         mpAdvanced->hide();
-        mpAdvButton->setText(i18n("&Options >>"));
+        m_btnOptions->setText(i18n("&Options >>"));
         if( m_FocusWidget && m_FocusWidget->parent() != mpAdvanced )
             m_FocusWidget->setFocus();
         mpAdvanced->setMaximumSize(0, 0);
@@ -461,7 +411,7 @@ void Minicli::slotParseTimer()
     if ( cmd.isEmpty() )
     {
         m_runIcon->setPixmap(DesktopIcon("go"));
-    	return;
+        return;
     }
 
     if( mpAdvanced->terminal() )
@@ -469,24 +419,22 @@ void Minicli::slotParseTimer()
         m_IconName = QString::fromLatin1( "konsole" );
     }
     else
-	{
+    {
         m_filterData->setData( cmd );
         QStringList filters;
-        filters << "kshorturifilter" << "kurisearchfilter";
+        filters << "kurisearchfilter" << "kshorturifilter";
         KURIFilter::self()->filterURI( *(m_filterData), filters );
-        kdDebug(1207) << "Filtered command: " << m_filterData->uri().url() << endl;
-        kdDebug(1207) << "Command line options:" << m_filterData->argsAndOptions() << endl;
         m_IconName = m_filterData->iconName();
         if( m_IconName.isEmpty() || m_IconName == "unknown" )
             m_IconName = QString::fromLatin1("go");
-	}
+    }
     QPixmap icon = DesktopIcon( m_IconName );
     if ( m_IconName == "www" )
     {
         // Not using KIconEffect::overlay as that requires the same size
         // for the icon and the overlay, also the overlay definately doesn't
         // have a more that one-bit alpha channel here
-        QPixmap overlay( locate ( "icon", m_favIconMgr->iconForURL( m_filterData->uri().url() ) + ".png" ) );
+        QPixmap overlay( locate ( "icon", KMimeType::favIconForURL( m_filterData->uri() ) + ".png" ) );
         if ( !overlay.isNull() )
         {
             int x = icon.width() - overlay.width(),
@@ -494,7 +442,8 @@ void Minicli::slotParseTimer()
             if ( icon.mask() )
             {
                 QBitmap mask = *icon.mask();
-                bitBlt( &mask, x, y, overlay.mask(),
+                bitBlt( &mask, x, y,
+                        overlay.mask() ? const_cast<QBitmap *>(overlay.mask()) : &overlay,
                         0, 0, overlay.width(), overlay.height(),
                         overlay.mask() ? OrROP : SetROP );
                 icon.setMask(mask);
@@ -509,36 +458,34 @@ void Minicli::slotParseTimer()
 MinicliAdvanced::MinicliAdvanced(QWidget *parent, const char *name)
                 :QGroupBox(parent, name)
 {
-    mbTerminal = mbChangeUid = mbChangeScheduler = false;
-    mScheduler = 0;
-
     setTitle(i18n("Advanced settings"));
-
-    QBoxLayout *top = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
-    top->addSpacing(20);
-
+    QBoxLayout *top = new QVBoxLayout( this, KDialog::marginHint(),
+                                       KDialog::spacingHint() );
+    top->addSpacing( fontMetrics().lineSpacing() );
     mpCBTerm = new QCheckBox(i18n("Run in &terminal"), this);
-    QWhatsThis::add(mpCBTerm, i18n("Check this option if the application you want "
-	    "to run is a text mode application. The application will then be "
-	    "run in a terminal emulator window."));
+    QWhatsThis::add(mpCBTerm, i18n("Check this option if the application you "
+                                   "want to run is a text mode application. The "
+                                   "application will then be run in a terminal "
+                                   "emulator window."));
     connect(mpCBTerm, SIGNAL(toggled(bool)), SLOT(slotTerminal(bool)));
     top->addWidget(mpCBTerm, AlignLeft);
     mpCBUser = new QCheckBox(i18n("Run as a different &user"), this);
     QWhatsThis::add(mpCBUser, i18n("Check this option if you want to run the "
-	    "application with a different user id. Every process has a "
-	    "user id associated with it. This id code determines file "
-	    "access and other permissions. The password of the user is "
-	    "required to do this."));
+                                   "application with a different user id. "
+                                   "Every process has a user id associated with "
+                                   "it. This id code determines file access and "
+                                   "other permissions. The password of the user "
+                                   "is required to do this."));
     connect(mpCBUser, SIGNAL(toggled(bool)), SLOT(slotChangeUid(bool)));
     top->addWidget(mpCBUser, AlignLeft);
     QBoxLayout *hbox = new QHBoxLayout(0L, KDialog::marginHint(), KDialog::spacingHint());
     top->addLayout(hbox);
-    hbox->addSpacing(20);
-    QLabel *lbl = new QLabel(i18n("user&name:"), this);
+    hbox->addSpacing( KDialog::spacingHint() );
+    QLabel *lbl = new QLabel(i18n("User&name:"), this);
     hbox->addWidget(lbl);
     mpEdit = new KLineEdit(this);
-    QWhatsThis::add(mpEdit, i18n("Enter the user as who you want to run "
-                                 "the application here."));
+    QWhatsThis::add(mpEdit, i18n("Enter the user here who you want to run the "
+                                 "application as."));
     lbl->setBuddy(mpEdit);
     connect(mpEdit, SIGNAL(textChanged(const QString &)),
             SLOT(slotUsername(const QString &)));
@@ -546,48 +493,54 @@ MinicliAdvanced::MinicliAdvanced(QWidget *parent, const char *name)
     hbox->addStretch();
     mpCBPrio = new QCheckBox(i18n("Run with a different &priority"), this);
     QWhatsThis::add(mpCBPrio, i18n("Check this option if you want to run the "
-	    "application with a different priority. A higher priority "
-	    "tells the operating system to give more processing time to your "
-	    "application."));
+                                   "application with a different priority. A "
+                                   "higher priority tells the operating system "
+                                   "to give more processing time to your "
+                                   "application."));
     top->addWidget(mpCBPrio, AlignLeft);
     connect(mpCBPrio, SIGNAL(toggled(bool)), SLOT(slotChangeScheduler(bool)));
 
     hbox = new QHBoxLayout(0L, KDialog::marginHint(), KDialog::spacingHint());
     top->addLayout(hbox);
-    hbox->addSpacing(20);
-    lbl = new QLabel(i18n("pr&iority:"), this);
-    hbox->addWidget(lbl);
+    hbox->addSpacing( KDialog::spacingHint() );
+    priorityLbl = new QLabel(i18n("Pr&iority:"), this);
+    hbox->addWidget(priorityLbl);
     mpSlider = new QSlider(0, 100, 10, 50, QSlider::Horizontal, this);
+    priorityLbl->setBuddy(mpSlider);
     QWhatsThis::add(mpSlider, i18n("The priority can be set here. From left "
-	    "to right, it goes from low to high. The center position is the "
-	    "default value. For priorities higher than the default, you will "
-	    "need root's password."));
+                                   "to right, it goes from low to high. The "
+                                   "center position is the default value. For "
+                                   "priorities higher than the default, you "
+                                   "will need root's password."));
     lbl->setBuddy(mpSlider);
     mpSlider->setLineStep(5);
     connect(mpSlider, SIGNAL(valueChanged(int)), SLOT(slotPriority(int)));
     hbox->addWidget(mpSlider);
-    lbl = new QLabel(i18n("high"), this);
-    hbox->addWidget(lbl);
+    priorityHighLbl = new QLabel(i18n("High"), this);
+    hbox->addWidget(priorityHighLbl);
     hbox->addStretch();
 
     hbox = new QHBoxLayout(0L, KDialog::marginHint(), KDialog::spacingHint());
     top->addLayout(hbox);
-    hbox->addSpacing(20);
-    lbl = new QLabel(i18n("&scheduler:"), this);
+    hbox->addSpacing(KDialog::spacingHint());
+    lbl = new QLabel(i18n("&Scheduler:"), this);
     hbox->addWidget(lbl);
     mpCombo = new KComboBox(this);
+// does completion make sense for a read-only combobox?
+//    mpCombo->completionBox()->setTabHandling( true );
     QWhatsThis::add(mpCombo, i18n("Here you can select which scheduler to use "
-	    "for the application. The scheduler is that part of the operating "
-	    "system which decides what process will run and which will have "
-	    "to wait. Two schedulers are available:"
-	    "<ul><li><em>Normal:</em> This is the standard, timesharing "
-	    "scheduler. It will fairly divide the available processing time "
-	    "over all processes. </li>"
-	    "<li><em>Realtime:</em> This scheduler will run your application "
-	    "uninterrupted until it gives up the processor. This can be "
-	    "dangerous. An application that does not give up the processor "
-	    "might hang the system. You need root's password to use this "
-	    "scheduler."));
+                                  "for the application. The scheduler governs "
+                                  "which process will run and which will have "
+                                  "to wait. Two schedulers are available:"
+                                  "<ul><li><em>Normal:</em> This is the "
+                                  "standard, timesharing scheduler. It will "
+                                  "divide fairly the available processing time "
+                                  "between all processes. </li><li><em>Realtime:</em> "
+                                  "This scheduler will run your application "
+                                  "uninterrupted until it gives up the processor. "
+                                  "This can be dangerous. An application that does "
+                                  "not give up the processor might hang the system. "
+                                  "You need root's password to use the scheduler."));
     lbl->setBuddy(mpCombo);
     connect(mpCombo, SIGNAL(activated(int)), SLOT(slotScheduler(int)));
     hbox->addWidget(mpCombo);
@@ -596,9 +549,9 @@ MinicliAdvanced::MinicliAdvanced(QWidget *parent, const char *name)
     mpAuthLabel = new QLabel(this);
     top->addWidget(mpAuthLabel);
     hbox = new QHBoxLayout(0L, KDialog::marginHint(), KDialog::spacingHint());
-    hbox->addSpacing(20);
+    hbox->addSpacing( KDialog::spacingHint() );
     top->addLayout(hbox);
-    lbl = new QLabel(i18n("pass&word:"), this);
+    lbl = new QLabel(i18n("Pass&word:"), this);
     hbox->addWidget(lbl);
     mpPassword = new KPasswordEdit(this);
     QWhatsThis::add(mpPassword, i18n("Enter the requested password here."));
@@ -613,25 +566,25 @@ MinicliAdvanced::MinicliAdvanced(QWidget *parent, const char *name)
     int i, maxEntries = 1000;
     setpwent();
     for (i=0; ((pw = getpwent()) != 0L) && (i < maxEntries); i++)
-	completion->addItem(QString::fromLocal8Bit(pw->pw_name));
+        completion->addItem(QString::fromLocal8Bit(pw->pw_name));
     endpwent();
     if (i < maxEntries)
     {
-	mpEdit->setCompletionObject(completion, true);
-	mpEdit->setCompletionMode(KGlobalSettings::completionMode());
+        mpEdit->setCompletionObject(completion, true);
+        mpEdit->setCompletionMode(KGlobalSettings::completionMode());
         mpEdit->setAutoDeleteCompletionObject( true );
     }
     else
-	delete completion;
+        delete completion;
 
     mpCombo->insertItem(i18n("Normal"), StubProcess::SchedNormal);
     mpCombo->insertItem(i18n("Realtime"), StubProcess::SchedRealtime);
-
     mpEdit->setEnabled(false);
     mpCombo->setEnabled(false);
     mpSlider->setEnabled(false);
-
-    updateAuthLabel();
+    priorityLbl->setEnabled(false);
+    priorityHighLbl->setEnabled(false);
+    reset();
 }
 
 MinicliAdvanced::~MinicliAdvanced()
@@ -643,16 +596,16 @@ void MinicliAdvanced::updateAuthLabel()
     QString authUser;
     if (mbChangeScheduler && (mPriority > 50) || (mScheduler != StubProcess::SchedNormal))
     {
-	authUser = QString::fromLatin1("root");
-	mpPassword->setEnabled(true);
+        authUser = QString::fromLatin1("root");
+        mpPassword->setEnabled(true);
     } else if (mbChangeUid && !mUsername.isEmpty())
     {
-	authUser = mpEdit->text();
-	mpPassword->setEnabled(true);
+        authUser = mpEdit->text();
+        mpPassword->setEnabled(true);
     } else
     {
-	authUser = i18n("none");
-	mpPassword->setEnabled(false);
+        authUser = i18n("none");
+        mpPassword->setEnabled(false);
     }
     mpAuthLabel->setText(i18n("Password required: %1").arg(authUser));
 }
@@ -667,13 +620,16 @@ void MinicliAdvanced::slotChangeUid(bool ena)
     mbChangeUid = ena;
     mpEdit->setEnabled(ena);
     if(ena)
+    {
+        mpEdit->selectAll();
         mpEdit->setFocus();
+    }
     updateAuthLabel();
 }
 
 void MinicliAdvanced::slotUsername(const QString &name)
 {
-    kdDebug(1207) << "text: " << mpEdit->text() << endl;
+    //kdDebug(1207) << "text: " << mpEdit->text() << endl;
     mUsername = name;
     updateAuthLabel();
 }
@@ -683,13 +639,15 @@ void MinicliAdvanced::slotChangeScheduler(bool ena)
     mbChangeScheduler = ena;
     mpCombo->setEnabled(ena);
     mpSlider->setEnabled(ena);
+    priorityLbl->setEnabled(ena);
+    priorityHighLbl->setEnabled(ena);
     updateAuthLabel();
 }
 
 bool MinicliAdvanced::needsKDEsu()
 {
     return ((mbChangeScheduler && ((mPriority != 50) || (mScheduler != StubProcess::SchedNormal)))
-	    || (mbChangeUid && !mUsername.isEmpty()));
+            || (mbChangeUid && !mUsername.isEmpty()));
 }
 
 void MinicliAdvanced::slotScheduler(int scheduler)
@@ -699,16 +657,16 @@ void MinicliAdvanced::slotScheduler(int scheduler)
     {
         // we have to set the flags of the toplevelwidget, not ours
         KWin::clearState( topLevelWidget()->winId(), NET::StaysOnTop );
-	if (KMessageBox::warningContinueCancel(this,
-		    i18n("Running a realtime application can be very dangerous.\n"
-			 "If the application misbehaves, the system might hang\n"
-			 "unrecoverably.\n\nAre you sure you want to continue?"),
-		    i18n("Danger, Will Robinson!"), i18n("Continue"))
-	    != KMessageBox::Continue )
-	{
-	  mScheduler = StubProcess::SchedNormal;
-	  mpCombo->setCurrentItem(mScheduler);
-	}
+        if (KMessageBox::warningContinueCancel(this,
+                    i18n("Running a realtime application can be very dangerous. "
+                         "If the application misbehaves, the system might hang "
+                         "unrecoverably.\nAre you sure you want to continue?"),
+                    i18n("Warning - Run Command"))
+            != KMessageBox::Continue )
+        {
+          mScheduler = StubProcess::SchedNormal;
+          mpCombo->setCurrentItem(mScheduler);
+        }
         KWin::setState( topLevelWidget()->winId(), NET::StaysOnTop );
     }
     updateAuthLabel();
@@ -719,8 +677,8 @@ void MinicliAdvanced::slotPriority(int priority)
     // Provide a way to easily return to the default priority
     if ((priority > 40) && (priority < 60))
     {
-	priority = 50;
-	mpSlider->setValue(50);
+        priority = 50;
+        mpSlider->setValue(50);
     }
     mPriority = priority;
     updateAuthLabel();
@@ -737,7 +695,8 @@ void MinicliAdvanced::reset()
     mpCBTerm->setChecked(false);
     mbChangeUid = false;
     mpCBUser->setChecked(false);
-    mpEdit->clear();
+    mUsername = "root";
+    mpEdit->setText(mUsername);
     mbChangeScheduler = false;
     mpCBPrio->setChecked(false);
     mPriority = 50;
