@@ -72,6 +72,7 @@ private:
     KHistoryCombo* m_runCombo;
     KURIFilterData* m_filterData;
     QWidget* m_FocusWidget;
+    QPushButton* btnRun;
 };
 
 class MinicliAdvanced : public QGroupBox
@@ -114,6 +115,8 @@ private:
     KLineEdit *mpEdit;
     KComboBox *mpCombo;
     KPasswordEdit *mpPassword;
+    QLabel *priorityLbl;
+    QLabel *priorityHighLbl;
 };
 
 #endif
