@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdesu.cpp,v 1.16 2000/05/25 07:48:03 jansen Exp $
+ * $Id: kdesu.cpp,v 1.26 2002/03/14 23:02:23 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1998 Pietro Iglio <iglio@fub.it>
@@ -21,15 +21,21 @@
 #include <qstring.h>
 #include <qfileinfo.h>
 #include <qglobal.h>
+#include <qfile.h>
+#include <qdir.h>
+
+#include <dcopclient.h>
 
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kapp.h>
-#include <kstddirs.h>
+#include <kapplication.h>
+#include <kstandarddirs.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#include <kmessagebox.h>
+#include <krun.h>
 
 #include <kdesu/defaults.h>
 #include <kdesu/su.h>
@@ -39,23 +45,51 @@
 
 #define ERR strerror(errno)
 
+QCString command;
 const char *Version = "1.0";
 
+// NOTE: if you change the position of the -u switch, be sure to adjust it
+// at the beginning of main()
 static KCmdLineOptions options[] = {
     { "+command", I18N_NOOP("Specifies the command to run."), 0 },
+    { "c <command>", I18N_NOOP("Specifies the command to run."), "" },
     { "f <file>", I18N_NOOP("Run command under target uid if <file> is not writeable."), "" },
+    // FIXME 3.1: add dot at eol for consistency
     { "u <user>", I18N_NOOP("Specifies the target uid"), "root" },
     { "n", I18N_NOOP("Do not keep password."), 0 },
     { "s", I18N_NOOP("Stop the daemon (forgets all passwords)."), 0 },
     { "t", I18N_NOOP("Enable terminal output (no password keeping)."), 0 },
     { "p <prio>", I18N_NOOP("Set priority value: 0 <= prio <= 100, 0 is lowest."), "50" },
     { "r", I18N_NOOP("Use realtime scheduling."), 0 },
+    { "nonewdcop", I18N_NOOP("Let command use existing dcopserver."), 0 },
     { 0, 0, 0 }
 };
 
 
+QCString dcopNetworkId()
+{
+    QCString result;
+    result.resize(1025);
+    QFile file(DCOPClient::dcopServerFile());
+    if (!file.open(IO_ReadOnly))
+        return "";
+    int i = file.readLine(result.data(), 1024);
+    if (i <= 0)
+        return "";
+    result.data()[i-1] = '\0'; // strip newline
+    return result;
+}
+
 int main(int argc, char *argv[])
 {
+    // FIXME: this can be considered a poor man's solution, as it's not
+    // directly obvious to a gui user. :)
+    // anyway, i vote against removing it even when we have a proper gui
+    // implementation.  -- ossi
+    const char *duser = ::getenv("ADMIN_ACCOUNT");
+    if (duser && duser[0])
+        options[3].def = duser;
+
     KAboutData aboutData("kdesu", I18N_NOOP("KDE su"),
 	    Version, I18N_NOOP("Runs a program with elevated privileges."),
 	    KAboutData::License_Artistic, 
@@ -68,6 +102,9 @@ int main(int argc, char *argv[])
     KCmdLineArgs::init(argc, argv, &aboutData);
     KCmdLineArgs::addCmdLineOptions(options);
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    KApplication::disableAutoDcopRegistration();
+
+    KApplication *app = new KApplication;
 
     // Stop daemon and exit?
     if (args->isSet("s")) 
@@ -141,14 +178,35 @@ int main(int argc, char *argv[])
     }
 
     // Get command
-    if (args->count() == 0)
+    if (args->isSet("c")) 
+    {
+    command = args->getOption("c");
+    for (int i=0; i<args->count(); i++)
+    {
+        QString arg = QFile::decodeName(args->arg(i));
+        KRun::shellQuote(arg);
+	command += " ";
+	command += QFile::encodeName(arg);
+    }
+    }
+    else {
+    if( args->count() == 0 )
+    {
 	KCmdLineArgs::usage(i18n("No command specified!"));
-    QCString command = args->arg(0);
+	exit(1);
+    }
+    command = args->arg(0); 
     for (int i=1; i<args->count(); i++) 
     {
+        QString arg = QFile::decodeName(args->arg(i));
+        KRun::shellQuote(arg);
 	command += " ";
-	command += args->arg(i);
-    }
+	command += QFile::encodeName(arg);
+    }}
+
+//  CJM - Test lines remove when working
+//    kdWarning(1206) << args->count();
+//    kdWarning(1206) << command;
 
     // Don't change uid if we're don't need to.
     if (!change_uid)
@@ -175,11 +233,23 @@ int main(int argc, char *argv[])
     // Try to exec the command with kdesud.
     bool keep = !args->isSet("n") && have_daemon;
     bool terminal = args->isSet("t");
+    bool new_dcop = args->isSet("newdcop");
+
+    QCStringList env;
+    QCString options;
+    if (!new_dcop)
+    {
+        QCString ksycoca = "KDESYCOCA="+QFile::encodeName(locateLocal("tmp", "ksycoca"));
+        env << ksycoca;
+        
+        options += "xf"; // X-only, dcop forwarding enabled.
+    }
+
     if (keep && !terminal && !just_started) 
     {
 	client.setPriority(priority);
 	client.setScheduler(scheduler);
-	if (client.exec(command, user) != -1)
+	if (client.exec(command, user, options, env) != -1)
 	    return 0;
     }
 
@@ -193,54 +263,76 @@ int main(int argc, char *argv[])
 	exit(1);
     }
 
-    // From  here, we need the GUI: create a KApplication
-    KApplication *app = new KApplication;
-
     // Read configuration
     KConfig *config = KGlobal::config();
     config->setGroup("Passwords");
     int timeout = config->readNumEntry("Timeout", defTimeout);
 
-     // Start the dialog
-    KDEsuDialog *dlg = new KDEsuDialog(user, auth_user, keep && !terminal);
-    dlg->addLine(i18n("Command:"), command);
-    if ((priority != 50) || (scheduler != SuProcess::SchedNormal)) 
+    // Check if we need a password
+    SuProcess proc;
+    proc.setUser(auth_user);
+    int needpw = proc.checkNeedPassword();
+    if (needpw < 0)
     {
-	QString prio;
-	if (scheduler == SuProcess::SchedRealtime)
-	    prio += i18n("realtime: ");
-	prio += QString("%1/100").arg(priority);
-	dlg->addLine(i18n("Priority:"), prio);
+	QString err = i18n("Su returned with an error!\n");
+	KMessageBox::error(0L, err);
+	exit(1);
+    }
+    if (needpw == 0)
+    {
+	keep = 0;
+	kdDebug() << "Don't need password!!\n";
     }
-    int ret = dlg->exec();
-    if (ret == KDEsuDialog::Rejected)
-	exit(0);
-    if (ret == KDEsuDialog::AsUser)
-	change_uid = false;
-    QCString password = dlg->password();
-    int k = dlg->keep();
-    delete dlg;
 
-    // This destroys the Qt event loop and makes sure the dialog goes away.
-    delete app;
+    // Start the dialog
+    QCString password;
+    if (needpw)
+    {
+	KDEsuDialog *dlg = new KDEsuDialog(user, auth_user, keep && !terminal);
+	dlg->addLine(i18n("Command:"), command);
+	if ((priority != 50) || (scheduler != SuProcess::SchedNormal)) 
+	{
+	    QString prio;
+	    if (scheduler == SuProcess::SchedRealtime)
+		prio += i18n("realtime: ");
+	    prio += QString("%1/100").arg(priority);
+	    dlg->addLine(i18n("Priority:"), prio);
+	}
+	int ret = dlg->exec();
+	if (ret == KDEsuDialog::Rejected)
+	    exit(0);
+	if (ret == KDEsuDialog::AsUser)
+	    change_uid = false;
+	password = dlg->password();
+	keep = dlg->keep();
+	delete dlg;
+    }
+
+    // Some events may need to be handled (like a button animation)
+    app->processEvents();
 
     if (!change_uid)
 	return system(command);
 
     // Run command
-
-    if (k && have_daemon) 
+    if (keep && have_daemon) 
     {
 	client.setPass(password, timeout);
 	client.setPriority(priority);
 	client.setScheduler(scheduler);
-	return client.exec(command, user);
+	return client.exec(command, user, options, env);
     } else 
     {
 	SuProcess proc;
 	proc.setTerminal(terminal);
 	proc.setErase(true);
 	proc.setUser(user);
+	if (!new_dcop)
+	{
+	    proc.setXOnly(true);
+	    proc.setDCOPForwarding(true);
+	    proc.setEnvironment(env);
+	}
 	proc.setPriority(priority);
 	proc.setScheduler(scheduler);
 	proc.setCommand(command);
