@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: sudlg.cpp,v 1.7 2000/11/16 18:25:10 tranter Exp $
+ * $Id: sudlg.cpp,v 1.9 2002/01/18 13:27:35 mhunter Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -56,15 +56,15 @@ bool KDEsuDialog::checkPassword(const char *password)
 
     case SuProcess::SuNotFound:
         KMessageBox::sorry(this, 
-		i18n("The program `su' is not found!\n\n"
+		i18n("The program 'su' is not found!\n"
 		     "Make sure your PATH is set correctly."));
 	done(Rejected);
 	return false;
 
     case SuProcess::SuNotAllowed:
         KMessageBox::sorry(this, 
-		i18n("You are not allowed to use `su'!\n\n"
-		     "On some systems, you need to be in a special\n"
+		i18n("You are not allowed to use 'su'!\n"
+		     "On some systems, you need to be in a special "
 		     "group (often: wheel) to use this program."));
 	done(Rejected);
 	return false;
