@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: handler.cpp,v 1.13 2000/12/29 00:59:20 adawit Exp $
+ * $Id: handler.cpp,v 1.17 2002/01/08 01:26:35 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -152,7 +152,7 @@ int ConnectionHandler::doCommand(QCString buf)
 	return -1;
     }
 
-    QCString key, command, pass, name, user, value;
+    QCString key, command, pass, name, user, value, env_check;
     Data_entry data;
 
     // kdDebug(1205) << "Received command: " << buf << endl;
@@ -209,8 +209,10 @@ int ConnectionHandler::doCommand(QCString buf)
 	respond(Res_OK);
 	break;
 
-    case Lexer::Tok_exec:  // "EXEC command:string user:string\n"
+    case Lexer::Tok_exec:  // "EXEC command:string user:string [options:string (env:string)*]\n"
     {
+        QCString options;
+        QCStringList env;
 	tok = l->lex();
 	if (tok != Lexer::Tok_str)
 	    goto parse_error;
@@ -219,16 +221,36 @@ int ConnectionHandler::doCommand(QCString buf)
 	if (tok != Lexer::Tok_str)
 	    goto parse_error;
 	user = l->lval();
-	if (l->lex() != '\n')
-	    goto parse_error;
+	tok = l->lex();
+	if (tok != '\n')
+	{
+	    if (tok != Lexer::Tok_str)
+		goto parse_error;
+	    options = l->lval();
+            tok = l->lex();
+	    while (tok != '\n')
+            {
+               if (tok != Lexer::Tok_str)
+	           goto parse_error;
+	       QCString env_str = l->lval();
+	       env.append(env_str);
+	       env_check += "*"+env_str;
+               tok = l->lex();
+            }
+	}
 
 	QCString auth_user;
 	if ((m_Scheduler != SuProcess::SchedNormal) || (m_Priority > 50))
 	    auth_user = "root";
 	else
 	    auth_user = user;
-	key = makeKey(0, m_Host, auth_user, command);
-	pass = repo->find(key);
+	key = makeKey(2, m_Host, auth_user, command);
+	// We only use the command if the environment is the same.
+	if (repo->find(key) == env_check)
+	{
+           key = makeKey(0, m_Host, auth_user, command);
+           pass = repo->find(key);
+        }
 	if (pass.isNull())
 	{
 	    if (m_Pass.isNull())
@@ -236,8 +258,13 @@ int ConnectionHandler::doCommand(QCString buf)
 		respond(Res_NO);
 		break;
 	    }
+	    data.value = env_check;
+	    data.timeout = m_Timeout;
+            key = makeKey(2, m_Host, auth_user, command);
+	    repo->add(key, data);
 	    data.value = m_Pass;
 	    data.timeout = m_Timeout;
+            key = makeKey(0, m_Host, auth_user, command);
 	    repo->add(key, data);
 	    pass = m_Pass;
 	}
@@ -265,8 +292,13 @@ int ConnectionHandler::doCommand(QCString buf)
 	    SuProcess proc;
 	    proc.setCommand(command);
 	    proc.setUser(user);
+	    if (options.contains('x'))
+	       proc.setXOnly(true);
+	    if (options.contains('f'))
+	       proc.setDCOPForwarding(true);
 	    proc.setPriority(m_Priority);
 	    proc.setScheduler(m_Scheduler);
+	    proc.setEnvironment(env);
 	    ret = proc.exec(pass.data());
 	} else
 	{
@@ -406,7 +438,7 @@ int ConnectionHandler::doCommand(QCString buf)
 	value = repo->findKeys(name);
 	if (!value.isEmpty())
     {
-        kdDebug(1205) << "Requested value: " << value << endl;
+        // kdDebug(1205) << "Requested value: " << value << endl;
 	    respond(Res_OK, value);
     }
 	else
