@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: secure.cpp,v 1.6 2001/03/29 08:46:32 leitner Exp $
+ * $Id: secure.cpp,v 1.6.4.1 2002/04/10 08:52:21 espie Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -42,6 +42,20 @@ SocketSecurity::SocketSecurity(int sockfd)
 }
 
 #else
+# if defined(HAVE_GETPEEREID)
+SocketSecurity::SocketSecurity(int sockfd)
+{
+    uid_t euid;
+    gid_t egid;
+    if (getpeereid(sockfd, &euid, &egid) == 0) {
+	cred.uid = euid;
+	cred.gid = egid;
+	cred.pid = -1;
+	ok = true;
+    }
+}
+
+# else
 
 
 /**
@@ -63,4 +77,5 @@ SocketSecurity::SocketSecurity(int sockfd)
     ok = true;
 }
 
+# endif
 #endif
