@@ -18,7 +18,7 @@
 */
 
 #ifndef __khc_factory_h__
-#define __khc_factory_h__ $Id: khc_factory.h,v 1.1 1999/11/18 16:33:53 shausman Exp $
+#define __khc_factory_h__ $Id: khc_factory.h,v 1.2 2001/09/10 17:59:26 hausmann Exp $
 
 #include <klibloader.h>
 #include <kinstance.h>
@@ -30,7 +30,7 @@ public:
   KHCFactory();
   virtual ~KHCFactory();
 
-  virtual QObject* create( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
+  virtual QObject* createObject( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
 
   static KInstance *instance();	
 
