@@ -22,19 +22,34 @@
 #define __khc_navigator_h__
 
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <kparts/browserextension.h>
 #include <kparts/part.h>
 #include <qtabwidget.h>
 #include <qlistview.h>
-#include <kprocess.h>
+#include <qdict.h>
+
+// ACHU
+#include <regex.h>
+#include <qfile.h>
+#include <qtextstream.h>
+#include <qtimer.h>
+#include <map>
+//#include "khc_infohierarchymaker.h"
+//#include "khc_infonode.h"
+// END ACHU
 
 class SearchWidget;
 class khcNavigatorItem;
 class khcNavigator;
 class KListView;
 class KService;
+class KProcess;
 class KProcIO;
+// ACHU
+class khcInfoNode;
+class khcInfoHierarchyMaker;
+//END ACHU
 
 class SectionItem : public QListViewItem
 {
@@ -54,6 +69,7 @@ class khcNavigatorExtension : public KParts::BrowserExtension
 
  public slots:
     void slotItemSelected(const QString&);
+    void print() {}
 };
 
 class khcNavigator : public KParts::ReadOnlyPart
@@ -94,13 +110,19 @@ class khcNavigatorWidget : public QTabWidget
     khcNavigatorWidget(QWidget *parent=0, const char *name=0);
     virtual ~khcNavigatorWidget();
 
-		GlossaryEntry glossEntry(const QString &term) const { return *glossEntries[term]; }
+    GlossaryEntry glossEntry(const QString &term) const { return *glossEntries[term]; }
 
  public slots:
     void slotURLSelected(QString url);
     void slotItemSelected(QListViewItem* index);
+    // ACHU
+    void slotItemExpanded(QListViewItem* index);
+    void slotInfoHierarchyCreated(uint key, uint nErrorCode, const khcInfoNode* pRootNode);
+    void slotCleanHierarchyMakers();
+    // END ACHU
     void slotGlossaryItemSelected(QListViewItem* item);
     void slotReloadTree();
+    void slotShowPage(QWidget *);
 
  signals:
     void itemSelected(const QString& itemURL);
@@ -109,44 +131,84 @@ class khcNavigatorWidget : public QTabWidget
 
  private slots:
     void getScrollKeeperContentsList(KProcIO *proc);
-    void gotMeinprocOutput(KProcess *, char *data, int len);
     void meinprocExited(KProcess *);
+    //ACHU
+    /* Cog-wheel animation handling -- enable after creating the icons
+    void slotAnimation();
+    */
+    // END ACHU
+
 
  private:
     void setupContentsTab();
     void setupIndexTab();
     void setupSearchTab();
     void setupGlossaryTab();
-    void buildGlossaryCache();
+    void buildGlossary();
     void buildTree();
     void clearTree();
     QString langLookup(const QString &);
+    QString decodeEntities(const QString &s) const;
+
+    // ACHU
+    void buildInfoSubTree(khcNavigatorItem *parent);
+    QString findInfoDirFile();
+    bool readInfoDirFile(QString& sFileContents);
+    bool parseInfoSubjectLine(QString sLine, QString& sItemTitle, QString& sItemURL);
+    void addChildren(const khcInfoNode* pParentNode, khcNavigatorItem* pParentTreeItem);
+    // END ACHU
 
     void buildManSubTree(khcNavigatorItem *parent);
 
-    void buildManualSubTree(khcNavigatorItem *parent, QString relPath);
-    QString documentationURL(KService *s);
-
     void insertPlugins();
     void insertScrollKeeperItems();
     int insertScrollKeeperSection(khcNavigatorItem *parentItem,QDomNode sectNode);
     void insertScrollKeeperDoc(khcNavigatorItem *parentItem,QDomNode docNode);
 
-    bool appendEntries (const QString &dirName,  khcNavigatorItem *parent, QList<khcNavigatorItem> *appendList);
-    bool processDir(const QString &dirName, khcNavigatorItem *parent,  QList<khcNavigatorItem> *appendList);
+    bool appendEntries (const QString &dirName,  khcNavigatorItem *parent, QPtrList<khcNavigatorItem> *appendList);
+    bool processDir(const QString &dirName, khcNavigatorItem *parent,  QPtrList<khcNavigatorItem> *appendList);
 
     QListViewItem *byTopicItem, *alphabItem;
     KListView *contentsTree, *glossaryTree;
     // SearchWidget *search;
 
-    QList<khcNavigatorItem> staticItems, manualItems, pluginItems, scrollKeeperItems;
+    QPtrList<khcNavigatorItem> manualItems, pluginItems, scrollKeeperItems;
+
+    // ACHU
+    regex_t compInfoRegEx;
+    std::map<khcNavigatorItem*, khcInfoHierarchyMaker*> hierarchyMakers;
+    QTimer cleaningTimer;
+    // END ACHU
+
+    // ACHU
+    /* Cog-wheel animation handling -- enable after creating the icons
+    struct AnimationInfo
+    {
+        AnimationInfo( const char * _iconBaseName, uint _iconCount, const QPixmap & _originalPixmap )
+            : iconBaseName(_iconBaseName), iconCount(_iconCount), iconNumber(1), originalPixmap(_originalPixmap) {}
+        AnimationInfo() : iconCount(0) {}
+        QCString iconBaseName;
+        uint iconCount;
+        uint iconNumber;
+        QPixmap originalPixmap;
+    };
+    typedef QMap<khcNavigatorItem *, AnimationInfo> MapCurrentOpeningSubjects;
+    MapCurrentOpeningSubjects m_mapCurrentOpeningSubjects;
+
+    QTimer *m_animationTimer;
+
+    void startAnimation(khcNavigatorItem * item, const char * iconBaseName = "kde", uint iconCount = 6);
+    void stopAnimation(khcNavigatorItem * item);
+    */
+    // END ACHU
 
     bool mScrollKeeperShowEmptyDirs;
     QString mScrollKeeperContentsList;
     
     QDict<GlossaryEntry> glossEntries;
-    KProcess *meinproc;
-    QString htmlData;
+    enum { NeedRebuild, CacheOk, ListViewOk} glossaryHtmlStatus;
+    QString glossaryHtmlFile;
+    QString glossarySource;
 };
 
 inline QDataStream &operator<<( QDataStream &stream, const khcNavigatorWidget::GlossaryEntry &e )
