@@ -22,12 +22,12 @@
 #include <qstring.h>
 #include <qfile.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <ksimpleconfig.h>
 
 #include "khc_navigatoritem.h"
 #include "khc_factory.h"
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 
@@ -43,6 +43,20 @@ khcNavigatorItem::khcNavigatorItem(QListViewItem* parent, const QString& _text,
     init(_text, _miniicon);
 }
 
+// ACHU
+khcNavigatorItem::khcNavigatorItem(QListView* parent, QListViewItem* after, const QString& _text, const QString& _miniicon)
+    : QListViewItem(parent, after)
+{
+    init(_text, _miniicon);
+}
+
+khcNavigatorItem::khcNavigatorItem(QListViewItem* parent, QListViewItem* after, const QString& _text, const QString& _miniicon)
+    : QListViewItem(parent, after)
+{
+    init(_text, _miniicon);
+}
+// END ACHU
+
 void khcNavigatorItem::init(const QString& _text, const QString& _miniicon)
 {
     name = _text;
