@@ -32,19 +32,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qvbox.h>
 
 #include <kpanelapplet.h>
-#include <kdatepik.h>
 
 class QTimer;
 class QBoxLayout;
 class KConfig;
-
-
-class DatePickerWidget : public KDatePicker
-{
-public:
-	DatePickerWidget(QWidget*);
-	~DatePickerWidget();
-};
+class KDatePicker;
+class QPixmap;
 
 
 class DatePicker : public QVBox
@@ -53,7 +46,7 @@ public:
 	DatePicker(QWidget*);
 	~DatePicker();
 private:
-	DatePickerWidget *picker;
+	KDatePicker *picker;
 };
 
 
@@ -64,7 +57,7 @@ class ClockSettings : public QObject
   Q_OBJECT
 
 public:
-	enum ClockType { Analog = 0, Digital, Fuzzy };
+	enum ClockType { Plain = 0, Digital, Analog, Fuzzy };
 
 	ClockSettings(QWidget* app, KConfig* conf);
 	~ClockSettings();
@@ -76,14 +69,19 @@ public:
 
 	ClockType type()     { return _type; }
 	bool lcdStyle()      { return _type == Digital?_lcdStyleDig:_lcdStyleAna; }
-        bool showSeconds()   { return _type == Digital?_showSecsDig:_showSecsAna; }
+	bool showSeconds();
         bool showDate();
 	QColor foreColor();
-	QColor shadowColor() { return _type == Digital?_shadowColorDig:_shadowColorAna; }
+	QColor shadowColor();
 	QColor backColor();
 	bool blink()         { return _blink; }
-        QFont font()         { return _fontFuz; }
-        int fuzzyness()      { return _fuzzynessFuz; }
+	QFont font()         { return _type == Plain? _fontPlain:_fontFuz; }
+	int fuzzyness()      { return _fuzzynessFuz; }
+	int antialiasFactor() { return  _antialiasFactorAna; }
+	bool showFrame()     { return  _showFrameAna; }
+
+        QFont dateFont()     { return _fontDate; }
+        QColor dateForeColor();
 
 signals:
 	void newSettings();
@@ -93,7 +91,9 @@ protected slots:
 	void dlgApplyClicked();
 	void dlgCancelClicked();
 	void dlgDeleted();
-        void dlgbChooseFontClicked();
+        void dlgLCDDigitalToggled(bool);
+        void dlgLCDAnalogToggled(bool);
+	void dlgChooseFontButtonClicked();
 
 protected:
         QWidget *applet;
@@ -101,93 +101,124 @@ protected:
 	ClockType _type;
 	QGuardedPtr<ClockConfDialog> confDlg;
 
-	bool _lcdStyleAna, _lcdStyleDig,
-	     _showSecsAna, _showSecsDig,
-	     _showDateAna, _showDateDig, _showDateFuz,
+	bool _lcdStyleDig, _lcdStyleAna,
+	     _showSecsPlain, _showSecsDig, _showSecsAna,
+	     _showDatePlain, _showDateDig,  _showDateAna,  _showFrameAna,  _showDateFuz,
+             _useColDate, _useColPlain, _useColDig, _useColAna, _useColFuz,
 	     _blink;
-	QColor _foreColorAna, _foreColorDig, _foreColorFuz,
-	       _backColorAna, _backColorDig, _backColorFuz,
+	QColor _foreColorDate, _foreColorPlain, _foreColorDig, _foreColorAna,  _foreColorFuz,
+	       _backColorPlain, _backColorDig, _backColorAna,  _backColorFuz,
 	       _shadowColorAna, _shadowColorDig;
- 	bool colAnalogModified, colDigitalModified, colFuzzyModified;
-        int _fuzzynessFuz;
-        QFont _fontFuz;
-
-};
-
-
-class DigitalClock : public QLCDNumber
-{
-  Q_OBJECT
-
-public:
-	DigitalClock(ClockSettings* set, QWidget *parent=0, const char *name=0);
-	~DigitalClock();
-        QSize sizeHint() const;
-        int heightForWidth(int w) const;
-        int widthForHeight(int h) const;
-
-public slots:
-	void slotUpdate();
-	void relayout();
-
-protected:
-	void paintEvent( QPaintEvent*);
-	void drawContents( QPainter * p);
-	void resizeEvent ( QResizeEvent *ev);
-        void styleChange( QStyle& );
-
-	QPixmap *buffer;
-	QString timeStr;
-	bool ampm;
-	ClockSettings *settings;
-
-};
-
-
-class AnalogClock : public QFrame
-{
-  Q_OBJECT
-
-public:
-	AnalogClock(ClockSettings* set, QWidget *parent=0, const char *name=0);
-	~AnalogClock();
-
-protected slots:
-	void slotUpdate();
-
-protected:
-	virtual void paintEvent( QPaintEvent * );
-        void styleChange( QStyle& );
-
-	QTime time;
-	ClockSettings *settings;
-
+	int _fuzzynessFuz, _antialiasFactorAna;
+	QFont _fontDate, _fontPlain, _fontFuz;
 };
 
 
 class ClockApplet;
 
-class FuzzyClock : public QFrame
+// base class for all clock types
+class ClockWidget
+{
+
+public:
+	ClockWidget(ClockApplet *applet, ClockSettings* settings);
+	virtual ~ClockWidget();
+
+	virtual QWidget* widget()=0;
+	virtual int preferedWidthForHeight(int h) const =0;
+	virtual int preferedHeightForWidth(int w) const =0;
+	virtual void updateClock()=0;
+
+protected:
+	ClockApplet *_applet;
+	ClockSettings *_settings;
+};
+
+
+class PlainClock : public QLabel, public ClockWidget
 {
   Q_OBJECT
 
 public:
-	FuzzyClock(ClockSettings* set, QWidget *parent=0, const char *name=0);
+	PlainClock(ClockApplet *applet, ClockSettings* settings, QWidget *parent=0, const char *name=0);
+	~PlainClock();
+
+	QWidget* widget()    { return this; }
+	int preferedWidthForHeight(int h) const;
+	int preferedHeightForWidth(int w) const;
+	void updateClock();
+
+protected:
+	QString _timeStr;
+};
+
+
+class DigitalClock : public QLCDNumber, public ClockWidget
+{
+  Q_OBJECT
+
+public:
+	DigitalClock(ClockApplet *applet, ClockSettings* settings, QWidget *parent=0, const char *name=0);
+	~DigitalClock();
+
+	QWidget* widget()    { return this; }
+	int preferedWidthForHeight(int h) const;
+	int preferedHeightForWidth(int w) const;
+	void updateClock();
+
+protected:
+	void paintEvent( QPaintEvent*);
+	void drawContents( QPainter * p);
+	void resizeEvent ( QResizeEvent *ev);
+	void styleChange( QStyle& );
+
+	QPixmap *_buffer;
+	QString _timeStr;
+};
+
+
+class AnalogClock : public QFrame, public ClockWidget
+{
+  Q_OBJECT
+
+public:
+	AnalogClock(ClockApplet *applet, ClockSettings* settings, QWidget *parent=0, const char *name=0);
+	~AnalogClock();
+
+	QWidget* widget()                        { return this; }
+	int preferedWidthForHeight(int h) const  { return h; }
+	int preferedHeightForWidth(int w) const  { return w; }
+	void updateClock();
+
+protected:
+	virtual void paintEvent(QPaintEvent *);
+	void styleChange(QStyle&);
+  void initBackgroundPixmap();
+
+	QTime _time;
+	QPixmap *_spPx;
+  int _bgScale;
+};
+
+
+class FuzzyClock : public QFrame, public ClockWidget
+{
+  Q_OBJECT
+
+public:
+	FuzzyClock(ClockApplet *applet, ClockSettings* settings, QWidget *parent=0, const char *name=0);
 	~FuzzyClock();
-        QSize sizeHint() const;
 
-
-protected slots:
-	void slotUpdate();
+	QWidget* widget()    { return this; }
+	int preferedWidthForHeight(int h) const;
+	int preferedHeightForWidth(int w) const;
+	void updateClock();
 
 protected:
 	virtual void drawContents(QPainter *p);
 
-	QTime time;
-        QString timeStr;
-	ClockSettings *settings;
-        ClockApplet *_parent;
-
+	QTime _time;
+	QString _timeStr;
 };
 
 
@@ -204,39 +235,31 @@ public:
 	int widthForHeight(int h) const;
 	int heightForWidth(int w) const;
 	void preferences();
-        void intUpdateLayout()          { emit(updateLayout()); }
-        Orientation getOrientation()    { return orientation(); }
-
-public slots:
-	void slotApplySettings();
-
-signals:
-	void layoutChanged();
+	Orientation getOrientation()    { return orientation(); }
+	void resizeRequest()            { emit(updateLayout()); }
 
 protected slots:
+	void slotApplySettings();
 	void slotUpdate();
 	void slotCalendarDeleted();
 	void slotEnableCalendar();
-	void copyMenuActivated( int id );
+	void slotCopyMenuActivated( int id );
 
 protected:
-	void openCalendar();
+	void toggleCalendar();
 	void openContextMenu();
-	void relayout();
 
+	void paletteChange(const QPalette &)   { slotApplySettings(); }
 	void mousePressEvent(QMouseEvent *ev);
-	void resizeEvent ( QResizeEvent *ev);
-	bool eventFilter( QObject *, QEvent * );
-
-	ClockSettings *settings;
-	DatePicker *cal;
-	bool disableCalendar;
-	QWidget *clock;
-	QLabel *date;
-	QDate lastDate;
-	QTimer *timer;
+	bool eventFilter(QObject *, QEvent *);
 
+	ClockSettings *_settings;
+	DatePicker *_calendar;
+	bool _disableCalendar;
+	ClockWidget *_clock;
+	QLabel *_date;
+	QDate _lastDate;
+	QTimer *_timer;
 };
 
-
 #endif
