@@ -24,14 +24,25 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __quicklauncher_h__
 #define __quicklauncher_h__
 
-#include <qlist.h>
 #include <qstring.h>
 #include <qpopupmenu.h>
 
+#if QT_VERSION < 300
+#include <qptrlist.h>
+#else
+#include <qptrlist.h>
+#endif
+
 #include <kpanelapplet.h>
 
 #include "quickbutton.h"
 
+#if QT_VERSION < 300
+typedef QList<QuickButton> QuickButtonList;
+#else
+typedef QPtrList<QuickButton> QuickButtonList;
+#endif
+
 class QuickLauncher : public KPanelApplet
 {
    Q_OBJECT
@@ -54,7 +65,7 @@ protected:
    void saveConfig();
 private:
    QPopupMenu *popup;
-   QList<QuickButton> buttonList;
+   QuickButtonList buttonList;
    int iconSize;
 };
 
