@@ -27,9 +27,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qvaluelist.h>
 #include <qbutton.h>
 #include <qlayout.h>
+#include <qintdict.h>
+#include <qtimer.h>
 
 #include <kpanelapplet.h>
 #include <kwin.h>
+#include <qxembed.h>
 
 class KProcess;
 class KWinModule;
@@ -71,20 +74,6 @@ private:
     QTimer dragSwitchTimer;
 };
 
-class QDesktopPreviewFrame : public QFrame
-{
-    Q_OBJECT
-
-public:
-    QDesktopPreviewFrame(KMiniPager *pPager);
-
-protected:
-    void keyPressEvent(QKeyEvent *evt);
-
-private:
-    KMiniPager *m_pPager;
-};
-
 class KMiniPager : public KPanelApplet
 {
     Q_OBJECT
@@ -102,22 +91,14 @@ public:
     KWinModule* kwin() { return kwin_module; }
 
     enum Mode { Preview = 14, Number, Name };
-    Mode mode() const { return m; }
+    Mode mode() const { return m_mode; }
 
     Orientation orientation() const { return KPanelApplet::orientation(); }
 
-
     void preferences();
 
     void emitRequestFocus(){ emit requestFocus(); }
 
-    void hideDesktopPreview();
-protected:
-
-    void createDesktopPreview();
-    void destroyDesktopPreview();
-    QSize calculateDesktopPreviewFrameSize() const;
-
 public slots:
     void slotSetDesktop(int desktop);
     void slotSetDesktopCount(int count);
@@ -133,12 +114,14 @@ public slots:
 
 protected:
     void allocateButtons();
+    void updateDesktopLayout(int,int,int);
     void popupDirectionChange( Direction d );
     void resizeEvent(QResizeEvent*);
+    void showKPager(bool toggleShow);
 
 protected slots:
-    void desktopPreviewProcessExited(KProcess *p);
     void desktopPreview();
+    void applicationRegistered(const QCString &appName);
 
 private:
 
@@ -148,13 +131,15 @@ private:
     WId active;
     QIntDict<KWin::Info> windows;
     KWinModule* kwin_module;
-    Mode m;
+    Mode m_mode;
 
     bool bShowDesktopPreviewButton;
     KArrowButton *m_pBtnDesktopPreview;
-    QFrame *m_pDesktopPreviewFrame; // a parent frame of virtual dsktop preview
     QBoxLayout *m_pBoxLayout;
     KProcess *m_pPagerProcess;
+    int desktopLayoutOrientation;
+    int desktopLayoutX;
+    int desktopLayoutY;
 };
 
 #endif
