@@ -27,7 +27,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qpushbutton.h>
 #include <qhbox.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kconfig.h>
@@ -85,6 +85,8 @@ RunApplet::RunApplet(const QString& configFile, Type type, int actions,
     _input->completionObject()->setItems(list);
     list = c->readListEntry("History list");
     _input->setHistoryItems(list);
+    int mode = c->readNumEntry( "CompletionMode", KGlobalSettings::completionMode() );
+    _input->setCompletionMode( (KGlobalSettings::Completion) mode );
 
     _filterData = new KURIFilterData();
 
@@ -102,6 +104,7 @@ RunApplet::~RunApplet()
     c->writeEntry("Completion list", list);
     list = _input->historyItems();
     c->writeEntry("History list", list);
+    c->writeEntry( "CompletionMode", (int) _input->completionMode() );
     c->sync();
 
     delete _filterData;
@@ -133,8 +136,8 @@ void RunApplet::resizeEvent(QResizeEvent*)
 		}
 	    else
 		{
-		    _input->setGeometry(0, 0, width(), _input->height());
 		    _label->hide();
+		    _input->setGeometry(0, 0, width(), /*_input->*/height());
 		}
 	}
     else
@@ -156,6 +159,7 @@ void RunApplet::popupDirectionChange(KPanelApplet::Direction)
 void RunApplet::setButtonText()
 {
     QString t;
+
     if (popupDirection() == Left)
 	{
 	    if (width() >= 42)
@@ -170,6 +174,7 @@ void RunApplet::setButtonText()
 	    else
 		t = ">";
 	}
+
     _btn->setText(t);
 }
 
@@ -197,30 +202,22 @@ void RunApplet::popup_combo()
 
 void RunApplet::run_command(const QString& command)
 {
-    _input->addToHistory(command);
-    _input->clearEdit();
-    kapp->propagateSessionManager();
-
-    // Okay lets get the actual data...
-    // But get it from the combo, not from _filterData,
-    // because in the filter we only put the first 'word' (David)
-    QString cmd = command.stripWhiteSpace();
-
-    // Extract first word (executable name...)
-    QChar ch = cmd[0];
-    int space_pos = cmd.find( ' ' );
-    if( ch != '\'' && ch != '"' && space_pos > -1 &&
-	cmd[space_pos - 1] != '\\' )
-	{
-	    cmd = cmd.left( space_pos );
-	}
-    _filterData->setData( cmd );
-    KURIFilter::self()->filterURI( *(_filterData) );
-
     QString exec;
 
+    kapp->propagateSessionManager();
+
+    _filterData->setData( _input->currentText().stripWhiteSpace() );
+    QStringList filters;
+    filters << "kurisearchfilter" << "kshorturifilter";
+    KURIFilter::self()->filterURI( *(_filterData), filters );
+
+    _input->addToHistory(command);
+    _input->clearEdit();
+
+    QString cmd = (_filterData->uri().isLocalFile() ? _filterData->uri().path():_filterData->uri().url());
+
     // Nothing interesting. Quit!
-    if (cmd.isEmpty()){
+    if ( cmd.isEmpty() ){
 	KMessageBox::sorry(0L, i18n("You have to enter a command to execute "
 				    "or a URL to be opened first."));
 	goto hide;
@@ -230,10 +227,10 @@ void RunApplet::run_command(const QString& command)
 	    bool shutdown = kapp->requestShutDown();
 	    if( !shutdown )
                 // This i18n string is in kdesktop/desktop.cc as well. Maybe we should DCOP to kdesktop instead ?
-		KMessageBox::error( 0, i18n("Could not logout properly.  The session manager cannot\n"
-					    "be contacted.  You can try to force a shutdown by pressing\n"
-					    "the CTRL, ALT and BACKSPACE keys at the same time.  Note\n"
-					    "however that your current session will not be saved with a\n"
+		KMessageBox::error( 0, i18n("Could not logout properly.\nThe session manager cannot "
+					    "be contacted. You can try to force a shutdown by pressing "
+					    "the CTRL, ALT and BACKSPACE keys at the same time. Note "
+					    "however that your current session will not be saved with a "
 					    "forced shutdown." ) );
 	    goto hide;
 	}
@@ -246,37 +243,28 @@ void RunApplet::run_command(const QString& command)
 		case KURIFilterData::NET_PROTOCOL:
 		case KURIFilterData::HELP:
 		    {
-			(void) new KRun( _filterData->uri() );
+		        (void) new KRun( _filterData->uri() );
 			goto hide;
 		    }
 		case KURIFilterData::EXECUTABLE:
 		case KURIFilterData::SHELL:
 		    {
-			QChar ch = cmd[0];
-			int space_pos = cmd.find( ' ' );
-			if( ch != '\'' && ch != '"' && space_pos > -1 &&
-			    cmd[space_pos - 1] != '\\' )
-			    {
-				exec = cmd.left( space_pos );
-			    } else
-				{
-				    exec = cmd;
-				}
+		        exec = cmd;
+			if( _filterData->hasArgsAndOptions() )
+			  cmd += _filterData->argsAndOptions();
 			break;
 		    }
+		case KURIFilterData::UNKNOWN:
 		case KURIFilterData::ERROR:
-		    KMessageBox::error( 0, _filterData->errorMsg() );
-		    _input->removeFromHistory( _input->currentText() );
-		    goto hide;
 		default:
 		    KMessageBox::sorry( 0, i18n("<qt>The program name or command <b>%1</b>\n"
-						"cannot be found.  Please correct the command\n"
+						"cannot be found. Please correct the command\n"
 						"or URL and try again</qt>").arg( cmd ) );
 		    _input->removeFromHistory( _input->currentText() );
 		    goto hide;
 		}
 	}
-    if (KRun::runCommand(cmd, exec, ""))
+    if (KRun::runCommand( cmd, exec, "" ))
 	goto hide;
     else
 	{
