@@ -23,7 +23,7 @@
 #include <qlayout.h>
 #include <qstringlist.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <kdebug.h>
@@ -37,14 +37,16 @@
 #include <X11/Xutil.h>
 
 #include "swallow.h"
+#include "prefwidget.h"
 
-template class QList<SwallowApp>;
-template class QList<SwallowCommand>;
+template class QPtrList<SwallowApp>;
+typedef QPtrListIterator<SwallowApp> SwallowAppListIterator;
+template class QPtrList<SwallowCommand>;
 
 
 // init static variables
-QList<SwallowApp> * SwallowApplet::appList = 0L;
-QList<SwallowApp> * SwallowApplet::embeddedList = 0L;
+SwallowAppList * SwallowApplet::appList = 0L;
+SwallowAppList * SwallowApplet::embeddedList = 0L;
 KWinModule * SwallowApplet::wModule = 0L;
 SwallowApplet * SwallowApplet::self = 0L;
 
@@ -63,24 +65,26 @@ SwallowApplet::SwallowApplet( const QString& configFile,
     resize( 30, 30 );
     kdDebug() << "**** constructing swallow applet (" << configFile << ") ****" << endl;
     self = this;
-    swcList = new QList<SwallowCommand>;
-    swcList->setAutoDelete( true );
+    m_swcList = new SwallowCommandList;
+    m_swcList->setAutoDelete( true );
     wModule = new KWinModule(this);
-    embeddedList = new QList<SwallowApp>;
+    embeddedList = new SwallowAppList;
     embeddedList->setAutoDelete( false );
-    appList = new QList<SwallowApp>;
+    appList = new SwallowAppList;
     appList->setAutoDelete( true );
 
     QBoxLayout::Direction d = (orientation() == Horizontal) ?
 			     QBoxLayout::LeftToRight : QBoxLayout::TopToBottom;
-    layout = new QBoxLayout( this, d, 0, 2 ); // make stretch configurable?
-    layout->setAutoAdd( false );
+    m_layout = new QBoxLayout( this, d, 0, 2 ); // make stretch configurable?
+    m_layout->setAutoAdd( false );
 
     // read the config file and start all the configured apps
     createApps( readConfig() );
 
     if ( appList->count() == 0 ) {
-	if ( KMessageBox::questionYesNo(0L, i18n("There is no swallowed application,\ndo you want to configure or quit?"), i18n("No swallowed application"), i18n("Configure"), i18n("Quit")) == KMessageBox::Yes )
+	if ( KMessageBox::questionYesNo(0L, i18n("There is no swallowed application, "
+		"do you want to configure or quit?"), i18n("No swallowed application"), 
+		i18n("Configure"), i18n("Quit")) == KMessageBox::Yes )
 	    preferences();
 	else {
 	    delete this;
@@ -95,7 +99,7 @@ SwallowApplet::~SwallowApplet()
 {
     kdDebug() << "********************** DELETING ************************" << endl;
 
-    delete swcList;
+    delete m_swcList;
     delete embeddedList;
     delete appList;
     delete wModule;
@@ -103,9 +107,9 @@ SwallowApplet::~SwallowApplet()
 }
 
 
-QList<SwallowCommand>* SwallowApplet::readConfig()
+SwallowCommandList* SwallowApplet::readConfig()
 {
-    swcList->clear();
+    m_swcList->clear();
     KConfig *kc = config();
 
     kc->setGroup("General");
@@ -126,7 +130,7 @@ QList<SwallowCommand>* SwallowApplet::readConfig()
 	    swc = new SwallowCommand;
 	    swc->cmdline = cmd;
 	    swc->title = title;
-	    swcList->append( swc );
+	    m_swcList->append( swc );
 	}
 	// remember items with non-null cmdline or title,
 	// discard items with empty cmdline and empty title
@@ -140,15 +144,15 @@ QList<SwallowCommand>* SwallowApplet::readConfig()
 	    preferences();
     }
 
-    return swcList;
+    return m_swcList;
 }
 
 
-void SwallowApplet::createApps( QList<SwallowCommand>* list )
+void SwallowApplet::createApps( SwallowCommandList* list )
 {
     SwallowApp *app = 0L;
 
-    QListIterator<SwallowCommand> it( *list );
+    SwallowCommandListIterator it( *list );
     while ( (it.current()) ) {
 	app = new SwallowApp( it.current(), this );
 	app->hide();
@@ -159,7 +163,7 @@ void SwallowApplet::createApps( QList<SwallowCommand>* list )
 	kapp->processEvents();
     }
 
-    layout->activate();
+    m_layout->activate();
 }
 
 
@@ -184,7 +188,7 @@ void SwallowApplet::embedded( SwallowApp *app )
     else
 	resize( width(), heightForWidth( width() ));
     
-    layout->addWidget( app );
+    m_layout->addWidget( app );
     app->show();
     updateGeometry();
     emit updateLayout();
@@ -192,7 +196,8 @@ void SwallowApplet::embedded( SwallowApp *app )
 
 void SwallowApplet::preferences()
 {
-    kdDebug() << "**** preferences ****" << endl;
+	PreferencesWidget *prefs = new PreferencesWidget(m_swcList,this);
+	prefs->show();
 }
 
 
@@ -201,7 +206,7 @@ int SwallowApplet::widthForHeight(int he)
     kdDebug() << "**** width for h: " << he << endl;
     int w = embeddedList->isEmpty() ? 30 : 0;
     layoutApps();
-    QListIterator<SwallowApp> it( *embeddedList );
+    SwallowAppListIterator it( *embeddedList );
     while ( it.current() ) {
 	kdDebug() << "current: " << it.current()->width() << endl;
 	w += (it.current())->width();
@@ -217,7 +222,7 @@ int SwallowApplet::heightForWidth(int)
 {
     int h = embeddedList->isEmpty() ? 30 : 0;
     layoutApps();
-    QListIterator<SwallowApp> it( *embeddedList );
+    SwallowAppListIterator it( *embeddedList );
     while ( it.current() ) {
 	h += (it.current())->height();
 	++it;
@@ -230,9 +235,9 @@ int SwallowApplet::heightForWidth(int)
 void SwallowApplet::layoutApps()
 {
     if ( KPanelApplet::orientation() == Horizontal )
-	layout->setDirection( QBoxLayout::LeftToRight );
+	m_layout->setDirection( QBoxLayout::LeftToRight );
     else
-	layout->setDirection( QBoxLayout::TopToBottom );
+	m_layout->setDirection( QBoxLayout::TopToBottom );
 }
 
 
