@@ -26,11 +26,22 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <kpanelapplet.h>
 
-#include <qlist.h>
+#if QT_VERSION < 300
+#include <qptrlist.h>
+#else
+#include <qptrlist.h>
+#endif
 #include <qxembed.h>
 #include <qpushbutton.h>
 
 class KWinModule;
+class KXEmbed;
+
+#if QT_VERSION < 300
+typedef QList<KXEmbed> KXEmbedList;
+#else
+typedef QPtrList<KXEmbed> KXEmbedList;
+#endif
 
 // Hacky class that is the same as QXEmbed, but does not destroy its
 // window in the destructor. It would be nice if Qt would have support
@@ -44,19 +55,6 @@ public:
     virtual ~KXEmbed() {}
 };
 
-class TrayButton : public QPushButton
-{
-    Q_OBJECT
-
-public:
-    TrayButton(QWidget* parent, const char* name)
-        : QPushButton(parent, name) { }
-    virtual ~TrayButton() {}
-
-protected:
-    void drawButton(QPainter *p);
-};
-
 class SystemTrayApplet : public KPanelApplet
 {
     Q_OBJECT
@@ -69,7 +67,6 @@ public:
 
     int widthForHeight(int h) const;
     int heightForWidth(int w) const;
-		virtual bool eventFilter( QObject *o, QEvent *e );
 
 protected:
     void resizeEvent( QResizeEvent* );
@@ -85,18 +82,11 @@ protected slots:
     void updateTrayWindows();
     void layoutTray();
 
-    void lock();
-    void logout();
-
 
 private:
-    QList<KXEmbed> m_Wins;
+    KXEmbedList m_Wins;
     KWinModule *kwin_module;
-    TrayButton *lockButton, *logoutButton;
 
-private slots:
-		void slotLockPrefs();
-		void slotLogoutPrefs();
 };
 
 #endif
