@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 class QLayout;
 class PanelButton;
-class KConfig;
+class KConfigGroup;
 
 class ButtonContainer : public BaseContainer
 {
@@ -38,21 +38,22 @@ public:
     ButtonContainer(QWidget* parent = 0);
 
     // buttons have a quadratic shape
-    virtual int widthForHeight(int height) { return height; }
-    virtual int heightForWidth(int width) { return width; }
+    virtual int widthForHeight(int height) const { return height; }
+    virtual int heightForWidth(int width)  const { return width; }
 
-    virtual void saveConfiguration(KConfig* config, const QString& group);
     virtual void configure();
 
-
     bool eventFilter (QObject *, QEvent *);
     void completeMoveOperation();
 
+    PanelButton* button() const { return _button; }
+
 public slots:
     void slotSetPopupDirection(Direction d);
     void slotSetOrientation(Orientation o);
 
 protected:
+    virtual void doSaveConfiguration( KConfigGroup&, bool layoutOnly ) const;
     void embedButton(PanelButton* p);
 
 protected:
@@ -67,8 +68,8 @@ public:
     KMenuButtonContainer(QWidget* parent);
     QString appletType() { return "KMenuButton"; }
 
-    virtual int widthForHeight( int height );
-    virtual int heightForWidth( int width );
+    virtual int widthForHeight( int height ) const;
+    virtual int heightForWidth( int width )  const;
 };
 
 class DesktopButtonContainer : public ButtonContainer
@@ -78,10 +79,18 @@ public:
     QString appletType() { return "DesktopButton"; }
 };
 
+class ServiceButtonContainer : public ButtonContainer
+{
+public:
+    ServiceButtonContainer(const KConfigGroup& config, QWidget* parent = 0);
+    ServiceButtonContainer(QWidget* parent, const QString& desktopFile);
+    QString appletType() { return "ServiceButton"; }
+};
+
 class URLButtonContainer : public ButtonContainer
 {
 public:
-    URLButtonContainer(KConfig* config, const QString& configGroup, QWidget* parent = 0);
+    URLButtonContainer(const KConfigGroup& config, QWidget* parent = 0);
     URLButtonContainer(QWidget* parent, const QString& url);
     QString appletType() { return "URLButton"; }
 };
@@ -89,7 +98,7 @@ public:
 class BrowserButtonContainer : public ButtonContainer
 {
 public:
-    BrowserButtonContainer(KConfig* config, const QString& configGroup, QWidget* parent = 0);
+    BrowserButtonContainer(const KConfigGroup& config, QWidget* parent = 0);
     BrowserButtonContainer(QWidget* parent, const QString& startDir, const QString& icon = "kdisknav");
     QString appletType() { return "BrowserButton"; }
 };
@@ -97,7 +106,7 @@ public:
 class ServiceMenuButtonContainer : public ButtonContainer
 {
 public:
-    ServiceMenuButtonContainer(KConfig* config, const QString& configGroup, QWidget* parent = 0);
+    ServiceMenuButtonContainer(const KConfigGroup& config, QWidget* parent = 0);
     ServiceMenuButtonContainer(QWidget* parent, const QString& label, const QString& relPath);
     QString appletType() { return "ServiceMenuButton"; }
 };
@@ -123,11 +132,11 @@ public:
     QString appletType() { return "RecentDocumentsButton"; }
 };
 
-class ExeButtonContainer : public ButtonContainer
+class NonKDEAppButtonContainer : public ButtonContainer
 {
 public:
-    ExeButtonContainer(KConfig* config, const QString& configGroup, QWidget *parent=0);
-    ExeButtonContainer(QWidget *parent, const QString &filePath, const QString &icon,
+    NonKDEAppButtonContainer(const KConfigGroup& config, QWidget *parent=0);
+    NonKDEAppButtonContainer(QWidget *parent, const QString &filePath, const QString &icon,
                        const QString &cmdLine, bool inTerm);
     QString appletType() { return "ExeButton"; }
 };
@@ -139,5 +148,13 @@ public:
     QString appletType() { return "KonsoleButton"; }
 };
 
+class ExtensionButtonContainer : public ButtonContainer
+{
+public:
+    ExtensionButtonContainer(const KConfigGroup& config, QWidget *parent=0);
+    ExtensionButtonContainer(const QString& desktopFile, QWidget *parent = 0);
+    QString appletType() { return "ExtensionButton"; }
+};
+
 #endif
 
