@@ -23,20 +23,20 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <qxembed.h>
 #include <qfile.h>
+#include <qvbox.h>
 
 #include <kglobal.h>
-#include <kglobalsettings.h>
 #include <kconfig.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kprocess.h>
 #include <kdebug.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <dcopclient.h>
-#include <kwinmodule.h>
 
 #include "extensionop_mnu.h"
-#include "global.h"
-#include "pluginmgr.h"
+#include "pluginloader.h"
+#include "container_base.h"
+#include "popupposition.h"
 
 #include "container_extension.h"
 #include "container_extension.moc"
@@ -53,8 +53,6 @@ ExtensionContainer::ExtensionContainer(const AppletInfo& info, QWidget *parent)
 
 ExtensionContainer::~ExtensionContainer()
 {
-    delete _opMnu;
-    writeConfig();
 }
 
 PanelSettings ExtensionContainer::defaultSettings()
@@ -73,17 +71,6 @@ PanelSettings ExtensionContainer::defaultSettings()
     return settings;
 }
 
-QRect ExtensionContainer::workArea()
-{
-    QValueList<WId> list;
-    QListIterator<PanelContainer> it(_containers);
-    for( ; it.current(); ++it ) {
-	if( !(*it)->inherits( "Panel" ) )
-	    list.append((*it)->winId());
-    }
-    return PGlobal::kwin_module->workArea(list);
-}
-
 void ExtensionContainer::readConfig()
 {
 //    kdDebug(1210) << "ExtensionContainer::readConfig()" << endl;
@@ -105,7 +92,6 @@ void ExtensionContainer::writeConfig()
 
     config->writeEntry("ConfigFile", _info.configFile());
     config->writeEntry("DesktopFile", _info.desktopFile());
-    config->sync();
 
     config = new KConfig(_info.configFile());
     config->setGroup("General");
@@ -116,75 +102,69 @@ void ExtensionContainer::writeConfig()
     delete config;
 }
 
-bool ExtensionContainer::eventFilter (QObject *o, QEvent *e)
+void ExtensionContainer::showPanelMenu( QPoint globalPos )
 {
-    if( e->type() == QEvent::MouseButtonPress )
-    {
-	QMouseEvent* ev = (QMouseEvent*) e;
-	if ( ev->button() == RightButton )
-	{
-	    if (!_opMnu)
-	    _opMnu = new PanelExtensionOpMenu(_actions);
+    if (!_opMnu)
+        _opMnu = new PanelExtensionOpMenu( _actions, this );
 
-	    switch(_opMnu->exec(getPopupPosition(_opMnu, ev->pos())))
-	    {
-		case PanelExtensionOpMenu::Move:
-		    moveMe();
-		    break;
-		case PanelExtensionOpMenu::Remove:
-		    emit removeme(this);
-		    break;
-		case PanelExtensionOpMenu::About:
-		    about();
-		    break;
-		case PanelExtensionOpMenu::Help:
-		    help();
-		    break;
-		case PanelExtensionOpMenu::Preferences:
-		    preferences();
-		    break;
-		case PanelExtensionOpMenu::ReportBug:
-		    reportBug();
-		    break;
-		default:
-		    break;
-	    }
-	    return true;
-	}
+    QPopupMenu *menu = BaseContainer::reduceMenu(_opMnu);
+
+    switch( menu->exec( popupPosition(
+            positionToDirection( position() ),
+            menu, this, mapFromGlobal( globalPos ) ) ) )
+    {
+    case PanelExtensionOpMenu::Remove:
+        emit removeme(this);
+        break;
+    case PanelExtensionOpMenu::About:
+        about();
+        break;
+    case PanelExtensionOpMenu::Help:
+        help();
+        break;
+    case PanelExtensionOpMenu::Preferences:
+        preferences();
+        break;
+    case PanelExtensionOpMenu::ReportBug:
+        reportBug();
+        break;
+    default:
+        break;
     }
-    return PanelContainer::eventFilter(o, e);
 }
 
 void ExtensionContainer::removeSessionConfigFile()
 {
     if (_info.configFile().isEmpty()) return;
     if (_info.isUniqueApplet()) return;
-    QString path = locate("config", _info.configFile());
 
-    QFile f (path);
-    if (f.exists()) {
-        kdDebug(1210) << "Removing session config file: " << path << endl;
-        f.remove();
+    if( QFile::exists( locate( "config", _info.configFile() ) ) ) {
+        // Seems to be some sort of bug here.
+    kdDebug(1210) << "ExtensionContainer::removeSessionConfigFile(): " <<_info.configFile() << ", "
+                  << locate( "config", _info.configFile() ) << endl;
+        QFile::remove( locate( "config", _info.configFile() ) );
     }
 }
 
 InternalExtensionContainer::InternalExtensionContainer(const AppletInfo& info, QWidget *parent)
     : ExtensionContainer(info, parent)
+    , _extension( 0 )
 {
-    _extension = PGlobal::pluginmgr->loadExtension( info.desktopFile(),
-                           info.configFile(), containerAreaBox());
+    _extension = PluginLoader::pluginLoader()->loadExtension( info, this );
 
     if (!_extension) return;
 
+    setMainWidget( _extension );
+
     _type = _extension->type();
     _actions = _extension->actions();
 
     connect(_extension, SIGNAL(updateLayout()), SLOT(updateLayout()));
 
-    connect(this, SIGNAL(positionChange(Position)), _extension, SLOT(slotSetPosition(Position)));
-
-    // initialise
-    readConfig();
+    connect( this, SIGNAL(positionChange(Position)),
+             this, SLOT(slotPositionChange(Position)) );
+    connect( this, SIGNAL(alignmentChange(Alignment)),
+             this, SLOT(slotAlignmentChange(Alignment)) );
 }
 
 InternalExtensionContainer::~InternalExtensionContainer()
@@ -215,10 +195,16 @@ QSize InternalExtensionContainer::sizeHint(Position p, QSize maxSize)
     return size.boundedTo( maxSize );
 }
 
-void InternalExtensionContainer::slotSetPosition(Position p)
+void InternalExtensionContainer::slotPositionChange(Position p)
 {
     if (!_extension) return;
-    _extension->slotSetPosition((KPanelExtension::Position)(p));
+    _extension->setPosition( (KPanelExtension::Position)p );
+}
+
+void InternalExtensionContainer::slotAlignmentChange( Alignment a )
+{
+    if (!_extension) return;
+    _extension->setAlignment( (KPanelExtension::Alignment)a );
 }
 
 void InternalExtensionContainer::about()
@@ -251,8 +237,12 @@ ExternalExtensionContainer::ExternalExtensionContainer(const AppletInfo& info, Q
     , _isdocked(false)
 {
 
+    QVBox* box = new QVBox( this );
+    setMainWidget( box );
+
     // init QXEmbed
-    _embed = new QXEmbed( containerAreaBox() );
+    _embed = new QXEmbed( box );
+    
     connect (_embed, SIGNAL(embeddedWindowDestroyed()),
              this, SIGNAL(embeddedWindowDestroyed()));
 
@@ -266,9 +256,8 @@ ExternalExtensionContainer::ExternalExtensionContainer(const AppletInfo& info, Q
     process.start(KProcess::DontCare);
 
     connect(this, SIGNAL(positionChange(Position)), SLOT(slotSetPosition(Position)));
-
-    // initialise
-    readConfig();
+    connect( this, SIGNAL(alignmentChange(Alignment)),
+             this, SLOT(slotAlignmentChange(Alignment)) );
 }
 
 ExternalExtensionContainer::~ExternalExtensionContainer()
@@ -288,6 +277,17 @@ void ExternalExtensionContainer::slotSetPosition(Position p)
     kapp->dcopClient()->send( _app, "ExtensionProxy", "setPosition(int)", data );
 }
 
+void ExternalExtensionContainer::slotAlignmentChange( Alignment a )
+{
+    if (!_isdocked) return;
+
+    QByteArray data;
+    QDataStream dataStream( data, IO_WriteOnly );
+    dataStream << static_cast<int>(a);
+
+    kapp->dcopClient()->send( _app, "ExtensionProxy", "setAlignment(int)", data );
+}
+
 void ExternalExtensionContainer::about()
 {
     if (!_isdocked) return;
@@ -379,8 +379,12 @@ void ExternalExtensionContainer::dockRequest(QCString app, int actions, int type
 
     kdDebug(1210) << "ExternalExtensionContainer::dockRequest: " << app << endl;
 
-    // get prefered position
+    KConfig config(_info.configFile());
+    config.setGroup("General");
+    if( !config.hasKey( "Position" ) )
     {
+
+        // get prefered position
         QByteArray data;
         QCString replyType;
         QByteArray replyData;
