@@ -50,11 +50,11 @@ public:
     QString extensionId() const { return _id; }
     void setExtensionId(const QString& s) { _id = s; }
 
-    bool eventFilter (QObject *, QEvent *);
-
     void readConfig();
     void writeConfig();
 
+    virtual QString panelId() { return extensionId(); }
+
     virtual void about() {}
     virtual void help() {}
     virtual void preferences() {}
@@ -65,9 +65,11 @@ public:
 signals:
     void removeme(ExtensionContainer*);
 
+protected slots:
+    virtual void showPanelMenu( QPoint pos );
+
 protected:
     virtual PanelSettings defaultSettings();
-    virtual QRect workArea();
 
     QString               _id;
     PanelExtensionOpMenu *_opMnu;
@@ -94,8 +96,9 @@ public:
 protected:
     PanelSettings defaultSettings();
 
-protected slots:
-    void slotSetPosition(Position p);
+private slots:
+   void slotPositionChange( Position p );
+   void slotAlignmentChange( Alignment a );
 
 private:
     KPanelExtension *_extension;
@@ -129,6 +132,9 @@ protected:
 protected slots:
     void slotSetPosition(Position p);
 
+private slots:
+   void slotAlignmentChange( Alignment a );
+
 private:
     QXEmbed  *_embed;
     QCString  _app;
