@@ -23,13 +23,29 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "global.h"
 
-Panel* PGlobal::panel = 0;
-KickerPluginManager* PGlobal::pluginmgr = 0;
-KWinModule* PGlobal::kwin_module = 0;
-ExtensionManager* PGlobal::extensionManager = 0;
-QMap<int, NETStrut> PGlobal::strutMap;
+Position directionToPosition( Direction d )
+{
+    switch( d ) {
+    case ::dDown:   return ::Top;
+    case ::dLeft:   return ::Right;
+    case ::dRight:  return ::Left;
+    default:
+    case ::dUp:     return ::Bottom;
+    }
+}
 
-int PGlobal::sizeValue(Size s)
+Direction positionToDirection( Position p )
+{
+    switch( p ) {
+    case ::Top:     return ::dDown;
+    case ::Right:   return ::dLeft;
+    case ::Left:    return ::dRight;
+    default:
+    case ::Bottom:  return ::dUp;
+    }
+}
+
+int sizeValue(Size s)
 {
     switch(s) {
         case Tiny:
@@ -43,13 +59,3 @@ int PGlobal::sizeValue(Size s)
             return 58;
     }
 }
-
-bool PGlobal::areEqual(NETStrut s1, NETStrut s2)
-{
-    if (s1.left != s2.left) return false;
-    if (s1.right != s2.right) return false;
-    if (s1.top != s2.top) return false;
-    if (s1.bottom != s2.bottom) return false;
-    return true;
-}
-
