@@ -1,6 +1,6 @@
 /*****************************************************************
 
-Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.
+Copyright (c) 1996-2001 the kicker authors. See file AUTHORS.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -22,14 +22,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ******************************************************************/
 
 #include <klocale.h>
-#include <kglobal.h>
-#include <kstddirs.h>
 #include <kcmdlineargs.h>
 #include <kdebug.h>
 #include <kaboutdata.h>
-#include <kimageio.h>
 #include <kcrash.h>
-#include <kopenwith.h>
 #include <kconfig.h>
 #include <dcopclient.h>
 
@@ -40,63 +36,31 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <signal.h>
 #include <unistd.h>
 
-#include "main.h"
-#include "panel.h"
-#include "global.h"
+#include "kicker.h"
 
 int kicker_screen_number = 0;
 
-static DCOPClient * client = 0;
-//static KFileOpenWithHandler* owh = new KFileOpenWithHandler;
-
-KickerApp::KickerApp() : KUniqueApplication()
+static void crashHandler(int signal)
 {
-    KGlobal::dirs()->addResourceType("mini", KStandardDirs::kde_default("data") +
-				     "kicker/pics/mini");
+    fprintf(stderr, "kicker: crashHandler called\n");
 
-    KGlobal::dirs()->addResourceType("icon", KStandardDirs::kde_default("data") +
-				     "kicker/pics");
-
-    KGlobal::dirs()->addResourceType("applets", KStandardDirs::kde_default("data") +
-                                     "kicker/applets");
-
-    KGlobal::dirs()->addResourceType("tiles", KStandardDirs::kde_default("data") +
-				     "kicker/tiles");
-
-    KGlobal::dirs()->addResourceType("extensions", KStandardDirs::kde_default("data") +
-				     "kicker/extensions");
-
-    KImageIO::registerFormats();
-
-    KGlobal::locale()->insertCatalogue("libkonq");
-
-    p = new Panel();
-    setMainWidget(p);
-    p->show();
-}
-
-KickerApp::~KickerApp()
-{
-    delete p;
-}
-
-static void crashHandler(int)
-{
-    KCrash::setCrashHandler(0); // exit on next crash
-    if (client)
-	client->detach();  // unregister with dcop
+    DCOPClient::emergencyClose();
+    // try to delete our main window gracefully, if this doesn't
+    // crash again, it can save the system tray docks from being
+    // destroyed.
+    delete kapp->mainWidget();
+    sleep( 1 );
     system("kicker --nocrashhandler &"); // try to restart
 }
 
-
 static void sighandler(int)
 {
+    fprintf(stderr, "kicker: sighandler called\n");
     QApplication::exit();
 }
 
 int main( int argc, char ** argv )
 {
-    QCString env;
     {
         QCString multiHead = getenv("KDE_MULTIHEAD");
         if (multiHead.lower() == "true") {
@@ -117,6 +81,7 @@ int main( int argc, char ** argv )
 	    if ((pos = display_name.findRev('.')) != -1)
 		display_name.remove(pos, 10);
 
+            QCString env;
 	    if (number_of_screens != 1) {
 		for (int i = 0; i < number_of_screens; i++) {
 		    if (i != kicker_screen_number && fork() == 0) {
@@ -129,7 +94,7 @@ int main( int argc, char ** argv )
 
 		env.sprintf("DISPLAY=%s.%d", display_name.data(), kicker_screen_number);
 
-		if (putenv(env.data())) {
+		if (putenv(strdup(env.data()))) {
 		    fprintf(stderr,
 			    "%s: WARNING: unable to set DISPLAY environment variable\n",
 			    argv[0]);
@@ -149,7 +114,7 @@ int main( int argc, char ** argv )
 			 , "1.1"
 			 , I18N_NOOP("The KDE desktop panel.")
 			 , KAboutData::License_BSD
-			 , "(c) 1999-2000, The KDE Team");
+			 , I18N_NOOP("(c) 1999-2000, The KDE Team"));
 
     aboutData.addAuthor("Matthias Elter",0, "elter@kde.org");
     aboutData.addAuthor("Matthias Ettrich",0, "ettrich@kde.org");
@@ -157,10 +122,11 @@ int main( int argc, char ** argv )
     aboutData.addAuthor("Rik Hemsley",0, "rik@kde.org");
     aboutData.addAuthor("Daniel M. Duley",0, "mosfet@kde.org");
     aboutData.addAuthor("Preston Brown",0, "pbrown@kde.org");
+    aboutData.addAuthor("John Firebaugh",0, "jfirebaugh@kde.org");
 
     KCmdLineArgs::init( argc, argv, &aboutData );
 
-    if (!KickerApp::start()) {
+    if (!Kicker::start()) {
 	kdError() << "kicker is already running!" << endl;
 	return 0;
     }
@@ -172,14 +138,15 @@ int main( int argc, char ** argv )
     if (signal(SIGHUP, sighandler) == SIG_IGN)
 	signal(SIGHUP, SIG_IGN);
 
-    KickerApp a;
-    a.disableSessionManagement();
+    Kicker kicker;
 
-    KCrash::setCrashHandler(crashHandler); // Try to restart on crash
+    // See if a crash handler was installed. It was if the -nocrashhandler
+    // argument was given, but the app eats the kde options so we can't
+    // check that directly. If it wasn't, don't install our handler either.
+    if( KCrash::crashHandler() != 0 ) {
+//	kdDebug(1210) << "Installing crash handler" << endl;
+	KCrash::setEmergencySaveFunction(crashHandler); // Try to restart on crash
+    }
 
-    client = kapp->dcopClient();
-    client->setDefaultObject("Panel");
-    client->send( "ksplash", "", "upAndRunning(QString)", QString(appname.data()));
-
-    return a.exec();
+    return kicker.exec();
 }
