@@ -24,13 +24,14 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __panel_h__
 #define __panel_h__
 
-#include <qbutton.h>
 #include <dcopobject.h>
 
 #include "global.h"
 #include "container_panel.h"
 
 class ContainerArea;
+class FittsLawFrame;
+class PanelOpMenu;
 
 class Panel : public PanelContainer, virtual public DCOPObject
 {
@@ -38,15 +39,19 @@ class Panel : public PanelContainer, virtual public DCOPObject
     K_DCOP
 
 public:
+    static Panel* the();
+
     Panel();
     ~Panel();
 
+    void initialize();
+
 k_dcop:
-    int panelSize() { return static_cast<int>(size()); }
+    int panelSize() { return _panelsize; }
     int panelOrientation() { return static_cast<int>(orientation()); }
     int panelPosition() { return static_cast<int>(position()); }
 
-    void setPanelSize(int size) { setSize(static_cast<Size>(size)); }
+    void setPanelSize(int size) { setSize( size ); }
     void setPanelPosition(int position) { setPosition(static_cast<Position>(position)); }
 
     // It makes sense to have these in Panel and not in ContainerArea, think of child panels.
@@ -56,18 +61,16 @@ k_dcop:
     void addURLButton(const QString &url);
     void addBrowserButton(const QString &startDir);
     void addServiceMenuButton(const QString &name, const QString& relPath);
-    void addExeButton(const QString &filePath, const QString &icon, const QString &cmdLine, bool inTerm);
+    void addNonKDEAppButton(const QString &filePath, const QString &icon, const QString &cmdLine, bool inTerm);
     void addKonsoleButton();
-
     void addApplet( const QString &desktopFile  );
-    void addExtension( const QString &desktopFile );
 
-    void configure();
     void restart();
+    void configure();
 
 public:
-    Size size() const { return _size; }
-    void setSize(Size s);
+    Size size() const;
+    void setSize( int size );
     QSize sizeHint( Position p, QSize maxSize );
 
     ContainerArea *containerArea() { return(_containerArea); }
@@ -75,24 +78,24 @@ public:
     void readConfig();
     void writeConfig();
 
-signals:
-    void configurationChanged();
+    virtual QString panelId() { return "MainPanel"; }
 
 protected:
-    void autoHide(bool hide);
+    virtual void showPanelMenu( QPoint globalPos );
+    virtual bool vetoAutoHide();
     void closeEvent( QCloseEvent * );
 
 protected slots:
     void slotSetPosition( Position p );
-    void slotRestart();
-    void scrollLeftUp();
-    void scrollRightDown();
+    void slotAlignmentChange( Alignment a );
+    void slotResizeRequest( int dx, int dy );
 
 private:
-    Size _size;
-    int _panelsize;
-
-    ContainerArea    *_containerArea;
+    Size              _size;
+    int               _panelsize;
+    FittsLawFrame*    _frame;
+    ContainerArea*    _containerArea;
+    PanelOpMenu*      _opMnu;
 };
 
 #endif // __panel_h__
