@@ -1,22 +1,31 @@
 #include <qpainter.h>
+
+#include <kapp.h>
+#include <kdebug.h>
 #include <krootpixmap.h>
 #include <kpixmap.h>
 #include <kpixmapeffect.h>
+#include <kpixmapio.h>
+
 #include "kasbar.h"
+
 #include "kasitem.h"
+#include "kasbar.moc"
 
 const int SMALL_EXTENT = 36;
 const int MEDIUM_EXTENT = 52;
 const int LARGE_EXTENT = 68;
 
-KasBar::KasBar( Orientation o, QWidget* parent, const char* name )
-   : QWidget( parent, name ),
+KasBar::KasBar( Orientation o, QWidget *parent, const char *name, WFlags f )
+   : QWidget( parent, name, f ),
      items(),
      orient( o ),
      itemUnderMouse_( 0 ),
      maxBoxes_( 100 ), // Temp value
      itemSize_( Medium ),
      itemExtent_( MEDIUM_EXTENT ),
+     oldR( 0 ),
+     oldC( 0 ),
      transparent_( false ),
      enableTint_( false ),
      tintAmount_( 0.1 ), 
@@ -24,9 +33,10 @@ KasBar::KasBar( Orientation o, QWidget* parent, const char* name )
      actBg( 0 ), inactBg( 0 ),
      activePenColor_( Qt::black ), inactivePenColor_( Qt::black )
 {
-   items.setAutoDelete( true );
-   setMouseTracking( true );
-   setMaxBoxes( 0 );
+    setBackgroundMode( NoBackground );
+    items.setAutoDelete( true );
+    setMouseTracking( true );
+    setMaxBoxes( 0 );
 }
 
 KasBar::~KasBar()
@@ -61,6 +71,8 @@ void KasBar::setItemSize( int size )
    inactBg = 0;
 
    emit itemSizeChanged( size );
+   emit configChanged();
+
    updateLayout();
 }
 
@@ -72,23 +84,29 @@ void KasBar::setTransparent( bool enable )
    transparent_ = enable;
 
    if ( transparent_ ) {
+       kdDebug(1345) << "KasBar: Enabling transparency" << endl;
+
       rootPix = new KRootPixmap( this );
+      connect( rootPix, SIGNAL( backgroundUpdated(const QPixmap &) ),
+	       this, SLOT( setBackground(const QPixmap &) ) );
+
+      rootPix->setCustomPainting( true );
 
       if ( enableTint_ )
 	 rootPix->setFadeEffect( tintAmount_, tintColour_ );
 
       rootPix->start();
-
-      if ( rootPix->checkAvailable( false ) )
-	rootPix->repaint( true );
    }
    else {
-      rootPix->stop();
-      delete rootPix;
-      rootPix = 0;
-      setBackgroundMode( NoBackground );
-      repaint();
+       kdDebug(1345) << "KasBar: Disabling transparency" << endl;
+
+       rootPix->stop();
+       delete rootPix;
+       rootPix = 0;
    }
+
+   emit configChanged();
+   repaint();
 }
 
 void KasBar::setTint( bool enable )
@@ -105,8 +123,9 @@ void KasBar::setTint( bool enable )
       else {
 	 rootPix->setFadeEffect( 0.0, tintColour_ );
       }
-      if ( rootPix->checkAvailable( false ) )
-	rootPix->repaint( true );
+
+      emit configChanged();
+      repaint( true );
    }
 }
 
@@ -117,7 +136,9 @@ void KasBar::setTint( double amount, QColor color )
 
    if ( transparent_ && enableTint_ ) {
       rootPix->setFadeEffect( tintAmount_, tintColour_ );
-      if ( rootPix->checkAvailable( false ) )
+      emit configChanged();
+
+      if ( rootPix->isAvailable() )
 	rootPix->repaint( true );
    }
 }
@@ -140,6 +161,7 @@ void KasBar::setMaxBoxes( int count )
       count = 15; // XXX Hacked
 
     maxBoxes_ = count;
+    emit configChanged();
     updateLayout();
   }
 }
@@ -181,18 +203,16 @@ QSize KasBar::sizeHint( Orientation o,  QSize )
 
 void KasBar::updateLayout()
 {
+//    kdDebug(1345) << "KasBar: updateLayout(), count is " << items.count() << endl;
+
+    // Empty bar
    if ( !items.count() ) {
-      resize(itemExtent(), itemExtent());
-
-      if ( transparent_ ) {
-	 rootPix->repaint();
-      }
-      else
-	 repaint( false );
-
+      resize( itemExtent(), itemExtent() );
+      update();
       return;
    }
 
+   // Work out the number of rows and columns
    unsigned int r=0, c=0;
    if( items.count() > (unsigned int) maxBoxes_ ) {
       r = items.count()/maxBoxes_;
@@ -202,10 +222,10 @@ void KasBar::updateLayout()
       r = 1;
       c = items.count();
    }
-   if(r*c < items.count()) // remainders
+
+   if( r*c < items.count() ) // remainders
       ++r;
 
-   static unsigned int oldR = 0, oldC = 0;
    if ( oldR != r || oldC != c ) {
       if ( orientation() == Horizontal )
 	 resize( c * itemExtent(), r * itemExtent() );
@@ -213,13 +233,10 @@ void KasBar::updateLayout()
 	 resize( r * itemExtent(), c * itemExtent() );
       oldR = r;
       oldC = c;
+
+      update();
    }
 
-   if ( transparent_ ) {
-     rootPix->repaint();
-   }
-   else
-     repaint( false );
 }
 
 void KasBar::append( KasItem *i )
@@ -289,59 +306,57 @@ void KasBar::dragMoveEvent ( QDragMoveEvent *ev )
 
 void KasBar::paintEvent(QPaintEvent *ev)
 {
+//    kdDebug(1345) << "KasBar: paintEvent()" << endl;
+
+    QPainter p(this);
+
+    // If we're empty
+    if ( !items.count() )
+	paintBackground( &p, rect() );
+
    QRect cr;
-   QPainter p(this);
    KasItem *i;
    int r=0, c=0;
 
-   int totalcols = width()/itemExtent();
-   int totalrows = height()/itemExtent();
+   if ( orientation() == Horizontal ) {
+       int totalcols = width()/itemExtent();
 
-   if ( items.count() ) {
-      if ( orientation() == Horizontal ) {
-	 for ( i = items.first(); i; i = items.next() ) {
-	    if ( c >= totalcols ) {
+       for ( i = items.first(); i; i = items.next() ) {
+	   if ( c >= totalcols ) {
 	       c = 0; ++r;
-	    }
-	    cr.setRect(c*itemExtent(), r*itemExtent(), itemExtent(), itemExtent());
-	    if ( ev->rect().intersects(cr) )
+	   }
+	   cr.setRect(c*itemExtent(), r*itemExtent(), itemExtent(), itemExtent());
+	   if ( ev->rect().intersects(cr) )
 	       i->paint( &p, c*itemExtent(), r*itemExtent() );
-	    ++c;
-	 }
-      }
-      else {
-	 for ( i = items.first(); i; i = items.next() ) {
-	    if ( r >= totalrows ) {
-	       r = 0; ++c;
-	    }
-	    cr.setRect(c*itemExtent(), r*itemExtent(), itemExtent(), itemExtent());
-	    if ( ev->rect().intersects(cr) )
-	       i->paint( &p, c*itemExtent(), r*itemExtent() );
-	    ++r;
-	 }
-      }
+	   ++c;
+       }
    }
+   else {
+       int totalrows = height()/itemExtent();
 
-   if ( !transparent_ ) {
-      if( orientation() == Horizontal && c < totalcols ) {
-	 p.fillRect( c*itemExtent(), r*itemExtent(), width()-c*itemExtent(),
-		     itemExtent(), colorGroup().brush(QColorGroup::Mid) );
-      }
-      else if( r < totalrows ) {
-	 p.fillRect( c*itemExtent(), r*itemExtent(), itemExtent(),
-		     height()-r*itemExtent(), colorGroup().brush(QColorGroup::Mid) );
-      }
+       for ( i = items.first(); i; i = items.next() ) {
+	   if ( r >= totalrows ) {
+	       r = 0; ++c;
+	   }
+	   cr.setRect(c*itemExtent(), r*itemExtent(), itemExtent(), itemExtent());
+	   if ( ev->rect().intersects(cr) )
+	       i->paint( &p, c*itemExtent(), r*itemExtent() );
+	   ++r;
+       }
    }
 }
 
 void KasBar::resizeEvent(QResizeEvent *ev)
 {
-   QWidget::resizeEvent(ev);
-   emit layoutChanged();
+//    kdDebug(1345) << "KasBar: resizeEvent()" << endl;
+
+    QWidget::resizeEvent(ev);
+    emit layoutChanged();
 }
 
 void KasBar::repaintItem(KasItem *i, bool erase )
 {
+//    kdDebug(1345) << "KasBar: repaintItem()" << endl;
    QPoint p = itemPos( i );
    repaint( QRect( p, QSize( itemExtent(), itemExtent()  ) ), transparent_ || erase );
 }
@@ -437,4 +452,22 @@ KPixmap *KasBar::inactiveBg()
 
    return inactBg;
 }
-#include "kasbar.moc"
+
+void KasBar::setBackground( const QPixmap &newBg )
+{
+    bg = newBg;
+    update();
+}
+
+void KasBar::paintBackground( QPainter *p, const QRect &r )
+{
+    // If we're transparent and know the bg
+    if ( transparent_ && (!bg.isNull()) ) {
+	p->drawPixmap( QPoint(0, 0), bg, r );
+	return;
+    }
+
+    // We're opaque
+    p->fillRect( rect(), colorGroup().brush(QColorGroup::Mid) );
+}
+
