@@ -2,7 +2,7 @@
 
 /*****************************************************************
 
-Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.
+Copyright (c) 1996-2002 the kicker authors. See file AUTHORS.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -27,17 +27,28 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __KASBAR_H
 
 #include <qwidget.h>
-#include <qlist.h>
 #include <qpoint.h>
+#if QT_VERSION < 300
+#include <qlist.h>
+#else
+#include <qptrlist.h>
+#endif
+
+#include <kpixmap.h>
 
 class KasItem;
 class KRootPixmap;
-class KPixmap;
+
+#if QT_VERSION < 300
+typedef QList<KasItem> KasItemList;
+#else
+typedef QPtrList<KasItem> KasItemList;
+#endif
 
 /**
  * The main view for KasBar.
  *
- * @version $Id: kasbar.h,v 1.13 2001/05/21 20:59:41 rich Exp $
+ * @version $Id: kasbar.h,v 1.18 2002/02/24 21:41:59 rich Exp $
  */
 class KasBar : public QWidget
 {
@@ -45,7 +56,7 @@ class KasBar : public QWidget
 
    friend class KasItem;
 public:
-   KasBar( Orientation o, QWidget* parent = 0, const char* name = 0 );
+   KasBar( Orientation o, QWidget* parent = 0, const char* name = 0, WFlags f = 0 );
    virtual ~KasBar();
 
    //
@@ -61,11 +72,9 @@ public:
    //
    // Layout options.
    //
-   enum ItemSize {
-      Large,
-      Medium,
-      Small
-    };
+
+   /** The possible item sizes. */
+   enum ItemSize { Large, Medium, Small };
 
    int itemSize() const { return itemSize_; }
    int itemExtent() const { return itemExtent_; }
@@ -86,34 +95,22 @@ public:
    // Look and feel options
    //
 
-   /**
-    * Is transparency enabled?
-    */
+   /** Is transparency enabled? */
    bool isTransparent() const { return transparent_; }
 
-   /**
-    * Is tinting enabled?
-    */
+   /** Is tinting enabled? */
    bool hasTint() const { return enableTint_; }
 
-   /**
-    * Set the amount and color of the tint.
-    */
+   /** Sets the amount and color of the tint. */
    void setTint( double amount, QColor color );
 
-   /**
-    * Set the amount of tinting.
-    */
+   /** Sets the amount of tinting. */
    void setTintAmount( double amount ) { setTint( amount, tintColour_ ); }
 
-   /**
-    * Get the amount of tinting.
-    */
+   /** Get the amount of tinting. */
    double tintAmount() const { return tintAmount_; }
 
-   /**
-    * Get the color of the tint.
-    */
+   /** Get the color of the tint. */
    QColor tintColor() const { return tintColour_; }
 
    QColor inactivePenColor() const { return inactivePenColor_; }
@@ -123,24 +120,16 @@ public:
    // Utilities
    //
 
-   /**
-    * Redraws the specified item.
-    */
+   /** Redraws the specified item. */
    void repaintItem(KasItem *i, bool erase = true );
 
-   /**
-    * Returns the item at p or 0.
-    */
+   /** Returns the item at p or 0. */
    KasItem* itemAt(const QPoint &p);
 
-   /**
-    * Get the position of the specified item.
-    */
+   /** Get the position of the specified item. */
    QPoint itemPos( KasItem *i );
 
-   /**
-    * The item under the mouse pointer (or 0).
-    */
+   /** The item under the mouse pointer (or 0). */
    KasItem *itemUnderMouse() const { return itemUnderMouse_; }
 
 public slots:
@@ -152,85 +141,71 @@ public slots:
 
    virtual void updateLayout();
 
-   /**
-    * Enable or disable tinting.
-    */
+   /** Enable or disable tinting. */
    void setTint( bool enable );
 
-   /**
-    * Enable or disable transparency.
-    */
+   /** Enable or disable transparency. */
    void setTransparent( bool enable );
 
-   /**
-    * Set the color of the tint.
-    */
+   /** Set the color of the tint. */
    void setTintColor( const QColor &c );
 
-   /**
-    * Set the strength of the tint (as a percentage).
-    */
+   /** Set the strength of the tint (as a percentage). */
    void setTintAmount( int percent );
 
+   void setBackground( const QPixmap &pix );
+
 signals:
-   /**
-    * Emitted when kasbar wants to resize. This happens when a new window is added.
-    */
+   /** Emitted when kasbar wants to resize. This happens when a new window is added. */
    void layoutChanged();
 
-   /**
-    * Emitted when the item size is changed.
-    */
+   /** Emitted when the item size is changed. */
    void itemSizeChanged( int );
 
+   void configChanged();
+
 protected:
-   /**
-    * Displays the popup menus, hides/shows windows.
-    */
+    KRootPixmap *rootPixmap() const { return rootPix; }
+
+   /** Displays the popup menus, hides/shows windows. */
    void mousePressEvent(QMouseEvent *ev);
 
-   /**
-    * Overridden to implement the mouse-over highlight effect.
-    */
+   /** Overridden to implement the mouse-over highlight effect. */
    void mouseMoveEvent(QMouseEvent *ev);
 
-   /**
-    * Overridden to implement the drag-over task switching.
-    */
+   /** Overridden to implement the drag-over task switching. */
    void dragMoveEvent(QDragMoveEvent *ev);
 
-   /**
-    * Calls the paint methods for the items in the rectangle specified by the event.
-    */
+   /** Paints the background of the item to the painter. */
+   void paintBackground( QPainter *p, const QRect &r );
+
+   /** Calls the paint methods for the items in the rectangle specified by the event. */
    void paintEvent(QPaintEvent *ev);
 
-   /**
-    * Forces the widget to re-layout it's contents.
-    */
+   /** Forces the widget to re-layout it's contents. */
    void resizeEvent(QResizeEvent *ev);
 
 private:
-   /**
-    * Internal factory method used by items to get the active bg fill.
-    */
+   /** Internal factory method used by items to get the active bg fill. */
    KPixmap *activeBg();
 
-   /**
-    * Internal factory method used by items to get the inactive bg fill.
-    */
+   /** Internal factory method used by items to get the inactive bg fill. */
    KPixmap *inactiveBg();
 
 private:
    // Core data
-   QList<KasItem> items;
+   KasItemList items;
    Orientation orient;
    KasItem *itemUnderMouse_;
    int maxBoxes_;
    int itemSize_;
    int itemExtent_;
+   uint oldR;
+   uint oldC;
 
    // Implements pseudo-transparency
    bool transparent_;
+   KPixmap bg;
    KRootPixmap *rootPix;
    bool enableTint_;
    double tintAmount_;
