@@ -5,10 +5,12 @@
 
 #include <kpanelextension.h>
 
-class KasBar;
+class KasTasker;
 
 /**
- * @version $Id: kasbarextension.h,v 1.3 2000/12/17 11:53:47 elter Exp $
+ * A KPanelExtension that displays a KasTasker widget.
+ *
+ * @version $Id: kasbarextension.h,v 1.6 2002/02/24 21:41:59 rich Exp $
  */
 class KasBarExtension : public KPanelExtension
 {
@@ -27,14 +29,16 @@ public:
 
     virtual void positionChange( Position position );
 
+protected slots:
+    void updateConfig();
+
 protected:
     void resizeEvent( QResizeEvent * );
-    void about();
-    void help();
-    void preferences();
-
+    virtual void about();
+    virtual void preferences();
+    
 private:
-    KasBar* kasbar;
+    KasTasker* kasbar;
 };
 
 #endif // KASBAREXTENSION_H
