@@ -5,7 +5,12 @@
 #include "kaspopup.h"
 
 KasPopup::KasPopup( KasItem *item, const char *name )
-   : QWidget( 0, name, WStyle_Customize | WStyle_Tool | WStyle_StaysOnTop ),
+   : QWidget( 0, name, WStyle_Customize | WStyle_StaysOnTop 
+	             | WStyle_Tool | WStyle_NoBorder
+#if QT_VERSION >= 300
+	      | WX11BypassWM
+#endif
+	      ),
      item_( item ),
      kasbar_( item->kasbar() )
 {
