@@ -30,13 +30,15 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qpoint.h>
 #include <qobject.h>
 #include <qvaluelist.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 
 #include <dcopobject.h>
 #include <kwin.h>
 #include <kstartupinfo.h>
 
+class TaskManager;
+
 /**
  * A dynamic interface to a task (main window).
  *
@@ -66,9 +68,11 @@ class Task: public QObject
     Q_PROPERTY( QPixmap thumbnail READ thumbnail )
 
 public:
-    Task( WId win, QObject * parent, const char *name = 0 );
+    Task( WId win, TaskManager * parent, const char *name = 0 );
     virtual ~Task();
 
+    TaskManager* taskManager() const { return (TaskManager*) parent(); }
+
     WId window() const { return _win; }
     QString name() const { return _info.name; }
     QString visibleName() const { return _info.visibleName; }
@@ -76,6 +80,7 @@ public:
     QString iconName() const;
     QString visibleIconName() const;
     QString className();
+    QString classClass();
 
     /**
      * A list of the window ids of all transient windows (dialogs) associated
@@ -117,6 +122,10 @@ public:
      */
     QPixmap icon( int width, int height, bool allowResize = false );
 
+    /**
+     * Returns true iff the windows with the specified ids should be grouped
+     * together in the task list.
+     */
     static bool idMatch(const QString &, const QString &);
 
     // state
@@ -141,6 +150,12 @@ public:
      */
     bool isActive() const;
 
+    /**
+     * Returns true if the task's window is the topmost non-iconified,
+     * non-always-on-top window.
+     */
+    bool isOnTop() const;
+
     /**
      * Returns true if the task's window is on the current virtual desktop.
      */
@@ -238,20 +253,34 @@ public slots:
     void raise();
 
     /**
+     * Lower the task's window.
+     */
+    void lower();
+
+   /**
      * Activate the task's window.
      */
     void activate();
 
+    /**
+     * Perform the action that is most appropriate for this task. If it
+     * is not active, activate it. Else if it is not the top window, raise
+     * it. Otherwise, iconify it.
+     */
+    void activateRaiseOrIconify();
+
     /**
      * If true, the task's window will remain at the top of the stacking order.
      */
     void setAlwaysOnTop(bool);
+    void toggleAlwaysOnTop();
 
     /**
      * If true then the task's window will be shaded. Most window managers
      * represent this state by displaying on the window's title bar.
      */
     void setShaded(bool);
+    void toggleShaded();
 
     /**
      * Moves the task's window to the specified virtual desktop.
@@ -371,6 +400,10 @@ private:
     class StartupPrivate *d;
 };
 
+typedef QPtrList<Task> TaskList;
+typedef QPtrList<Startup> StartupList;
+
+
 /**
  * A generic API for task managers. This class provides an easy way to
  * build NET compliant task managers. It provides support for startup
@@ -379,7 +412,7 @@ private:
  * @see Task
  * @see Startup
  * @see KWinModule
- * @version $Id: taskmanager.h,v 1.28 2001/06/14 19:24:51 lunakl Exp $
+ * @version $Id: taskmanager.h,v 1.37 2002/03/01 14:24:54 ettrich Exp $
  */
 class TaskManager : public QObject
 {
@@ -392,14 +425,16 @@ public:
     virtual ~TaskManager();
 
     /**
-     * Returns a list of all current tasks.
+     * Returns a list of all current tasks. Return type changed to
+     * QPtrList in KDE 3.
      */
-    QList<Task> tasks() const { return _tasks; }
+    TaskList tasks() const { return _tasks; }
 
     /**
-     * Returns a list of all current startups.
+     * Returns a list of all current startups. Return type changed to
+     * QPtrList in KDE 3.
      */
-    QList<Startup> startups() const { return _startups; }
+    StartupList startups() const { return _startups; }
 
     /**
      * Returns the name of the nth desktop.
@@ -419,7 +454,7 @@ public:
     /**
      * Returns true if the specified task is on top.
      */
-    bool isOnTop(Task*);
+    bool isOnTop( const Task*);
 signals:
     /**
      * Emitted when a new task has started.
@@ -476,7 +511,7 @@ protected slots:
     void gotStartupChange( const KStartupInfoId&, const KStartupInfoData& );
     //* @internal
     void gotRemoveStartup( const KStartupInfoId& );
-    
+
 protected:
     /**
      * Returns the task for a given WId, or 0 if there is no such task.
@@ -486,8 +521,8 @@ protected:
 
 private:
     Task*               _active;
-    QList<Task>         _tasks;
-    QList<Startup>      _startups;
+    TaskList           _tasks;
+    StartupList         _startups;
     KStartupInfo*       _startup_info;
 
     class TaskManagerPrivate *d;
