@@ -25,7 +25,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kiconloader.h>
 #include <kpanelapplet.h>
 
-#include "appletinfo.h"
+#include "kicker.h"
+#include "panel.h"
 #include "panelop_mnu.h"
 #include "appletop_mnu.h"
 
@@ -33,27 +34,26 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, const QString &/*title*/, cons
                                      QWidget *parent, const char *name)
   : QPopupMenu(parent, name)
 {
-    /*
-      if (!title.isEmpty())
-      {
+/*
+    if ( !title.isEmpty() )
+    {
       if (icon.isEmpty())
-      insertTitle(title);
+        insertTitle(title);
       else
-      insertTitle(SmallIcon(icon), title);
-      }
-    */
+        insertTitle(SmallIcon(icon), title);
+    }
+*/
+    if (!Kicker::kicker()->isImmutable())
+    {
+        insertItem(SmallIcon("move"), i18n("&Move"), Move);
+        setAccel(CTRL+Key_M, Move);
 
-    insertItem(SmallIcon("panel"), i18n("Panel Menu"), new PanelOpMenu(false, this));
-    insertSeparator();
-
-    insertItem(SmallIcon("move"), i18n("&Move"), Move);
-    setAccel(CTRL+Key_M, Move);
-
-    insertItem(SmallIcon("remove"), i18n("&Remove"), Remove);
-    setAccel(CTRL+Key_R, Remove);
+        insertItem(SmallIcon("remove"), i18n("&Remove"), Remove);
+        setAccel(CTRL+Key_R, Remove);
+    }
 
     if (actions & KPanelApplet::ReportBug)
-		{
+    {
         insertSeparator();
         insertItem(i18n("Report &Bug..."), ReportBug);
         setAccel(CTRL+Key_B, ReportBug);
@@ -61,7 +61,7 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, const QString &/*title*/, cons
 
     if (actions & KPanelApplet::Help
         || actions & KPanelApplet::About)
-	insertSeparator();
+        insertSeparator();
 
     if (actions & KPanelApplet::About)
     {
@@ -75,13 +75,35 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, const QString &/*title*/, cons
         setAccel(CTRL+Key_H, Help);
     }
 
-    if (actions & KPanelApplet::Preferences)
+    if (!Kicker::kicker()->isImmutable() && (actions & KPanelApplet::Preferences))
     {
         insertSeparator();
         insertItem(SmallIcon("configure"), i18n("&Preferences..."), Preferences);
         setAccel(CTRL+Key_P, Preferences);
     }
 
+    if (actions & PanelAppletOpMenu::KMenuEditor)
+    {
+        insertSeparator();
+        insertItem(SmallIcon("kmenuedit"), i18n("&Menu Editor"), Preferences);
+        setAccel(CTRL+Key_M, Preferences);
+    }
+    
+    if (count() > 0) insertSeparator();
+    insertItem(SmallIcon("panel"), i18n("Panel"), new PanelOpMenu(Panel::the(), this));
+
     adjustSize();
 }
 
+void PanelAppletOpMenu::keyPressEvent(QKeyEvent* e)
+{
+    if (e->key() == Qt::Key_Escape)
+    {
+        emit escapePressed();
+    }
+
+    QPopupMenu::keyPressEvent(e);
+}
+
+#include "appletop_mnu.moc" 
+
