@@ -37,7 +37,7 @@ PanelExeDialog::PanelExeDialog(const QString &path, const QString &pixmap,
                                QWidget *parent, const char *name)
     : QDialog(parent, name, true)
 {
-    setCaption(i18n("Non-KDE application configuration"));
+    setCaption(i18n("Non-KDE Application Configuration"));
     QFileInfo fi(path);
     QLabel *fileLbl = new QLabel(i18n("Filename: ") + fi.fileName(), this);
     QLabel *clLbl = new QLabel(i18n("Optional command line arguments:"), this);
