@@ -26,64 +26,59 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <kmimetype.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdesktopfile.h>
 #include <kglobalsettings.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kurldrag.h>
+#include <krecentdocument.h>
 
 #include "recent_mnu.h"
 #include "recent_mnu.moc"
 
 PanelRecentMenu::PanelRecentMenu(QWidget *parent, const char *name)
-    : PanelMenu(locateLocal("data", "RecentDocuments/"), parent, name) {}
+    : KPanelMenu(KRecentDocument::recentDocumentDirectory(), parent, name) {}
 
 void PanelRecentMenu::initialize()
 {
-    if (init) clear();
-    init = true;
+    if (initialized()) clear();
+    setInitialized(true);
 
-    QDir d(path(), "*.desktop", QDir::Time | QDir::Reversed, QDir::Files | QDir::Readable);
+    insertItem(SmallIconSet("fileclose"), i18n("Clear History"), this, SLOT(slotClearHistory()));
+    insertSeparator();
 
-    if (!d.exists())
-	d.mkdir(path());
+    fileList = KRecentDocument::recentDocuments();
 
-    QStringList list = d.entryList();
-
-    if (list.isEmpty()) {
-	insertItem(i18n("No entries"), 0);
+    if (fileList.isEmpty()) {
+	insertItem(i18n("No Entries"), 0);
 	setItemEnabled(0, false);
 	return;
     }
 
     int id = 0;
 
-    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
+    for (QStringList::ConstIterator it = fileList.begin(); it != fileList.end(); ++it) {
 
-	KDesktopFile f(path() + "/" + *it, true /* read only */);
+	KDesktopFile f(*it, true /* read only */);
 	insertItem(SmallIconSet(f.readIcon()), f.readName(), id++);
-	fileList.append(*it);
     }
-
-    insertSeparator();
-    insertItem(SmallIconSet("fileclose"), i18n("Clear History"), this, SLOT(slotClearHistory()));
 }
 
 void PanelRecentMenu::slotClearHistory()
 {
-    QDir dir(locateLocal("data", "RecentDocuments/"));
-    QStringList list = dir.entryList(QDir::Files | QDir::Writable);
-    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
-        dir.remove(*it);
+    KRecentDocument::clear();
 }
 
 void PanelRecentMenu::slotExec(int id)
 {
     if (id >= 0) {
       kapp->propagateSessionManager();
-      KApplication::startServiceByDesktopPath(path() + "/" + fileList[id]);
+      KURL u;
+      u.setPath( fileList[id] );
+      KDEDesktopMimeType::run( u, true );
     }
 }
 
@@ -95,7 +90,7 @@ void PanelRecentMenu::mousePressEvent(QMouseEvent * e)
 
 void PanelRecentMenu::mouseMoveEvent(QMouseEvent * e)
 {
-  PanelMenu::mouseMoveEvent(e);
+  KPanelMenu::mouseMoveEvent(e);
 
   if (!(e->state() & LeftButton))
     return;
@@ -113,7 +108,7 @@ void PanelRecentMenu::mouseMoveEvent(QMouseEvent * e)
     if (id < 0)
       return;
 
-    KDesktopFile f(path() + "/" + fileList[id], true /* read only */);
+    KDesktopFile f(fileList[id], true /* read only */);
 
     KURL url = f.readURL();
 
