@@ -38,25 +38,28 @@ public:
 
   KAudiocdModule(QWidget *parent=0, const char *name=0);
 
-   QString quickHelp() const;
+  QString quickHelp() const;
+  const KAboutData* aboutData() const;    
 
 public slots:
 
- void defaults();
- void save();
- void load();
+  void defaults();
+  void save();
+  void load();
  
 private slots:
 
- void slotSelectMethod(int);
- void slotUpdateVBRWidgets();
- void slotUpdateVBRCombos();
- void slotConfigChanged();
- void slotChangeFilter();
- void slotEcDisable();
- void slotAddCDDBServer();
- void slotDelCDDBServer();
- void slotServerTextChanged(const QString & );
+  void slotSelectMethod(int);
+  void slotUpdateVBRWidgets();
+  void slotConfigChanged();
+  void slotChangeFilter();
+  void slotEcDisable();
+  void slotAddCDDBServer();
+  void slotDelCDDBServer();
+  void slotServerTextChanged(const QString & );
+  void slotAddCDDBDir();
+  void slotDelCDDBDir();
+  void slotServerSelectionChanged();
 private:
 
   AudiocdConfig *audiocdConfig;
@@ -67,10 +70,12 @@ private:
   QLineEdit *cd_device_string;
 
   QCheckBox *cddb_enable;
-  QLineEdit *cddb_server;
-  QListBox *cddb_server_listbox;
-  QStringList cddbserverlist;
+  QCheckBox *cddb_save_local;
+  QLineEdit *cddb_server, *cddbdir;
+  QListBox *cddb_server_listbox, *cddbdir_listbox;
+  QStringList cddbserverlist, cddbdirlist;
   QPushButton *cddbserver_add_push,*cddbserver_del_push;
+  QPushButton *cddbdir_add_push, *cddbdir_del_push;
 
   QCheckBox *vbr_min_br, *vbr_min_hard, *vbr_max_br, *vbr_average_br, *vbr_xing_tag;
 
