@@ -16,7 +16,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: kio_finger.cpp,v 1.15 2001/05/11 20:59:50 schlpbch Exp $ */
+/* $Id: kio_finger.cpp,v 1.18 2002/01/20 14:12:53 hausmann Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,14 +27,14 @@
 #include <qdict.h>
 #include <qcstring.h>
 #include <qfile.h>
+#include <qregexp.h>
 
 #include <kdebug.h>
 #include <kinstance.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kurl.h>
-#include <kregexp.h>
 
 #include "kio_finger.h"
 
@@ -116,9 +116,9 @@ void FingerProtocol::get(const KURL& url )
   QRegExp regExp("?refreshRate=[0-9][0-9]*", true, true);
   if (query.contains(regExp)) {
     //kdDebug() << "looks like a valid query" << endl;
-    KRegExp regExp( "([0-9]+)" );
-    regExp.match(query.local8Bit());
-    refreshRate = regExp.group(0);
+    QRegExp regExp( "([0-9]+)" );
+    regExp.search(query);
+    refreshRate = regExp.cap(0);
   }
   
   //kdDebug() << "Refresh rate: " << refreshRate << endl;
