@@ -1,7 +1,8 @@
-// $Id: imap4.cc,v 1.62.2.1 2001/08/22 10:33:17 haeckel Exp $
+// $Id: imap4.cc,v 1.110 2002/03/01 09:50:57 firebaugh Exp $
 /**********************************************************************
  *
  *   imap4.cc  - IMAP4rev1 KIOSlave
+ *   Copyright (C) 2001  Michael Haeckel <Michael@Haeckel.Net>
  *   Copyright (C) 1999  John Corey
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -44,26 +45,18 @@
 
 #include "rfcdecoder.h"
 
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/select.h>
-#include <sys/time.h>
-#include <sys/wait.h>
 #include <sys/stat.h>
 
-#include <fcntl.h>
-
-#include <errno.h>
-#include <signal.h>
 #include <stdio.h>
-#include <unistd.h>
 #include <stdlib.h>
+#include <signal.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 
 #include <qbuffer.h>
 #include <kprotocolmanager.h>
-#include <ksock.h>
+#include <kmessagebox.h>
 #include <kdebug.h>
-#include <kinstance.h>
 #include <kio/connection.h>
 #include <kio/slaveinterface.h>
 #include <kio/passdlg.h>
@@ -71,28 +64,12 @@
 
 using namespace KIO;
 
-FILE *myDebug;
-
 extern "C"
 {
   void sigalrm_handler (int);
   int kdemain (int argc, char **argv);
 };
 
-void
-debugOut (FILE * myFile, const char *msg)
-{
-  fprintf (myFile, "%s\n", msg);
-  fflush (myFile);
-}
-
-void
-myHandler (QtMsgType type, const char *msg)
-{
-  if (&type);
-  debugOut (myDebug, msg);
-}
-
 int
 kdemain (int argc, char **argv)
 {
@@ -106,12 +83,6 @@ kdemain (int argc, char **argv)
   }
 
   //set debug handler
-#ifdef EBUGGING
-  myDebug = fopen ("/tmp/imap_slave", "a");
-  fprintf (myDebug, "Debugging\n");
-  fflush (myDebug);
-  qInstallMsgHandler (myHandler);
-#endif
 
   IMAP4Protocol *slave;
   if (strcasecmp (argv[1], "imaps") == 0)
@@ -123,10 +94,6 @@ kdemain (int argc, char **argv)
   slave->dispatchLoop ();
   delete slave;
 
-#ifdef EBUGGING
-  fclose (myDebug);
-#endif
-
   return 0;
 }
 
@@ -159,9 +126,11 @@ IMAP4Protocol::IMAP4Protocol (const QCString & pool, const QCString & app, bool
               app, isSSL), imapParser (),
 mimeIO ()
 {
+  mySSL = isSSL;
   readBuffer[0] = 0x00;
-  readSize = 0;
   relayEnabled = false;
+  readBufferLen = 0;
+  cacheOutput = false;
 }
 
 IMAP4Protocol::~IMAP4Protocol ()
@@ -173,11 +142,18 @@ IMAP4Protocol::~IMAP4Protocol ()
 void
 IMAP4Protocol::get (const KURL & _url)
 {
+  if (!makeLogin()) return;
   kdDebug(7116) << "IMAP4::get -  " << hidePass(_url) << endl;
   QString aBox, aSequence, aType, aSection, aValidity, aDelimiter;
   enum IMAP_TYPE aEnum =
     parseURL (_url, aBox, aSection, aType, aSequence, aValidity, aDelimiter);
 
+  if (aSequence == "0:0" && getState() == ISTATE_SELECT)
+  {
+    imapCommand *cmd = doCommand (imapCommand::clientNoop());
+    completeQueue.removeRef(cmd);
+  }
+
   if (aSequence.isEmpty ())
   {
     aSequence = "1:*";
@@ -233,6 +209,9 @@ IMAP4Protocol::get (const KURL & _url)
         outputLineStr ("X-uidValidity: " +
                        QString ().setNum (selectInfo.uidValidity ()) +
                        "\r\n");
+      if (selectInfo.uidNextAvailable ())
+        outputLineStr ("X-UidNext: " +
+                       QString ().setNum (selectInfo.uidNext ()) + "\r\n");
       if (selectInfo.flagsAvailable ())
         outputLineStr ("X-Flags: " + QString ().setNum (selectInfo.flags ()) +
                        "\r\n");
@@ -250,56 +229,60 @@ IMAP4Protocol::get (const KURL & _url)
     if (aEnum == ITYPE_MSG)
       relayEnabled = true;
 
-    cmd = sendCommand (imapCommand::clientFetch (aSequence, aSection));
-    int res;
-    do
+    if (aSequence != "0:0")
     {
-      while (!(res = parseLoop()));
-      if (res == -1) break;
-
-      mailHeader *lastone = NULL;
-      imapCache *cache;
-      cache = getLastHandled ();
-      if (cache)
-        lastone = cache->getHeader ();
-
-      if (!cmd->isComplete ())
+      cmd = sendCommand (imapCommand::clientFetch (aSequence, aSection));
+      int res;
+      do
       {
-        kdDebug(7116) << "IMAP4::get - got " << lastone << " from client" << endl;
-        if (lastone && ((aSection.find ("BODYSTRUCTURE", 0, false) != -1)
-                  || (aSection.find ("ENVELOPE", 0, false) != -1)
-                  || (aSection.find ("BODY.PEEK[0]", 0, false) != -1
-                      && (aEnum == ITYPE_BOX || aEnum == ITYPE_DIR_AND_BOX))))
+        while (!(res = parseLoop()));
+        if (res == -1) break;
+
+        mailHeader *lastone = NULL;
+        imapCache *cache;
+        cache = getLastHandled ();
+        if (cache)
+          lastone = cache->getHeader ();
+
+        if (!cmd->isComplete ())
         {
-          if (aEnum == ITYPE_BOX || aEnum == ITYPE_DIR_AND_BOX)
+          if (lastone && ((aSection.find ("BODYSTRUCTURE", 0, false) != -1)
+                    || (aSection.find ("ENVELOPE", 0, false) != -1)
+                    || (aSection.find ("BODY.PEEK[0]", 0, false) != -1
+                        && (aEnum == ITYPE_BOX || aEnum == ITYPE_DIR_AND_BOX))))
           {
-            // write the mime header (default is here message/rfc822)
-            outputLine ("--IMAPDIGEST\r\n");
-            if (cache->getUid () != 0)
-              outputLineStr ("X-UID: " +
-                             QString ().setNum (cache->getUid ()) + "\r\n");
-            if (cache->getSize () != 0)
-              outputLineStr ("X-Length: " +
-                             QString ().setNum (cache->getSize ()) + "\r\n");
-            if (cache->getDate ()->tm_year != 0)
-              outputLineStr ("X-Date: " + cache->getDateStr () + "\r\n");
-            if (cache->getFlags () != 0)
-              outputLineStr ("X-Flags: " +
-                             QString ().setNum (cache->getFlags ()) + "\r\n");
-            outputLine ("\r\n");
+            if (aEnum == ITYPE_BOX || aEnum == ITYPE_DIR_AND_BOX)
+            {
+              // write the mime header (default is here message/rfc822)
+              outputLine ("--IMAPDIGEST\r\n");
+              cacheOutput = true;
+              if (cache->getUid () != 0)
+                outputLineStr ("X-UID: " +
+                               QString ().setNum (cache->getUid ()) + "\r\n");
+              if (cache->getSize () != 0)
+                outputLineStr ("X-Length: " +
+                               QString ().setNum (cache->getSize ()) + "\r\n");
+              if (!cache->getDate ().isEmpty())
+                outputLineStr ("X-Date: " + cache->getDate () + "\r\n");
+              if (cache->getFlags () != 0)
+                outputLineStr ("X-Flags: " +
+                               QString ().setNum (cache->getFlags ()) + "\r\n");
+            } else cacheOutput = true;
+            lastone->outputPart (*this);
+            cacheOutput = false;
+            flushOutput();
           }
-          lastone->outputPart (*this);
         }
       }
-    }
-    while (!cmd->isComplete ());
-    if (aEnum == ITYPE_BOX || aEnum == ITYPE_DIR_AND_BOX)
-    {
-      // write the end boundary
-      outputLine ("--IMAPDIGEST--\r\n");
-    }
+      while (!cmd->isComplete ());
+      if (aEnum == ITYPE_BOX || aEnum == ITYPE_DIR_AND_BOX)
+      {
+        // write the end boundary
+        outputLine ("--IMAPDIGEST--\r\n");
+      }
 
-    completeQueue.removeRef (cmd);
+      completeQueue.removeRef (cmd);
+    }
   }
 
   // just to keep everybody happy when no data arrived
@@ -315,6 +298,15 @@ IMAP4Protocol::listDir (const KURL & _url)
 {
   kdDebug(7116) << "IMAP4::listDir - " << hidePass(_url) << endl;
 
+  if (_url.path().isEmpty())
+  {
+    KURL url = _url;
+    url.setPath("/");
+    redirection( url.url() );
+    finished();
+    return;
+  }
+
   QString myBox, mySequence, myLType, mySection, myValidity, myDelimiter;
   enum IMAP_TYPE myType =
     parseURL (_url, myBox, mySection, myLType, mySequence, myValidity,
@@ -356,7 +348,8 @@ IMAP4Protocol::listDir (const KURL & _url)
       }
       completeQueue.removeRef (cmd);
     }
-    if (myType == ITYPE_BOX || myType == ITYPE_DIR_AND_BOX)
+    if ((myType == ITYPE_BOX || myType == ITYPE_DIR_AND_BOX)
+        && myLType != "LIST" && myLType != "LSUB")
     {
       if (!_url.query ().isEmpty ())
       {
@@ -385,31 +378,13 @@ IMAP4Protocol::listDir (const KURL & _url)
             if (selectInfo.uidNextAvailable ())
               stretch = QString ().setNum (selectInfo.uidNext ()).length ();
             UDSEntry entry;
-            mailHeader *lastone = NULL;
-            imapCache *cache;
-            mailHeader fake;
+            imapCache fake;
 
-//            kdDebug(7116) << "SEARCH returned - " << list.count() << endl;
             for (QStringList::Iterator it = list.begin (); it != list.end ();
                  ++it)
             {
-//              kdDebug(7116) << "SEARCH processing - " << (*it) << endl;
-
-              // get the cached entry
-              cache = getUid ((*it));
-              if (cache)
-                lastone = cache->getHeader ();
-              else
-                lastone = NULL;
-
-              // if the uid is not in the cache we fake an entry
-/*              if (!lastone)  Does not really work with the cache, Michael */
-              {
-//                kdDebug(7116) << "SEARCH faking - " << (*it) << endl;
-                fake.setPartSpecifier ((*it));
-                lastone = &fake;
-              }
-              doListEntry (_url, lastone, stretch);
+              fake.setUid((*it).toULong());
+              doListEntry (_url, stretch, &fake);
             }
             entry.clear ();
             listEntry (entry, true);
@@ -463,30 +438,24 @@ IMAP4Protocol::listDir (const KURL & _url)
             //        kdDebug(7116) << selectInfo.uidNext() << "d used to stretch " << stretch << endl;
             UDSEntry entry;
 
-            if (mySequence.isEmpty ())
-              mySequence = "1:*";
+            if (mySequence.isEmpty()) mySequence = "1:*";
+
+            bool withSubject = mySection.isEmpty();
+            if (mySection.isEmpty()) mySection = "UID RFC822.SIZE ENVELOPE";
+            
+            bool withFlags = mySection.upper().find("FLAGS") != -1;
             imapCommand *fetch =
               sendCommand (imapCommand::
-                           clientFetch (mySequence, "UID RFC822.SIZE"));
+                           clientFetch (mySequence, mySection));
+            imapCache *cache;
             do
             {
               while (!parseLoop ());
 
-              mailHeader *lastone;
-              imapCache *cache;
               cache = getLastHandled ();
-              if (cache)
-                lastone = cache->getHeader ();
-              else
-                lastone = NULL;
 
               if (cache && !fetch->isComplete())
-              {
-                mailHeader fake;
-                fake.setPartSpecifier(QString::number(cache->getUid()));
-                fake.setLength(cache->getSize());
-                doListEntry (_url, &fake, stretch);
-              }
+                doListEntry (_url, stretch, cache, withFlags, withSubject);
             }
             while (!fetch->isComplete ());
             entry.clear ();
@@ -543,9 +512,9 @@ IMAP4Protocol::parseRelay (ulong len)
 bool IMAP4Protocol::parseRead(QByteArray & buffer, ulong len, ulong relay)
 {
   char buf[4096];
-  while (buffer.size() < len && !AtEOF())
+  while (buffer.size() < len)
   {
-    ulong readLen = Read(buf, QMIN(len - buffer.size(), sizeof(buf) - 1));
+    ssize_t readLen = myRead(buf, QMIN(len - buffer.size(), sizeof(buf) - 1));
     if (readLen == 0)
     {
       error (ERR_CONNECTION_BROKEN, myHost);
@@ -576,63 +545,56 @@ bool IMAP4Protocol::parseRead(QByteArray & buffer, ulong len, ulong relay)
 bool IMAP4Protocol::parseReadLine (QByteArray & buffer, ulong relay)
 {
   if (myHost.isEmpty()) return FALSE;
-  char buf[1024];
-  fd_set FDs;
-  ssize_t readLen;
-  struct timeval m_tTimeout;
 
-  errno = 0;
-  while (1)
-  {
-    memset (&buf, sizeof (buf), 0);
-    if (!AtEOF()) readLen = ReadLine(buf, sizeof(buf) - 1);
-    else {
-      int wait_time = 120;
-      do {
-        FD_ZERO (&FDs);
-        FD_SET (m_iSock, &FDs);
-        m_tTimeout.tv_sec = 1;
-        m_tTimeout.tv_usec = 0;
-        wait_time--;
+  while (true) {
+    ssize_t copyLen = 0;
+    if (readBufferLen > 0)
+    {
+      while (copyLen < readBufferLen && readBuffer[copyLen] != '\n') copyLen++;
+      if (copyLen < readBufferLen) copyLen++;
+      if (relay > 0)
+      {
+        QByteArray relayData;
+
+        if (copyLen < relay)
+          relay = copyLen;
+        relayData.setRawData (readBuffer, relay);
+        parseRelay (relayData);
+        relayData.resetRawData (readBuffer, relay);
+        kdDebug(7116) << "relayed : " << relay << "d" << endl;
       }
-      while (wait_time && select(m_iSock+1, &FDs, 0, 0, &m_tTimeout) == 0);
-      readLen = ReadLine (buf, sizeof (buf) - 1);
+      // append to buffer
+      {
+        QBuffer stream (buffer);
+
+        stream.open (IO_WriteOnly);
+        stream.at (buffer.size ());
+        stream.writeBlock (readBuffer, copyLen);
+        stream.close ();
+//        kdDebug(7116) << "appended " << copyLen << "d got now " << buffer.size() << endl;
+      }
+
+      readBufferLen -= copyLen;
+      if (readBufferLen) memcpy(readBuffer, &readBuffer[copyLen], readBufferLen);
+      if (buffer[buffer.size() - 1] == '\n') return TRUE;
     }
-    if (readLen <= 0)
+    if (!isConnectionValid())
     {
       error (ERR_CONNECTION_BROKEN, myHost);
       setState(ISTATE_CONNECT);
       closeConnection();
       return FALSE;
     }
-
-    if (relay > 0)
+    waitForResponse(600);
+    readBufferLen = read(readBuffer, IMAP_BUFFER - 1);
+    if (readBufferLen == 0)
     {
-    QByteArray relayData;
-
-      if ((ulong)readLen < relay)
-        relay = readLen;
-      relayData.setRawData (buf, relay);
-      parseRelay (relayData);
-      relayData.resetRawData (buf, relay);
-      kdDebug(7116) << "relayed : " << relay << "d" << endl;
+      error (ERR_CONNECTION_BROKEN, myHost);
+      setState(ISTATE_CONNECT);
+      closeConnection();
+      return FALSE;
     }
-    // append to buffer
-    {
-      QBuffer stream (buffer);
-
-      stream.open (IO_WriteOnly);
-      stream.at (buffer.size ());
-      stream.writeBlock (buf, readLen);
-      stream.close ();
-//        kdDebug(7116) << "appended " << readLen << "d got now " << buffer.size() << endl;
-    }
-    if (buffer[buffer.size () - 1] != '\n')
-      kdDebug(7116) << "************************** Partial filled buffer" << endl;
-    else
-      break;
   }
-  return TRUE;
 }
 
 
@@ -676,7 +638,7 @@ IMAP4Protocol::put (const KURL & _url, int, bool, bool)
   }
   else
   {
-    QList < QByteArray > bufferList;
+    QPtrList < QByteArray > bufferList;
     int length = 0;
 
     int result;
@@ -701,21 +663,8 @@ IMAP4Protocol::put (const KURL & _url, int, bool, bool)
       return;
     }
 
-    // Some servers can't append mails to the selected mailbox
-    if (getState() == ISTATE_SELECT)
-    {
-      imapCommand *cmd = doCommand (imapCommand::clientClose());
-      if (cmd->result() != "OK")
-      {
-        error (ERR_ABORTED, i18n("Unable to close mailbox."));
-        finished();
-        return;
-      }
-      setState(ISTATE_LOGIN);
-    }
-
     imapCommand *cmd =
-      sendCommand (imapCommand::clientAppend (aBox, "", length));
+      sendCommand (imapCommand::clientAppend (aBox, aSection, length));
     while (!parseLoop ());
 
     // see if server is waiting
@@ -730,7 +679,7 @@ IMAP4Protocol::put (const KURL & _url, int, bool, bool)
         buffer = bufferList.take (0);
 
         sendOk =
-          (Write (buffer->data (), buffer->size ()) ==
+          (write (buffer->data (), buffer->size ()) ==
            (ssize_t) buffer->size ());
         wrote += buffer->size ();
         delete buffer;
@@ -738,8 +687,8 @@ IMAP4Protocol::put (const KURL & _url, int, bool, bool)
         {
           error (ERR_CONNECTION_BROKEN, myHost);
           completeQueue.removeRef (cmd);
+          setState(ISTATE_CONNECT);
           closeConnection();
-          finished();
           return;
         }
       }
@@ -775,17 +724,55 @@ void
 IMAP4Protocol::mkdir (const KURL & _url, int)
 {
   kdDebug(7116) << "IMAP4::mkdir - " << hidePass(_url) << endl;
-//  KIO::TCPSlaveBase::mkdir(_url,permissions);
+  QString path = _url.path();
+  int slash = path.findRev('/', (path.at(path.length() - 1) == '/') ?
+    (int)path.length() - 2 : -1);
+  KURL parentUrl = _url;
+  QString newBox;
+  if (slash != -1)
+  {
+    parentUrl.setPath(path.left(slash) + ";TYPE=LIST");
+    newBox = path.mid(slash + 1);
+  }
   QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter;
-  parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter);
-  if (aBox[aBox.length () - 1] != '/')
-    aBox += "/";
-  imapCommand *cmd = doCommand (imapCommand::clientCreate (aBox));
+  parseURL(parentUrl, aBox, aSection, aLType, aSequence, aValidity, aDelimiter);
+/*  if (aBox[aBox.length () - 1] != '/')
+    aBox += "/"; */
+  newBox = (newBox.isEmpty()) ? aBox : aBox + aDelimiter + newBox;
+  imapCommand *cmd = doCommand (imapCommand::clientCreate(newBox));
 
   if (cmd->result () != "OK")
+  {
     error (ERR_COULD_NOT_MKDIR, hidePass(_url));
-
+    completeQueue.removeRef (cmd);
+    return;
+  }
   completeQueue.removeRef (cmd);
+
+  enum IMAP_TYPE type =
+    parseURL(_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter);
+  if (type == ITYPE_BOX)
+  {
+    if (messageBox(QuestionYesNo,
+      i18n("What do you want to store in this folder?"), i18n("Create folder"),
+      i18n("&Messages"), i18n("&Subfolders")) == KMessageBox::No)
+    {
+      cmd = doCommand(imapCommand::clientDelete(newBox));
+      completeQueue.removeRef (cmd);
+      cmd = doCommand(imapCommand::clientCreate(newBox + aDelimiter));
+      if (cmd->result () != "OK")
+      {
+        error (ERR_COULD_NOT_MKDIR, hidePass(_url));
+        completeQueue.removeRef (cmd);
+        return;
+      }
+      completeQueue.removeRef (cmd);
+    }
+  }
+
+  cmd = doCommand(imapCommand::clientSubscribe(newBox));
+  completeQueue.removeRef(cmd);
+
   finished ();
 }
 
@@ -862,7 +849,7 @@ IMAP4Protocol::copy (const KURL & src, const KURL & dest, int, bool overwrite)
 
     }
   }
-  if (sType == ITYPE_MSG)
+  if (sType == ITYPE_MSG || sType == ITYPE_BOX)
   {
     //select the source box
     if (assureBox (sBox, true))
@@ -921,7 +908,7 @@ IMAP4Protocol::del (const KURL & _url, bool isFile)
         {
           imapCommand *cmd =
             doCommand (imapCommand::
-                       clientStore (aSequence, "+FLAGS", "\\DELETED"));
+                       clientStore (aSequence, "+FLAGS.SILENT", "\\DELETED"));
           if (cmd->result () != "OK")
             error (ERR_CANNOT_DELETE, hidePass(_url));
           completeQueue.removeRef (cmd);
@@ -932,7 +919,50 @@ IMAP4Protocol::del (const KURL & _url, bool isFile)
     }
     else
     {
-      //TODO delete the mailbox
+      if (getCurrentBox() == aBox)
+      {
+        imapCommand *cmd = doCommand(imapCommand::clientClose());
+        completeQueue.removeRef(cmd);
+        setState(ISTATE_LOGIN);
+      }
+      // We unsubscribe, otherwise we get ghost folders on UW-IMAP
+      imapCommand *cmd = doCommand(imapCommand::clientUnsubscribe(aBox));
+      completeQueue.removeRef(cmd);
+      cmd = doCommand(imapCommand::clientDelete (aBox));
+      // If this doesn't work, we try to empty the mailbox first
+      if (cmd->result () != "OK")
+      {
+        completeQueue.removeRef(cmd);
+        bool stillOk = true;
+        if (!assureBox(aBox, false)) stillOk = false;
+        if (stillOk)
+        {
+          imapCommand *cmd = doCommand(
+            imapCommand::clientStore("1:*", "+FLAGS.SILENT", "\\DELETED"));
+          if (cmd->result () != "OK") stillOk = false;
+          completeQueue.removeRef(cmd);
+        }
+        if (stillOk)
+        {
+          imapCommand *cmd = doCommand(imapCommand::clientClose());
+          if (cmd->result () != "OK") stillOk = false;
+          completeQueue.removeRef(cmd);
+          setState(ISTATE_LOGIN);
+        }
+        if (stillOk)
+        {
+          imapCommand *cmd = doCommand (imapCommand::clientDelete(aBox));
+          if (cmd->result () != "OK") stillOk = false;
+          completeQueue.removeRef(cmd);
+        }
+        if (!stillOk)
+        {
+          error (ERR_COULD_NOT_RMDIR, hidePass(_url));
+          return;
+        }
+      } else {
+        completeQueue.removeRef (cmd);
+      }
     }
     break;
 
@@ -952,7 +982,7 @@ IMAP4Protocol::del (const KURL & _url, bool isFile)
       {
         imapCommand *cmd =
           doCommand (imapCommand::
-                     clientStore (aSequence, "+FLAGS", "\\DELETED"));
+                     clientStore (aSequence, "+FLAGS.SILENT", "\\DELETED"));
         if (cmd->result () != "OK")
           error (ERR_CANNOT_DELETE, hidePass(_url));
         completeQueue.removeRef (cmd);
@@ -970,15 +1000,22 @@ IMAP4Protocol::del (const KURL & _url, bool isFile)
 }
 
 void
-IMAP4Protocol::special (const QByteArray & data)
+IMAP4Protocol::special (const QByteArray & aData)
 {
-  KURL _url(data.data() + 1);
-  if (data.at(0) == 'C')
+  if (!makeLogin()) return;
+  KURL _url(aData.data() + 1);
+  if (aData.at(0) == 'C')
   {
-    copy(_url, KURL(data.data() + data.find('\0') + 1), 0, FALSE);
+    copy(_url, KURL(aData.data() + aData.find('\0') + 1), 0, FALSE);
     return;
   }
-  if (data.at(0) == 'N')
+  if (aData.at(0) == 'c')
+  {
+kdDebug(7116) << "IMAP4Protocol::special" << endl;
+    infoMessage(imapCapabilities.join(" "));
+    finished();
+  }
+  if (aData.at(0) == 'N')
   {
     imapCommand *cmd = doCommand(imapCommand::clientNoop());
     completeQueue.removeRef (cmd);
@@ -991,16 +1028,28 @@ IMAP4Protocol::special (const QByteArray & data)
     if (assureBox (aBox, false))
     {
       imapCommand *cmd = doCommand (imapCommand::
-        clientStore (aSequence, "-FLAGS",
-        "\\SEEN \\ANSWERED \\FLAGGED \\DRAFT \\DELETED"));
+        clientStore (aSequence, "-FLAGS.SILENT",
+        "\\SEEN \\ANSWERED \\FLAGGED \\DRAFT"));
       if (cmd->result () != "OK")
-        error (ERR_NO_CONTENT, hidePass(_url));
-      completeQueue.removeRef (cmd);
-      cmd = doCommand (imapCommand::
-        clientStore (aSequence, "+FLAGS", data.data() + data.find('\0') + 1));
-      if (cmd->result () != "OK")
-        error (ERR_NO_CONTENT, hidePass(_url));
+      {
+        error(ERR_NO_CONTENT, i18n("Changing the flags of message %1 "
+          "failed.").arg(hidePass(_url)));
+        return;
+      }
       completeQueue.removeRef (cmd);
+      QCString newFlags = aData.data() + aData.find('\0') + 1;
+      if (!newFlags.isEmpty())
+      {
+        cmd = doCommand (imapCommand::
+          clientStore (aSequence, "+FLAGS.SILENT", newFlags));
+        if (cmd->result () != "OK")
+        {
+          error(ERR_NO_CONTENT, i18n("Changing the flags of message %1 "
+            "failed.").arg(hidePass(_url)));
+          return;
+        }
+        completeQueue.removeRef (cmd);
+      }
       finished();
     }
     else error (ERR_CANNOT_OPEN_FOR_WRITING, hidePass(_url));
@@ -1070,6 +1119,38 @@ IMAP4Protocol::stat (const KURL & _url)
   enum IMAP_TYPE aType =
     parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter);
 
+  UDSEntry entry;
+  UDSAtom atom;
+
+  atom.m_uds = UDS_NAME;
+  atom.m_str = aBox;
+  entry.append (atom);
+
+  if (!aSection.isEmpty())
+  {
+    if (getState() == ISTATE_SELECT && aBox == getCurrentBox())
+    {
+      imapCommand *cmd = doCommand (imapCommand::clientClose());
+      if (cmd->result() != "OK")
+      {
+        error (ERR_ABORTED, i18n("Unable to close mailbox."));
+        finished();
+        return;
+      }
+      setState(ISTATE_LOGIN);
+    }
+    imapCommand *cmd = doCommand(imapCommand::clientStatus(aBox, aSection));
+    completeQueue.removeRef(cmd);
+    if ((aSection == "UIDNEXT" && getStatus().uidNextAvailable())
+      || (aSection == "UNSEEN" && getStatus().unseenAvailable()))
+    {
+      atom.m_uds = UDS_SIZE;
+      atom.m_str = QString::null;
+      atom.m_long = (aSection == "UIDNEXT") ? getStatus().uidNext()
+        : getStatus().unseen();
+      entry.append(atom);
+    }
+  } else
   if (aType == ITYPE_BOX || aType == ITYPE_DIR_AND_BOX || aType == ITYPE_MSG)
   {
     ulong validity = 0;
@@ -1117,14 +1198,6 @@ IMAP4Protocol::stat (const KURL & _url)
     }
   }
 
-
-  UDSEntry entry;
-  UDSAtom atom;
-
-  atom.m_uds = UDS_NAME;
-  atom.m_str = aBox;
-  entry.append (atom);
-
   atom.m_uds = UDS_MIME_TYPE;
   atom.m_str = getMimeType (aType);
   entry.append (atom);
@@ -1184,28 +1257,35 @@ void IMAP4Protocol::closeConnection()
   }
   CloseDescriptor();
   setState(ISTATE_NO);
+  completeQueue.clear();
+  sentQueue.clear();
+  lastHandled = NULL;
   currentBox = QString::null;
+  readBufferLen = 0;
 }
 
 bool IMAP4Protocol::makeLogin ()
 {
-  bool skipFirst = true;
-
   kdDebug(7116) << "IMAP4::makeLogin - checking login" << endl;
   if (getState () == ISTATE_LOGIN || getState () == ISTATE_SELECT)
     return true;
 
-  if (getState() == ISTATE_CONNECT || ConnectToHost (myHost.latin1(), myPort))
+  bool alreadyConnected = getState() == ISTATE_CONNECT;
+  if (alreadyConnected || connectToHost (myHost.latin1(), myPort))
   {
 //      fcntl (m_iSock, F_SETFL, (fcntl (m_iSock, F_GETFL) | O_NDELAY));
 
     setState(ISTATE_CONNECT);
+
     myAuth = metaData("auth");
     myTLS  = metaData("tls");
 
     imapCommand *cmd;
 
-    while (!parseLoop ());    //get greeting
+    unhandled.clear ();
+    if (!alreadyConnected) while (!parseLoop ());    //get greeting
+    QString greeting;
+    if (!unhandled.isEmpty()) greeting = unhandled.first().stripWhiteSpace();
     unhandled.clear ();       //get rid of it
     cmd = doCommand (new imapCommand ("CAPABILITY", ""));
 
@@ -1215,11 +1295,23 @@ bool IMAP4Protocol::makeLogin ()
     {
       kdDebug(7116) << "'" << (*it) << "'" << endl;
     }
-
     completeQueue.removeRef (cmd);
+
+    if (!hasCapability("IMAP4") && !hasCapability("IMAP4rev1"))
+    {
+      error(ERR_COULD_NOT_LOGIN, i18n("Sorry, the server %1 supports neither "
+        "IMAP4 nor IMAP4rev1.\nIt identified itself with: %2")
+        .arg(myHost).arg(greeting));
+      closeConnection();
+      return false;
+    }
+
+    if (metaData("nologin") == "on") return TRUE;
+
     if (myTLS == "on" && !hasCapability(QString("STARTTLS")))
     {
-      error(ERR_ABORTED, i18n("The server does not support TLS."));
+      error(ERR_COULD_NOT_LOGIN, i18n("The server does not support TLS.\n"
+        "Disable this security feature to connect unencrypted."));
       closeConnection();
       return false;
     }
@@ -1243,57 +1335,60 @@ bool IMAP4Protocol::makeLogin ()
           completeQueue.removeRef (cmd2);
         } else {
           kdDebug() << "TLS mode setup has failed.  Aborting." << endl;
-          error (ERR_ABORTED, i18n("Starting TLS failed."));
+          error (ERR_COULD_NOT_LOGIN, i18n("Starting TLS failed."));
           closeConnection();
           return false;
         }
       } else completeQueue.removeRef(cmd);
     }
-  }
 
-  if (!myAuth.isEmpty () && myAuth != "*"
-      && !hasCapability (QString ("AUTH=") + myAuth))
-  {
-    error (ERR_UNSUPPORTED_PROTOCOL, i18n("Authentication method %1 not "
-      "supported.").arg(myAuth));
-    closeConnection();
-    return false;
-  }
+    if (!myAuth.isEmpty () && myAuth != "*"
+        && !hasCapability (QString ("AUTH=") + myAuth))
+    {
+      error (ERR_COULD_NOT_LOGIN, i18n("The authentication method %1 is not "
+        "supported by the server.").arg(myAuth));
+      closeConnection();
+      return false;
+    }
 
-  kdDebug(7116) << "IMAP4::makeLogin - attempting login" << endl;
+    kdDebug(7116) << "IMAP4::makeLogin - attempting login" << endl;
 
-  if (myUser.isEmpty () || myPass.isEmpty ())
-    skipFirst = false;
-
-  while (skipFirst
-         ||
-         openPassDlg (i18n ("Username and password for your IMAP account:"),
-                      myUser, myPass))
-  {
+    KIO::AuthInfo authInfo;
+    authInfo.username = myUser;
+    authInfo.password = myPass;
+    authInfo.prompt = i18n ("Username and password for your IMAP account:");
+    if (myUser.isEmpty () || myPass.isEmpty ()) {
+      if(openPassDlg (authInfo)) {
+        myUser = authInfo.username;
+        myPass = authInfo.password;
+      }
+    }
 
     kdDebug(7116) << "IMAP4::makeLogin - open_PassDlg: user=" << myUser << " pass=xx" << endl;
-    skipFirst = false;
 
+    QString resultInfo;
     if (myAuth.isEmpty () || myAuth == "*")
     {
-      if (clientLogin (myUser, myPass))
-      {
-        kdDebug(7116) << "IMAP4::makeLogin - login succeded" << endl;
-      }
-      else
-        kdDebug(7116) << "IMAP4::makeLogin - login failed" << endl;
+      if (QString(myUser.utf8()) != myUser)
+        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Sorry, in IMAP clear text login, "
+          "only US-ASCII characters are possible. Please use a different "
+          "authentication method that your server supports or try to get a "
+          "different username."));
+      else if (QString(myPass.utf8()) != myPass)
+        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Sorry, in IMAP clear text login, "
+          "only US-ASCII characters are possible. Please use a different "
+          "authentication method that your server supports or change your "
+          "password."));
+      else if (!clientLogin (myUser, myPass, resultInfo))
+        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Could not login. Probably the "
+        "password is wrong.\nThe server replied:\n%1").arg(resultInfo));
     }
     else
     {
-      if (clientAuthenticate (myUser, myPass, myAuth))
-      {
-        kdDebug(7116) << "IMAP4::makeLogin: " << myAuth << " succeded" << endl;
-      }
-      else
-        kdDebug(7116) << "IMAP4::makeLogin: " << myAuth << " failed" << endl;
+      if (!clientAuthenticate (myUser, myPass, myAuth, mySSL, resultInfo))
+        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Could not authenticate via %1.\n"
+        "The server replied:\n%2").arg(myAuth).arg(resultInfo));
     }
-    if (getState () == ISTATE_LOGIN)
-      break;
   }
 
   return getState() == ISTATE_LOGIN;
@@ -1309,7 +1404,7 @@ IMAP4Protocol::parseWriteLine (const QString & aStr)
     writer += "\r\n";
 
   // write it
-  Write (writer.data (), writer.length ());
+  write (writer.data (), writer.length ());
 }
 
 QString
@@ -1346,9 +1441,10 @@ IMAP4Protocol::getMimeType (enum IMAP_TYPE aType)
 
 
 void
-IMAP4Protocol::doListEntry (const KURL & _url, mailHeader * what, int stretch)
+IMAP4Protocol::doListEntry (const KURL & _url, int stretch, imapCache * cache,
+  bool withFlags, bool withSubject)
 {
-  if (what)
+  if (cache)
   {
     UDSEntry entry;
     UDSAtom atom;
@@ -1358,13 +1454,19 @@ IMAP4Protocol::doListEntry (const KURL & _url, mailHeader * what, int stretch)
     entry.clear ();
 
     atom.m_uds = UDS_NAME;
-    atom.m_str = what->getPartSpecifier ();
+    atom.m_str = QString::number(cache->getUid());
     atom.m_long = 0;
     if (stretch > 0)
     {
       atom.m_str = "0000000000000000" + atom.m_str;
       atom.m_str = atom.m_str.right (stretch);
     }
+    if (withSubject)
+    {
+      mailHeader *header = cache->getHeader();
+      if (header)
+        atom.m_str += " " + header->getSubject();
+    }
 //    atom.m_str.prepend(";UID=");
     entry.append (atom);
 
@@ -1372,7 +1474,7 @@ IMAP4Protocol::doListEntry (const KURL & _url, mailHeader * what, int stretch)
     atom.m_str = aURL.url ();
     if (atom.m_str[atom.m_str.length () - 1] != '/')
       atom.m_str += "/";
-    atom.m_str += ";UID=" + what->getPartSpecifier ();
+    atom.m_str += ";UID=" + QString::number(cache->getUid());
     atom.m_long = 0;
     entry.append (atom);
 
@@ -1382,8 +1484,9 @@ IMAP4Protocol::doListEntry (const KURL & _url, mailHeader * what, int stretch)
     entry.append (atom);
 
     atom.m_uds = UDS_SIZE;
-    atom.m_long = what->getLength ();
+    atom.m_long = cache->getSize();
     entry.append (atom);
+
     atom.m_uds = UDS_MIME_TYPE;
     atom.m_str = "message/rfc822-imap";
     atom.m_long = 0;
@@ -1394,7 +1497,7 @@ IMAP4Protocol::doListEntry (const KURL & _url, mailHeader * what, int stretch)
     entry.append (atom);
 
     atom.m_uds = KIO::UDS_ACCESS;
-    atom.m_long = S_IRUSR | S_IXUSR | S_IWUSR;
+    atom.m_long = (withFlags) ? cache->getFlags() : S_IRUSR | S_IXUSR | S_IWUSR;
     entry.append (atom);
 
     listEntry (entry, false);
@@ -1424,6 +1527,8 @@ IMAP4Protocol::doListEntry (const KURL & _url, const QString & myBox,
         mailboxName = mailboxName.right (mailboxName.length () - 1);
     if (mailboxName.left(hdLen) == item.hierarchyDelimiter())
       mailboxName = mailboxName.right(mailboxName.length () - hdLen);
+    if (mailboxName.right(hdLen) == item.hierarchyDelimiter())
+      mailboxName = mailboxName.left(mailboxName.length () - hdLen);
 
     atom.m_uds = UDS_NAME;
     atom.m_str = mailboxName;
@@ -1449,6 +1554,12 @@ IMAP4Protocol::doListEntry (const KURL & _url, const QString & myBox,
         atom.m_long = 0;
         entry.append (atom);
         mailboxName += "/";
+
+        // explicitly set this as a directory for KFileDialog
+        atom.m_uds = UDS_FILE_TYPE;
+        atom.m_str = "";
+        atom.m_long = S_IFDIR;
+        entry.append (atom);
       }
       else if (!item.noInferiors ())
       {
@@ -1457,6 +1568,12 @@ IMAP4Protocol::doListEntry (const KURL & _url, const QString & myBox,
         atom.m_long = 0;
         entry.append (atom);
         mailboxName += "/";
+
+        // explicitly set this as a directory for KFileDialog
+        atom.m_uds = UDS_FILE_TYPE;
+        atom.m_str = "";
+        atom.m_long = S_IFDIR;
+        entry.append (atom);
       }
       else
       {
@@ -1509,9 +1626,16 @@ IMAP4Protocol::parseURL (const KURL & _url, QString & _box,
   {
     kdDebug(7116) << "IMAP4::parseURL: box " << _box << endl;
 
+    // Hack for UW-IMAP news folders
+    if (_box.left(5) == "#news")
+    {
+      _hierarchyDelimiter = ".";
+      retVal = ITYPE_DIR_AND_BOX;
+    } else
+
     if (makeLogin ())
     {
-      if (getCurrentBox () != _box || _type == "LIST")
+      if (getCurrentBox () != _box || _type == "LIST" || _type == "LSUB")
       {
         imapCommand *cmd;
 
@@ -1579,6 +1703,16 @@ IMAP4Protocol::parseURL (const KURL & _url, QString & _box,
 int
 IMAP4Protocol::outputLine (const QCString & _str)
 {
+  if (cacheOutput)
+  {
+    QBuffer stream(outputCache);
+    stream.open(IO_WriteOnly);
+    stream.at(outputCache.size());
+    stream.writeBlock(_str.data(), _str.length());
+    stream.close();
+    return 0;
+  }
+
   QByteArray temp;
   bool relay = relayEnabled;
 
@@ -1591,6 +1725,13 @@ IMAP4Protocol::outputLine (const QCString & _str)
   return 0;
 }
 
+void IMAP4Protocol::flushOutput()
+{
+  if (outputCache.isEmpty()) return;
+  data(outputCache);
+  outputCache.resize(0);
+}
+
 /* memccpy appeared first in BSD4.4 */
 void *
 mymemccpy (void *dest, const void *src, int c, size_t n)
@@ -1605,51 +1746,20 @@ mymemccpy (void *dest, const void *src, int c, size_t n)
   return NULL;
 }
 
-/* ssize_t
-IMAP4Protocol::ReadLine (char *buf, ssize_t len)
+ssize_t IMAP4Protocol::myRead(void *data, ssize_t len)
 {
-  ssize_t result;
-  char *copied;
-//  kdDebug(7116) << "Request for " << len << endl;
-  // see what is still in the buffer
-  if (len > readSize)
+  if (readBufferLen)
   {
-//    kdDebug(7116) << "Reading" << endl;
-    // append to our internal buffer
-    result = Read (readBuffer + readSize, IMAP_BUFFER - readSize);
-    if (result > 0)
-      readSize += result;
-//    kdDebug(7116) << "Result is " << result << endl;
-//    kdDebug(7116) << "Now got " << readSize << endl;
+    ssize_t copyLen = (len < readBufferLen) ? len : readBufferLen;
+    memcpy(data, readBuffer, copyLen);
+    readBufferLen -= copyLen;
+    if (readBufferLen) memcpy(readBuffer, &readBuffer[copyLen], readBufferLen);
+    return copyLen;
   }
-
-  // give what is there to the caller
-  if (readSize < len)
-    len = readSize;
-
-  if (len > 0)
-  {
-    // copy it to the destination
-//    kdDebug(7116) << "Giving to caller at most " << len << endl;
-    copied = (char *) mymemccpy (buf, readBuffer, '\n', len);
-    if (copied)
-      len = copied - buf;
-//    kdDebug(7116) << "Copied " << len << endl;
-    buf[len] = 0x00;
-//    kdDebug(7116) << "Giving to caller " << len << endl;
-//    kdDebug(7116) << "That is '" << buf << "'" << endl;
-
-    // now we need to readjust our buffer
-    memcpy (readBuffer, readBuffer + len, readSize - len);
-    readSize -= len;
-    readBuffer[readSize] = 0x00;
-//    kdDebug(7116) << "Keeping " << readSize << " [" << readBuffer << "]" << endl;
-  }
-
-  if (len <= 0)
-    len = 0;
-  return len;
-} */
+  if (!isConnectionValid()) return 0;
+  waitForResponse(600);
+  return read(data, len);
+}
 
 bool
 IMAP4Protocol::assureBox (const QString & aBox, bool readonly)
@@ -1660,6 +1770,7 @@ IMAP4Protocol::assureBox (const QString & aBox, bool readonly)
   {
     // open the box with the appropriate mode
     kdDebug(7116) << "IMAP4Protocol::assureBox - opening box" << endl;
+    selectInfo = imapInfo();
     cmd = doCommand (imapCommand::clientSelect (aBox, readonly));
     completeQueue.removeRef (cmd);
   }
@@ -1677,6 +1788,7 @@ IMAP4Protocol::assureBox (const QString & aBox, bool readonly)
     {
       // reopen the box with the appropriate mode
       kdDebug(7116) << "IMAP4Protocol::assureBox - reopening box" << endl;
+      selectInfo = imapInfo();
       cmd = doCommand (imapCommand::clientSelect (aBox, readonly));
       completeQueue.removeRef (cmd);
     }
