@@ -1,8 +1,9 @@
 #ifndef _IMAP4_H
-#define _IMAP4_H "$Id: imap4.h,v 1.24 2001/06/04 18:47:07 haeckel Exp $"
+#define _IMAP4_H "$Id: imap4.h,v 1.31 2002/01/14 20:17:29 haeckel Exp $"
 /**********************************************************************
  *
  *   imap4.h  - IMAP4rev1 KIOSlave
+ *   Copyright (C) 2001  Michael Haeckel <Michael@Haeckel.Net>
  *   Copyright (C) 1999  John Corey
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -28,7 +29,7 @@
 
 #include <kio/tcpslavebase.h>
 
-#define IMAP_BUFFER 2048
+#define IMAP_BUFFER 8192
 
 enum IMAP_TYPE
 {
@@ -95,13 +96,15 @@ public:
   // reimplement the mimeIO
   virtual int outputLine (const QCString & _str);
 
+  // send out cached data to the application
+  virtual void flushOutput();
+
 protected:
 
   // select or examine the box if needed
   bool assureBox (const QString & aBox, bool readonly);
 
-  // our new ReadLine supports 0x00 within data
-//  ssize_t ReadLine (char *data, ssize_t len);
+  ssize_t myRead(void *data, ssize_t len);
 
   enum IMAP_TYPE
   parseURL (const KURL & _url, QString & _box, QString & _section,
@@ -113,18 +116,22 @@ protected:
 
   QString myHost, myUser, myPass, myAuth, myTLS;
   int myPort;
+  bool mySSL;
 
-  bool relayEnabled;
+  bool relayEnabled, cacheOutput;
+  QByteArray outputCache;
 
   void outputLineStr (const QString & _str)
   {
     outputLine (_str.latin1 ());
   }
-  void doListEntry (const KURL & _url, mailHeader * what, int stretch);
+  void doListEntry (const KURL & _url, int stretch, imapCache * cache = NULL,
+    bool withFlags = FALSE, bool withSubject = FALSE);
   void doListEntry (const KURL & _url, const QString & myBox,
                     const imapList & item);
 
   char readBuffer[IMAP_BUFFER];
+  ssize_t readBufferLen;
   int readSize;
 };
 
