@@ -1,4 +1,4 @@
-// $Id: imapcommand.cc,v 1.9 2001/07/17 21:25:57 haeckel Exp $
+// $Id: imapcommand.cc,v 1.14 2002/02/12 17:40:26 haeckel Exp $
 /**********************************************************************
  *
  *   imapcommand.cc  - IMAP4rev1 command handler
@@ -29,7 +29,6 @@
 
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <sys/time.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
 
@@ -86,6 +85,12 @@ imapCommand::result ()
   return mResult;
 }
 
+const QString &
+imapCommand::resultInfo ()
+{
+  return mResultInfo;
+}
+
 const QString &
 imapCommand::id ()
 {
@@ -123,6 +128,12 @@ imapCommand::setResult (const QString & result)
   mResult = result;
 }
 
+void
+imapCommand::setResultInfo (const QString & result)
+{
+  mResultInfo = result;
+}
+
 void
 imapCommand::setCommand (const QString & command)
 {
@@ -194,7 +205,10 @@ imapCommand::clientList (const QString & reference, const QString & path,
 imapCommand *
 imapCommand::clientSelect (const QString & path, bool examine)
 {
-  return new imapCommand ((examine && path != "INBOX") ? "EXAMINE" : "SELECT",
+  /* We use always SELECT, because UW-IMAP doesn't check for new mail, when
+     used with the "mbox driver" and the folder is opened with EXAMINE
+     and Courier can't append to a mailbox that is in EXAMINE state */
+  return new imapCommand ("SELECT",
                           QString ("\"") + rfcDecoder::toIMAP (path) + "\"");
 }
 
@@ -213,12 +227,13 @@ imapCommand::clientCopy (const QString & box, const QString & sequence,
 }
 
 imapCommand *
-imapCommand::clientAppend (const QString & box, const QString &,
+imapCommand::clientAppend (const QString & box, const QString & flags,
                            ulong size)
 {
   return new imapCommand ("APPEND",
-                          "\"" + rfcDecoder::toIMAP (box) + "\" {" +
-                          QString ().setNum (size) + "}");
+                          "\"" + rfcDecoder::toIMAP (box) + "\" " +
+                          ((flags.isEmpty()) ? "" : ("(" + flags + ") ")) +
+                          "{" + QString ().setNum (size) + "}");
 }
 
 imapCommand *
@@ -243,6 +258,20 @@ imapCommand::clientDelete (const QString & path)
                           QString ("\"") + rfcDecoder::toIMAP (path) + "\"");
 }
 
+imapCommand *
+imapCommand::clientSubscribe (const QString & path)
+{
+  return new imapCommand ("SUBSCRIBE",
+                          QString ("\"") + rfcDecoder::toIMAP (path) + "\"");
+}
+
+imapCommand *
+imapCommand::clientUnsubscribe (const QString & path)
+{
+  return new imapCommand ("UNSUBSCRIBE",
+                          QString ("\"") + rfcDecoder::toIMAP (path) + "\"");
+}
+
 imapCommand *
 imapCommand::clientExpunge ()
 {
