@@ -5,10 +5,11 @@
 #include <qdir.h>
 #include <qfile.h>
 #include <qtextstream.h>
+#include <qregexp.h>
 
 #include <kdebug.h>
 #include <kprocess.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kinstance.h>
 
 #include "info.h"
@@ -27,7 +28,7 @@ InfoProtocol::InfoProtocol( const QCString &pool, const QCString &app )
     m_perl = KGlobal::dirs()->findExe( "perl" );
     
     if( m_infoScript.isEmpty() )
-	kDebugFatal( 7108, "Critical error: Cannot locate 'kde-info2html' for HTML-conversion" );
+	kdError( 7108 ) << "Critical error: Cannot locate 'kde-info2html' for HTML-conversion" << endl;
     
     kdDebug( 7108 ) << "InfoProtocol::InfoProtocol - done" << endl;
 }
@@ -44,28 +45,21 @@ void InfoProtocol::get( const KURL& url )
     kdDebug( 7108 ) << "InfoProtocol::get" << endl;
     kdDebug( 7108 ) << "URL: " << url.prettyURL() << " , Path :" << url.path() << endl;
 
+    if (url.path()=="/")
+    {
+       KURL newUrl("info:/dir");
+       redirection(newUrl);
+       finished();
+       return;
+    };
+
     mimeType("text/html");
     // extract the path and node from url
     decodeURL( url );
-    /*
-    if( m_page.isEmpty() )
-    {
-	//error( 1, "Syntax error in URL" );
-	
-	QByteArray array = errorMessage();
-	
-	data( array );
-	finished();
-
-	return;
-    }
-    */
-    if ( m_page.isEmpty() )
-      m_page = "dir";
 
     QString cmds("%1 %2 %3 %4 \"%5\" \"%6\"");
     QCString cmd = cmds.arg(m_perl).arg(m_infoScript).arg(locate("data", "kio_info/kde-info2html.conf")).arg(KGlobal::dirs()->findResourceDir("icon", "hicolor/22x22/actions/up.png")).arg(m_page).arg(m_node).latin1();
-    //kdDebug( 7108 ) << "cmd: " << (const char *)cmd << endl;
+    kdDebug( 7108 ) << "cmd: " << (const char *)cmd << endl;
     
     FILE *fd = popen( cmd.data(), "r" );
     
@@ -120,6 +114,7 @@ void InfoProtocol::decodeURL( const KURL &url )
 
 
     QString dirstr;
+    //huh, what is this good for ? aleXXX
     if (url.hasHost()) {
       dirstr = '/';
       dirstr += url.host();
@@ -130,8 +125,17 @@ void InfoProtocol::decodeURL( const KURL &url )
     /* now we got a description where a directory is in.
      * Lets test it */
 
+/*    if (dirstr.isEmpty())
+       dirstr="dir";
+
+    if (dirstr[0]!='/')
+    {
+       decodePath(dirstr);
+       return;
+    };*/
+
     int slashPos = dirstr.find( "/", 1 );
-    int oldPos = 1;
+    int oldPos = 0;
     QDir dir(dirstr.left(slashPos));
     //kdDebug( 7108 ) << "dirpath: " << dir.path() << endl;
     while (dir.exists()) {
@@ -149,21 +153,21 @@ void InfoProtocol::decodeURL( const KURL &url )
     // oldPos now has the last dir '/'
     //kdDebug( 7108 ) << "dirstr_ length = " <<dirstr.length() << ", pos = " << oldPos << endl;
     //kdDebug( 7108 ) << "info_ request: " << dirstr.right(dirstr.length() - oldPos) << endl;
-    decodePath(dirstr.right(dirstr.length() - oldPos));
+    decodePath(dirstr.right(1+dirstr.length() - oldPos));
 
     kdDebug( 7108 ) << "InfoProtocol::decodeURL - done" << endl;
 }
 
 void InfoProtocol::decodePath( QString path )
 {
-    kdDebug( 7108 ) << "InfoProtocol::decodePath" << endl;
+    kdDebug( 7108 ) << "InfoProtocol::decodePath(-" <<path<<"-)"<< endl;
 
-    m_page = "";
+    m_page = "dir";  //default
     m_node = "";
 
     // remove leading slash
     if ('/' == path[0]) {
-      path = path.right( path.length() - 1 );
+      path = path.mid( 1 );
     }
     //kdDebug( 7108 ) << "Path: " << path << endl;
 
@@ -189,7 +193,7 @@ QCString InfoProtocol::errorMessage()
     kdDebug( 7108 ) << "InfoProtocol::errorMessage" << endl;
 
     // i18n !!!!!!!!!!!!!!!!!!
-    return QCString( "<html><body bgcolor=\"#FFFFFF\">An error occured during converting an info-page to HTML</body></html>" );
+    return QCString( "<html><body>An error occured during converting an info-page to HTML</body></html>" );
 }
 
 // A minimalistic stat with only the file type
@@ -210,7 +214,7 @@ void InfoProtocol::stat( const KURL &url )
 	finished();
 }
 
-void InfoProtocol::listDir( const KURL &url )
+/*void InfoProtocol::listDir( const KURL &url )
 {
     kdDebug( 7108 ) << "InfoProtocol::listDir" << endl;
  
@@ -269,7 +273,7 @@ void InfoProtocol::listDir( const KURL &url )
         kdError(7108) << "cannot open file '/usr/info/dir'" << endl;
     }
     kdDebug( 7108 ) << "InfoProtocol::listDir - done" << endl;
-}
+}*/
 
 extern "C" { int kdemain( int argc, char **argv ); }
 
