@@ -7,11 +7,6 @@
 
 #include <lber.h>
 #include <ldap.h>
-#include <config.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <sys/time.h>
-#endif
-#include <time.h>
 
 namespace KLDAP
 {
@@ -28,7 +23,7 @@ namespace KLDAP
    *
    * @short Base class of all LDAP objects.
    * @author Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-   * @version $Id: kldap.h,v 1.5.2.1 2001/02/27 19:41:33 mueller Exp $
+   * @version $Id: kldap.h,v 1.7 2001/03/06 15:43:55 matz Exp $
    */
   class LDAPBase
   {
@@ -58,7 +53,7 @@ namespace KLDAP
      * Return the last result code.
      *
      * Returns the result of the last LDAP operation.
-     * 
+     *
      * The possible values are defined in ldap.h. The most
      * prominent result code is LDAP_SUCCESS.
      */
@@ -66,7 +61,7 @@ namespace KLDAP
 
     /**
      * Returns a description of the last result.
-     * 
+     *
      * Returns a textual description of the last result code.
      * This text can be used in error messages.
      *
@@ -86,11 +81,11 @@ namespace KLDAP
      * @return TRUE, if result == LDAP_SUCCESS, else FALSE
      */
     bool check(int r);
- 
+
     int res;          // the last result code checked
     LDAP *_handle;    // the ldap handle
-    
-  }; 
+
+  };
 
   /**
    * A LDAP connection.
@@ -101,7 +96,7 @@ namespace KLDAP
    *
    * @short A LDAP connection.
    * @author Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-   * @version $Id: kldap.h,v 1.5.2.1 2001/02/27 19:41:33 mueller Exp $
+   * @version $Id: kldap.h,v 1.7 2001/03/06 15:43:55 matz Exp $
    */
   class Connection : public LDAPBase
   {
@@ -122,12 +117,12 @@ namespace KLDAP
      *
      */
     Connection(const char *s="localhost", int p=LDAP_PORT);
-    
+
     /**
      * Destructor. Destroys the connection.
      *
      * The destructor disconnects from the server, is
-     * the connection was still active. 
+     * the connection was still active.
      *
      */
     ~Connection();
@@ -169,7 +164,7 @@ namespace KLDAP
      *
      * This method is used to authenticate to the server.
      *
-     * Some servers require the user to authenticate before 
+     * Some servers require the user to authenticate before
      * operations are allowed. Currently, there are two authentication
      * methods:
      *
@@ -177,7 +172,7 @@ namespace KLDAP
      * Kerberos authentication using a ticket.
      *
      * Please note that LDAP does not provide a high level of
-     * security. Especially simple authentication over 
+     * security. Especially simple authentication over
      * unencrypted lines is dangerous.
      *
      * @param dn Distinguished name of the entity to authorize as.
@@ -196,14 +191,14 @@ namespace KLDAP
 
     /// Returns the port for the connection.
     int port() { return _port; }
-    
+
     /// Sets the port for the connection.
     void setPort(int port) { _port=port; };
 
   private:
 
     QString _server;
-    int     _port;   
+    int     _port;
 
   };
 
@@ -213,12 +208,12 @@ namespace KLDAP
    * This class encapsulates a LDAP attribute.
    * Attributes are returned as results of queries.
    *
-   * Note that an attribute can have more than one value. 
+   * Note that an attribute can have more than one value.
    * In fact, most attributes have several values.
    *
    * @short A LDAP attribute.
    * @author Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-   * @version $Id: kldap.h,v 1.5.2.1 2001/02/27 19:41:33 mueller Exp $
+   * @version $Id: kldap.h,v 1.7 2001/03/06 15:43:55 matz Exp $
    *
    */
   class Attribute : public LDAPBase
@@ -228,7 +223,7 @@ namespace KLDAP
     /**
      * Constructor. Initializes an attribute.
      *
-     * The constructor sets up the data structures 
+     * The constructor sets up the data structures
      * necessary to retrieve an attributes values.
      *
      * @param h The LDAP handle.
@@ -240,7 +235,7 @@ namespace KLDAP
 
     /// Returns the name of the attribute.
     QString name() { return _name; };
-    
+
     /**
      * Returns the attributes values.
      *
@@ -252,7 +247,7 @@ namespace KLDAP
      *
      * @param list The list that will store the values.
      *
-     */     
+     */
     void getValues(QStrList &list);
 
 
@@ -294,7 +289,7 @@ namespace KLDAP
    *
    * @short A LDAP entry.
    * @author Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-   * @version $Id: kldap.h,v 1.5.2.1 2001/02/27 19:41:33 mueller Exp $
+   * @version $Id: kldap.h,v 1.7 2001/03/06 15:43:55 matz Exp $
    *
    */
   class Entry : public LDAPBase
@@ -304,7 +299,7 @@ namespace KLDAP
     /**
      * Constructor. Creates a LDAP entry.
      *
-     * The constructor initializes the data structures 
+     * The constructor initializes the data structures
      * necessary to retrieve an entries attributes.
      *
      * @param h The LDAP handle.
@@ -317,7 +312,7 @@ namespace KLDAP
      * Returns the distinguished name of the entry.
      *
      * The distinguished name of the entry is a unique
-     * identifier of an entry. 
+     * identifier of an entry.
      *
      * @return The distinguished name.
      *
@@ -350,21 +345,21 @@ namespace KLDAP
     Attribute getAttribute(const char *name);
 
   private:
-    
+
     LDAPMessage *message;
 
   };
 
-  /** 
+  /**
    * The base class for LDAP requests.
    *
-   * This class is the base of all classes encapsulating 
+   * This class is the base of all classes encapsulating
    * LDAP requests. It contains the methods and datastructures
    * to send a request to the servern and retrieve the results.
    *
    * @short Base class for LDAP requests.
    * @author Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-   * @version $Id: kldap.h,v 1.5.2.1 2001/02/27 19:41:33 mueller Exp $
+   * @version $Id: kldap.h,v 1.7 2001/03/06 15:43:55 matz Exp $
    *
    */
   class Request : public LDAPBase
@@ -376,7 +371,7 @@ namespace KLDAP
      *
      * LDAP operations can be done in two ways: Synchronous requests
      * block the calling process until the result is available.
-     * Asynchronous request return immediately and require the 
+     * Asynchronous request return immediately and require the
      * programm to retrieve the result later.
      *
      * As LDAP operations connect to a (remote) server, nonblocking
@@ -414,7 +409,7 @@ namespace KLDAP
     /**
      * Finish the request.
      *
-     * This method retrieves the result of the request. 
+     * This method retrieves the result of the request.
      * If the mode is "Asynchronous", this will block until the
      * result is available, or the timeout has been exceeded.
      *
@@ -434,7 +429,7 @@ namespace KLDAP
      *
      */
     virtual bool abandon();
-    
+
     /**
      * Set timeout usage.
      *
@@ -457,20 +452,20 @@ namespace KLDAP
      *
      * Allows to set the time to wait for a request to finish.
      *
-     * You can use a timeout of 0 seconds, 0 microseconds to 
-     * implement a polling. 
+     * You can use a timeout of 0 seconds, 0 microseconds to
+     * implement a polling.
      *
      * Note that the timeout is ignored until you call
      * setUseTimeout(TRUE).
-     * 
+     *
      * @see Request#setUseTimeout
      *
      * @param sec seconds to wait
      * @param usec microseconds to wait
      *
      */
-    void setTimeout(int sec, int usec=0) { _timeout.tv_sec=sec; _timeout.tv_usec=usec; };
-    
+    void setTimeout(int sec, int usec=0) { to_sec=sec; to_usec=usec; };
+
     /**
      * Returns the timeout.
      *
@@ -480,7 +475,7 @@ namespace KLDAP
      * @param usec Variable to store the microseconds.
      *
      */
-    void timeout(int &sec, int &usec) { sec=_timeout.tv_sec; usec=_timeout.tv_usec; };
+    void timeout(int &sec, int &usec) { sec=to_sec; usec=to_usec; };
 
   protected:
 
@@ -492,7 +487,8 @@ namespace KLDAP
     int all;
 
     LDAPMessage    *req_result;
-    struct timeval _timeout;
+    int to_sec;
+    int to_usec;
     bool           use_timeout;
 
   };
@@ -503,7 +499,7 @@ namespace KLDAP
    * This class enapsulates LDAP search requests, the most common
    * form of LDAP requests.
    *
-   */ 
+   */
   class SearchRequest : public Request
   {
   public:
@@ -511,7 +507,7 @@ namespace KLDAP
     /**
      * Constructor. Initializes a search request.
      *
-     * Creates a new search request object. 
+     * Creates a new search request object.
      *
      * @param c The connection to use.
      * @param m The mode for the request.
@@ -527,7 +523,7 @@ namespace KLDAP
      * LDAP urls are defined in RFC 2255.
      *
      * @param c The connection to use.
-     * @param url The LDAP url. 
+     * @param url The LDAP url.
      * @param m The mode for the request.
      *
      */
@@ -540,7 +536,7 @@ namespace KLDAP
      * Performs a search.
      *
      * This method is a just a shortcut for:
-     * 
+     *
      * setBase(base); setFilter(filter); execute();
      *
      * @param base The base DN to start the search.
@@ -569,10 +565,10 @@ namespace KLDAP
      */
     QString base() { return _base; };
 
-    /** 
+    /**
      * Set the filter for the search.
      *
-     * This method sets a filter expression for the 
+     * This method sets a filter expression for the
      * search. The search will only return entries matching
      * the filter.
      *
@@ -591,7 +587,7 @@ namespace KLDAP
      *
      * This method sets the list of attributes to return
      * for each entry found in the search.
-     * 
+     *
      * @param list The list of attributes to return.
      *
      */
@@ -659,7 +655,7 @@ namespace KLDAP
     int      _scope, _attrsonly;
 
     LDAPMessage *entry;
-    
+
   };
 
 };
