@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project
 
-    $Id: kio_nfs.cpp,v 1.20 2001/05/25 02:14:49 mhunter Exp $
+    $Id: kio_nfs.cpp,v 1.24 2002/02/28 16:34:41 coolo Exp $
 
     Copyright (C) 2000 Alexander Neundorf <neundorf@kde.org>
 
@@ -71,6 +71,8 @@
 #define NFSPROG ((u_long)100003)
 #define NFSVERS ((u_long)2)
 
+using namespace KIO;
+using namespace std;
 
 //this is taken from kdelibs/kdecore/fakes.cpp
 //#if !defined(HAVE_GETDOMAINNAME)
@@ -110,8 +112,6 @@ int x_getdomainname(char *name, size_t len)
 //#endif
 
 
-using namespace KIO;
-
 extern "C" { int kdemain(int argc, char **argv); }
 
 int kdemain( int argc, char **argv )
@@ -123,7 +123,7 @@ int kdemain( int argc, char **argv )
      fprintf(stderr, "Usage: kio_nfs protocol domain-socket1 domain-socket2\n");
      exit(-1);
   }
-  kdDebug(7101) << "NFS: kdemain: starting" << endl;
+  kdDebug(7121) << "NFS: kdemain: starting" << endl;
 
   NFSProtocol slave(argv[2], argv[3]);
   slave.dispatchLoop();
@@ -205,8 +205,8 @@ time_t NFSFileHandle::age() const
 ostream& operator<< (ostream& s, const NFSFileHandle& x)
 {
    for (int i =0; i<NFS_FHSIZE; i++)
-      s<<iostream::hex<<(unsigned int)x[i]<<" ";
-   s<<iostream::dec;
+      s<<hex<<(unsigned int)x[i]<<" ";
+   s<<dec;
    return s;
 }
 
@@ -216,7 +216,7 @@ NFSProtocol::NFSProtocol (const QCString &pool, const QCString &app )
 ,m_sock(-1)
 ,m_lastCheck(time(0))
 {
-   kdDebug(7101)<<"NFS::NFS: -"<<pool<<"-"<<endl;
+   kdDebug(7121)<<"NFS::NFS: -"<<pool<<"-"<<endl;
 };
 
 NFSProtocol::~NFSProtocol()
@@ -226,16 +226,16 @@ NFSProtocol::~NFSProtocol()
 
 void NFSProtocol::checkForOldFHs()
 {
-   kdDebug(7101)<<"checking for fhs older than "<<MAXFHAGE<<endl;
-   kdDebug(7101)<<"current items: "<<m_handleCache.count()<<endl;
+   kdDebug(7121)<<"checking for fhs older than "<<MAXFHAGE<<endl;
+   kdDebug(7121)<<"current items: "<<m_handleCache.count()<<endl;
    NFSFileHandleMap::Iterator it=m_handleCache.begin();
    NFSFileHandleMap::Iterator lastIt=it;
    while (it!=m_handleCache.end())
    {
-      kdDebug(7101)<<it.data().age()<<flush;
+      kdDebug(7121)<<it.data().age()<<flush;
       if (it.data().age()>MAXFHAGE)
       {
-         kdDebug(7101)<<"removing"<<endl;
+         kdDebug(7121)<<"removing"<<endl;
          m_handleCache.remove(it);
          if (it==lastIt)
          {
@@ -248,7 +248,7 @@ void NFSProtocol::checkForOldFHs()
       lastIt=it;
       it++;
    };
-   kdDebug(7101)<<"left items: "<<m_handleCache.count()<<endl;
+   kdDebug(7121)<<"left items: "<<m_handleCache.count()<<endl;
    m_lastCheck=time(0);
 };
 
@@ -281,13 +281,13 @@ NFSFileHandle NFSProtocol::getFileHandle(QString path)
    //if ((time(0)-m_lastCheck)>MAXFHAGE) checkForOldFHs();
 
    stripTrailingSlash(path);
-   kdDebug(7101)<<"getting FH for -"<<path<<"-"<<endl;
+   kdDebug(7121)<<"getting FH for -"<<path<<"-"<<endl;
    //now the path looks like "/root/some/dir" or "" if it was "/"
    NFSFileHandle parentFH;
    //we didn't find it
    if (path.isEmpty())
    {
-      kdDebug(7101)<<"path is empty, invalidating the FH"<<endl;
+      kdDebug(7121)<<"path is empty, invalidating the FH"<<endl;
       parentFH.setInvalid();
       return parentFH;
    };
@@ -295,18 +295,18 @@ NFSFileHandle NFSProtocol::getFileHandle(QString path)
    //the filehandles of the exported root dirs are always in the cache
    if (m_handleCache.find(path)!=m_handleCache.end())
    {
-      kdDebug(7101)<<"path is in the cache, returning the FH -"<<m_handleCache[path]<<"-"<<endl;
+      kdDebug(7121)<<"path is in the cache, returning the FH -"<<m_handleCache[path]<<"-"<<endl;
       return m_handleCache[path];
    };
    QString rest, lastPart;
    getLastPart(path,lastPart,rest);
-   kdDebug(7101)<<"splitting path into rest -"<<rest<<"- and lastPart -"<<lastPart<<"-"<<endl;
+   kdDebug(7121)<<"splitting path into rest -"<<rest<<"- and lastPart -"<<lastPart<<"-"<<endl;
 
    parentFH=getFileHandle(rest);
    //f*ck, it's invalid
    if (parentFH.isInvalid())
    {
-      kdDebug(7101)<<"the parent FH is invalid"<<endl;
+      kdDebug(7121)<<"the parent FH is invalid"<<endl;
       return parentFH;
    };
    // do the rpc call
@@ -325,21 +325,21 @@ NFSFileHandle NFSProtocol::getFileHandle(QString path)
    if ((clnt_stat!=RPC_SUCCESS) || (dirres.status!=NFS_OK))
    {
       //we failed
-      kdDebug(7101)<<"lookup of filehandle failed"<<endl;
+      kdDebug(7121)<<"lookup of filehandle failed"<<endl;
       parentFH.setInvalid();
       return parentFH;
    };
    //everything went fine up to now :-)
    parentFH=dirres.diropres_u.diropres.file.data;
-   //kdDebug(7101)<<"filesize: "<<dirres.diropres_u.diropres.attributes.size<<endl;
+   //kdDebug(7121)<<"filesize: "<<dirres.diropres_u.diropres.attributes.size<<endl;
    m_handleCache.insert(path,parentFH);
-   kdDebug(7101)<<"return FH -"<<parentFH<<"-"<<endl;
+   kdDebug(7121)<<"return FH -"<<parentFH<<"-"<<endl;
    return parentFH;
 };
 
 void NFSProtocol::openConnection()
 {
-   kdDebug(7101)<<"NFS::openConnection"<<endl;
+   kdDebug(7121)<<"NFS::openConnection"<<endl;
    struct sockaddr_in server_addr;
    if (m_currentHost[0] >= '0' && m_currentHost[0] <= '9')
    {
@@ -396,7 +396,7 @@ void NFSProtocol::openConnection()
          }
       }
    };
-   kdDebug(7101) << "hostname is -" << hostName << "-" << endl;
+   kdDebug(7121) << "hostname is -" << hostName << "-" << endl;
    m_client->cl_auth = authunix_create(hostName.data(), geteuid(), getegid(), 0, 0);
    total_timeout.tv_sec = 20;
    total_timeout.tv_usec = 0;
@@ -412,7 +412,7 @@ void NFSProtocol::openConnection()
    fhstatus fhStatus;
    bool atLeastOnceSucceeded(FALSE);
    for(; exportlist!=0;exportlist = exportlist->ex_next) {
-      kdDebug(7101) << "found export: " << exportlist->ex_dir << endl;
+      kdDebug(7121) << "found export: " << exportlist->ex_dir << endl;
 
       memset(&fhStatus, 0, sizeof(fhStatus));
       clnt_stat = clnt_call(m_client, MOUNTPROC_MNT,(xdrproc_t) xdr_dirpath, (char*)(&(exportlist->ex_dir)),
@@ -446,7 +446,7 @@ void NFSProtocol::openConnection()
    };
    m_client->cl_auth = authunix_create(hostName.data(),geteuid(),getegid(),0,0);
    connected();
-   kdDebug(7101)<<"openConnection succeeded"<<endl;
+   kdDebug(7121)<<"openConnection succeeded"<<endl;
 }
 
 void NFSProtocol::listDir( const KURL& _url)
@@ -467,7 +467,7 @@ void NFSProtocol::listDir( const KURL& _url)
    if (m_client==0) return;
    if (isRoot(path))
    {
-      kdDebug(7101)<<"listing root"<<endl;
+      kdDebug(7121)<<"listing root"<<endl;
       totalSize( m_exportedDirs.count());
       //in this case we don't need to do a real listdir
       UDSEntry entry;
@@ -477,7 +477,7 @@ void NFSProtocol::listDir( const KURL& _url)
          entry.clear();
          atom.m_uds = KIO::UDS_NAME;
          atom.m_str = (*it);
-         kdDebug(7101)<<"listing "<<(*it)<<endl;
+         kdDebug(7121)<<"listing "<<(*it)<<endl;
          entry.append( atom );
          createVirtualDirEntry(entry);
          listEntry( entry, false);
@@ -488,7 +488,7 @@ void NFSProtocol::listDir( const KURL& _url)
    }
 
    QStringList filesToList;
-   kdDebug(7101)<<"getting subdir -"<<path<<"-"<<endl;
+   kdDebug(7121)<<"getting subdir -"<<path<<"-"<<endl;
    stripTrailingSlash(path);
    NFSFileHandle fh=getFileHandle(path);
    //cerr<<"this is the fh: -"<<fh<<"-"<<endl;
@@ -527,7 +527,7 @@ void NFSProtocol::listDir( const KURL& _url)
       QCString tmpStr=QFile::encodeName(*it);
       dirargs.name=tmpStr.data();
 
-      kdDebug(7101)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
+      kdDebug(7121)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
 
       int clnt_stat= clnt_call(m_client, NFSPROC_LOOKUP,
                          (xdrproc_t) xdr_diropargs, (char*)&dirargs,
@@ -547,7 +547,7 @@ void NFSProtocol::listDir( const KURL& _url)
       //is it a symlink ?
       if (S_ISLNK(dirres.diropres_u.diropres.attributes.mode))
       {
-         kdDebug(7101)<<"it's a symlink !"<<endl;
+         kdDebug(7121)<<"it's a symlink !"<<endl;
          //cerr<<"fh: "<<tmpFH<<endl;
          nfs_fh nfsFH;
          memcpy(nfsFH.data,dirres.diropres_u.diropres.file.data,NFS_FHSIZE);
@@ -559,7 +559,7 @@ void NFSProtocol::listDir( const KURL& _url)
                                  (xdrproc_t) xdr_nfs_fh, (char*)&nfsFH,
                                  (xdrproc_t) xdr_readlinkres, (char*)&readLinkRes,total_timeout);
          if (!checkForError(clnt_stat,readLinkRes.status,(*it))) return;
-         kdDebug(7101)<<"link dest is -"<<readLinkRes.readlinkres_u.data<<"-"<<endl;
+         kdDebug(7121)<<"link dest is -"<<readLinkRes.readlinkres_u.data<<"-"<<endl;
          QCString linkDest(readLinkRes.readlinkres_u.data);
          atom.m_uds = KIO::UDS_LINK_DEST;
          atom.m_str = linkDest;
@@ -585,7 +585,7 @@ void NFSProtocol::listDir( const KURL& _url)
 
                attrstat attrAndStat;
 
-               kdDebug(7101)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
+               kdDebug(7121)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
 
                clnt_stat = clnt_call(m_client, NFSPROC_GETATTR,
                                          (xdrproc_t) xdr_diropargs, (char*)&dirargs,
@@ -632,7 +632,7 @@ void NFSProtocol::stat( const KURL & url)
 {
    QString path( QFile::encodeName(url.path()));
    stripTrailingSlash(path);
-   kdDebug(7101)<<"NFS::stat for -"<<path<<"-"<<endl;
+   kdDebug(7121)<<"NFS::stat for -"<<path<<"-"<<endl;
    QString tmpPath=path;
    if ((tmpPath.length()>1) && (tmpPath[0]=='/')) tmpPath=tmpPath.mid(1);
    // We can't stat root, but we know it's a dir
@@ -648,7 +648,7 @@ void NFSProtocol::stat( const KURL & url)
       // no size
       statEntry( entry );
       finished();
-      kdDebug(7101)<<"succeeded"<<endl;
+      kdDebug(7121)<<"succeeded"<<endl;
       return;
    }
 
@@ -665,7 +665,7 @@ void NFSProtocol::stat( const KURL & url)
    QCString tmpStr=QFile::encodeName(path);
    dirargs.name=tmpStr.data();
 
-   kdDebug(7101)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
+   kdDebug(7121)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
 
    int clnt_stat = clnt_call(m_client, NFSPROC_GETATTR,
                          (xdrproc_t) xdr_diropargs, (char*)&dirargs,
@@ -687,7 +687,7 @@ void NFSProtocol::stat( const KURL & url)
    //is it a symlink ?
    if (S_ISLNK(attrAndStat.attrstat_u.attributes.mode))
    {
-      kdDebug(7101)<<"it's a symlink !"<<endl;
+      kdDebug(7121)<<"it's a symlink !"<<endl;
       nfs_fh nfsFH;
       memcpy(nfsFH.data,fh,NFS_FHSIZE);
       //get the link dest
@@ -699,7 +699,7 @@ void NFSProtocol::stat( const KURL & url)
                               (xdrproc_t) xdr_nfs_fh, (char*)&nfsFH,
                               (xdrproc_t) xdr_readlinkres, (char*)&readLinkRes,total_timeout);
       if (!checkForError(clnt_stat,readLinkRes.status,path)) return;
-      kdDebug(7101)<<"link dest is -"<<readLinkRes.readlinkres_u.data<<"-"<<endl;
+      kdDebug(7121)<<"link dest is -"<<readLinkRes.readlinkres_u.data<<"-"<<endl;
       QCString linkDest(readLinkRes.readlinkres_u.data);
       atom.m_uds = KIO::UDS_LINK_DEST;
       atom.m_str = linkDest;
@@ -726,7 +726,7 @@ void NFSProtocol::stat( const KURL & url)
             tmpFH=getFileHandle(tmpStr);
             memcpy(dirargs.dir.data,tmpFH,NFS_FHSIZE);
 
-            kdDebug(7101)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
+            kdDebug(7121)<<"calling rpc: FH: -"<<fh<<"- with name -"<<dirargs.name<<"-"<<endl;
             clnt_stat = clnt_call(m_client, NFSPROC_GETATTR,
                                   (xdrproc_t) xdr_diropargs, (char*)&dirargs,
                                   (xdrproc_t) xdr_attrstat, (char*)&attrAndStat,total_timeout);
@@ -897,29 +897,29 @@ void NFSProtocol::completeUDSEntry(UDSEntry& entry, fattr& attributes)
    for( ; it != entry.end(); it++ ) {
       switch ((*it).m_uds) {
       case KIO::UDS_FILE_TYPE:
-         kdDebug(7101) << "File Type : " << (mode_t)((*it).m_long) << endl;
+         kdDebug(7121) << "File Type : " << (mode_t)((*it).m_long) << endl;
          break;
       case KIO::UDS_ACCESS:
-         kdDebug(7101) << "Access permissions : " << (mode_t)((*it).m_long) << endl;
+         kdDebug(7121) << "Access permissions : " << (mode_t)((*it).m_long) << endl;
          break;
       case KIO::UDS_USER:
-         kdDebug(7101) << "User : " << ((*it).m_str.ascii() ) << endl;
+         kdDebug(7121) << "User : " << ((*it).m_str.ascii() ) << endl;
          break;
       case KIO::UDS_GROUP:
-         kdDebug(7101) << "Group : " << ((*it).m_str.ascii() ) << endl;
+         kdDebug(7121) << "Group : " << ((*it).m_str.ascii() ) << endl;
          break;
       case KIO::UDS_NAME:
-         kdDebug(7101) << "Name : " << ((*it).m_str.ascii() ) << endl;
+         kdDebug(7121) << "Name : " << ((*it).m_str.ascii() ) << endl;
          //m_strText = decodeFileName( (*it).m_str );
          break;
       case KIO::UDS_URL:
-         kdDebug(7101) << "URL : " << ((*it).m_str.ascii() ) << endl;
+         kdDebug(7121) << "URL : " << ((*it).m_str.ascii() ) << endl;
          break;
       case KIO::UDS_MIME_TYPE:
-         kdDebug(7101) << "MimeType : " << ((*it).m_str.ascii() ) << endl;
+         kdDebug(7121) << "MimeType : " << ((*it).m_str.ascii() ) << endl;
          break;
       case KIO::UDS_LINK_DEST:
-         kdDebug(7101) << "LinkDest : " << ((*it).m_str.ascii() ) << endl;
+         kdDebug(7121) << "LinkDest : " << ((*it).m_str.ascii() ) << endl;
          break;
       }
    }*/
@@ -927,7 +927,7 @@ void NFSProtocol::completeUDSEntry(UDSEntry& entry, fattr& attributes)
 
 void NFSProtocol::setHost(const QString& host, int /*port*/, const QString& /*user*/, const QString& /*pass*/)
 {
-   kdDebug(7101)<<"setHost: -"<<host<<"-"<<endl;
+   kdDebug(7121)<<"setHost: -"<<host<<"-"<<endl;
    if (host.isEmpty())
    {
       error(ERR_UNKNOWN_HOST,"");
@@ -942,13 +942,13 @@ void NFSProtocol::setHost(const QString& host, int /*port*/, const QString& /*us
 
 void NFSProtocol::mkdir( const KURL& url, int permissions )
 {
-   kdDebug(7101)<<"mkdir"<<endl;
+   kdDebug(7121)<<"mkdir"<<endl;
    QString thePath( QFile::encodeName(url.path()));
    stripTrailingSlash(thePath);
    QString dirName, parentDir;
    getLastPart(thePath, dirName, parentDir);
    stripTrailingSlash(parentDir);
-   kdDebug(7101)<<"path: -"<<thePath<<"- dir: -"<<dirName<<"- parentDir: -"<<parentDir<<"-"<<endl;
+   kdDebug(7121)<<"path: -"<<thePath<<"- dir: -"<<dirName<<"- parentDir: -"<<parentDir<<"-"<<endl;
    if (isRoot(parentDir))
    {
       error(ERR_WRITE_ACCESS_DENIED,thePath);
@@ -981,14 +981,14 @@ bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text
 {
    if (clientStat!=RPC_SUCCESS)
    {
-      kdDebug(7101)<<"rpc error: "<<clientStat<<endl;
+      kdDebug(7121)<<"rpc error: "<<clientStat<<endl;
       //does this mapping make sense ?
       error(ERR_CONNECTION_BROKEN,i18n("An RPC error occurred."));
       return FALSE;
    };
    if (nfsStat!=NFS_OK)
    {
-      kdDebug(7101)<<"nfs error: "<<nfsStat<<endl;
+      kdDebug(7121)<<"nfs error: "<<nfsStat<<endl;
       switch (nfsStat)
       {
       case NFSERR_PERM:
@@ -1062,7 +1062,7 @@ void NFSProtocol::del( const KURL& url, bool isfile)
    QString fileName, parentDir;
    getLastPart(thePath, fileName, parentDir);
    stripTrailingSlash(parentDir);
-   kdDebug(7101)<<"del(): path: -"<<thePath<<"- file -"<<fileName<<"- parentDir: -"<<parentDir<<"-"<<endl;
+   kdDebug(7121)<<"del(): path: -"<<thePath<<"- file -"<<fileName<<"- parentDir: -"<<parentDir<<"-"<<endl;
    if (isRoot(parentDir))
    {
       error(ERR_ACCESS_DENIED,thePath);
@@ -1078,7 +1078,7 @@ void NFSProtocol::del( const KURL& url, bool isfile)
 
    if (isfile)
    {
-      kdDebug(7101)<<"Deleting file "<<thePath<<endl;
+      kdDebug(7121)<<"Deleting file "<<thePath<<endl;
       diropargs dirOpArgs;
       memcpy(dirOpArgs.dir.data,fh,NFS_FHSIZE);
       QCString tmpName=QFile::encodeName(fileName);
@@ -1090,13 +1090,13 @@ void NFSProtocol::del( const KURL& url, bool isfile)
                             (xdrproc_t) xdr_diropargs, (char*)&dirOpArgs,
                             (xdrproc_t) xdr_nfsstat, (char*)&nfsStat,total_timeout);
       if (!checkForError(clnt_stat,nfsStat,thePath)) return;
-      kdDebug(7101)<<"removing "<<thePath<<" from cache"<<endl;
+      kdDebug(7121)<<"removing "<<thePath<<" from cache"<<endl;
       m_handleCache.remove(m_handleCache.find(thePath));
       finished();
    }
    else
    {
-      kdDebug(7101)<<"Deleting directory "<<thePath<<endl;
+      kdDebug(7121)<<"Deleting directory "<<thePath<<endl;
       diropargs dirOpArgs;
       memcpy(dirOpArgs.dir.data,fh,NFS_FHSIZE);
       QCString tmpName=QFile::encodeName(fileName);
@@ -1108,7 +1108,7 @@ void NFSProtocol::del( const KURL& url, bool isfile)
                             (xdrproc_t) xdr_diropargs, (char*)&dirOpArgs,
                             (xdrproc_t) xdr_nfsstat, (char*)&nfsStat,total_timeout);
       if (!checkForError(clnt_stat,nfsStat,thePath)) return;
-      kdDebug(7101)<<"removing "<<thePath<<" from cache"<<endl;
+      kdDebug(7121)<<"removing "<<thePath<<" from cache"<<endl;
       m_handleCache.remove(m_handleCache.find(thePath));
       finished();
    };
@@ -1118,7 +1118,7 @@ void NFSProtocol::chmod( const KURL& url, int permissions )
 {
    QString thePath( QFile::encodeName(url.path()));
    stripTrailingSlash(thePath);
-   kdDebug( 7101 ) <<  "chmod -"<< thePath << "-"<<endl;
+   kdDebug( 7121 ) <<  "chmod -"<< thePath << "-"<<endl;
    if (isRoot(thePath) || isExportedDir(thePath))
    {
       error(ERR_ACCESS_DENIED,thePath);
@@ -1157,7 +1157,7 @@ void NFSProtocol::chmod( const KURL& url, int permissions )
 void NFSProtocol::get( const KURL& url )
 {
    QString thePath( QFile::encodeName(url.path()));
-   kdDebug(7101)<<"get() -"<<thePath<<"-"<<endl;
+   kdDebug(7121)<<"get() -"<<thePath<<"-"<<endl;
    NFSFileHandle fh=getFileHandle(thePath);
    if (fh.isInvalid())
    {
@@ -1174,9 +1174,6 @@ void NFSProtocol::get( const KURL& url )
    char buf[NFS_MAXDATA];
    readRes.readres_u.reply.data.data_val=buf;
 
-   time_t t_start = time( 0L );
-   time_t t_last = t_start;
-
    QByteArray array;
    do
    {
@@ -1188,7 +1185,7 @@ void NFSProtocol::get( const KURL& url )
          totalSize(readRes.readres_u.reply.attributes.size);
 
       offset=readRes.readres_u.reply.data.data_len;
-      //kdDebug(7101)<<"read "<<offset<<" bytes"<<endl;
+      //kdDebug(7121)<<"read "<<offset<<" bytes"<<endl;
       readArgs.offset+=offset;
       if (offset>0)
       {
@@ -1196,13 +1193,7 @@ void NFSProtocol::get( const KURL& url )
          data( array );
          array.resetRawData(readRes.readres_u.reply.data.data_val, offset);
 
-         time_t t = time( 0L );
-         if ( t - t_last >= 1 )
-         {
-            processedSize(readArgs.offset);
-            speed(readArgs.offset/(t-t_start));
-            t_last = t;
-         }
+	 processedSize(readArgs.offset);
       };
 
    } while (offset>0);
@@ -1214,7 +1205,7 @@ void NFSProtocol::get( const KURL& url )
 void NFSProtocol::put( const KURL& url, int _mode, bool _overwrite, bool /*_resume*/ )
 {
     QString destPath( QFile::encodeName(url.path()));
-    kdDebug( 7101 ) << "Put -" << destPath <<"-"<<endl;
+    kdDebug( 7121 ) << "Put -" << destPath <<"-"<<endl;
     /*QString dest_part( dest_orig );
     dest_part += ".part";*/
 
@@ -1229,7 +1220,7 @@ void NFSProtocol::put( const KURL& url, int _mode, bool _overwrite, bool /*_resu
 
     NFSFileHandle destFH;
     destFH=getFileHandle(destPath);
-    kdDebug(7101)<<"file handle for -"<<destPath<<"- is "<<destFH<<endl;
+    kdDebug(7121)<<"file handle for -"<<destPath<<"- is "<<destFH<<endl;
 
     //the file exists and we don't want to overwrite
     if ((!_overwrite) && (!destFH.isInvalid()))
@@ -1244,14 +1235,14 @@ void NFSProtocol::put( const KURL& url, int _mode, bool _overwrite, bool /*_resu
     //in the existing file, i.e. a file could not become smaller, since
     //write only overwrites or extends, but doesn't remove stuff from a file (aleXXX)
 
-    kdDebug(7101)<<"creating the file -"<<fileName<<"-"<<endl;
+    kdDebug(7121)<<"creating the file -"<<fileName<<"-"<<endl;
     NFSFileHandle parentFH;
     parentFH=getFileHandle(parentDir);
     //cerr<<"fh for parent dir: "<<parentFH<<endl;
     //the directory doesn't exist
     if (parentFH.isInvalid())
     {
-       kdDebug(7101)<<"parent directory -"<<parentDir<<"- does not exist"<<endl;
+       kdDebug(7121)<<"parent directory -"<<parentDir<<"- does not exist"<<endl;
        error(ERR_DOES_NOT_EXIST,parentDir);
        return;
     };
@@ -1281,7 +1272,7 @@ void NFSProtocol::put( const KURL& url, int _mode, bool _overwrite, bool /*_resu
     //we created the file successfully
     //destFH=getFileHandle(destPath);
     destFH=dirOpRes.diropres_u.diropres.file.data;
-    kdDebug(7101)<<"file -"<<fileName<<"- in dir -"<<parentDir<<"- created successfully"<<endl;
+    kdDebug(7121)<<"file -"<<fileName<<"- in dir -"<<parentDir<<"- created successfully"<<endl;
     //cerr<<"with fh "<<destFH<<endl;
 
     //now we can put
@@ -1294,13 +1285,13 @@ void NFSProtocol::put( const KURL& url, int _mode, bool _overwrite, bool /*_resu
     writeArgs.offset=0;
     attrstat attrStat;
     int bytesWritten(0);
-    kdDebug(7101)<<"starting to put"<<endl;
+    kdDebug(7121)<<"starting to put"<<endl;
     do
     {
        QByteArray buffer;
        dataReq(); // Request for data
        result = readData( buffer );
-       //kdDebug(7101)<<"received "<<result<<" bytes for putting"<<endl;
+       //kdDebug(7121)<<"received "<<result<<" bytes for putting"<<endl;
        char * data=buffer.data();
        int bytesToWrite=buffer.size();
        int writeNow(0);
@@ -1322,7 +1313,7 @@ void NFSProtocol::put( const KURL& url, int _mode, bool _overwrite, bool /*_resu
              int clnt_stat = clnt_call(m_client, NFSPROC_WRITE,
                                        (xdrproc_t) xdr_writeargs, (char*)&writeArgs,
                                        (xdrproc_t) xdr_attrstat, (char*)&attrStat,total_timeout);
-             //kdDebug(7101)<<"written"<<endl;
+             //kdDebug(7121)<<"written"<<endl;
              if (!checkForError(clnt_stat,attrStat.status,fileName)) return;
              bytesWritten+=writeNow;
              writeArgs.offset=bytesWritten;
@@ -1343,7 +1334,7 @@ void NFSProtocol::rename( const KURL &src, const KURL &dest, bool _overwrite )
    QString destPath( QFile::encodeName(dest.path()));
    stripTrailingSlash(srcPath);
    stripTrailingSlash(destPath);
-   kdDebug(7101)<<"renaming -"<<srcPath<<"- to -"<<destPath<<"-"<<endl;
+   kdDebug(7121)<<"renaming -"<<srcPath<<"- to -"<<destPath<<"-"<<endl;
 
    if (isRoot(srcPath) || isExportedDir(srcPath))
    {
@@ -1400,7 +1391,7 @@ void NFSProtocol::copy( const KURL &src, const KURL &dest, int _mode, bool _over
    //prepare the source
    QString thePath( QFile::encodeName(src.path()));
    stripTrailingSlash(thePath);
-   kdDebug( 7101 ) << "Copy to -" << thePath <<"-"<<endl;
+   kdDebug( 7121 ) << "Copy to -" << thePath <<"-"<<endl;
    NFSFileHandle fh=getFileHandle(thePath);
    if (fh.isInvalid())
    {
@@ -1420,7 +1411,7 @@ void NFSProtocol::copy( const KURL &src, const KURL &dest, int _mode, bool _over
    };
    NFSFileHandle destFH;
    destFH=getFileHandle(destPath);
-   kdDebug(7101)<<"file handle for -"<<destPath<<"- is "<<destFH<<endl;
+   kdDebug(7121)<<"file handle for -"<<destPath<<"- is "<<destFH<<endl;
 
    //the file exists and we don't want to overwrite
    if ((!_overwrite) && (!destFH.isInvalid()))
@@ -1435,13 +1426,13 @@ void NFSProtocol::copy( const KURL &src, const KURL &dest, int _mode, bool _over
    //in the existing file, i.e. a file could not become smaller, since
    //write only overwrites or extends, but doesn't remove stuff from a file
 
-   kdDebug(7101)<<"creating the file -"<<fileName<<"-"<<endl;
+   kdDebug(7121)<<"creating the file -"<<fileName<<"-"<<endl;
    NFSFileHandle parentFH;
    parentFH=getFileHandle(parentDir);
    //the directory doesn't exist
    if (parentFH.isInvalid())
    {
-      kdDebug(7101)<<"parent directory -"<<parentDir<<"- does not exist"<<endl;
+      kdDebug(7121)<<"parent directory -"<<parentDir<<"- does not exist"<<endl;
       error(ERR_DOES_NOT_EXIST,parentDir);
       return;
    };
@@ -1466,7 +1457,7 @@ void NFSProtocol::copy( const KURL &src, const KURL &dest, int _mode, bool _over
    if (!checkForError(clnt_stat,dirOpRes.status,destPath)) return;
    //we created the file successfully
    destFH=dirOpRes.diropres_u.diropres.file.data;
-   kdDebug(7101)<<"file -"<<fileName<<"- in dir -"<<parentDir<<"- created successfully"<<endl;
+   kdDebug(7121)<<"file -"<<fileName<<"- in dir -"<<parentDir<<"- created successfully"<<endl;
 
    char buf[NFS_MAXDATA];
    writeargs writeArgs;
@@ -1497,7 +1488,7 @@ void NFSProtocol::copy( const KURL &src, const KURL &dest, int _mode, bool _over
          totalSize(readRes.readres_u.reply.attributes.size);
 
       bytesRead=readRes.readres_u.reply.data.data_len;
-      //kdDebug(7101)<<"read "<<bytesRead<<" bytes"<<endl;
+      //kdDebug(7121)<<"read "<<bytesRead<<" bytes"<<endl;
       //then write
       if (bytesRead>0)
       {
@@ -1508,7 +1499,7 @@ void NFSProtocol::copy( const KURL &src, const KURL &dest, int _mode, bool _over
          clnt_stat = clnt_call(m_client, NFSPROC_WRITE,
                                (xdrproc_t) xdr_writeargs, (char*)&writeArgs,
                                (xdrproc_t) xdr_attrstat, (char*)&attrStat,total_timeout);
-         //kdDebug(7101)<<"written"<<endl;
+         //kdDebug(7121)<<"written"<<endl;
          if (!checkForError(clnt_stat,attrStat.status,destPath)) return;
          writeArgs.offset+=bytesRead;
       };
@@ -1520,13 +1511,13 @@ void NFSProtocol::copy( const KURL &src, const KURL &dest, int _mode, bool _over
 //TODO why isn't this even called ?
 void NFSProtocol::symlink( const QString &target, const KURL &dest, bool )
 {
-   kdDebug(7101)<<"symlinking "<<endl;
+   kdDebug(7121)<<"symlinking "<<endl;
    QString destPath=dest.path();
    stripTrailingSlash(destPath);
 
    QString parentDir, fileName;
    getLastPart(destPath,fileName, parentDir);
-   kdDebug(7101)<<"symlinking "<<parentDir<<" "<<fileName<<" to "<<target<<endl;
+   kdDebug(7121)<<"symlinking "<<parentDir<<" "<<fileName<<" to "<<target<<endl;
    NFSFileHandle fh=getFileHandle(parentDir);
    if (fh.isInvalid())
    {
@@ -1539,7 +1530,7 @@ void NFSProtocol::symlink( const QString &target, const KURL &dest, bool )
       return;
    };
 
-   kdDebug(7101)<<"tach"<<endl;
+   kdDebug(7121)<<"tach"<<endl;
    QCString tmpStr=target.latin1();
    symlinkargs symLinkArgs;
    symLinkArgs.to=tmpStr.data();
@@ -1559,29 +1550,29 @@ void NFSProtocol::symlink( const QString &target, const KURL &dest, bool )
 
 bool NFSProtocol::isValidLink(const QString& parentDir, const QString& linkDest)
 {
-   kdDebug(7101)<<"isValidLink: parent: "<<parentDir<<" link: "<<linkDest<<endl;
+   kdDebug(7121)<<"isValidLink: parent: "<<parentDir<<" link: "<<linkDest<<endl;
    if (linkDest.isEmpty()) return FALSE;
    if (isAbsoluteLink(linkDest))
    {
-      kdDebug(7101)<<"is an absolute link"<<endl;
+      kdDebug(7121)<<"is an absolute link"<<endl;
       return QFile::exists(linkDest);
    }
    else
    {
-      kdDebug(7101)<<"is a relative link"<<endl;
+      kdDebug(7121)<<"is a relative link"<<endl;
       QString absDest=parentDir+"/"+linkDest;
-      kdDebug(7101)<<"pointing abs to "<<absDest<<endl;
+      kdDebug(7121)<<"pointing abs to "<<absDest<<endl;
       absDest=removeFirstPart(absDest);
-      kdDebug(7101)<<"removed first part "<<absDest<<endl;
+      kdDebug(7121)<<"removed first part "<<absDest<<endl;
       absDest=QDir::cleanDirPath(absDest);
-      kdDebug(7101)<<"simplified to "<<absDest<<endl;
+      kdDebug(7121)<<"simplified to "<<absDest<<endl;
       if (absDest.find("../")==0)
          return FALSE;
 
-      kdDebug(7101)<<"is inside the nfs tree"<<endl;
+      kdDebug(7121)<<"is inside the nfs tree"<<endl;
       absDest=parentDir+"/"+linkDest;
       absDest=QDir::cleanDirPath(absDest);
-      kdDebug(7101)<<"getting file handle of "<<absDest<<endl;
+      kdDebug(7121)<<"getting file handle of "<<absDest<<endl;
       NFSFileHandle fh=getFileHandle(absDest);
       return (!fh.isInvalid());
    };
