@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2000 Alex Zepeda <jazepeda@pacbell.net>
+ * Copyright (c) 2000, 2001 Alex Zepeda <jazepeda@pacbell.net>
+ * Copyright (c) 2001 Michael Hckel <Michael@Haeckel.Net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,50 +24,55 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *	$Id: smtp.h,v 1.15 2001/01/16 08:42:42 garbanzo Exp $
+ *	$Id: smtp.h,v 1.30 2002/01/13 10:18:06 haeckel Exp $
  */
 
 #ifndef _SMTP_H
-#define _SMTP_H "$Id: smtp.h,v 1.15 2001/01/16 08:42:42 garbanzo Exp $"
+#define _SMTP_H "$Id: smtp.h,v 1.30 2002/01/13 10:18:06 haeckel Exp $"
 
 #include <qstring.h>
 #include <kio/tcpslavebase.h>
 
-#include <kconfig.h>
+class KDESasl;
 
-class KSASLContext;
-
-class SMTPProtocol
-	: public KIO::TCPSlaveBase {
+class SMTPProtocol:public KIO::TCPSlaveBase {
 public:
-	SMTPProtocol (const QCString &pool, const QCString &app);
-	virtual ~SMTPProtocol ();
+  SMTPProtocol(const QCString & pool, const QCString & app, bool useSSL);
+  virtual ~ SMTPProtocol();
 
-	virtual void setHost (const QString &host, int port, const QString &user, const QString &pass);
+  virtual void setHost(const QString & host, int port,
+                       const QString & user, const QString & pass);
 
-	virtual void put (const KURL& url, int permissions, bool overwrite, bool resume);
-	virtual void stat (const KURL&url);
+  virtual void special(const QByteArray & aData);
+  virtual void put(const KURL & url, int permissions, bool overwrite,
+                   bool resume);
+  virtual void stat(const KURL & url);
+  virtual void openConnection();
+  virtual void closeConnection();
 
 protected:
 
-	bool smtp_open (const KURL &u);
-	void smtp_close ();
-	bool command (const QString &buf, char *r_buf = NULL, unsigned int r_len = 0);
-	int getResponse (char *real_buf = NULL, unsigned int real_len = 0);
-	bool Authenticate (const KURL &url);
-	void HandleSMTPWriteError (const KURL &url);
-	void ParseFeatures (const char *buf);
+  bool smtp_open();
+  void smtp_close();
+  bool command(const QString & buf, char *r_buf =
+               NULL, unsigned int r_len = 0);
+  int getResponse(char *real_buf = NULL, unsigned int real_len = 0);
+  bool Authenticate();
+  void ParseFeatures(const char *buf);
+  bool PutRecipients(QStringList & list, const KURL & url);
 
-	unsigned short m_iOldPort;
-	bool opened, haveTLS;
-	struct timeval m_tTimeout;
-	QString m_sServer, m_sOldServer;
-	QString m_sUser, m_sOldUser;
-	QString m_sPass, m_sOldPass;
-	QString m_sError;
+  unsigned short m_iOldPort;
+  bool opened, haveTLS;
+  struct timeval m_tTimeout;
+  QString m_sServer, m_sOldServer;
+  QString m_sUser, m_sOldUser;
+  QString m_sPass, m_sOldPass;
+  QString m_sError;
 
-	KSASLContext *m_pSASL;
-	QString m_sAuthConfig;
+  KDESasl *m_pSASL;
+  QString m_sAuthConfig;
+  QCString lastError;
+  bool errorSent;
 };
 
 #endif
