@@ -17,7 +17,11 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: gscreator.cpp,v 1.5.2.1 2001/09/05 00:36:58 malte Exp $
+// $Id: gscreator.cpp,v 1.8 2002/02/19 19:50:27 arbab Exp $
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <assert.h>
 #include <stdlib.h>
