@@ -1,5 +1,5 @@
 /*  This file is part of the KDE libraries
-    Copyright (C) 2000 Malte Starostik <malte.starostik@t-online.de>
+    Copyright (C) 2000 Malte Starostik <malte@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -18,16 +18,16 @@
 */
 
 #ifndef _IMAGECREATOR_H_
-#define _IMAGECREATOR_H_ "$Id: imagecreator.h,v 1.1 2000/12/09 05:45:21 malte Exp $"
+#define _IMAGECREATOR_H_ "$Id: imagecreator.h,v 1.5 2001/10/01 20:32:50 faure Exp $"
 
-#include "thumbcreator.h"
+#include <kio/thumbcreator.h>
 
 class ImageCreator : public ThumbCreator
 {
 public:
     ImageCreator() {};
-    virtual bool create(const QString &path, int extent, QPixmap &pix);
-
+    virtual bool create(const QString &path, int, int, QImage &img);
+	virtual Flags flags() const;
 };
 
 #endif
