@@ -18,9 +18,9 @@
 */
 
 #ifndef _TEXTCREATOR_H_
-#define _TEXTCREATOR_H_ "$Id: textcreator.h,v 1.3 2001/07/27 22:45:50 malte Exp $"
+#define _TEXTCREATOR_H_ "$Id: textcreator.h,v 1.4 2001/10/01 20:32:50 faure Exp $"
 
-#include "thumbcreator.h"
+#include <kio/thumbcreator.h>
 
 class KPixmapSplitter;
 
