@@ -2,7 +2,7 @@
 
    configdialog.h (part of Klipper - Cut & paste history for KDE)
 
-   $Id: configdialog.h,v 1.14.2.1 2001/08/25 20:20:08 pfeiffer Exp $
+   $Id: configdialog.h,v 1.25 2002/02/27 14:00:13 pfeiffer Exp $
 
    (C) 2000 by Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -18,7 +18,6 @@
 #include <qgroupbox.h>
 #include <qheader.h>
 #include <qvbox.h>
-#include <qvgroupbox.h>
 
 #include <kdialogbase.h>
 #include <keditlistbox.h>
@@ -29,10 +28,13 @@
 #include "urlgrabber.h"
 
 class KGlobalAccel;
+class KKeyChooser;
 class KListView;
 class QPushButton;
+class QDialog;
+class ConfigDialog;
 
-class GeneralWidget : public QVGroupBox
+class GeneralWidget : public QVBox
 {
     Q_OBJECT
 
@@ -43,7 +45,8 @@ public:
     ~GeneralWidget();
 
 private:
-    QCheckBox *cbMousePos, *cbSaveContents, *cbReplayAIH;
+    QCheckBox *cbMousePos, *cbSaveContents, *cbReplayAIH, *cbSynchronize;
+    QCheckBox *cbNoNull;
     KIntNumInput *popupTimeout, *maxItems;
 
 };
@@ -65,14 +68,14 @@ private:
     KEditListBox *editListBox;
 };
 
-class ActionWidget : public QVGroupBox
+class ActionWidget : public QVBox
 {
     Q_OBJECT
 
     friend class ConfigDialog;
 
 public:
-    ActionWidget( const ActionList *list, QWidget *parent, const char *name );
+    ActionWidget( const ActionList *list, ConfigDialog* configWidget, QWidget *parent, const char *name );
     ~ActionWidget();
 
     /**
@@ -98,21 +101,22 @@ private:
     QStringList m_wmClasses;
     AdvancedWidget *advancedWidget;
     QPushButton *delActionButton;
+    QCheckBox *cbUseGUIRegExpEditor;
 };
 
-class KeysWidget : public QVGroupBox
+/*class KeysWidget : public QVBox
 {
     Q_OBJECT
 
     friend class ConfigDialog;
 
 public:
-    KeysWidget( KKeyEntryMap *keyMap, QWidget *parent, const char *name );
+    KeysWidget( KAccelActions &keyMap, QWidget *parent, const char *name );
     ~KeysWidget();
 
 private:
     KKeyChooser *keyChooser;
-};
+};*/
 
 
 class ConfigDialog : public KDialogBase
@@ -120,7 +124,7 @@ class ConfigDialog : public KDialogBase
     Q_OBJECT
 
 public:
-    ConfigDialog( const ActionList *list, KKeyEntryMap *keyMap );
+    ConfigDialog( const ActionList *list, KGlobalAccel *accel, bool isApplet );
     ~ConfigDialog();
 
     ActionList * actionList() const { return actionWidget->actionList(); }
@@ -131,10 +135,16 @@ public:
     bool popupAtMousePos() const {
 	return generalWidget->cbMousePos->isChecked();
     }
-
     bool replayActionInHistory() const {
 	return generalWidget->cbReplayAIH->isChecked();
     }
+    bool synchronize() const {
+        return generalWidget->cbSynchronize->isChecked();
+    }
+    bool noNullClipboard() const {
+        return generalWidget->cbNoNull->isChecked();
+    }
+
     int popupTimeout() const {
 	return generalWidget->popupTimeout->value();
     }
@@ -144,6 +154,10 @@ public:
     QStringList noActionsFor() const {
 	return actionWidget->wmClasses();
     }
+    bool useGUIRegExpEditor() const
+    {
+      return actionWidget->cbUseGUIRegExpEditor->isChecked();
+    }
 
     void setKeepContents( bool enable ) {
 	generalWidget->cbSaveContents->setChecked( enable );
@@ -154,6 +168,12 @@ public:
     void setReplayActionInHistory( bool enable ) {
 	generalWidget->cbReplayAIH->setChecked( enable );
     }
+    void setSynchronize( bool enable ) {
+	generalWidget->cbSynchronize->setChecked( enable );
+    }
+    void setNoNullClipboard( bool enable ) {
+        generalWidget->cbNoNull->setChecked( enable );
+    }
     void setPopupTimeout( int timeout ) {
 	generalWidget->popupTimeout->setValue( timeout );
     }
@@ -163,21 +183,30 @@ public:
     void setNoActionsFor( const QStringList& items ) {
 	actionWidget->setWMClasses( items );
     }
+    void setUseGUIRegExpEditor( bool enabled )
+    {
+	// the checkbox is only hidden explicitly when there's no
+	// regexp editor component available.
+	if ( !actionWidget->cbUseGUIRegExpEditor->isHidden() )
+            actionWidget->cbUseGUIRegExpEditor->setChecked( enabled );
+    }
 
     virtual void show();
+    void commitShortcuts();
 
 private:
     GeneralWidget *generalWidget;
     ActionWidget *actionWidget;
-    KeysWidget *keysWidget;
+    KKeyChooser *keysWidget;
 
 };
 
 class ListView : public KListView
 {
 public:
-    ListView( QWidget *parent, const char *name )
-	: KListView( parent, name ) {}
+    ListView( ConfigDialog* configWidget, QWidget *parent, const char *name )
+	: KListView( parent, name ), _configWidget( configWidget ), 
+          _regExpEditor(0L) {}
     // QListView has a weird idea of a sizeHint...
     virtual QSize sizeHint () const {
 	int w = minimumSizeHint().width();
@@ -194,6 +223,11 @@ public:
 	return QSize( w, h );
     }
 
+protected:
+    virtual void rename( QListViewItem* item, int c );
+private:
+    ConfigDialog* _configWidget;
+    QDialog* _regExpEditor;
 };
 
 #endif // CONFIGDIALOG_H
