@@ -1,5 +1,6 @@
 /*
  *   Copyright (C) 2000 Matthias Elter <elter@kde.org>
+ *   Copyright (C) 2001-2002 Raffaele Sandrini <sandrini@kde.org)
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,7 +25,7 @@
 #include <kstdaction.h>
 #include <kdebug.h>
 #include <dcopclient.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "menueditview.h"
 #include "kmenuedit.h"
@@ -65,7 +66,9 @@ void KMenuEdit::setupActions()
 {
     (void)new KAction(i18n("&New Submenu"), "menu_new", 0, actionCollection(), "newsubmenu");
     (void)new KAction(i18n("New &Item"), "filenew", 0, actionCollection(), "newitem");
-    (void)new KAction(i18n("&Delete"), "editdelete", 0, actionCollection(), "delete");
+    (void)new KAction(i18n("&Delete"), "edittrash", 0, actionCollection(), "delete");
+    (void)new KAction(i18n("&Hide"), "editdelete", 0, actionCollection(), "hide");
+    (void)new KAction(i18n("&Unhide"), "redo", 0, actionCollection(), "unhide");
 
     KStdAction::quit(this, SLOT( slotClose() ), actionCollection());
     KStdAction::cut(0, 0, actionCollection());
