@@ -19,18 +19,16 @@
 */
 
 #include "KonqMainWindowIface.h"
-#include "konq_mainwindow.h"
 #include "KonqViewIface.h"
 #include "konq_view.h"
 
-#include <qvariant.h>
 
 #include <dcopclient.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdcopactionproxy.h>
 
 KonqMainWindowIface::KonqMainWindowIface( KonqMainWindow * mainWindow )
-    : m_pMainWindow( mainWindow )
+    : DCOPObject( mainWindow->name() ), m_pMainWindow( mainWindow )
 {
   m_dcopActionProxy = new KDCOPActionProxy( mainWindow->actionCollection(), this );
 }
