@@ -1,26 +1,22 @@
 #include "konq_aboutpage.h"
 
-#include <qfile.h>
 #include <qtextcodec.h>
-#include <qtextstream.h>
 
 #include <kaboutdata.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
-#include <kglobal.h>
-#include <khtml_part.h>
-#include <kinstance.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ksavefile.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kaction.h>
 
 #include <assert.h>
+#include <qfile.h>
 
 extern "C"
 {
-    void *init_libkonqaboutpage()
+    void *init_konq_aboutpage()
     {
         return new KonqAboutPageFactory;
     }
@@ -88,7 +84,7 @@ QString KonqAboutPageFactory::intro()
     if ( s_intro_html )
         return *s_intro_html;
 
-    QString res = loadFile( locate( "data", "konqueror/about/intro.html" ));
+    QString res = loadFile( locate( "data", kapp->reverseLayout() ? "konqueror/about/intro_rtl.html" : "konqueror/about/intro.html" ));
     if ( res.isEmpty() )
 	return res;
 
@@ -101,7 +97,7 @@ QString KonqAboutPageFactory::intro()
           .arg( i18n( "Welcome to Konqueror %1." ).arg( KGlobal::instance()->aboutData()->version() ) )
           .arg( i18n( "With Konqueror you have your filesystem at your command, browsing "
 		      "local or networked drives with equal ease. Thanks to the component "
-		      "technology used throughout KDE 2, Konqueror is also a full featured, "
+		      "technology used throughout KDE, Konqueror is also a full featured, "
 		      "easy to use and comfortable Web Browser, which you can use to explore "
 		      "the Internet." ) )
           .arg( i18n( "Simply enter the Internet address (e.g. <A HREF=\"http://www.kde.org\">http://www.kde.org</A>) "
@@ -132,7 +128,7 @@ QString KonqAboutPageFactory::specs()
     if ( s_specs_html )
         return *s_specs_html;
 
-    QString res = loadFile( locate( "data", "konqueror/about/specs.html" ));
+    QString res = loadFile( locate( "data", kapp->reverseLayout() ? "konqueror/about/specs_rtl.html" : "konqueror/about/specs.html" ));
     if ( res.isEmpty() )
 	return res;
 
@@ -188,7 +184,7 @@ QString KonqAboutPageFactory::specs()
           .arg( i18n("Manual"))
 	  .arg( i18n("Popup"))
 	  .arg( i18n("(Short-) Automatic"))
-          .arg( i18n("<A HREF=\"%1\">Back</A> to the Introduction").arg("intro.html") )
+          .arg( i18n("<A HREF=\"%1\">Back</A> to the Introduction").arg(kapp->reverseLayout() ? "intro_rtl.html" : "intro.html") )
 
           ;
 
@@ -202,7 +198,7 @@ QString KonqAboutPageFactory::tips()
     if ( s_tips_html )
         return *s_tips_html;
 
-    QString res = loadFile( locate( "data", "konqueror/about/tips.html" ));
+    QString res = loadFile( locate( "data", kapp->reverseLayout() ? "konqueror/about/tips_rtl.html" : "konqueror/about/tips.html" ));
     if ( res.isEmpty() )
 	return res;
 
@@ -221,7 +217,8 @@ QString KonqAboutPageFactory::tips()
 		      " toolbar to increase the font size on your web page.").arg("viewmag.png") )
 	  .arg( i18n( "When you want to paste a new address into the Location toolbar you might want to "
 		      "clear the current entry by pressing the black arrow with the white cross &nbsp;"
-		      "<IMG WIDTH=16 HEIGHT=16 SRC=\"%1\"> &nbsp; in the toolbar.").arg("locationbar_erase.png"))
+		      "<IMG WIDTH=16 HEIGHT=16 SRC=\"%1\"> &nbsp; in the toolbar.")
+              .arg(QApplication::reverseLayout() ? "locationbar_erase_rtl.png" : "locationbar_erase.png"))
 	  .arg( i18n( "To create a link on your desktop pointing to the current page, "
 		      "simply drag the \"Location\" label that is to the left of the Location toolbar, drop it on to "
 		      "the desktop, and choose \"Link\"." ) )
@@ -261,11 +258,11 @@ KonqAboutPage::KonqAboutPage( //KonqMainWindow *
     : KHTMLPart( parentWidget, widgetName, parent, name, BrowserViewGUI )
 {
     //m_mainWindow = mainWindow;
-    QTextCodec *codec = QTextCodec::codecForName(KGlobal::locale()->charset().latin1());
+    QTextCodec* codec = KGlobal::locale()->codecForEncoding();
     if (codec)
 	setCharset(codec->name(), true);
     else
-	setCharset(KGlobal::locale()->charset(), true);
+	setCharset("iso-8859-1", true);
     // about:blah isn't a kioslave -> disable View source
     KAction * act = actionCollection()->action("viewDocumentSource");
     if ( act )
@@ -306,7 +303,7 @@ void KonqAboutPage::serve( const QString& html )
     m_htmlDoc = html;
 }
 
-void KonqAboutPage::urlSelected( const QString &url, int button, int state, const QString &target )
+void KonqAboutPage::urlSelected( const QString &url, int button, int state, const QString &target, KParts::URLArgs _args )
 {
     KURL u( url );
     if ( u.protocol() == "exec" )
@@ -318,19 +315,19 @@ void KonqAboutPage::urlSelected( const QString &url, int button, int state, cons
         return;
     }
 
-    if ( url == QString::fromLatin1("intro.html") )
+    if ( url == QString::fromLatin1("intro.html") || url == QString::fromLatin1("intro_rtl.html") )
     {
         emit browserExtension()->openURLNotify();
 	serve( KonqAboutPageFactory::intro() );
         return;
     }
-    else if ( url == QString::fromLatin1("specs.html") )
+    else if ( url == QString::fromLatin1("specs.html") || url == QString::fromLatin1("specs_rtl.html") )
     {
         emit browserExtension()->openURLNotify();
 	serve( KonqAboutPageFactory::specs() );
         return;
     }
-    else if ( url == QString::fromLatin1("tips.html") )
+    else if ( url == QString::fromLatin1("tips.html") || url == QString::fromLatin1("tips_rtl.html") )
     {
         emit browserExtension()->openURLNotify();
         serve( KonqAboutPageFactory::tips() );
@@ -339,11 +336,11 @@ void KonqAboutPage::urlSelected( const QString &url, int button, int state, cons
 
     else if ( url == QString::fromLatin1("config:/disable_overview") )
     {
-	if ( KMessageBox::questionYesNo( widget(), 
-					 i18n("Do you want to disable showing\n"
+	if ( KMessageBox::questionYesNo( widget(),
+					 i18n("Do you want to disable showing "
 					      "the Introduction in the webbrowsing profile?"),
-					 i18n("Faster startup?") )
-	     == KMessageBox::Yes ) 
+					 i18n("Faster Startup?") )
+	     == KMessageBox::Yes )
 	{
 	    QString profile = locateLocal("data", "konqueror/profiles/webbrowsing");
 	    KSaveFile file( profile );
@@ -356,8 +353,8 @@ void KonqAboutPage::urlSelected( const QString &url, int button, int state, cons
 	}
 	return;
     }
-    
-    KHTMLPart::urlSelected( url, button, state, target );
+
+    KHTMLPart::urlSelected( url, button, state, target, _args );
 }
 
 #include "konq_aboutpage.moc"
