@@ -25,43 +25,25 @@
 #include <sys/stat.h>
 #include <time.h>
 #include <unistd.h>
+#include <qfile.h>
 
-#include <kaccel.h>
 #include <kaction.h>
 #include <kdebug.h>
-#include <konq_dirlister.h>
-#include <kfileivi.h>
-#include <konq_fileitem.h>
-#include <kio/job.h>
-#include <klibloader.h>
+#include <kdirlister.h>
 #include <klineeditdlg.h>
 #include <kmessagebox.h>
-#include <kmimetype.h>
-#include <konq_iconviewwidget.h>
 #include <konq_settings.h>
-#include <kpropsdlg.h>
-#include <krun.h>
+#include <kpropertiesdialog.h>
 #include <kstdaction.h>
-#include <kurl.h>
 #include <kparts/factory.h>
-#include <kiconloader.h>
-#include <kapp.h>
 #include <ktrader.h>
 #include <klocale.h>
 
-#include <qmessagebox.h>
-#include <qclipboard.h>
-#include <qfile.h>
-#include <qkeycode.h>
-#include <qpalette.h>
 #include <qregexp.h>
-#include <qvaluelist.h>
-#include <qpainter.h>
-#include <qpen.h>
 
 #include <config.h>
 
-template class QList<KFileIVI>;
+template class QPtrList<KFileIVI>;
 //template class QValueList<int>;
 
 class KonqIconViewFactory : public KParts::Factory
@@ -85,14 +67,13 @@ public:
       s_defaultViewProps = 0;
    }
 
-    virtual KParts::Part* createPart( QWidget *parentWidget, const char *,
+    virtual KParts::Part* createPartObject( QWidget *parentWidget, const char *,
                                       QObject *parent, const char *name, const char*, const QStringList &args )
    {
       if( args.count() < 1 )
          kdWarning() << "KonqKfmIconView: Missing Parameter" << endl;
 
       KonqKfmIconView *obj = new KonqKfmIconView( parentWidget, parent, name,args.first() );
-      emit objectCreated( obj );
       return obj;
    }
 
@@ -121,7 +102,7 @@ KonqPropsView *KonqIconViewFactory::s_defaultViewProps = 0;
 
 extern "C"
 {
-    void *init_libkonqiconview()
+    void *init_konq_iconview()
     {
         return new KonqIconViewFactory;
     }
@@ -189,15 +170,6 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     m_pIconView = new KonqIconViewWidget( parentWidget, "qiconview" );
     m_pIconView->initConfig( true );
 
-    QTimer * timer = new QTimer( this );
-    connect( timer, SIGNAL( timeout() ), this, SLOT( slotProcessMimeIcons() ) );
-    m_mimeTypeResolver = new KonqMimeTypeResolver<KFileIVI,KonqKfmIconView>(this,timer);
-
-    // When our viewport is adjusted (resized or scrolled) we need
-    // to get the mime types for any newly visible icons. (Rikkus)
-    connect( m_pIconView, SIGNAL( viewportAdjusted() ),
-             SLOT( slotViewportAdjusted() ) );
-
     connect( m_pIconView,  SIGNAL(imagePreviewFinished()),
              this, SLOT(slotRenderingFinished()));
 
@@ -210,6 +182,7 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     connect( this, SIGNAL( findClosed( KonqDirPart * ) ), SLOT( slotKFindClosed() ) );
 
     setWidget( m_pIconView );
+    m_mimeTypeResolver = new KMimeTypeResolver<KFileIVI,KonqKfmIconView>(this);
 
     setInstance( KonqIconViewFactory::instance() );
 
@@ -238,10 +211,10 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
 
     //    m_pamSort = new KActionMenu( i18n( "Sort..." ), actionCollection(), "sort" );
 
-    KToggleAction *aSortByNameCS = new KRadioAction( i18n( "by Name (Case Sensitive)" ), 0, actionCollection(), "sort_nc" );
-    KToggleAction *aSortByNameCI = new KRadioAction( i18n( "by Name (Case Insensitive)" ), 0, actionCollection(), "sort_nci" );
-    KToggleAction *aSortBySize = new KRadioAction( i18n( "by Size" ), 0, actionCollection(), "sort_size" );
-    KToggleAction *aSortByType = new KRadioAction( i18n( "by Type" ), 0, actionCollection(), "sort_type" );
+    KToggleAction *aSortByNameCS = new KRadioAction( i18n( "By Name (Case Sensitive)" ), 0, actionCollection(), "sort_nc" );
+    KToggleAction *aSortByNameCI = new KRadioAction( i18n( "By Name (Case Insensitive)" ), 0, actionCollection(), "sort_nci" );
+    KToggleAction *aSortBySize = new KRadioAction( i18n( "By Size" ), 0, actionCollection(), "sort_size" );
+    KToggleAction *aSortByType = new KRadioAction( i18n( "By Type" ), 0, actionCollection(), "sort_type" );
 
     aSortByNameCS->setExclusiveGroup( "sorting" );
     aSortByNameCI->setExclusiveGroup( "sorting" );
@@ -258,7 +231,7 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     connect( aSortBySize, SIGNAL( toggled( bool ) ), this, SLOT( slotSortBySize( bool ) ) );
     connect( aSortByType, SIGNAL( toggled( bool ) ), this, SLOT( slotSortByType( bool ) ) );
 
-    m_paSortDirsFirst = new KToggleAction( i18n( "Directories first" ), 0, actionCollection(), "sort_directoriesfirst" );
+    m_paSortDirsFirst = new KToggleAction( i18n( "Directories First" ), 0, actionCollection(), "sort_directoriesfirst" );
     KToggleAction *aSortDescending = new KToggleAction( i18n( "Descending" ), 0, actionCollection(), "sort_descend" );
 
     m_paSortDirsFirst->setChecked( true );
@@ -278,7 +251,7 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
                               actionCollection(), "select" );
     m_paUnselect = new KAction( i18n( "&Unselect..." ), CTRL+Key_Minus, this, SLOT( slotUnselect() ),
                                 actionCollection(), "unselect" );
-    m_paSelectAll = KStdAction::selectAll( this, SLOT( slotSelectAll() ), this, "selectall" );
+    m_paSelectAll = KStdAction::selectAll( this, SLOT( slotSelectAll() ), actionCollection(), "selectall" );
     m_paUnselectAll = new KAction( i18n( "U&nselect All" ), CTRL+Key_U, this, SLOT( slotUnselectAll() ),
                                    actionCollection(), "unselectall" );
     m_paInvertSelection = new KAction( i18n( "&Invert Selection" ), CTRL+Key_Asterisk,
@@ -298,8 +271,6 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     //connect( m_paBottomText, SIGNAL( toggled( bool ) ), this, SLOT( slotTextBottom( bool ) ) );
     //connect( m_paRightText, SIGNAL( toggled( bool ) ), this, SLOT( slotTextRight( bool ) ) );
 
-    //
-
     connect( m_pIconView, SIGNAL( executed( QIconViewItem * ) ),
              this, SLOT( slotReturnPressed( QIconViewItem * ) ) );
     connect( m_pIconView, SIGNAL( returnPressed( QIconViewItem * ) ),
@@ -316,11 +287,35 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     connect( m_pIconView, SIGNAL( mouseButtonClicked(int, QIconViewItem*, const QPoint&)),
              this, SLOT( slotMouseButtonClicked(int, QIconViewItem*, const QPoint&)) );
 
+    // Create the directory lister
+    m_dirLister = new KDirLister( true );
+
+    connect( m_dirLister, SIGNAL( started( const KURL & ) ),
+             this, SLOT( slotStarted() ) );
+    connect( m_dirLister, SIGNAL( completed() ), this, SLOT( slotCompleted() ) );
+    connect( m_dirLister, SIGNAL( canceled( const KURL& ) ), this, SLOT( slotCanceled( const KURL& ) ) );
+    connect( m_dirLister, SIGNAL( clear() ), this, SLOT( slotClear() ) );
+    connect( m_dirLister, SIGNAL( newItems( const KFileItemList& ) ),
+             this, SLOT( slotNewItems( const KFileItemList& ) ) );
+    connect( m_dirLister, SIGNAL( deleteItem( KFileItem * ) ),
+             this, SLOT( slotDeleteItem( KFileItem * ) ) );
+    connect( m_dirLister, SIGNAL( refreshItems( const KFileItemList& ) ),
+             this, SLOT( slotRefreshItems( const KFileItemList& ) ) );
+    connect( m_dirLister, SIGNAL( redirection( const KURL & ) ),
+             this, SLOT( slotRedirection( const KURL & ) ) );
+    connect( m_dirLister, SIGNAL( itemsFilteredByMime(const KFileItemList& ) ),
+             SIGNAL( itemsFilteredByMime(const KFileItemList& ) ) );
+    connect( m_dirLister, SIGNAL( infoMessage( const QString& ) ),
+             extension(), SIGNAL( infoMessage( const QString& ) ) );
+    connect( m_dirLister, SIGNAL( percent( int ) ),
+             extension(), SIGNAL( loadingProgress( int ) ) );
+    connect( m_dirLister, SIGNAL( speed( int ) ),
+             extension(), SIGNAL( speedProgress( int ) ) );
+
     // Now we may react to configuration changes
     m_bInit = false;
 
-    m_dirLister = 0L;
-    m_bLoading = false;
+    m_bLoading = true;
     m_bNeedAlign = false;
     m_bNeedEmitCompleted = false;
     m_pIconView->setResizeMode( QIconView::Adjust );
@@ -342,9 +337,10 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
 
 KonqKfmIconView::~KonqKfmIconView()
 {
-    delete m_mimeTypeResolver;
     kdDebug(1202) << "-KonqKfmIconView" << endl;
+    m_dirLister->disconnect( this );
     delete m_dirLister;
+    delete m_mimeTypeResolver;
     delete m_pProps;
     //no need for that, KParts deletes our widget already ;-)
     //    delete m_pIconView;
@@ -363,11 +359,27 @@ const KFileItem * KonqKfmIconView::currentItem()
 
 void KonqKfmIconView::slotPreview( bool toggle )
 {
-    m_pProps->setShowingPreview( sender()->name(), toggle );
+    QCString name = sender()->name(); // e.g. clipartthumbnail (or audio/, special case)
+    m_pProps->setShowingPreview( name, toggle );
     if ( !toggle )
     {
-        m_pIconView->stopImagePreview();
-        m_pIconView->setIcons( m_pIconView->iconSize(), sender()->name() );
+        kdDebug() << "KonqKfmIconView::slotPreview stopping image preview for " << name << endl;
+        if ( name == "sound/" )
+            m_pIconView->disableSoundPreviews();
+        else
+        {
+            KService::Ptr serv = KService::serviceByDesktopName( name );
+            Q_ASSERT( serv != 0L );
+            if ( serv ) {
+                bool previewRunning = m_pIconView->isPreviewRunning();
+                if ( previewRunning )
+                    m_pIconView->stopImagePreview();
+                QStringList mimeTypes = serv->property("MimeTypes").toStringList();
+                m_pIconView->setIcons( m_pIconView->iconSize(), mimeTypes );
+                if ( previewRunning )
+                    m_pIconView->startImagePreview( m_pProps->previewSettings(), false );
+            }
+        }
     }
     else
     {
@@ -379,6 +391,7 @@ void KonqKfmIconView::slotShowDot()
 {
     m_pProps->setShowingDotFiles( !m_pProps->isShowingDotFiles() );
     m_dirLister->setShowingDotFiles( m_pProps->isShowingDotFiles() );
+    m_dirLister->emitChanges();
     //we don't want the non-dot files to remain where they are
     m_bNeedAlign = true;
     slotCompleted();
@@ -400,7 +413,7 @@ void KonqKfmIconView::slotSelect()
         QIconViewItem *it = m_pIconView->firstItem();
         while ( it )
         {
-            if ( re.match( it->text() ) != -1 )
+            if ( re.search( it->text() ) != -1 )
                 it->setSelected( true, true );
             it = it->nextItem();
         }
@@ -429,7 +442,7 @@ void KonqKfmIconView::slotUnselect()
         QIconViewItem *it = m_pIconView->firstItem();
         while ( it )
         {
-            if ( re.match( it->text() ) != -1 )
+            if ( re.search( it->text() ) != -1 )
                 it->setSelected( false, true );
             it = it->nextItem();
         }
@@ -527,9 +540,10 @@ void KonqKfmIconView::newIconSize( int size )
         m_pIconView->startImagePreview( m_pProps->previewSettings(), true );
 }
 
-bool KonqKfmIconView::closeURL()
+bool KonqKfmIconView::doCloseURL()
 {
-    if ( m_dirLister ) m_dirLister->stop();
+    m_dirLister->stop();
+
     m_mimeTypeResolver->m_lstPendingMimeIconItems.clear();
     m_pIconView->stopImagePreview();
     return true;
@@ -543,13 +557,18 @@ void KonqKfmIconView::slotReturnPressed( QIconViewItem *item )
     item->setSelected( false, true );
     m_pIconView->visualActivate(item);
 
-    KonqFileItem *fileItem = (static_cast<KFileIVI*>(item))->item();
+    KFileItem *fileItem = (static_cast<KFileIVI*>(item))->item();
     if ( !fileItem )
         return;
     if ( !fileItem->isReadable() )
     {
-        KMessageBox::error( m_pIconView, i18n("You do not have enough permissions to read <b>%1</b>").arg(fileItem->url().prettyURL()) );
-        return;
+        // No permissions or local file that doesn't exist - need to find out which
+        if ( !fileItem->isLocalFile() || QFile::exists( fileItem->url().path() ) )
+        {
+            KMessageBox::error( m_pIconView, i18n("<p>You do not have enough permissions to read <b>%1</b></p>").arg(fileItem->url().prettyURL()) );
+            return;
+        }
+        // ### Add error message if the latter case, after msg freeze.
     }
     if (KonqFMSettings::settings()->alwaysNewWin() && fileItem->isDir()) {
         fileItem->run();
@@ -576,7 +595,6 @@ void KonqKfmIconView::slotMouseButtonPressed(int _button, QIconViewItem* _item,
         }
         else
         {
-            if (!m_dirLister) return;
             // Right click on viewport
             KFileItem * item = m_dirLister->rootItem();
             bool delRootItem = false;
@@ -615,9 +633,11 @@ void KonqKfmIconView::slotMouseButtonClicked(int _button, QIconViewItem* _item,
 
 void KonqKfmIconView::slotStarted()
 {
-    m_pIconView->selectAll( false );
+    // Only emit started if this comes after openURL, i.e. it's not for an update.
+    // We don't want to start a spinning wheel during updates.
     if ( m_bLoading )
-        emit started( m_dirLister->job() );
+        emit started( 0 );
+
     // An update may come in while we are still processing icons...
     // So don't clear the list.
     //m_mimeTypeResolver->m_lstPendingMimeIconItems.clear();
@@ -625,7 +645,15 @@ void KonqKfmIconView::slotStarted()
 
 void KonqKfmIconView::slotCanceled()
 {
-    if ( m_bLoading )
+    // Called by kfindpart. Not by kdirlister.
+    slotCanceled( m_pIconView->url() );
+}
+
+void KonqKfmIconView::slotCanceled( const KURL& url )
+{
+    // Check if this canceled() signal is about the URL we're listing.
+    // It could be about the URL we were listing, and openURL() aborted it.
+    if ( m_bLoading && url.cmp( m_pIconView->url(), true ) )
     {
         emit canceled( QString::null );
         m_bLoading = false;
@@ -635,7 +663,12 @@ void KonqKfmIconView::slotCanceled()
 void KonqKfmIconView::slotCompleted()
 {
     // Root item ? Store root item in konqiconviewwidget (whether 0L or not)
-    m_pIconView->setRootItem( static_cast<KonqFileItem *>(m_dirLister->rootItem()) );
+    m_pIconView->setRootItem( m_dirLister->rootItem() );
+
+    if ( m_bLoading ) // only after initial listing, not after updates
+        // If we don't set a current item, the iconview has none (one more keypress needed)
+        // but it appears on focusin... qiconview bug, Reggie acknowledged it LONG ago (07-2000).
+        m_pIconView->setCurrentItem( m_pIconView->firstItem() );
 
     if ( m_bUpdateContentsPosAfterListing )
         m_pIconView->setContentsPos( m_xOffset, m_yOffset );
@@ -666,11 +699,8 @@ void KonqKfmIconView::slotNewItems( const KFileItemList& entries )
 {
     for (KFileItemListIterator it(entries); it.current(); ++it)
     {
-        KonqFileItem * _fileitem = static_cast<KonqFileItem *>(it.current());
-
         //kdDebug(1202) << "KonqKfmIconView::slotNewItem(...)" << _fileitem->url().url() << endl;
-        KFileIVI* item = new KFileIVI( m_pIconView, _fileitem,
-                                       m_pIconView->iconSize() );
+        KFileIVI* item = new KFileIVI( m_pIconView, *it, m_pIconView->iconSize() );
         item->setRenameEnabled( false );
 
         QString key;
@@ -681,28 +711,34 @@ void KonqKfmIconView::slotNewItems( const KFileItemList& entries )
             case NameCaseInsensitive: key = item->text().lower(); break;
             case Size: key = makeSizeKey( item ); break;
             case Type: key = item->item()->mimetype(); break; // ### slows down listing :-(
-            default: ASSERT(0);
+            default: Q_ASSERT(0);
         }
 
         item->setKey( key );
 
-        //kdDebug() << "KonqKfmIconView::slotNewItems " << _fileitem->url().url() << " " << _fileitem->mimeTypePtr()->name() << endl;
-        if ( !_fileitem->isMimeTypeKnown() )
+        //kdDebug() << "KonqKfmIconView::slotNewItems " << (*it)->url().url() << " " << (*it)->mimeTypePtr()->name() << " mimetypeknown:" << (*it)->isMimeTypeKnown() << endl;
+        if ( !(*it)->isMimeTypeKnown() )
             m_mimeTypeResolver->m_lstPendingMimeIconItems.append( item );
 
-        m_itemDict.insert( _fileitem, item );
+        m_itemDict.insert( *it, item );
     }
     KonqDirPart::newItems( entries );
 }
 
 void KonqKfmIconView::slotDeleteItem( KFileItem * _fileitem )
 {
+    if ( _fileitem == m_dirLister->rootItem() )
+    {
+        m_pIconView->setRootItem( 0L );
+        return;
+    }
+
     KonqDirPart::deleteItem( _fileitem );
 
     //kdDebug(1202) << "KonqKfmIconView::slotDeleteItem(...)" << endl;
     // we need to find out the iconcontainer item containing the fileitem
     KFileIVI * ivi = m_itemDict[ _fileitem ];
-    ASSERT(ivi);
+    Q_ASSERT(ivi);
     if (ivi)
     {
         m_pIconView->takeItem( ivi );
@@ -716,20 +752,27 @@ void KonqKfmIconView::slotDeleteItem( KFileItem * _fileitem )
 // see also KDesktop::slotRefreshItems
 void KonqKfmIconView::slotRefreshItems( const KFileItemList& entries )
 {
+    bool bNeedRepaint = false;
     KFileItemListIterator rit(entries);
     for (; rit.current(); ++rit)
     {
         KFileIVI * ivi = m_itemDict[ rit.current() ];
-        ASSERT(ivi);
-        kdDebug() << "KonqKfmIconView::slotRefreshItems ivi=" << ivi << endl;
+        Q_ASSERT(ivi);
+        kdDebug() << "KonqKfmIconView::slotRefreshItems '" << rit.current()->name() << "' ivi=" << ivi << endl;
         if (ivi)
         {
+            QSize oldSize = ivi->pixmap()->size();
             ivi->refreshIcon( true );
             ivi->setText( rit.current()->text() );
+            if ( rit.current()->isMimeTypeKnown() )
+                ivi->setMouseOverAnimation( rit.current()->iconName() );
+            if ( !bNeedRepaint && oldSize != ivi->pixmap()->size() )
+                bNeedRepaint = true;
         }
     }
     // In case we replace a big icon with a small one, need to repaint.
-    m_pIconView->updateContents();
+    if ( bNeedRepaint )
+        m_pIconView->updateContents();
 }
 
 void KonqKfmIconView::slotClear()
@@ -738,6 +781,10 @@ void KonqKfmIconView::slotClear()
     m_pIconView->clear();
     m_mimeTypeResolver->m_lstPendingMimeIconItems.clear();
     m_itemDict.clear();
+    // Bug in QIconview IMHO - it should emit selectionChanged()
+    // (bug reported, but code seems to be that way on purpose)
+    m_pIconView->slotSelectionChanged();
+    slotSelectionChanged();
 }
 
 void KonqKfmIconView::slotRedirection( const KURL & url )
@@ -746,12 +793,6 @@ void KonqKfmIconView::slotRedirection( const KURL & url )
     m_url = url;
 }
 
-void KonqKfmIconView::slotCloseView()
-{
-    kdDebug() << "KonqKfmIconView::slotCloseView" << endl;
-    //delete this; // we need better support for this first
-}
-
 void KonqKfmIconView::slotSelectionChanged()
 {
     // Display statusbar info, and emit selectionInfo
@@ -761,15 +802,13 @@ void KonqKfmIconView::slotSelectionChanged()
 
 void KonqKfmIconView::determineIcon( KFileIVI * item )
 {
-  int oldSerial = item->pixmap()->serialNumber();
+  // kdDebug() << "KonqKfmIconView::determineIcon " << item->item()->name() << endl;
+  //int oldSerial = item->pixmap()->serialNumber();
 
   (void) item->item()->determineMimeType();
 
-  QPixmap newIcon = item->item()->pixmap( iconSize(),
-                                          item->state() );
-
-  if ( oldSerial != newIcon.serialNumber() )
-      item->setPixmap( newIcon );
+  item->setIcon( iconSize(), item->state(), true, true );
+  item->setMouseOverAnimation( item->item()->iconName() );
 }
 
 void KonqKfmIconView::mimeTypeDeterminationFinished()
@@ -795,7 +834,6 @@ void KonqKfmIconView::slotRenderingFinished()
         kdDebug(1202) << "KonqKfmIconView completed() after rendering" << endl;
         emit completed();
         m_bNeedEmitCompleted = false;
-        m_pIconView->setCurrentItem( m_pIconView->firstItem() ); // workaround for qiconview bug, says reggie ;-)
     }
     if ( m_bNeedAlign )
     {
@@ -805,41 +843,12 @@ void KonqKfmIconView::slotRenderingFinished()
     }
 }
 
-bool KonqKfmIconView::openURL( const KURL & url )
+bool KonqKfmIconView::doOpenURL( const KURL & url )
 {
-    beforeOpenURL(); // see KonqDirPart
-
-    if ( !m_dirLister )
-    {
-        // Create the directory lister
-        m_dirLister = new KonqDirLister( true );
-
-        QObject::connect( m_dirLister, SIGNAL( started( const QString & ) ),
-                          this, SLOT( slotStarted() ) );
-        QObject::connect( m_dirLister, SIGNAL( completed() ), this, SLOT( slotCompleted() ) );
-        QObject::connect( m_dirLister, SIGNAL( canceled() ), this, SLOT( slotCanceled() ) );
-        QObject::connect( m_dirLister, SIGNAL( clear() ), this, SLOT( slotClear() ) );
-        QObject::connect( m_dirLister, SIGNAL( newItems( const KFileItemList& ) ),
-                          this, SLOT( slotNewItems( const KFileItemList& ) ) );
-        QObject::connect( m_dirLister, SIGNAL( deleteItem( KFileItem * ) ),
-                          this, SLOT( slotDeleteItem( KFileItem * ) ) );
-        QObject::connect( m_dirLister, SIGNAL( refreshItems( const KFileItemList& ) ),
-                          this, SLOT( slotRefreshItems( const KFileItemList& ) ) );
-        QObject::connect( m_dirLister, SIGNAL( redirection( const KURL & ) ),
-                          this, SLOT( slotRedirection( const KURL & ) ) );
-        QObject::connect( m_dirLister, SIGNAL( closeView() ),
-                          this, SLOT( slotCloseView() ) );
-        QObject::connect( m_dirLister, SIGNAL( itemsFilteredByMime(const KFileItemList& ) ),
-                          SIGNAL( itemsFilteredByMime(const KFileItemList& ) ) );
-    }
-
-    m_bLoading = true;
-
     // Store url in the icon view
     m_pIconView->setURL( url );
 
-    // and in the part :-)
-    m_url = url;
+    m_bLoading = true;
 
     // Check for new properties in the new dir
     // newProps returns true the first time, and any time something might
@@ -850,7 +859,7 @@ bool KonqKfmIconView::openURL( const KURL & url )
 
     m_dirLister->setMimeFilter( mimeFilter() );
 
-    // This *must* happen before m_dirlister->openURL because it emits
+    // This *must* happen before m_dirLister->openURL because it emits
     // clear() and QIconView::clear() calls setContentsPos(0,0)!
     if ( m_extension->urlArgs().reload )
     {
@@ -858,8 +867,10 @@ bool KonqKfmIconView::openURL( const KURL & url )
         m_yOffset = m_pIconView->contentsY();
     }
 
+    m_dirLister->setShowingDotFiles( m_pProps->isShowingDotFiles() );
+
     // Start the directory lister !
-    m_dirLister->openURL( url, m_pProps->isShowingDotFiles() );
+    m_dirLister->openURL( url, false, m_extension->urlArgs().reload );
 
     m_bNeedAlign = false;
     m_bUpdateContentsPosAfterListing = true;
@@ -887,14 +898,12 @@ bool KonqKfmIconView::openURL( const KURL & url )
 
 void KonqKfmIconView::slotKFindOpened()
 {
-    if ( m_dirLister )
-        m_dirLister->setAutoUpdate( false );
+    m_dirLister->setAutoUpdate( false );
 }
 
 void KonqKfmIconView::slotKFindClosed()
 {
-    if ( m_dirLister )
-        m_dirLister->setAutoUpdate( true );
+    m_dirLister->setAutoUpdate( true );
 }
 
 void KonqKfmIconView::slotOnItem( QIconViewItem *item )
@@ -958,7 +967,7 @@ void KonqKfmIconView::setupSortKeys()
 
 QString KonqKfmIconView::makeSizeKey( KFileIVI *item )
 {
-    return QString::number( item->item()->size() ).rightJustify( 20, '0' );
+    return KIO::number( item->item()->size() ).rightJustify( 20, '0' );
 }
 
 void KonqKfmIconView::disableIcons( const KURL::List & lst )
