@@ -18,11 +18,12 @@
 
 #include "commands.h"
 #include "toplevel.h"
+#include <qregexp.h>
 #include <kbookmarkmanager.h>
 #include <kbookmarkimporter.h>
 #include <kdebug.h>
-#include <klistview.h>
 #include <klocale.h>
+#include <krfcdate.h>
 #include "kinsertionsort.h"
 
 void MoveCommand::execute()
@@ -30,21 +31,21 @@ void MoveCommand::execute()
     kdDebug() << "MoveCommand::execute moving from=" << m_from << " to=" << m_to << endl;
 
     // Look for m_from in the QDom tree
-    KBookmark bk = KBookmarkManager::self()->findByAddress( m_from );
-    ASSERT( !bk.isNull() );
-    //kdDebug() << "BEFORE:" << KBookmarkManager::self()->internalDocument().toString() << endl;
+    KBookmark bk = KEBTopLevel::bookmarkManager()->findByAddress( m_from );
+    Q_ASSERT( !bk.isNull() );
+    //kdDebug() << "BEFORE:" << KEBTopLevel::bookmarkManager()->internalDocument().toString() << endl;
     int posInOldParent = KBookmark::positionInParent( m_from );
-    KBookmark oldParent = KBookmarkManager::self()->findByAddress( KBookmark::parentAddress( m_from ) );
+    KBookmark oldParent = KEBTopLevel::bookmarkManager()->findByAddress( KBookmark::parentAddress( m_from ) );
     KBookmark oldPreviousSibling = posInOldParent == 0 ? KBookmark(QDomElement())
-                                   : KBookmarkManager::self()->findByAddress( KBookmark::previousAddress( m_from ) );
+                                   : KEBTopLevel::bookmarkManager()->findByAddress( KBookmark::previousAddress( m_from ) );
 
     // Look for m_to in the QDom tree (as parent address and position in parent)
     int posInNewParent = KBookmark::positionInParent( m_to );
     QString parentAddress = KBookmark::parentAddress( m_to );
     //kdDebug() << "MoveCommand::execute parentAddress=" << parentAddress << " posInNewParent=" << posInNewParent << endl;
-    KBookmark newParentBk = KBookmarkManager::self()->findByAddress( parentAddress );
-    ASSERT( !newParentBk.isNull() );
-    ASSERT( newParentBk.isGroup() );
+    KBookmark newParentBk = KEBTopLevel::bookmarkManager()->findByAddress( parentAddress );
+    Q_ASSERT( !newParentBk.isNull() );
+    Q_ASSERT( newParentBk.isGroup() );
 
     if ( posInNewParent == 0 ) // First child
     {
@@ -54,10 +55,10 @@ void MoveCommand::execute()
     {
         QString afterAddress = KBookmark::previousAddress( m_to );
         kdDebug() << "MoveCommand::execute afterAddress=" << afterAddress << endl;
-        KBookmark afterNow = KBookmarkManager::self()->findByAddress( afterAddress );
-        ASSERT(!afterNow.isNull());
+        KBookmark afterNow = KEBTopLevel::bookmarkManager()->findByAddress( afterAddress );
+        Q_ASSERT(!afterNow.isNull());
         bool result = newParentBk.toGroup().moveItem( bk, afterNow );
-        ASSERT(result);
+        Q_ASSERT(result);
         kdDebug() << "MoveCommand::execute after moving in the dom tree : item=" << bk.address() << endl;
     }
 
@@ -85,13 +86,16 @@ void MoveCommand::unexecute()
 
 void CreateCommand::execute()
 {
+
+    kdDebug() << "CreateCommand::execute-ing " << this << endl;
+
     // Gather some info
     QString parentAddress = KBookmark::parentAddress( m_to );
-    KBookmarkGroup parentGroup = KBookmarkManager::self()->findByAddress( parentAddress ).toGroup();
+    KBookmarkGroup parentGroup = KEBTopLevel::bookmarkManager()->findByAddress( parentAddress ).toGroup();
     QString previousSibling = KBookmark::previousAddress( m_to );
     //kdDebug() << "CreateCommand::execute previousSibling=" << previousSibling << endl;
     KBookmark prev = previousSibling.isEmpty() ? KBookmark(QDomElement())
-                     : KBookmarkManager::self()->findByAddress( previousSibling );
+                     : KEBTopLevel::bookmarkManager()->findByAddress( previousSibling );
 
     // Create
     KBookmark bk = KBookmark(QDomElement());
@@ -101,8 +105,8 @@ void CreateCommand::execute()
         else
             if (m_group)
             {
-                ASSERT( !m_text.isEmpty() );
-                bk = parentGroup.createNewFolder( m_text );
+                Q_ASSERT( !m_text.isEmpty() );
+                bk = parentGroup.createNewFolder( KEBTopLevel::bookmarkManager(), m_text, false );
 
                 kdDebug() << "CreateCommand::execute " << m_group << " open : " << m_open << endl;
                 bk.internalElement().setAttribute( "folded", m_open ? "no" : "yes" );
@@ -110,7 +114,7 @@ void CreateCommand::execute()
                     bk.internalElement().setAttribute( "icon",m_iconPath );
             }
             else
-                bk = parentGroup.addBookmark( m_text, m_url, m_iconPath);
+                bk = parentGroup.addBookmark( KEBTopLevel::bookmarkManager(), m_text, m_url, m_iconPath, false);
     else
         bk = m_originalBookmark;
 
@@ -122,15 +126,15 @@ void CreateCommand::execute()
         // Open the parent (useful if it was empty) - only for manual commands
         parentGroup.internalElement().setAttribute( "folded", "no" );
     }
-    ASSERT( bk.address() == m_to );
+    Q_ASSERT( bk.address() == m_to );
 }
 
 void CreateCommand::unexecute()
 {
     kdDebug() << "CreateCommand::unexecute deleting " << m_to << endl;
-    KBookmark bk = KBookmarkManager::self()->findByAddress( m_to );
-    ASSERT( !bk.isNull() );
-    ASSERT( !bk.parentGroup().isNull() );
+    KBookmark bk = KEBTopLevel::bookmarkManager()->findByAddress( m_to );
+    Q_ASSERT( !bk.isNull() );
+    Q_ASSERT( !bk.parentGroup().isNull() );
     // Update GUI
     // but first we need to select a valid item
     KListView * lv = KEBTopLevel::self()->listView();
@@ -165,8 +169,8 @@ void CreateCommand::unexecute()
 void DeleteCommand::execute()
 {
     kdDebug() << "DeleteCommand::execute " << m_from << endl;
-    KBookmark bk = KBookmarkManager::self()->findByAddress( m_from );
-    ASSERT(!bk.isNull());
+    KBookmark bk = KEBTopLevel::bookmarkManager()->findByAddress( m_from );
+    Q_ASSERT(!bk.isNull());
     if ( !m_cmd )
         if ( bk.isGroup() )
         {
@@ -210,8 +214,8 @@ KMacroCommand * DeleteCommand::deleteAll( const KBookmarkGroup & parentGroup )
 
 void EditCommand::execute()
 {
-    KBookmark bk = KBookmarkManager::self()->findByAddress( m_address );
-    ASSERT( !bk.isNull() );
+    KBookmark bk = KEBTopLevel::bookmarkManager()->findByAddress( m_address );
+    Q_ASSERT( !bk.isNull() );
     m_reverseEditions.clear();
     QValueList<Edition>::Iterator it = m_editions.begin();
     for ( ; it != m_editions.end() ; ++it )
@@ -234,11 +238,11 @@ void EditCommand::unexecute()
 
 void RenameCommand::execute()
 {
-    KBookmark bk = KBookmarkManager::self()->findByAddress( m_address );
-    ASSERT( !bk.isNull() );
+    KBookmark bk = KEBTopLevel::bookmarkManager()->findByAddress( m_address );
+    Q_ASSERT( !bk.isNull() );
 
     QDomNode titleNode = bk.internalElement().namedItem("title");
-    ASSERT( !titleNode.isNull() );
+    Q_ASSERT( !titleNode.isNull() );
     if ( titleNode.firstChild().isNull() ) // no text child yet
     {
         QDomText domtext = titleNode.ownerDocument().createTextNode( "" );
@@ -285,8 +289,8 @@ void SortCommand::execute()
 {
     if ( m_commands.isEmpty() )
     {
-        KBookmarkGroup grp = KBookmarkManager::self()->findByAddress( m_groupAddress ).toGroup();
-        ASSERT( !grp.isNull() );
+        KBookmarkGroup grp = KEBTopLevel::bookmarkManager()->findByAddress( m_groupAddress ).toGroup();
+        Q_ASSERT( !grp.isNull() );
         SortItem firstChild( grp.first() );
         // This will call moveAfter, which will add the subcommands for moving the items
         kInsertionSort<SortItem, SortByName, QString, SortCommand> ( firstChild, *this );
@@ -327,13 +331,13 @@ void ImportCommand::execute()
     {
         // Find or create "Netscape Bookmarks" toplevel item
         // Hmm, let's just create it. The user will clean up if he imports twice.
-        netscapeGroup = KBookmarkManager::self()->root().createNewFolder(m_folder);
+        netscapeGroup = KEBTopLevel::bookmarkManager()->root().createNewFolder(KEBTopLevel::bookmarkManager(),m_folder,false);
         netscapeGroup.internalElement().setAttribute("icon", m_icon);
         m_group = netscapeGroup.address();
     } else
     {
         // Import into the root, after cleaning it up
-        netscapeGroup = KBookmarkManager::self()->root();
+        netscapeGroup = KEBTopLevel::bookmarkManager()->root();
         delete m_cleanUpCmd;
         m_cleanUpCmd = DeleteCommand::deleteAll( netscapeGroup );
         // Unselect current item, it doesn't exist anymore
@@ -349,7 +353,7 @@ void ImportCommand::execute()
     connect( &importer, SIGNAL( newFolder( const QString &, bool, const QString & ) ),
              SLOT( newFolder( const QString &, bool, const QString & ) ) );
     connect( &importer, SIGNAL( newSeparator() ), SLOT( newSeparator() ) );
-    connect( &importer, SIGNAL( endMenu() ), SLOT( endMenu() ) );
+    connect( &importer, SIGNAL( endFolder() ), SLOT( endFolder() ) );
     importer.parseNSBookmarks( m_utf8 );
     // Save memory
     mlist.clear();
@@ -367,7 +371,7 @@ void ImportCommand::unexecute()
     else
     {
         // We imported at the root -> delete everything
-        KBookmarkGroup root = KBookmarkManager::self()->root();
+        KBookmarkGroup root = KEBTopLevel::bookmarkManager()->root();
         KCommand * cmd = DeleteCommand::deleteAll( root );
         // Unselect current item, it doesn't exist anymore
         KEBTopLevel::self()->listView()->clearSelection();
@@ -380,7 +384,7 @@ void ImportCommand::unexecute()
 
 void ImportCommand::newBookmark( const QString & text, const QCString & url, const QString & additionnalInfo )
 {
-    KBookmark bk = mstack.top()->addBookmark( text, QString::fromUtf8(url) );
+    KBookmark bk = mstack.top()->addBookmark( KEBTopLevel::bookmarkManager(), text, QString::fromUtf8(url), QString::null, false );
     // Store additionnal info
     bk.internalElement().setAttribute("netscapeinfo",additionnalInfo);
 }
@@ -388,7 +392,7 @@ void ImportCommand::newBookmark( const QString & text, const QCString & url, con
 void ImportCommand::newFolder( const QString & text, bool open, const QString & additionnalInfo )
 {
     // We use a qvaluelist so that we keep pointers to valid objects in the stack
-    mlist.append( mstack.top()->createNewFolder( text ) );
+    mlist.append( mstack.top()->createNewFolder( KEBTopLevel::bookmarkManager(), text,false ) );
     mstack.push( &(mlist.last()) );
     // Store additionnal info
     QDomElement element = mlist.last().internalElement();
@@ -401,9 +405,182 @@ void ImportCommand::newSeparator()
     mstack.top()->createNewSeparator();
 }
 
-void ImportCommand::endMenu()
+void ImportCommand::endFolder()
 {
     mstack.pop();
 }
 
+////////////////////////////////////////////////////////////////////////////
+//
+// TestLink
+////////////////////////////////////////////////////////////////////////////
+
+TestLink::TestLink(KBookmark  bk) : book(bk)
+{
+  connect( this, SIGNAL( deleteSelf(TestLink *)),
+	   KEBTopLevel::self(), SLOT(slotCancelTest(TestLink *)));
+  depth = 0;
+  Url( bk);
+}
+
+TestLink::~TestLink()
+{
+  if (job) {
+    kdDebug() << "JOB kill\n";
+    KEBListViewItem *p = KEBTopLevel::self()->findByAddress(book.address());
+    p->restoreStatus(oldStatus);
+    job->disconnect();
+    job->kill(false);
+  }
+}
+
+void TestLink::Url(KBookmark  bk)
+{
+  book = bk;
+  url = bk.url().url();
+  kdDebug() << "TestLink::Url " << url << " : " << book.address() << "\n";
+
+  KEBListViewItem *p = KEBTopLevel::self()->findByAddress(book.address());
+  if (p->firstChild()) {
+    doNext(p);
+  } else {
+
+    job = KIO::get(bk.url(), true, false);
+    connect( job, SIGNAL( result( KIO::Job *)),
+	     this, SLOT( finished(KIO::Job *)));
+    connect( job, SIGNAL( data( KIO::Job *,  const QByteArray &)),
+	     this, SLOT( read(KIO::Job *, const QByteArray &)));
+    job->addMetaData("errorPage", "true");
+
+    setTmpStatus(p, i18n("Checking....."));
+  }
+}
+
+void TestLink::setStatus(KEBListViewItem *p, QString status) {
+  p->nsPut(status);
+}
+
+void TestLink::setTmpStatus(KEBListViewItem *p, QString status) {
+  p->setTmpStatus(status, oldStatus);
+}
+
+void TestLink::setMod(KEBListViewItem *p, QString mod) {
+
+  time_t modt =  KRFCDate::parseDate(mod);
+  QString ms;
+  ms.setNum(modt);
+
+  p->nsPut(ms);
+}
+
+void TestLink::read(KIO::Job *j, const QByteArray &a)
+{
+  KEBListViewItem *p = KEBTopLevel::self()->findByAddress(book.address());
+  KIO::TransferJob *jb = (KIO::TransferJob *)j;
+
+  errSet = false;
+  QString s = a;
+
+  if (jb->isErrorPage()) {
+    QStringList list = QStringList::split('\n',s);
+    for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
+      int st = (*it).find("<title>", 0, false);
+      if (st >= 0) {
+	QString t = (*it).mid(st + 7);
+	int fn = t.findRev("</title>", -1, false);
+	if (fn >= 0) {
+	  t = t.left(fn);
+	}
+	setStatus(p, t);
+	errSet = true;
+	break;
+      }
+    }
+  } else {
+    QString s = jb->queryMetaData("modified");
+    if (!s.isEmpty()) {
+      setMod(p, s);
+    }
+  }
+  jb->kill(false);
+}
+
+
+void TestLink::finished(KIO::Job *j)
+{
+  job = 0;
+  KEBListViewItem *p = KEBTopLevel::self()->findByAddress( book.address());
+  KIO::TransferJob *jb = (KIO::TransferJob *)j;
+  QString mod = jb->queryMetaData("modified");
+
+  if (jb->error()) {
+    QString jerr = j->errorString();
+    if (!jerr.isEmpty()) {
+      jerr.replace( QRegExp("\n")," ");
+      //      kdDebug() << "MERR=" << jerr << "\n";
+      setStatus(p, jerr);
+    } else if (!mod.isEmpty()) {
+      setMod(p, mod);
+      //      kdDebug() << "MODE=" << mod <<"\n";
+    } else {
+      if (!errSet) {
+	//	kdDebug() << "Me==\n";
+	setMod(p, "0");
+      }
+    }
+  } else if (!mod.isEmpty()) {
+    setMod(p, mod);
+    //    kdDebug() << "MOD=" << mod <<"\n";
+  } else {
+    if (!errSet) {
+      //      kdDebug() << "M=\n";
+      setMod(p, "0");
+    }
+  }
+
+  p->modUpdate();
+
+  if (!doNext(p))
+    emit deleteSelf(this);
+}
+
+bool TestLink::doNext(KEBListViewItem *p)
+{
+  bool notFinished = false;
+
+  KEBListViewItem  * q;
+  if (p->firstChild ()) {
+    depth++;
+    q = (KEBListViewItem  *)p->firstChild ();
+    KBookmark bk = q->bookmark();
+    //    kdDebug() << "FC=" << depth << "\n";
+    Url(bk);
+    notFinished = true;
+  } else if (p->nextSibling()) {
+    if (depth > 0) {
+      q = (KEBListViewItem  *)p->nextSibling();
+      KBookmark bk = q->bookmark();
+      // kdDebug() << "NextD="<< depth << "\n";
+      Url(bk);
+    notFinished = true;
+    }
+  } else {
+  again:
+    depth--;
+    if (depth > 0) {
+      if (p->parent()->nextSibling()) {
+	q = (KEBListViewItem  *)p->parent()->nextSibling();
+	KBookmark bk = q->bookmark();
+	Url(bk);
+	notFinished = true;
+      } else {
+	p = (KEBListViewItem  *)p->parent();
+	goto again;
+      }
+    }
+  }
+  return notFinished;
+}
+
+
 #include "commands.moc"
