@@ -21,24 +21,22 @@
 
 #include <assert.h>
 
-#include <qlabel.h>
 #include <qapplication.h>
-#include <qdragobject.h>
-#include <qpopupmenu.h>
 #include <qwhatsthis.h>
+#include <qstyle.h>
 
 #include <kurldrag.h>
-#include <ktoolbar.h>
 #include <ktoolbarbutton.h>
-#include <kcombobox.h>
 #include <kanimwidget.h>
 #include <kdebug.h>
 #include <kstringhandler.h>
 
 #include <konq_pixmapprovider.h>
-#include "konq_view.h" // HistoryEntry
+#include "konq_view.h"
+#include <kiconloader.h>
+#include <kpopupmenu.h>
 
-template class QList<KonqHistoryEntry>;
+template class QPtrList<KonqHistoryEntry>;
 
 
 KonqComboAction::KonqComboAction( const QString& text, int accel, const QObject *receiver, const char *member,
@@ -101,7 +99,7 @@ void KonqComboAction::unplug( QWidget *w )
 /////////////////
 
 //static - used by KonqHistoryAction and KonqBidiHistoryAction
-void KonqBidiHistoryAction::fillHistoryPopup( const QList<HistoryEntry> &history,
+void KonqBidiHistoryAction::fillHistoryPopup( const QPtrList<HistoryEntry> &history,
                                           QPopupMenu * popup,
                                           bool onlyBack,
                                           bool onlyForward,
@@ -112,7 +110,7 @@ void KonqBidiHistoryAction::fillHistoryPopup( const QList<HistoryEntry> &history
 
   //kdDebug(1202) << "fillHistoryPopup position: " << history.at() << endl;
   HistoryEntry * current = history.current();
-  QListIterator<HistoryEntry> it( history );
+  QPtrListIterator<HistoryEntry> it( history );
   if (onlyBack || onlyForward)
   {
       it += history.at(); // Jump to current item
@@ -145,6 +143,7 @@ void KonqBidiHistoryAction::fillHistoryPopup( const QList<HistoryEntry> &history
 KonqBidiHistoryAction::KonqBidiHistoryAction ( const QString & text, QObject* parent, const char* name )
   : KAction( text, 0, parent, name )
 {
+  setShortcutConfigurable(false);
   m_firstIndex = 0;
   m_goMenu = 0L;
 }
@@ -169,7 +168,7 @@ int KonqBidiHistoryAction::plug( QWidget *widget, int index )
   return KAction::plug( widget, index );
 }
 
-void KonqBidiHistoryAction::fillGoMenu( const QList<HistoryEntry> & history )
+void KonqBidiHistoryAction::fillGoMenu( const QPtrList<HistoryEntry> & history )
 {
     if (history.isEmpty())
         return; // nothing to do
@@ -200,7 +199,7 @@ void KonqBidiHistoryAction::fillGoMenu( const QList<HistoryEntry> & history )
         if ( history.at() > (int)history.count() - 4 )
           m_startPos = history.count() - 1;
     }
-    ASSERT( m_startPos >= 0 && (uint)m_startPos < history.count() );
+    Q_ASSERT( m_startPos >= 0 && (uint)m_startPos < history.count() );
     if ( m_startPos < 0 || (uint)m_startPos >= history.count() )
     {
         kdWarning() << "m_startPos=" << m_startPos << " history.count()=" << history.count() << endl;
@@ -250,7 +249,7 @@ KonqLogoAction::KonqLogoAction( const QString& text, const QIconSet& pix,int acc
 KonqLogoAction::KonqLogoAction( const QStringList& icons, QObject* receiver,
                                 const char* slot, QObject* parent,
                                 const char* name )
-    : KAction( 0L, 0L, receiver, slot, parent, name ) // text missing !
+    : KAction( 0L, 0, receiver, slot, parent, name ) // text missing !
 {
   iconList = icons;
 }
@@ -321,12 +320,17 @@ int KonqLogoAction::plug( QWidget *widget, int index )
 ///////////
 
 
-class KonqDraggableLabel : public QLabel
+// Use a toolbutton instead of a label so it is styled correctly. (gallium)
+class KonqDraggableLabel : public QToolButton
 {
 public:
     KonqDraggableLabel( KonqMainWindow * mw, const QString & text, QWidget * parent = 0, const char * name = 0 )
-        : QLabel( text, parent, name ), m_mw(mw)
-    { validDrag = false; }
+        : QToolButton( parent, name ), m_mw(mw)
+    {
+	setText(text);
+        setAcceptDrops(true);
+        validDrag = false;
+    }
 protected:
     void mousePressEvent( QMouseEvent * ev )
     {
@@ -344,7 +348,7 @@ protected:
                 lst.append( m_mw->currentView()->url() );
                 QDragObject * drag = KURLDrag::newDrag( lst, m_mw );
                 drag->setPixmap( KMimeType::pixmapForURL( lst.first(), 0, KIcon::Small ) );
-                (void) drag->drag();
+                drag->dragCopy();
             }
         }
     }
@@ -352,14 +356,42 @@ protected:
     {
         validDrag = false;
     }
+    QSize sizeHint() const
+    {
+    	int w = fontMetrics().width( text() );
+	int h = fontMetrics().height();
+	return QSize( w, h );
+    }
+    void drawButton( QPainter * p )
+    {
+        // Draw the background
+        style().drawComplexControl( QStyle::CC_ToolButton, p, this, rect(), colorGroup(),
+                                    QStyle::Style_Enabled, QStyle::SC_ToolButton );
+        // Draw the label
+        style().drawControl( QStyle::CE_ToolButtonLabel, p, this, rect(), colorGroup(),
+                             QStyle::Style_Enabled );
+    }
+    void enterEvent( QEvent* ) {};
+    void leaveEvent( QEvent* ) {};
+    void dragEnterEvent( QDragEnterEvent *ev ) {
+        if ( QUriDrag::canDecode( ev ) )
+            ev->acceptAction();
+    }
+    void dropEvent( QDropEvent* ev ) {
+        KURL::List lst;
+        if ( KURLDrag::decode( ev, lst ) ) {
+            m_mw->openURL( 0L, lst.first() );
+        }
+    }
 private:
     QPoint startDragPos;
     bool validDrag;
     KonqMainWindow * m_mw;
 };
 
-KonqLabelAction::KonqLabelAction( const QString &text, QObject *parent, const char *name )
-    : KAction( text, 0, parent, name ), m_label( 0L )
+KonqLabelAction::KonqLabelAction( const QString &text, int accel,
+	            QObject* receiver, const char* slot, QObject *parent, const char *name )
+    : KAction( text, accel, receiver, slot, parent, name ), m_label( 0L )
 {
 }
 
@@ -374,8 +406,6 @@ int KonqLabelAction::plug( QWidget *widget, int index )
     int id = KAction::getToolButtonID();
 
     m_label = new KonqDraggableLabel( static_cast<KonqMainWindow *>(tb->mainWindow()), text(), widget );
-    m_label->setAlignment( Qt::AlignLeft | Qt::AlignVCenter | Qt::ShowPrefix );
-    m_label->adjustSize();
     tb->insertWidget( id, m_label->width(), m_label, index );
 
     addContainer( tb, id );
@@ -606,7 +636,7 @@ void KonqMostOftenURLSAction::slotClearMenu()
 
 void KonqMostOftenURLSAction::slotActivated( int id )
 {
-    ASSERT( s_mostEntries ); // can basically not happen
+    Q_ASSERT( s_mostEntries ); // can basically not happen
 
     const KonqHistoryEntry *entry = s_mostEntries->at( id );
     KURL url = entry ? entry->url : KURL();
@@ -617,8 +647,8 @@ void KonqMostOftenURLSAction::slotActivated( int id )
 }
 
 // sort by numberOfTimesVisited (least often goes first)
-int MostOftenList::compareItems( QCollection::Item item1,
-				 QCollection::Item item2)
+int MostOftenList::compareItems( QPtrCollection::Item item1,
+				 QPtrCollection::Item item2)
 {
     KonqHistoryEntry *entry1 = static_cast<KonqHistoryEntry *>( item1 );
     KonqHistoryEntry *entry2 = static_cast<KonqHistoryEntry *>( item2 );
