@@ -18,17 +18,18 @@
 */
 
 #ifndef __konq_actions_h__
-#define __konq_actions_h__ "$Id: konq_actions.h,v 1.34 2001/02/07 20:11:21 deller Exp $"
+#define __konq_actions_h__ "$Id: konq_actions.h,v 1.41 2002/02/28 11:45:00 faure Exp $"
 
 #include <qguardedptr.h>
+#include <konq_historymgr.h>
 
 #include <kaction.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class KBookmarkOwner;
 class KonqCombo;
 class HistoryEntry;
-class QLabel;
+class QToolButton;
 class QPopupMenu;
 
 class KonqComboAction : public KAction
@@ -68,10 +69,10 @@ public:
     virtual int plug( QWidget *widget, int index = -1 );
     //virtual void unplug( QWidget *widget );
 
-    void fillGoMenu( const QList<HistoryEntry> &history );
+    void fillGoMenu( const QPtrList<HistoryEntry> &history );
 
     // Used by KonqHistoryAction and KonqBidiHistoryAction
-    static void fillHistoryPopup( const QList<HistoryEntry> &history,
+    static void fillHistoryPopup( const QPtrList<HistoryEntry> &history,
                            QPopupMenu * popup,
                            bool onlyBack = false,
                            bool onlyForward = false,
@@ -122,13 +123,14 @@ class KonqLabelAction : public KAction
 {
   Q_OBJECT
 public:
-  KonqLabelAction( const QString &text, QObject *parent = 0, const char *name = 0 );
+  KonqLabelAction( const QString &text, int accel,
+	            QObject* receiver, const char* slot, QObject *parent = 0, const char *name = 0 );
 
   virtual int plug( QWidget *widget, int index = -1 );
   virtual void unplug( QWidget *widget );
-  QLabel * label() { return m_label; }
+  QToolButton * label() { return m_label; }
 private:
-  QLabel * m_label;
+  QToolButton * m_label;
 };
 
 class KonqViewModeAction : public KRadioAction
@@ -153,4 +155,53 @@ private:
     QPopupMenu *m_menu;
 };
 
+class MostOftenList : public KonqBaseHistoryList
+{
+protected:
+    /**
+     * Ensures that the items are sorted by numberOfTimesVisited
+     */
+    virtual int compareItems( QPtrCollection::Item, QPtrCollection::Item );
+};
+
+class KonqMostOftenURLSAction : public KActionMenu
+{
+    Q_OBJECT
+
+public:
+    KonqMostOftenURLSAction( const QString& text, QObject *parent,
+			     const char *name );
+    virtual ~KonqMostOftenURLSAction();
+
+signals:
+    void activated( const KURL& );
+
+private slots:
+    void slotHistoryCleared();
+    void slotEntryAdded( const KonqHistoryEntry *entry );
+    void slotEntryRemoved( const KonqHistoryEntry *entry );
+
+    void slotFillMenu();
+    void slotClearMenu();
+
+    void slotActivated( int );
+
+private:
+    void parseHistory();
+
+    static MostOftenList *s_mostEntries;
+    static uint s_maxEntries;
+    static bool s_bLocked;
+};
+
+class KonqGoURLAction : public KAction
+{
+public:
+    KonqGoURLAction( const QString &text, const QString &pix, int accel,
+                     const QObject *receiver, const char *slot,
+                     QObject *parent, const char *name );
+
+    virtual int plug( QWidget *widget, int index = -1 );
+};
+
 #endif
