@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kcompletionbox.h>
 #include <kdebug.h>
@@ -31,6 +31,7 @@
 #include "konq_combo.h"
 
 KConfig * KonqCombo::s_config = 0L;
+const int KonqCombo::temporary = 0;
 
 KonqCombo::KonqCombo( QWidget *parent, const char *name )
     : KHistoryCombo( parent, name ),
@@ -41,7 +42,7 @@ KonqCombo::KonqCombo( QWidget *parent, const char *name )
     setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ));
     setDuplicatesEnabled( false );
 
-    ASSERT( s_config );
+    Q_ASSERT( s_config );
 
     KConfigGroupSaver cs( s_config, "Location Bar" );
     setMaxCount( s_config->readNumEntry("Maximum of URLs in combo", 20 ));
@@ -268,6 +269,11 @@ bool KonqCombo::eventFilter( QObject *o, QEvent *ev )
                 return true;
             }
         }
+
+        else if ( type == QEvent::MouseButtonDblClick ) {
+            lineEdit()->selectAll();
+            return true;
+        }
     }
     return KComboBox::eventFilter( o, ev );
 }
@@ -311,16 +317,16 @@ void KonqCombo::selectWord(QKeyEvent *e)
                 break;
 	} while( pos >= 0 && (chars.findIndex(text[pos]) == -1 || count <= 1) );
 	if( e->state() & ShiftButton ) {
-            edit->cursorLeft(true, count-1);
+            edit->cursorForward(true, 1-count);
 	} else if(  e->key() == Key_Backspace ) {
-            edit->cursorLeft(false, count-1);
+            edit->cursorForward(false, 1-count);
             QString text = edit->text();
             int pos_to_right = edit->text().length() - pos_old;
             QString cut = text.left(edit->cursorPosition()) + text.right(pos_to_right);
             edit->setText(cut);
             edit->setCursorPosition(pos_old-count+1);
         } else {
-            edit->cursorLeft(false, count-1);
+            edit->cursorForward(false, 1-count);
         }
      } else if( e->key() == Key_Right || e->key() == Key_Delete ){
 	do {
@@ -328,11 +334,11 @@ void KonqCombo::selectWord(QKeyEvent *e)
 	    count++;
             if( allow_space_break && text[pos].isSpace() )
                 break;
-	} while( pos < text.length() && chars.findIndex(text[pos]) == -1 );
+	} while( pos < (int) text.length() && chars.findIndex(text[pos]) == -1 );
 	if( e->state() & ShiftButton ) {
-            edit->cursorRight(true, count+1);
+            edit->cursorForward(true, count+1);
 	} else if(  e->key() == Key_Delete ) {
-            edit->cursorLeft(false, count+1);
+            edit->cursorForward(false, -count-1);
             QString text = edit->text();
             int pos_to_right = text.length() - pos - 1;
 	    QString cut = text.left(pos_old) + 
@@ -340,7 +346,7 @@ void KonqCombo::selectWord(QKeyEvent *e)
             edit->setText(cut);
             edit->setCursorPosition(pos_old);
         } else {
-            edit->cursorRight(false, count+1);
+            edit->cursorForward(false, count+1);
         }
     }
 }
@@ -414,5 +420,4 @@ void KonqCombo::setConfig( KConfig *kc )
     s_config = kc;
 }
 
-
 #include "konq_combo.moc"
