@@ -24,6 +24,7 @@
 
 #include <kcombobox.h>
 
+class KCompletion;
 class KConfig;
 
 // we use KHistoryCombo _only_ for the up/down keyboard handling, otherwise
@@ -36,12 +37,16 @@ public:
     KonqCombo( QWidget *parent, const char *name );
     ~KonqCombo();
 
+    // initializes with the completion object and calls loadItems()
+    void init( KCompletion * );
+    
     // determines internally if it's temporary or final
     void setURL( const QString& url );
 
     void setTemporary( const QString& );
     void setTemporary( const QString&, const QPixmap& );
     void clearTemporary( bool makeCurrent = true );
+    void removeURL( const QString& url );
 
     void insertPermanent( const QString& );
 
@@ -54,9 +59,14 @@ public:
 
 protected:
     virtual void keyPressEvent( QKeyEvent * );
-    
+    virtual bool eventFilter( QObject *, QEvent * );
+    virtual void mousePressEvent( QMouseEvent * );
+    virtual void mouseMoveEvent( QMouseEvent * );
+    void selectWord(QKeyEvent *e);
+
 private slots:
     void slotReturnPressed();
+    void slotCleared();
 
 private:
     void updateItem( const QPixmap& pix, const QString&, int index );
@@ -71,9 +81,10 @@ private:
     int m_cursorPos;
     int m_currentIndex;
     QString m_currentText;
+    QPoint m_dragStart;
 
     static KConfig *s_config;
-    static const int temporary = 0; // the index of our temporary item
+    static const int temporary; // the index of our temporary item
 
 };
 
