@@ -19,33 +19,22 @@
 #include <math.h>
 
 #include <qpainter.h>
-#include <qimage.h>
-#include <qbitmap.h>
 #include <qlayout.h>
-#include <qsplitter.h>
 #include <qwhatsthis.h>
-#include <qtimer.h>
-#include <qpushbutton.h>
 #include <qtoolbutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
-#include <kconfig.h>
-#include <kiconloader.h>
-#include <kpixmap.h>
 #include <kprogress.h>
 #include <klocale.h>
-#include <kseparator.h>
-#include <kaction.h>
 
-#include <kparts/browserextension.h>
-#include <kparts/event.h>
 #include "konq_frame.h"
 #include "konq_view.h"
 #include "konq_viewmgr.h"
-#include "konq_mainwindow.h"
 
 #include <assert.h>
+#include <kiconloader.h>
+#include <qpopupmenu.h>
 
 #define DEFAULT_HEADER_HEIGHT 13
 
@@ -94,7 +83,7 @@ KonqFrameStatusBar::KonqFrameStatusBar( KonqFrame *_parent, const char *_name )
 
    connect(m_pLinkedViewCheckBox,SIGNAL(toggled(bool)),this,SIGNAL(linkedViewClicked(bool)));
 
-   m_progressBar = new KProgress( 0, 100, 0, KProgress::Horizontal, this );
+   m_progressBar = new KProgress( this );
    m_progressBar->hide();
   //m_statusBar->insertWidget( m_progressBar, 120, STATUSBAR_LOAD_ID );
 //   m_msgTimer = 0;
@@ -130,7 +119,7 @@ void KonqFrameStatusBar::splitFrameMenu()
 
    // We have to ship the remove view action ourselves,
    // since this may not be the active view (passive view)
-   KAction actRemoveView(i18n("Remove View"), 0, m_pParentKonqFrame, SLOT(slotRemoveView()), 0, "removethisview");
+   KAction actRemoveView(i18n("Remove View"), 0, m_pParentKonqFrame, SLOT(slotRemoveView()), (QObject*)0, "removethisview");
    //KonqView * nextView = mw->viewManager()->chooseNextView( m_pParentKonqFrame->childView() );
    actRemoveView.setEnabled( mw->mainViewsCount() > 1 || m_pParentKonqFrame->childView()->isToggleView() || m_pParentKonqFrame->childView()->isPassiveMode() );
 
@@ -272,8 +261,8 @@ void KonqFrameStatusBar::paintEvent(QPaintEvent* e)
    bool hasFocus = m_pParentKonqFrame->isActivePart();
    QPalette pal = palette();
 
-   QColor bg = kapp->palette().active().background();
-   pal.setColor( QColorGroup::Background,
+   QBrush bg = kapp->palette().active().brush ( QColorGroup::Background );
+   pal.setBrush( QColorGroup::Background,
                  m_showLed ? ( hasFocus ? kapp->palette().active().midlight()
                                : kapp->palette().active().mid() ) // active/inactive
                  : bg ); // only one view
@@ -387,7 +376,7 @@ KonqFrame::KonqFrame( KonqFrameContainer *_parentContainer, const char *_name )
 
 KonqFrame::~KonqFrame()
 {
-  kdDebug(1202) << "KonqFrame::~KonqFrame() " << this << endl;
+  //kdDebug(1202) << "KonqFrame::~KonqFrame() " << this << endl;
   //delete m_pLayout;
 }
 
@@ -442,7 +431,7 @@ KParts::ReadOnlyPart *KonqFrame::attach( const KonqViewFactory &viewFactory )
 
 void KonqFrame::attachInternal()
 {
-   kdDebug(1202) << "KonqFrame::attachInternal()" << endl;
+   //kdDebug(1202) << "KonqFrame::attachInternal()" << endl;
    if (m_pLayout) delete m_pLayout;
 
    m_pLayout = new QVBoxLayout( this, 0, -1, "KonqFrame's QVBoxLayout" );
@@ -551,7 +540,7 @@ KonqFrameContainer::KonqFrameContainer( Orientation o,
 
 KonqFrameContainer::~KonqFrameContainer()
 {
-    kdDebug(1202) << "KonqFrameContainer::~KonqFrameContainer() " << this << " - " << className() << endl;
+    //kdDebug(1202) << "KonqFrameContainer::~KonqFrameContainer() " << this << " - " << className() << endl;
 }
 
 void KonqFrameContainer::listViews( ChildViewList *viewList )
@@ -642,19 +631,19 @@ void KonqFrameContainer::swapChildren()
 
 void KonqFrameContainer::insertChildFrame( KonqFrameBase* frame )
 {
-  kdDebug(1202) << "KonqFrameContainer " << this << ": insertChildFrame " << frame << endl;
+  //kdDebug(1202) << "KonqFrameContainer " << this << ": insertChildFrame " << frame << endl;
 
   if (frame)
   {
       if( !m_pFirstChild )
       {
           m_pFirstChild = frame;
-          kdDebug(1202) << "Setting as first child" << endl;
+          //kdDebug(1202) << "Setting as first child" << endl;
       }
       else if( !m_pSecondChild )
       {
           m_pSecondChild = frame;
-          kdDebug(1202) << "Setting as second child" << endl;
+          //kdDebug(1202) << "Setting as second child" << endl;
       }
       else
         kdWarning(1202) << this << " already has two children..."
@@ -665,7 +654,7 @@ void KonqFrameContainer::insertChildFrame( KonqFrameBase* frame )
 
 void KonqFrameContainer::removeChildFrame( KonqFrameBase * frame )
 {
-  kdDebug(1202) << "KonqFrameContainer::RemoveChildFrame " << this << ". Child " << frame << " removed" << endl;
+  //kdDebug(1202) << "KonqFrameContainer::RemoveChildFrame " << this << ". Child " << frame << " removed" << endl;
   if( m_pFirstChild == frame )
     m_pFirstChild = 0L;
 
