@@ -33,7 +33,11 @@
 
 class QPixmap;
 class QVBoxLayout;
+class QHBoxLayout;
 class QTimer;
+class QPushButton;
+class QToolButton;
+
 class KonqView;
 class KonqFrameBase;
 class KonqFrame;
@@ -41,6 +45,7 @@ class KonqFrameContainer;
 class KConfig;
 class KSeparator;
 class KProgress;
+class KAction;
 
 namespace KParts
 {
@@ -124,7 +129,41 @@ class KonqFrameStatusBar : public QWidget
       QString m_savedMessage;
 };
 
-typedef QList<KonqView> ChildViewList;
+
+/**
+ * The KonqFrameHeader provides a title and button to remove the view.
+ */
+
+class KonqFrameHeader : public QWidget
+{
+  Q_OBJECT
+
+   public:
+      KonqFrameHeader( KonqFrame *_parent = 0L, const char *_name = 0L );
+      virtual ~KonqFrameHeader();
+      /**
+       * Connects an action to the button.
+       * @param inAction the KAction to connect.
+       */
+      virtual void setAction( KAction *inAction );
+      /**
+       * Sets the text on the header.
+       * @param text the text to display.
+       */
+      virtual void setText(const QString& text);
+    /**
+     * Used to pop up close menu on RMB click.
+     */
+      virtual bool eventFilter(QObject *obj, QEvent *ev);
+   protected:
+      virtual void showCloseMenu();
+      KonqFrame* m_pParentKonqFrame;
+      QLabel *m_pHeaderLabel;
+      QToolButton *m_pCloseButton;
+      QHBoxLayout *m_pLayout;
+};
+
+typedef QPtrList<KonqView> ChildViewList;
 
 class KonqFrameBase
 {
@@ -169,10 +208,16 @@ public:
 
   /**
    * Attach a view to the KonqFrame.
-   * @param view the view to attach (instead of the current one, if any)
+   * @param viewFactory the view to attach (instead of the current one, if any)
    */
   KParts::ReadOnlyPart *attach( const KonqViewFactory &viewFactory );
 
+  /**
+   * Filters the CTRL+Tab event from the views and emits ctrlTabPressed to
+   make KonqMainWindow switch to the next view
+   */
+  virtual bool eventFilter(QObject*obj,QEvent *ev);
+
   /**
    * Inserts the part's widget and the statusbar into the layout
    */
@@ -211,6 +256,7 @@ public:
   QVBoxLayout *layout() { return m_pLayout; }
 
   KonqFrameStatusBar *statusbar() const { return m_pStatusBar; }
+  KonqFrameHeader    *header() const { return m_pHeader; }
 
 public slots:
 
@@ -236,6 +282,7 @@ protected:
 
   KSeparator *m_separator;
   KonqFrameStatusBar* m_pStatusBar;
+  KonqFrameHeader *m_pHeader;
 };
 
 /**
@@ -250,7 +297,7 @@ protected:
 class KonqFrameContainer : public QSplitter, public KonqFrameBase
 {
   Q_OBJECT
-
+  friend class KonqFrame; //for emitting ctrlTabPressed() only, aleXXX
 public:
   KonqFrameContainer( Orientation o,
                       QWidget* parent,
@@ -288,6 +335,9 @@ public:
   //make this one public
   int idAfter( QWidget* w ){ return QSplitter::idAfter( w ); }
 
+signals:
+  void ctrlTabPressed();
+
 protected:
   KonqFrameBase* m_pFirstChild;
   KonqFrameBase* m_pSecondChild;
