@@ -17,19 +17,18 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <kaction.h>
-#include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmenubar.h>
 #include <konq_view.h>
-#include <konq_factory.h>
 #include <konq_frame.h>
 #include <konq_guiclients.h>
-#include <konq_mainwindow.h>
 #include <konq_viewmgr.h>
+#include <kiconloader.h>
 
-PopupMenuGUIClient::PopupMenuGUIClient( KonqMainWindow *mainWindow, const KTrader::OfferList &embeddingServices )
+PopupMenuGUIClient::PopupMenuGUIClient( KonqMainWindow *mainWindow,
+                                        const KTrader::OfferList &embeddingServices,
+                                        bool dirsSelected )
 {
   m_mainWindow = mainWindow;
 
@@ -81,7 +80,7 @@ PopupMenuGUIClient::PopupMenuGUIClient( KonqMainWindow *mainWindow, const KTrade
     menu.appendChild( subMenu );
     QDomElement text = m_doc.createElement( "text" );
     subMenu.appendChild( text );
-    text.appendChild( m_doc.createTextNode( i18n( "Preview in" ) ) );
+    text.appendChild( m_doc.createTextNode( i18n( "Preview In" ) ) );
     subMenu.setAttribute( "group", "preview" );
 
     bool inserted = false;
@@ -101,6 +100,18 @@ PopupMenuGUIClient::PopupMenuGUIClient( KonqMainWindow *mainWindow, const KTrade
       menu.removeChild( menu.namedItem( "menu" ) );
   }
 
+  KonqView *v = mainWindow->currentView();
+  if ( v && v->part() && v->part()->inherits( "KonqDirPart" ) && dirsSelected )
+  {
+      QDomElement separator = m_doc.createElement( "separator" );
+      separator.setAttribute( "group", "find" );
+      menu.appendChild( separator );
+      QDomElement findAction = m_doc.createElement( "action" );
+      findAction.setAttribute( "name", "findfile" );
+      findAction.setAttribute( "group", "find" );
+      menu.appendChild( findAction );
+  }
+
   setDOMDocument( m_doc );
 }
 
@@ -195,9 +206,9 @@ ToggleViewGUIClient::~ToggleViewGUIClient()
 {
 }
 
-QList<KAction> ToggleViewGUIClient::actions() const
+QPtrList<KAction> ToggleViewGUIClient::actions() const
 {
-  QList<KAction> res;
+  QPtrList<KAction> res;
 
   QDictIterator<KAction> it( m_actions );
   for (; it.current(); ++it )
@@ -234,11 +245,13 @@ void ToggleViewGUIClient::slotToggleView( bool toggle )
     KonqFrameContainer *newContainer = childView->frame()->parentContainer();
     newContainer->setSizes( newSplitterSizes );
 
+#if 0 // already done by splitWindow
     if ( m_mainWindow->currentView() )
     {
         QString locBarURL = m_mainWindow->currentView()->url().prettyURL(); // default one in case it doesn't set it
         childView->openURL( m_mainWindow->currentView()->url(), locBarURL );
     }
+#endif
 
     // If not passive, set as active :)
     if (!childView->isPassiveMode())
@@ -246,15 +259,17 @@ void ToggleViewGUIClient::slotToggleView( bool toggle )
 
     kdDebug() << "ToggleViewGUIClient::slotToggleView setToggleView(true) on " << childView << endl;
     childView->setToggleView( true );
+
     m_mainWindow->viewCountChanged();
+
   }
   else
   {
-    QList<KonqView> viewList;
+    QPtrList<KonqView> viewList;
 
     mainContainer->listViews( &viewList );
 
-    QListIterator<KonqView> it( viewList );
+    QPtrListIterator<KonqView> it( viewList );
     for (; it.current(); ++it )
       if ( it.current()->service()->desktopEntryName() == serviceName )
         // takes care of choosing the new active view, and also calls slotViewRemoved
@@ -291,6 +306,20 @@ void ToggleViewGUIClient::slotViewAdded( KonqView *view )
   {
     static_cast<KToggleAction *>( action )->setChecked( true );
     saveConfig( true, name );
+
+    // KonqView::isToggleView() is not set yet.. so just check for the orientation
+
+    QVariant vert = view->service()->property( "X-KDE-BrowserView-ToggableView-Orientation");
+    bool vertical = vert.toString().lower() == "vertical";
+    QVariant nohead = view->service()->property( "X-KDE-BrowserView-ToggableView-NoHeader");
+    bool noheader = nohead.isValid() ? nohead.toBool() : false;
+    // if it is a vertical toggle part, turn on the header.
+    // this works even when konq loads the view from a profile.
+    if ( vertical && (!noheader))
+    {
+        view->frame()->header()->setText(view->service()->name());
+        view->frame()->header()->setAction(action);
+    }
   }
 }
 
