@@ -25,7 +25,7 @@
 #include <qtimer.h>
 #include <qguardedptr.h>
 
-#include <konq_fileitem.h>
+#include <kfileitem.h>
 #include <konq_openurlrequest.h>
 
 #include <kparts/mainwindow.h>
@@ -34,7 +34,7 @@
 #include <kurlcompletion.h>
 #include <kglobalsettings.h>
 #include <dcopobject.h>
-#include <kxmlgui.h>
+#include <kxmlguifactory.h>
 #include <kxmlguiclient.h>
 #include <ktrader.h>
 
@@ -114,6 +114,9 @@ public:
 
   KonqViewManager *viewManager() const { return m_pViewManager; }
 
+  // Central widget of the mainwindow, never 0L
+  QWidget *mainWidget() const;
+
   virtual QWidget *createContainer( QWidget *parent, int index, const QDomElement &element, int &id );
   virtual void removeContainer( QWidget *container, QWidget *parent, QDomElement &element, int id );
 
@@ -150,6 +153,9 @@ public:
   KonqView *currentView() const { return m_currentView; }
   KParts::ReadOnlyPart *currentPart() const;
 
+  /** URL of current part, or URLs of selected items for directory views */
+  KURL::List currentURLs() const;
+
   // Only valid if there are one or two views
   KonqView * otherView( KonqView * view ) const;
 
@@ -202,9 +208,11 @@ public:
    */
   bool isHTMLAllowed() const { return m_bHTMLAllowed; }
 
+  bool isBackRightClickEnabled() const { return m_bBackRightClick; }
+
   bool saveViewPropertiesLocally() const { return m_bSaveViewPropertiesLocally; }
 
-  static QList<KonqMainWindow> *mainWindowList() { return s_lstViews; }
+  static QPtrList<KonqMainWindow> *mainWindowList() { return s_lstViews; }
 
   // public for konq_guiclients
   void viewCountChanged();
@@ -217,6 +225,8 @@ public:
   static void comboAction( int action, const QString& url,
 			   const QCString& objId );
 
+  void setShowHTML( bool );
+
 signals:
   void viewAdded( KonqView *view );
   void viewRemoved( KonqView *view );
@@ -303,6 +313,7 @@ protected slots:
   void slotURLEntered( const QString &text );
 
   void slotFileNewAboutToShow();
+  void slotLocationLabelActivated();
 
   void slotSplitViewHorizontal();
   void slotSplitViewVertical();
@@ -336,6 +347,7 @@ protected slots:
   void slotComboPlugged();
   void slotCompletionModeChanged( KGlobalSettings::Completion );
   void slotMakeCompletion( const QString& );
+  void slotSubstringcompletion( const QString& );
   void slotRotation( KCompletionBase::KeyBindingType );
   void slotMatch( const QString& );
 
@@ -370,7 +382,7 @@ protected:
 
   virtual bool eventFilter(QObject*obj,QEvent *ev);
 
-  void fillHistoryPopup( QPopupMenu *menu, const QList<HistoryEntry> &history );
+  void fillHistoryPopup( QPopupMenu *menu, const QPtrList<HistoryEntry> &history );
 
   bool makeViewsFollow( const KURL & url, const KParts::URLArgs &args, const QString & serviceType,
                         KonqView * senderView );
@@ -396,6 +408,8 @@ private slots:
    */
   void goURL();
 
+  void bookmarksIntoCompletion();
+
 private:
   /**
    * takes care of hiding the bookmarkbar and calling setChecked( false ) on the
@@ -406,7 +420,15 @@ private:
   /**
    * Adds all children of @p group to the static completion object
    */
-  void bookmarksIntoCompletion( const KBookmarkGroup& group );
+  static void bookmarksIntoCompletion( const KBookmarkGroup& group );
+
+  /**
+   * Returns all matches of the url-history for @p s. If there are no direct
+   * matches, it will try completing with http:// prepended, and if there's
+   * still no match, then http://www. Due to that, this is only usable for
+   * popupcompletion and not for manual or auto-completion.
+   */
+  static QStringList historyPopupCompletionItems( const QString& s = QString::null);
 
   void startAnimation();
   void stopAnimation();
@@ -491,10 +513,6 @@ private:
 
   KAction *m_ptaFullScreen;
 
-  uint m_bCutWasEnabled:1;
-  uint m_bCopyWasEnabled:1;
-  uint m_bPasteWasEnabled:1;
-  uint m_bDeleteWasEnabled:1;
   uint m_bLocationBarConnected:1;
   uint m_bURLEnterLock:1;
   uint m_bFullScreen:1;
@@ -510,10 +528,11 @@ private:
 
   MapViews m_mapViews;
 
-  KonqView *m_currentView;
+  QGuardedPtr<KonqView> m_currentView;
 
   KBookmarkMenu* m_pBookmarkMenu;
-  KActionCollection*  m_bookmarksActionCollection;
+  KActionCollection* m_bookmarksActionCollection;
+  KActionCollection* m_bookmarkBarActionCollection;
 
   KonqViewManager *m_pViewManager;
 
@@ -538,11 +557,11 @@ private:
 
   QString m_sViewModeForDirectory; // is actually the name of the service
 
-  QList<KAction> m_openWithActions;
+  QPtrList<KAction> m_openWithActions;
   KActionMenu *m_viewModeMenu;
-  QList<KAction> m_toolBarViewModeActions; // basically holds two KonqViewActions, one of
+  QPtrList<KAction> m_toolBarViewModeActions; // basically holds two KonqViewActions, one of
                                            // iconview and one for listview
-  QList<KAction> m_viewModeActions;
+  QPtrList<KAction> m_viewModeActions;
   QMap<QString,KService::Ptr> m_viewModeToolBarServices; // similar to m_toolBarViewModeActions
   // it holds a map library name (libkonqiconview/libkonqlistview) ==> service (service for
   // iconview, multicolumnview, treeview, etc .)
@@ -551,11 +570,13 @@ private:
 
   static QStringList *s_plstAnimatedLogo;
 
-  static QList<KonqMainWindow> *s_lstViews;
-
+  static QPtrList<KonqMainWindow> *s_lstViews;
+    
   QString m_currentDir; // stores current dir for relative URLs whenever applicable
 
   bool m_urlCompletionStarted;
+
+  bool m_bBackRightClick;
 };
 
 #endif
