@@ -24,8 +24,7 @@
 #include <kmessagebox.h>
 #include <kurifilter.h>
 #include <klocale.h>
-#include <kstddirs.h>
-#include <kglobal.h>
+#include <kstandarddirs.h>
 #include <kwin.h>
 #include <kprotocolinfo.h>
 #include <qdir.h>
@@ -39,11 +38,11 @@
 // Terminates fullscreen-mode for any full-screen window on the current desktop
 void KonqMisc::abortFullScreenMode()
 {
-  QList<KonqMainWindow> *mainWindows = KonqMainWindow::mainWindowList();
+  QPtrList<KonqMainWindow> *mainWindows = KonqMainWindow::mainWindowList();
   if ( mainWindows )
   {
     int currentDesktop = KWin::currentDesktop();
-    QListIterator<KonqMainWindow> it( *mainWindows );
+    QPtrListIterator<KonqMainWindow> it( *mainWindows );
     for (; it.current(); ++it )
     {
       if ( it.current()->fullScreenMode() )
@@ -70,22 +69,21 @@ KonqMainWindow * KonqMisc::createSimpleWindow( const KURL & _url, const QString
   return win;
 }
 
-KonqMainWindow * KonqMisc::createNewWindow( const KURL &url, const KParts::URLArgs &args )
+KonqMainWindow * KonqMisc::createNewWindow( const KURL &url, const KParts::URLArgs &args, bool forbidUseHTML )
 {
   kdDebug() << "KonqMisc::createNewWindow url=" << url.url() << endl;
 
   // For HTTP or html files, use the web browsing profile, otherwise use filemanager profile
   QString profileName = (!(KProtocolInfo::supportsListing(url)) ||
-                        url.path().right(5) == ".html" ||
-			url.path().right(4) == ".htm" )
+                        KMimeType::findByURL(url)->name() == "text/html")
           ? "webbrowsing" : "filemanagement";
 
   QString profile = locate( "data", QString::fromLatin1("konqueror/profiles/") + profileName );
-  return createBrowserWindowFromProfile( profile, profileName, url, args );
+  return createBrowserWindowFromProfile( profile, profileName, url, args, forbidUseHTML );
 }
 
 
-KonqMainWindow * KonqMisc::createBrowserWindowFromProfile( const QString &path, const QString &filename, const KURL &url, const KParts::URLArgs &args )
+KonqMainWindow * KonqMisc::createBrowserWindowFromProfile( const QString &path, const QString &filename, const KURL &url, const KParts::URLArgs &args, bool forbidUseHTML )
 {
   kdDebug(1202) << "void KonqMisc::createBrowserWindowFromProfile() " << endl;
   kdDebug(1202) << "path=" << path << ",filename=" << filename << ",url=" << url.prettyURL() << endl;
@@ -96,10 +94,14 @@ KonqMainWindow * KonqMisc::createBrowserWindowFromProfile( const QString &path,
   {
       // The profile doesn't exit -> creating a simple window
       mainWindow = createSimpleWindow( url, args.frameName );
+      if ( forbidUseHTML )
+          mainWindow->setShowHTML( false );
   }
   else
   {
       mainWindow = new KonqMainWindow( KURL(), false );
+      if ( forbidUseHTML )
+          mainWindow->setShowHTML( false );
       //FIXME: obey args (like passing post-data (to KRun), etc.)
       KonqOpenURLRequest req;
       req.args = args;
