@@ -17,34 +17,34 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <qfile.h>
 
 #include "konq_view.h"
 #include "KonqViewIface.h"
-#include "konq_factory.h"
 #include "konq_frame.h"
-#include "konq_mainwindow.h"
-#include "konq_propsview.h"
 #include "konq_run.h"
 #include "konq_events.h"
 #include "konq_viewmgr.h"
-#include <kio/job.h>
+#include "konq_browseriface.h"
 
 #include <konq_historymgr.h>
 #include <konq_pixmapprovider.h>
 
 #include <assert.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <kcursor.h>
 #include <kurldrag.h>
+#include <qscrollview.h>
 
 #include <qapplication.h>
 #include <qmetaobject.h>
 #include <qobjectlist.h>
+#include <config.h>
+#if QT_VERSION >= 300
+#include <private/qucomextra_p.h>
+#endif
 
-#include <kparts/factory.h>
 
-template class QList<HistoryEntry>;
+template class QPtrList<HistoryEntry>;
 
 KonqView::KonqView( KonqViewFactory &viewFactory,
                     KonqFrame* viewFrame,
@@ -79,6 +79,10 @@ KonqView::KonqView( KonqViewFactory &viewFactory,
   m_bLinkedView = false;
   m_bAborted = false;
   m_bToggleView = false;
+  m_bGotIconURL = false;
+  m_bPopupMenuEnabled = true;
+  m_browserIface = new KonqBrowserInterface( this, "browseriface" );
+  m_bBackRightClick = m_pMainWindow->isBackRightClickEnabled();
 
   switchView( viewFactory );
 }
@@ -101,6 +105,14 @@ void KonqView::openURL( const KURL &url, const QString & locationBarURL, const Q
   kdDebug(1202) << "KonqView::openURL url=" << url.url() << " locationBarURL=" << locationBarURL << endl;
   setServiceTypeInExtension();
 
+  KParts::BrowserExtension *ext = browserExtension();
+  KParts::URLArgs args;
+  if ( ext )
+    args = ext->urlArgs();
+
+  if ( args.lockHistory() )
+    lockHistory();
+
   if ( !m_bLockHistory )
   {
     // Store this new URL in the history, removing any existing forward history.
@@ -112,11 +124,6 @@ void KonqView::openURL( const KURL &url, const QString & locationBarURL, const Q
   callExtensionStringMethod( "setNameFilter(QString)", nameFilter );
   setLocationBarURL( locationBarURL );
 
-  KParts::BrowserExtension *ext = browserExtension();
-  KParts::URLArgs args;
-  if ( ext )
-    args = ext->urlArgs();
-
   if ( m_bAborted && m_pPart && m_pPart->url() == url )
   {
     args.reload = true;
@@ -149,6 +156,7 @@ void KonqView::switchView( KonqViewFactory &viewFactory )
   // Activate the new part
   if ( oldPart )
   {
+    m_pPart->setName( oldPart->name() );
     emit sigPartChanged( this, oldPart, m_pPart );
     delete oldPart;
   }
@@ -161,7 +169,7 @@ void KonqView::switchView( KonqViewFactory &viewFactory )
     QVariant prop = m_service->property( "X-KDE-BrowserView-PassiveMode");
     if ( prop.isValid() && prop.toBool() )
     {
-      kdDebug() << "KonqView::switchView X-KDE-BrowserView-PassiveMode -> setPassiveMode" << endl;
+      kdDebug(1202) << "KonqView::switchView X-KDE-BrowserView-PassiveMode -> setPassiveMode" << endl;
       setPassiveMode( true ); // set as passive
     }
 
@@ -229,10 +237,10 @@ bool KonqView::changeViewMode( const QString &serviceType,
     kdDebug(1202) << "Giving focus to new part " << m_pPart << endl;
     m_pMainWindow->viewManager()->setActivePart( m_pPart );
   }
-  else
+  else if ( m_serviceType != serviceType )
   {
       m_serviceType = serviceType;
-      kdDebug() << "KonqView::changeViewMode service type set to " << m_serviceType << endl;
+      kdDebug(1202) << "KonqView::changeViewMode service type set to " << m_serviceType << endl;
       // Re-query the trader
       KonqFactory::getOffers( m_serviceType, &m_partServiceOffers, &m_appServiceOffers );
       if ( m_pMainWindow->currentView() == this )
@@ -250,28 +258,26 @@ void KonqView::connectPart(  )
            this, SLOT( slotCompleted() ) );
   connect( m_pPart, SIGNAL( completed(bool) ),
            this, SLOT( slotCompleted(bool) ) );
-   connect( m_pPart, SIGNAL( canceled( const QString & ) ),
+  connect( m_pPart, SIGNAL( canceled( const QString & ) ),
            this, SLOT( slotCanceled( const QString & ) ) );
+  connect( m_pPart, SIGNAL( setWindowCaption( const QString & ) ),
+           this, SLOT( setCaption( const QString & ) ) );
 
   KParts::BrowserExtension *ext = browserExtension();
 
   if ( !ext )
     return;
 
+  ext->setBrowserInterface( m_browserIface );
+
   connect( ext, SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs &) ),
            m_pMainWindow, SLOT( slotOpenURLRequest( const KURL &, const KParts::URLArgs & ) ) );
 
-  connect( ext, SIGNAL( popupMenu( const QPoint &, const KFileItemList & ) ),
-           m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KFileItemList & ) ) );
-
-  connect( ext, SIGNAL( popupMenu( const QPoint &, const KURL &, const QString &, mode_t ) ),
-           m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KURL &, const QString &, mode_t ) ) );
-
-  connect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ),
-           m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ) );
-
-  connect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KURL &, const QString &, mode_t ) ),
-           m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KURL &, const QString &, mode_t ) ) );
+  if ( m_bPopupMenuEnabled )
+  {
+    m_bPopupMenuEnabled = false; // force
+    enablePopupMenu( true );
+  }
 
   connect( ext, SIGNAL( setLocationBarURL( const QString & ) ),
            this, SLOT( setLocationBarURL( const QString & ) ) );
@@ -319,6 +325,10 @@ void KonqView::connectPart(  )
   if ( urlDropHandling.type() == QVariant::Bool &&
        urlDropHandling.toBool() )
       m_pPart->widget()->installEventFilter( this );
+  if (m_bBackRightClick && m_pPart->widget()->inherits("QScrollView") )
+  {
+    (static_cast<QScrollView *>(m_pPart->widget()))->viewport()->installEventFilter( this );
+  }
 
   // KonqDirPart signal
   if ( m_pPart->inherits("KonqDirPart") )
@@ -339,7 +349,8 @@ void KonqView::slotEnableAction( const char * name, bool enabled )
 void KonqView::slotStarted( KIO::Job * job )
 {
   //kdDebug(1202) << "KonqView::slotStarted"  << job << endl;
-  m_bLoading = true;
+  setLoading( true );
+  frame()->unsetCursor();
 
   if ( m_pMainWindow->currentView() == this )
     m_pMainWindow->updateToolBarActions();
@@ -352,6 +363,18 @@ void KonqView::slotStarted( KIO::Job * job )
   }
 }
 
+void KonqView::setLoading( bool b )
+{
+    if( b )
+    {
+        if( !m_bLoading )
+            frame()->setCursor( KCursor::workingCursor());
+    }
+    else
+        frame()->unsetCursor();
+    m_bLoading = b;
+}
+
 void KonqView::slotPercent( KIO::Job *, unsigned long percent )
 {
   m_pKonqFrame->statusbar()->slotLoadingProgress( percent );
@@ -375,7 +398,7 @@ void KonqView::slotCompleted()
 void KonqView::slotCompleted( bool hasPending )
 {
   kdDebug(1202) << "KonqView::slotCompleted" << endl;
-  m_bLoading = false;
+  setLoading( false );
   m_pKonqFrame->statusbar()->slotLoadingProgress( -1 );
 
   if ( m_pMainWindow->currentView() == this )
@@ -388,13 +411,26 @@ void KonqView::slotCompleted( bool hasPending )
 
       if ( m_bAborted ) // remove the pending entry on error
           KonqHistoryManager::kself()->removePending( url() );
-      else // register as proper history entry
+      else if ( m_lstHistory.current() ) // register as proper history entry
           KonqHistoryManager::kself()->confirmPending(url(), typedURL(),
 						      m_lstHistory.current()->title);
 
       emit viewCompleted( this );
   }
   m_bLoading = hasPending;
+
+  if (!m_bGotIconURL && !m_bAborted)
+  {
+    KConfig *config = KGlobal::config();
+    config->setGroup( "HTML Settings" );
+
+    if ( config->readBoolEntry( "EnableFavicon", true ) == true )
+    {
+      // Try to get /favicon.ico
+      if ( m_serviceType == "text/html" && url().protocol().left(4) == "http" )
+      KonqPixmapProvider::self()->downloadHostIcon( url() );
+    }
+  }
 }
 
 void KonqView::slotCanceled( const QString & errorMsg )
@@ -428,6 +464,7 @@ void KonqView::setLocationBarURL( const QString & locationBarURL )
 void KonqView::setIconURL( const KURL & iconURL )
 {
   KonqPixmapProvider::self()->setIconForURL( m_sLocationBarURL, iconURL );
+  m_bGotIconURL = true;
 }
 
 void KonqView::slotOpenURLNotify()
@@ -450,6 +487,11 @@ void KonqView::createHistoryEntry()
         {
             if ( !m_lstHistory.removeLast() ) // and remove from the end (faster and easier)
                 assert(0);
+            // go to last one. The documentation says that removeLast()
+            // makes current() null if it's the last item. however in qt2
+            // the behaviour was different than the documentation. this is
+            // changed in qt3 to behave as documented ;-) (Simon)
+            m_lstHistory.at( m_lstHistory.count() - 1 );
         }
         // Now current is the current again.
     }
@@ -462,16 +504,11 @@ void KonqView::createHistoryEntry()
 
 void KonqView::updateHistoryEntry( bool saveLocationBarURL )
 {
-  ASSERT( !m_bLockHistory ); // should never happen
+  Q_ASSERT( !m_bLockHistory ); // should never happen
 
   HistoryEntry * current = m_lstHistory.current();
-  assert( current ); // let's see if this happens
-  if ( current == 0L) // empty history
-  {
-    kdWarning(1202) << "Creating item because history is empty !" << endl;
-    current = new HistoryEntry;
-    m_lstHistory.append( current );
-  }
+  if ( !current )
+    return;
 
   if ( browserExtension() )
   {
@@ -494,8 +531,25 @@ void KonqView::updateHistoryEntry( bool saveLocationBarURL )
   current->strServiceName = m_service->desktopEntryName();
 }
 
+void KonqView::goHistory( int steps )
+{
+  // This is called by KonqBrowserInterface
+  if ( m_pMainWindow->currentView() == this )
+    m_pMainWindow->viewManager()->setActivePart( part() );
+
+  // Delay the go() call (we need to return to the caller first)
+  m_pMainWindow->slotGoHistoryActivated( steps );
+}
+
 void KonqView::go( int steps )
 {
+  if ( !steps ) // [WildFox] i bet there are sites on the net with stupid devs who do that :)
+  {
+      // [David] and you're right. And they expect that it reloads, apparently.
+      m_pMainWindow->slotReload();
+      return;
+  }
+
   stop();
 
   int newPos = m_lstHistory.at() + steps;
@@ -503,7 +557,9 @@ void KonqView::go( int steps )
                 << " newPos=" << newPos
                 << " m_lstHistory.count()=" << m_lstHistory.count()
                 << endl; */
-  assert( newPos >= 0 && (uint)newPos < m_lstHistory.count() );
+  if( newPos < 0 || (uint)newPos >= m_lstHistory.count() )
+    return;
+
   // Yay, we can move there without a loop !
   HistoryEntry *currentHistoryEntry = m_lstHistory.at( newPos ); // sets current item
 
@@ -551,17 +607,27 @@ void KonqView::copyHistory( KonqView *other )
 {
     m_lstHistory.clear();
 
-    QListIterator<HistoryEntry> it( other->m_lstHistory );
+    QPtrListIterator<HistoryEntry> it( other->m_lstHistory );
     for (; it.current(); ++it )
         m_lstHistory.append( new HistoryEntry( *it.current() ) );
 }
 
-KURL KonqView::url()
+KURL KonqView::url() const
 {
   assert( m_pPart );
   return m_pPart->url();
 }
 
+KURL KonqView::upURL() const
+{
+    KURL currentURL;
+    if ( m_pRun )
+	currentURL = m_pRun->url();
+    else
+	currentURL = m_sLocationBarURL;
+    return currentURL.upURL();
+}
+
 void KonqView::setRun( KonqRun * run )
 {
   if ( m_pRun )
@@ -583,7 +649,7 @@ void KonqView::stop()
     m_pPart->closeURL();
     m_bAborted = true;
     m_pKonqFrame->statusbar()->slotLoadingProgress( -1 );
-    m_bLoading = false;
+    setLoading( false );
   }
   if ( m_pRun )
   {
@@ -600,25 +666,6 @@ void KonqView::stop()
     updateHistoryEntry(true);
 }
 
-void KonqView::reload()
-{
-  //lockHistory();
-  if ( browserExtension() )
-  {
-    KParts::URLArgs args(true, browserExtension()->xOffset(), browserExtension()->yOffset());
-    args.serviceType = m_serviceType;
-    browserExtension()->setURLArgs( args );
-  }
-
-  // Happens with default webbrowsing profile
-  if ( m_pPart->url().isEmpty() )
-      return;
-
-  // Re-set the location bar URL (in case it was manually edited)
-  setLocationBarURL( m_sLocationBarURL );
-  m_pPart->openURL( m_pPart->url() );
-}
-
 void KonqView::setPassiveMode( bool mode )
 {
   // In theory, if m_bPassiveMode is true and mode is false,
@@ -656,16 +703,7 @@ void KonqView::sendOpenURLEvent( const KURL &url, const KParts::URLArgs &args )
 
   // We also do here what we want to do after opening an URL, whether a new one
   // or one from the history (common stuff).
-
-  KConfig *config = KGlobal::config();
-  config->setGroup( "HTML Settings" );
-
-  if ( config->readBoolEntry( "EnableFavicon", true ) == true )
-  {
-    // Try to get /favicon.ico
-    if ( m_serviceType == "text/html" && url.protocol().left(4) == "http" )
-      KonqPixmapProvider::self()->downloadHostIcon( url );
-  }
+  m_bGotIconURL = false;
 }
 
 void KonqView::setServiceTypeInExtension()
@@ -695,8 +733,8 @@ QStringList KonqView::childFrameNames( KParts::ReadOnlyPart *part )
 
   res += hostExtension->frameNames();
 
-  const QList<KParts::ReadOnlyPart> children = hostExtension->frames();
-  QListIterator<KParts::ReadOnlyPart> it( children );
+  const QPtrList<KParts::ReadOnlyPart> children = hostExtension->frames();
+  QPtrListIterator<KParts::ReadOnlyPart> it( children );
   for (; it.current(); ++it )
     res += childFrameNames( it.current() );
 
@@ -713,8 +751,8 @@ KParts::BrowserHostExtension* KonqView::hostExtension( KParts::ReadOnlyPart *par
   if ( ext->frameNames().contains( name ) )
     return ext;
 
-  const QList<KParts::ReadOnlyPart> children = ext->frames();
-  QListIterator<KParts::ReadOnlyPart> it( children );
+  const QPtrList<KParts::ReadOnlyPart> children = ext->frames();
+  QPtrListIterator<KParts::ReadOnlyPart> it( children );
   for (; it.current(); ++it )
   {
     KParts::BrowserHostExtension *childHost = hostExtension( it.current(), name );
@@ -732,6 +770,7 @@ bool KonqView::callExtensionMethod( const char *methodName )
   if ( !obj )
     return false;
 
+#if QT_VERSION < 300
   QMetaData * mdata = obj->metaObject()->slot( methodName );
   if( mdata )
   {
@@ -739,6 +778,15 @@ bool KonqView::callExtensionMethod( const char *methodName )
     return true;
   };
   return false;
+#else
+  int id = obj->metaObject()->findSlot( methodName );
+  if ( id == -1 )
+    return false;
+  QUObject o[ 1 ];
+
+  obj->qt_invoke( id, o );
+  return true;
+#endif
 }
 
 bool KonqView::callExtensionBoolMethod( const char *methodName, bool value )
@@ -748,6 +796,7 @@ bool KonqView::callExtensionBoolMethod( const char *methodName, bool value )
   if ( !obj )
     return false;
 
+#if QT_VERSION < 300
   typedef void (QObject::*BoolMethod)(bool);
   QMetaData * mdata = obj->metaObject()->slot( methodName );
   if( mdata )
@@ -756,6 +805,17 @@ bool KonqView::callExtensionBoolMethod( const char *methodName, bool value )
     return true;
   };
   return false;
+#else
+  int id = obj->metaObject()->findSlot( methodName );
+  if ( id == -1 )
+    return false;
+  QUObject o[ 2 ];
+
+  static_QUType_bool.set( o + 1, value );
+
+  obj->qt_invoke( id, o );
+  return true;
+#endif
 }
 
 bool KonqView::callExtensionStringMethod( const char *methodName, QString value )
@@ -765,6 +825,7 @@ bool KonqView::callExtensionStringMethod( const char *methodName, QString value
   if ( !obj )
     return false;
 
+#if QT_VERSION < 300
   //kdDebug(1202) << "KonqView::callExtensionStringMethod " << methodName << endl;
   typedef void (QObject::*StringMethod)(QString);
   QMetaData * mdata = obj->metaObject()->slot( methodName );
@@ -775,13 +836,85 @@ bool KonqView::callExtensionStringMethod( const char *methodName, QString value
     //kdDebug(1202) << "Call done" << endl;
   };
   return false;
+#else
+  int id = obj->metaObject()->findSlot( methodName );
+  if ( id == -1 )
+    return false;
+  QUObject o[ 2 ];
+
+  static_QUType_QString.set( o + 1, value );
+
+  obj->qt_invoke( id, o );
+  return true;
+#endif
 }
 
 void KonqView::setViewName( const QString &name )
 {
-    m_name = name;
+    //kdDebug() << "KonqView::setViewName this=" << this << " name=" << name << " part=" << m_pPart << endl;
     if ( m_pPart )
-        m_pPart->setName( m_name.local8Bit().data() );
+        m_pPart->setName( name.local8Bit().data() );
+}
+
+QString KonqView::viewName() const
+{
+    return m_pPart ? QString::fromLocal8Bit( m_pPart->name() ) : QString::null;
+}
+
+void KonqView::enablePopupMenu( bool b )
+{
+  Q_ASSERT( m_pMainWindow );
+
+  KParts::BrowserExtension *ext = browserExtension();
+
+  if ( !ext )
+    return;
+
+  // enable context popup
+  if ( !m_bPopupMenuEnabled && b ) {
+    m_bPopupMenuEnabled = true;
+
+    if ( m_bBackRightClick )
+    {
+      connect( this, SIGNAL( backRightClick() ),
+               m_pMainWindow, SLOT( slotBack() ) );
+    }
+
+    connect( ext, SIGNAL( popupMenu( const QPoint &, const KFileItemList & ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KFileItemList & ) ) );
+
+    connect( ext, SIGNAL( popupMenu( const QPoint &, const KURL &, const QString &, mode_t ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KURL &, const QString &, mode_t ) ) );
+
+    connect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ) );
+
+    connect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KURL &, const QString &, mode_t ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KURL &, const QString &, mode_t ) ) );
+  }
+
+  // disable context popup
+  if ( m_bPopupMenuEnabled && !b ) {
+    m_bPopupMenuEnabled = false;
+
+    if ( m_bBackRightClick )
+    {
+      disconnect( this, SIGNAL( backRightClick() ),
+               m_pMainWindow, SLOT( slotBack() ) );
+    }
+
+    disconnect( ext, SIGNAL( popupMenu( const QPoint &, const KFileItemList & ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KFileItemList & ) ) );
+
+    disconnect( ext, SIGNAL( popupMenu( const QPoint &, const KURL &, const QString &, mode_t ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KURL &, const QString &, mode_t ) ) );
+
+    disconnect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList & ) ) );
+
+    disconnect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KURL &, const QString &, mode_t ) ),
+             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KURL &, const QString &, mode_t ) ) );
+  }
 }
 
 KonqViewIface * KonqView::dcopObject()
@@ -793,10 +926,10 @@ KonqViewIface * KonqView::dcopObject()
 
 bool KonqView::eventFilter( QObject *obj, QEvent *e )
 {
-    if ( m_pPart && obj != m_pPart->widget() )
+    if ( !m_pPart )
         return false;
-
-    if ( e->type() == QEvent::DragEnter )
+//  kdDebug() << "--" << obj->className() << "--" << e->type() << "--"  << endl;
+    if ( e->type() == QEvent::DragEnter && obj == m_pPart->widget() )
     {
         QDragEnterEvent *ev = static_cast<QDragEnterEvent *>( e );
 
@@ -817,7 +950,7 @@ bool KonqView::eventFilter( QObject *obj, QEvent *e )
             delete children;
         }
     }
-    else if ( e->type() == QEvent::Drop )
+    else if ( e->type() == QEvent::Drop && obj == m_pPart->widget() )
     {
         QDropEvent *ev = static_cast<QDropEvent *>( e );
 
@@ -825,10 +958,47 @@ bool KonqView::eventFilter( QObject *obj, QEvent *e )
         bool ok = KURLDrag::decode( ev, lstDragURLs );
 
         KParts::BrowserExtension *ext = browserExtension();
-        if ( ok && ext )
+        if ( ok && ext && lstDragURLs.first().isValid() )
             emit ext->openURLRequest( lstDragURLs.first() ); // this will call m_pMainWindow::slotOpenURLRequest delayed
     }
-
+    if ( m_bBackRightClick )
+    {
+        if ( e->type() == QEvent::ContextMenu )
+        {
+            return true;
+        }
+        else if ( e->type() == QEvent::MouseButtonPress )
+        {
+            QMouseEvent *ev = static_cast<QMouseEvent *>( e );
+            if ( ev->button() == RightButton )
+            {
+                return true;
+            }
+        }
+        else if ( e->type() == QEvent::MouseButtonRelease )
+        {
+            QMouseEvent *ev = static_cast<QMouseEvent *>( e );
+            if ( ev->button() == RightButton )
+            {
+                emit backRightClick();
+                return true;
+            }
+        }
+        else if ( e->type() == QEvent::MouseMove )
+        {
+            QMouseEvent *ev = static_cast<QMouseEvent *>( e );
+            if ( ev->state() == RightButton )
+            {
+                obj->removeEventFilter( this );
+                QMouseEvent me( QEvent::MouseButtonPress, ev->pos(), 2, 2 );
+                QApplication::sendEvent( obj, &me );
+//              QContextMenuEvent ce( QContextMenuEvent::Mouse, ev->pos(), 2 );
+//              QApplication::sendEvent( obj, &ce );
+                obj->installEventFilter( this );
+                return true;
+            }
+        }
+    }
     return false;
 }
 
