@@ -18,7 +18,7 @@
 */
 
 #ifndef __konq_viewmgr_h__
-#define __konq_viewmgr_h__ "$Id: konq_viewmgr.h,v 1.55 2001/06/26 23:46:12 faure Exp $"
+#define __konq_viewmgr_h__ "$Id: konq_viewmgr.h,v 1.58 2002/03/18 10:22:51 staikos Exp $"
 
 #include "konq_factory.h"
 
@@ -51,7 +51,7 @@ class KonqViewManager : public KParts::PartManager
 {
   Q_OBJECT
 public:
-  KonqViewManager( KonqMainWindow *mainWindow );
+  KonqViewManager( KonqMainWindow *mainWindow, QWidget *parentWidget );
   ~KonqViewManager();
 
   /**
@@ -67,7 +67,7 @@ public:
   KonqView* splitView( Qt::Orientation orientation,
                        const QString & serviceType = QString::null,
                        const QString & serviceName = QString::null,
-                       bool newOneFirst = false);
+                       bool newOneFirst = false, bool forceAutoEmbed = false );
 
   /**
    * Does basically the same as splitView() but inserts the new view at the top
@@ -90,7 +90,7 @@ public:
                    const QString &serviceType = QString::null,
                    const QString &serviceName = QString::null,
                    KonqFrameContainer **newFrameContainer = 0L,
-                   bool passiveMode = false );
+                   bool passiveMode = false, bool forceAutoEmbed = false );
 
   /**
    * Guess!:-)
@@ -174,6 +174,7 @@ public:
 
   void profileListDirty( bool broadcast = true );
 
+  // Can be 0L (initially)
   KonqFrameContainer *mainContainer() const { return m_pMainContainer; }
 
   KonqMainWindow *mainWindow() const { return m_pMainWindow; }
@@ -193,7 +194,10 @@ public:
 
   void showProfileDlg( const QString & preselectProfile );
 
-  static QSize readConfigSize( KConfig &cfg );
+  /**
+   *   The widget is the one which you are referring to.
+   */
+  static QSize readConfigSize( KConfig &cfg, QWidget *widget = NULL);
 
 protected slots:
   void emitActivePartChanged();
@@ -233,7 +237,8 @@ private:
                               const QString &serviceName,
                               KService::Ptr &service,
                               KTrader::OfferList &partServiceOffers,
-                              KTrader::OfferList &appServiceOffers );
+                              KTrader::OfferList &appServiceOffers,
+			      bool forceAutoEmbed = false );
 
   /**
    * Mainly creates the backend structure(KonqView) for a view and
@@ -254,7 +259,7 @@ private:
   void printFullHierarchy( KonqFrameContainer * container, int ident = 0 );
 
   KonqMainWindow *m_pMainWindow;
-
+  QWidget *m_pParentWidget;
   KonqFrameContainer *m_pMainContainer;
 
   QGuardedPtr<KActionMenu> m_pamProfiles;
