@@ -18,43 +18,29 @@
 */
 
 #include "konq_listview.h"
-#include "konq_listviewitems.h"
-#include "konq_listviewwidget.h"
 #include "konq_textviewwidget.h"
 #include "konq_treeviewwidget.h"
-#include <konq_undo.h>
 
 #include <kaction.h>
-#include <kcolordlg.h>
-#include <kcursor.h>
 #include <kdebug.h>
-#include <kio/job.h>
-#include <klibloader.h>
+#include <kdirlister.h>
 #include <klineeditdlg.h>
 #include <klocale.h>
-#include <konq_bgnddlg.h>
-#include <konq_dirlister.h>
 #include <konq_drag.h>
-#include <konq_fileitem.h>
-#include <kpropsdlg.h>
-#include <kprotocolmanager.h>
+#include <kpropertiesdialog.h>
 #include <kstdaction.h>
 
 #include <qapplication.h>
 #include <qclipboard.h>
-#include <qdragobject.h>
 #include <qheader.h>
-#include <qkeycode.h>
-#include <qlist.h>
 #include <qregexp.h>
-#include <qstringlist.h>
-#include <qtimer.h>
 
 #include <assert.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <time.h>
 #include <unistd.h>
+#include <kinstance.h>
 
 KonqListViewFactory::KonqListViewFactory()
 {
@@ -73,13 +59,12 @@ KonqListViewFactory::~KonqListViewFactory()
   s_defaultViewProps = 0;
 }
 
-KParts::Part* KonqListViewFactory::createPart( QWidget *parentWidget, const char *, QObject *parent, const char *name, const char*, const QStringList &args )
+KParts::Part* KonqListViewFactory::createPartObject( QWidget *parentWidget, const char *, QObject *parent, const char *name, const char*, const QStringList &args )
 {
   if( args.count() < 1 )
     kdWarning() << "KonqListView: Missing Parameter" << endl;
 
   KParts::Part *obj = new KonqListView( parentWidget, parent, name, args.first() );
-  emit objectCreated( obj );
   return obj;
 }
 
@@ -104,7 +89,7 @@ KonqPropsView *KonqListViewFactory::s_defaultViewProps = 0;
 
 extern "C"
 {
-  void *init_libkonqlistview()
+  void *init_konq_listview()
   {
     return new KonqListViewFactory;
   }
@@ -118,11 +103,13 @@ ListViewBrowserExtension::ListViewBrowserExtension( KonqListView *listView )
 
 int ListViewBrowserExtension::xOffset()
 {
+  kdDebug(1202) << k_funcinfo << endl;
   return m_listView->listViewWidget()->contentsX();
 }
 
 int ListViewBrowserExtension::yOffset()
 {
+  kdDebug(1202) << k_funcinfo << endl;
   return m_listView->listViewWidget()->contentsY();
 }
 
@@ -148,7 +135,7 @@ void ListViewBrowserExtension::updateActions()
 
   emit enableAction( "copy", cutcopy );
   emit enableAction( "cut", cutcopy );
-  emit enableAction( "trash", del && !bInTrash );
+  emit enableAction( "trash", del && !bInTrash && m_listView->url().isLocalFile() );
   emit enableAction( "del", del );
   emit enableAction( "shred", del );
 
@@ -198,7 +185,7 @@ void ListViewBrowserExtension::rename()
 {
   QValueList<KonqBaseListViewItem*> selection;
   m_listView->listViewWidget()->selectedItems( selection );
-  ASSERT ( selection.count() == 1 );
+  Q_ASSERT ( selection.count() == 1 );
   m_listView->listViewWidget()->rename( selection.first(), 0 );
 }
 
@@ -266,13 +253,7 @@ KonqListView::KonqListView( QWidget *parentWidget, QObject *parent, const char *
    }
    setWidget( m_pListView );
 
-   QTimer * timer = new QTimer( this );
-   connect( timer, SIGNAL( timeout() ), this, SLOT( slotProcessMimeIcons() ) );
-   m_mimeTypeResolver = new KonqMimeTypeResolver<KonqBaseListViewItem,KonqListView>(this,timer);
-   // When our viewport is adjusted (resized or scrolled) we need
-   // to get the mime types for any newly visible icons. (Rikkus)
-   connect( m_pListView, SIGNAL( viewportAdjusted() ),
-            SLOT( slotViewportAdjusted() ) );
+   m_mimeTypeResolver = new KMimeTypeResolver<KonqBaseListViewItem,KonqListView>(this);
 
    setupActions();
 
@@ -293,6 +274,10 @@ KonqListView::KonqListView( QWidget *parentWidget, QObject *parent, const char *
                      m_extension, SLOT( updateActions() ) );
    connect(m_pListView->header(),SIGNAL(indexChange(int,int,int)),this,SLOT(headerDragged(int,int,int)));
    connect(m_pListView->header(),SIGNAL(clicked(int)),this,SLOT(slotHeaderClicked(int)));
+
+   // signals from konqdirpart (for BC reasons)
+   connect( this, SIGNAL( findOpened( KonqDirPart * ) ), SLOT( slotKFindOpened() ) );
+   connect( this, SIGNAL( findClosed( KonqDirPart * ) ), SLOT( slotKFindClosed() ) );
 }
 
 KonqListView::~KonqListView()
@@ -301,18 +286,21 @@ KonqListView::~KonqListView()
   delete m_pProps;
 }
 
-bool KonqListView::openURL( const KURL &url )
+void KonqListView::guiActivateEvent( KParts::GUIActivateEvent *event )
 {
-  m_url = url;
+   KonqDirPart::guiActivateEvent(event );
+   //ReadOnlyPart::guiActivateEvent(event );
+   ((ListViewBrowserExtension*)m_extension)->updateActions();
+};
 
+bool KonqListView::doOpenURL( const KURL &url )
+{
   KURL u( url );
-
   emit setWindowCaption( u.prettyURL() );
-
   return m_pListView->openURL( url );
 }
 
-bool KonqListView::closeURL()
+bool KonqListView::doCloseURL()
 {
   m_pListView->stop();
   m_mimeTypeResolver->m_lstPendingMimeIconItems.clear();
@@ -341,13 +329,14 @@ void KonqListView::determineIcon( KonqBaseListViewItem * item )
 
 void KonqListView::saveState( QDataStream &stream )
 {
-    kdDebug() << "KonqListView::saveState" << endl;
+    kdDebug(1202) << k_funcinfo << endl;
     KonqDirPart::saveState( stream );
     m_pListView->saveState( stream );
 }
 
 void KonqListView::restoreState( QDataStream &stream )
 {
+    kdDebug(1202) << k_funcinfo << endl;
     KonqDirPart::restoreState( stream );
     m_pListView->restoreState( stream );
 }
@@ -371,11 +360,21 @@ void KonqListView::slotSelect()
       m_pListView->blockSignals( true );
 
       for (KonqBaseListViewWidget::iterator it = m_pListView->begin(); it != m_pListView->end(); it++ )
-         if ( re.match( it->text(0) ) != -1 )
+      {
+         if ((m_pListView->automaticSelection()) && (it->isSelected()))
+         {
+             it->setSelected(FALSE);
+             //the following line is to prevent that more than one item were selected
+             //and now get deselected and automaticSelection() was true, this shouldn't happen
+             //but who knows, aleXXX
+             m_pListView->deactivateAutomaticSelection();
+         };
+         if ( re.search( it->text(0) ) != -1 )
             it->setSelected( TRUE);
-
+      };
       m_pListView->blockSignals( false );
    }
+   m_pListView->deactivateAutomaticSelection();
    emit m_pListView->selectionChanged();
    m_pListView->viewport()->update();
 }
@@ -394,11 +393,12 @@ void KonqListView::slotUnselect()
       m_pListView->blockSignals(TRUE);
 
       for (KonqBaseListViewWidget::iterator it = m_pListView->begin(); it != m_pListView->end(); it++ )
-         if ( re.match( it->text(0) ) != -1 )
+         if ( re.search( it->text(0) ) != -1 )
             it->setSelected(FALSE);
 
       m_pListView->blockSignals(FALSE);
    }
+   m_pListView->deactivateAutomaticSelection();
    emit m_pListView->selectionChanged();
    m_pListView->viewport()->update();
 }
@@ -406,19 +406,27 @@ void KonqListView::slotUnselect()
 void KonqListView::slotSelectAll()
 {
    m_pListView->selectAll(TRUE);
+   m_pListView->deactivateAutomaticSelection();
    emit m_pListView->selectionChanged();
 }
 
 void KonqListView::slotUnselectAll()
 {
     m_pListView->selectAll(FALSE);
+   m_pListView->deactivateAutomaticSelection();
     emit m_pListView->selectionChanged();
 }
 
 
 void KonqListView::slotInvertSelection()
 {
-    m_pListView->invertSelection();
+   if ((m_pListView->automaticSelection())
+       && (m_pListView->currentItem()!=0)
+       && (m_pListView->currentItem()->isSelected()))
+      m_pListView->currentItem()->setSelected(FALSE);
+
+   m_pListView->invertSelection();
+    m_pListView->deactivateAutomaticSelection();
     emit m_pListView->selectionChanged();
     m_pListView->viewport()->update();
 }
@@ -433,6 +441,7 @@ void KonqListView::slotShowDot()
 {
    m_pProps->setShowingDotFiles( m_paShowDot->isChecked() );
    m_pListView->m_dirLister->setShowingDotFiles( m_pProps->isShowingDotFiles() );
+   m_pListView->m_dirLister->emitChanges();
 }
 
 void KonqListView::slotCaseInsensitive()
@@ -572,6 +581,17 @@ void KonqListView::slotSaveAfterHeaderDrag()
    config->sync();
 }
 
+void KonqListView::slotKFindOpened()
+{
+    if ( m_pListView->m_dirLister )
+        m_pListView->m_dirLister->setAutoUpdate( false );
+}
+
+void KonqListView::slotKFindClosed()
+{
+    if ( m_pListView->m_dirLister )
+        m_pListView->m_dirLister->setAutoUpdate( true );
+}
 
 void KonqListView::setupActions()
 {
@@ -589,7 +609,7 @@ void KonqListView::setupActions()
 
    m_paSelect = new KAction( i18n( "&Select..." ), CTRL+Key_Plus, this, SLOT( slotSelect() ), actionCollection(), "select" );
   m_paUnselect = new KAction( i18n( "&Unselect..." ), CTRL+Key_Minus, this, SLOT( slotUnselect() ), actionCollection(), "unselect" );
-  m_paSelectAll = KStdAction::selectAll( this, SLOT( slotSelectAll() ), this, "selectall" );
+  m_paSelectAll = KStdAction::selectAll( this, SLOT( slotSelectAll() ), actionCollection(), "selectall" );
   m_paUnselectAll = new KAction( i18n( "U&nselect All" ), CTRL+Key_U, this, SLOT( slotUnselectAll() ), actionCollection(), "unselectall" );
   m_paInvertSelection = new KAction( i18n( "&Invert Selection" ), CTRL+Key_Asterisk, this, SLOT( slotInvertSelection() ), actionCollection(), "invertselection" );
 
