@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
+                 2001, 2002 Michael Brade <brade@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,27 +19,24 @@
 */
 
 #include "konq_listview.h"
-#include "konq_listviewitems.h"
-#include "konq_listviewwidget.h"
-#include "konq_propsview.h"
 
-#include <konq_dirlister.h>
-#include <konq_operations.h>
 #include <konq_settings.h>
 
 #include <kdebug.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kio/job.h>
+#include <kdirlister.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kprotocolinfo.h>
 #include <kaction.h>
 #include <kurldrag.h>
 #include <qheader.h>
+#include <qpainter.h>
+#include <qstyle.h>
 
 #include <stdlib.h>
 #include <assert.h>
+#include <kiconloader.h>
+#include <qfile.h>
 
 ColumnInfo::ColumnInfo()
    :displayInColumn(-1)
@@ -74,19 +72,19 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
     :KListView(parentWidget)
 ,sortedByColumn(0)
 ,m_pBrowserView(parent)
-,m_dirLister(new KonqDirLister( true /*m_showIcons==FALSE*/))
+,m_dirLister(new KDirLister( true /*m_showIcons==FALSE*/))
 ,m_dragOverItem(0)
 ,m_scrollTimer(0)
 ,m_rubber(0)
 ,m_showIcons(true)
 ,m_bCaseInsensitive(true)
+,m_bUpdateContentsPosAfterListing(false)
 ,m_bAscending(true)
 ,m_itemFound(false)
-,m_goToFirstItem(false)
-,m_xOffset(0)
-,m_yOffset(0)
+,m_restored(false)
 ,m_filenameColumn(0)
 ,m_itemToGoTo("")
+,m_backgroundTimer(0)
 {
    kdDebug(1202) << "+KonqBaseListViewWidget" << endl;
 
@@ -94,7 +92,7 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
 
    //Adjust KListView behaviour
    setMultiSelection(true);
-   setSelectionModeExt( Konqueror );
+   setSelectionModeExt( FileManager );
    setDragEnabled(true);
    setItemsMovable(false);
 
@@ -128,7 +126,7 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
             this, SIGNAL(viewportAdjusted()));
 
    // Connect the directory lister
-   connect( m_dirLister, SIGNAL( started( const QString & ) ),
+   connect( m_dirLister, SIGNAL( started( const KURL & ) ),
             this, SLOT( slotStarted() ) );
    connect( m_dirLister, SIGNAL( completed() ), this, SLOT( slotCompleted() ) );
    connect( m_dirLister, SIGNAL( canceled() ), this, SLOT( slotCanceled() ) );
@@ -141,11 +139,18 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
             this, SLOT( slotRefreshItems( const KFileItemList & ) ) );
    connect( m_dirLister, SIGNAL( redirection( const KURL & ) ),
             this, SLOT( slotRedirection( const KURL & ) ) );
-   connect( m_dirLister, SIGNAL( closeView() ),
-            this, SLOT( slotCloseView() ) );
    connect( m_dirLister, SIGNAL( itemsFilteredByMime( const KFileItemList & ) ),
             m_pBrowserView, SIGNAL( itemsFilteredByMime( const KFileItemList & ) ) );
 
+   connect( m_dirLister, SIGNAL( infoMessage( const QString& ) ),
+            m_pBrowserView->extension(), SIGNAL( infoMessage( const QString& ) ) );
+   connect( m_dirLister, SIGNAL( percent( int ) ),
+            m_pBrowserView->extension(), SIGNAL( loadingProgress( int ) ) );
+   connect( m_dirLister, SIGNAL( speed( int ) ),
+            m_pBrowserView->extension(), SIGNAL( speedProgress( int ) ) );
+
+   connect( header(), SIGNAL( sizeChange( int, int, int ) ), SLOT( slotUpdateBackground() ) );
+
    viewport()->setMouseTracking( true );
    viewport()->setFocusPolicy( QWidget::WheelFocus );
    setFocusPolicy( QWidget::WheelFocus );
@@ -224,7 +229,7 @@ void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
    }
    //check what the protocol provides
    QStringList listingList=KProtocolInfo::listing(protocol);
-   kdDebug(1202)<<"protocol: -"<<protocol<<"-"<<endl;
+   kdDebug(1202) << k_funcinfo << "protocol: " << protocol << endl;
 
    // Even if this is not given by the protocol, we can determine it.
    // Please don't remove this ;-). It makes it possible to show the file type
@@ -387,8 +392,9 @@ void KonqBaseListViewWidget::drawRubber()
 
    QPoint pt( m_rubber->x(), m_rubber->y() );
    pt = contentsToViewport( pt );
-   style().drawFocusRect( &p, QRect( pt.x(), pt.y(), m_rubber->width(), m_rubber->height() ),
-                          colorGroup(), &colorGroup().base() );
+   style().drawPrimitive( QStyle::PE_FocusRect, &p,
+                          QRect( pt.x(), pt.y(), m_rubber->width(), m_rubber->height() ),
+                          colorGroup(), QStyle::Style_Default, colorGroup().base() );
    p.end();
 }
 
@@ -593,7 +599,7 @@ void KonqBaseListViewWidget::viewportDropEvent( QDropEvent *ev  )
    KonqBaseListViewItem *item =
        isExecuteArea( ev->pos() ) ? (KonqBaseListViewItem*)itemAt( ev->pos() ) : 0;
 
-   KonqFileItem * destItem = (item) ? item->item() : static_cast<KonqFileItem *>(m_dirLister->rootItem());
+   KFileItem * destItem = (item) ? item->item() : m_dirLister->rootItem();
    KURL u = destItem ? destItem->url() : url();
    if ( u.isEmpty() )
       return;
@@ -662,7 +668,7 @@ void KonqBaseListViewWidget::slotOnItem( QListViewItem* _item)
 
 void KonqBaseListViewWidget::slotItemRenamed(QListViewItem* item, const QString &name, int col)
 {
-   ASSERT(col==0);
+   Q_ASSERT(col==0);
    if (col != 0) return;
    assert(item);
    KFileItem * fileItem = static_cast<KonqBaseListViewItem*>(item)->item();
@@ -745,15 +751,20 @@ void KonqBaseListViewWidget::slotReturnPressed( QListViewItem *_item )
 {
    if ( !_item )
       return;
-   KonqFileItem *fileItem = static_cast<KonqBaseListViewItem*>(_item)->item();
+   KFileItem *fileItem = static_cast<KonqBaseListViewItem*>(_item)->item();
    if ( !fileItem )
       return;
 
    KURL u( fileItem->url() );
    if ( !fileItem->isReadable() )
    {
-      KMessageBox::error( this, i18n("You do not have enough permissions to read <b>%1</b>").arg(u.prettyURL()) );
-      return;
+        // No permissions or local file that doesn't exist - need to find out which
+        if ( !fileItem->isLocalFile() || QFile::exists( fileItem->url().path() ) )
+        {
+            KMessageBox::error( this, i18n("<p>You do not have enough permissions to read <b>%1</b></p>").arg(u.prettyURL()) );
+            return;
+        }
+        // ### Add error message if the latter case, after msg freeze.
    }
    if ( fileItem->isLink() )
       u = KURL( u, fileItem->linkDest() );
@@ -835,38 +846,21 @@ void KonqBaseListViewWidget::updateListContents()
 
 bool KonqBaseListViewWidget::openURL( const KURL &url )
 {
-   m_pBrowserView->beforeOpenURL();
+   kdDebug(1202) << k_funcinfo << "protocol: " << url.protocol()
+                               <<" url: " << url.path() << endl;
 
-   // The first time or new protocol ? So create the columns first
-   kdDebug(1202) << "protocol in ::openURL: -" << url.protocol()<<"- url: -"<<url.path()<<"-"<<endl;
-
-   if (( columns() <1) || ( url.protocol() != m_url.protocol() ))
+   // The first time or new protocol? So create the columns first.
+   if ( columns() < 1 || url.protocol() != m_url.protocol() )
    {
       readProtocolConfig( url.protocol() );
       createColumns();
    }
+
    m_bTopLevelComplete = false;
+   m_itemFound = false;
 
-   m_itemToGoTo="";
-   m_itemFound=false;
-   m_goToFirstItem=false;
-   if (url.protocol()!=m_url.protocol())
-      m_goToFirstItem=true;
-   else
-   {
-      //we go one dir deeper
-      if (url.path(-1).contains(m_url.path(-1)))
-         m_goToFirstItem=true;
-      //we go one dir up, get the position from the current url
-      else if (m_url.path(-1).contains(url.path(-1)))
-      {
-         m_itemToGoTo=m_url.fileName(true);
-         if (m_itemToGoTo.isEmpty())
-            m_goToFirstItem=true;
-      };
-   };
-
-   m_url=url;
+   if ( m_itemToGoTo.isEmpty() && url.cmp( m_url.upURL(), true ) )
+      m_itemToGoTo = m_url.fileName( true );
 
    // Check for new properties in the new dir
    // newProps returns true the first time, and any time something might
@@ -875,23 +869,28 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
 
    m_dirLister->setNameFilter( m_pBrowserView->nameFilter() );
    m_dirLister->setMimeFilter( m_pBrowserView->mimeFilter() );
+   m_dirLister->setShowingDotFiles( m_pBrowserView->m_pProps->isShowingDotFiles() );
+
    if ( m_pBrowserView->extension()->urlArgs().reload )
    {
-      if (currentItem()!=0)
-      {
-         m_itemToGoTo=currentItem()->text(0);
-         m_goToFirstItem = false;
-      }
-      else
-         m_goToFirstItem = true;
-      m_xOffset = contentsX();
-      m_yOffset = contentsY();
-   }
-   // Start the directory lister !
-   m_dirLister->openURL( url, m_pBrowserView->m_pProps->isShowingDotFiles(), false /* new url */ );
+      KParts::URLArgs args = m_pBrowserView->extension()->urlArgs();
+      args.xOffset = contentsX();
+      args.yOffset = contentsY();
+      m_pBrowserView->extension()->setURLArgs( args );
 
+      if ( currentItem() && itemRect( currentItem() ).isValid() )
+         m_itemToGoTo = currentItem()->text(0);
+   }
+
+   if ( columnWidthMode(0) == Maximum )
+      setColumnWidth(0,50);
+
+   m_url = url;
    m_bUpdateContentsPosAfterListing = true;
 
+   // Start the directory lister !
+   m_dirLister->openURL( url, false /* new url */, m_pBrowserView->extension()->urlArgs().reload );
+
    // Apply properties and reflect them on the actions
    // do it after starting the dir lister to avoid changing the properties
    // of the old view
@@ -905,14 +904,14 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
       m_pBrowserView->m_pProps->applyColors( viewport() );
    }
 
-   if (columnWidthMode(0)==Maximum)
-      setColumnWidth(0,50);
-
    return true;
 }
 
 void KonqBaseListViewWidget::setComplete()
 {
+   kdDebug(1202) << k_funcinfo << "Update Contents Pos: "
+                 << m_bUpdateContentsPosAfterListing << endl;
+
    m_bTopLevelComplete = true;
 
    // Alex: this flag is set when we are just finishing a voluntary listing,
@@ -921,25 +920,23 @@ void KonqBaseListViewWidget::setComplete()
    // we don't want to go to the first item ! (David)
    if ( m_bUpdateContentsPosAfterListing )
    {
-       //kdDebug() << "KonqBaseListViewWidget::setComplete m_bUpdateContentsPosAfterListing=true" << endl;
       m_bUpdateContentsPosAfterListing = false;
 
-      if ((m_goToFirstItem==true) || (m_itemFound==false))
-      {
-          kdDebug() << "going to first item" << endl;
-          setCurrentItem(firstChild());
-          ensureItemVisible(firstChild());
-          //selectCurrentItemAndEnableSelectedBySimpleMoveMode();
-      } else
-          setContentsPos( m_xOffset, m_yOffset );
+      if ( !m_itemFound )
+         setCurrentItem( firstChild() );
 
-      // this sucks a bit, for instance if you scroll with the wheel mouse, and the
-      // the active item was out of the view when you used back/forward.
-      // The x/y offset already restores the contents pos anyway.
-      //ensureItemVisible(currentItem());
+      if ( !m_restored && !m_pBrowserView->extension()->urlArgs().reload )
+         ensureItemVisible( currentItem() );
+      else
+         setContentsPos( m_pBrowserView->extension()->urlArgs().xOffset,
+                         m_pBrowserView->extension()->urlArgs().yOffset );
+
+      emit selectionChanged();
    }
-   // Show "cut" icons as such
-   m_pBrowserView->slotClipboardDataChanged();
+
+   m_itemToGoTo = "";
+   m_restored = false;
+
    // Show totals
    slotOnViewport();
 
@@ -949,33 +946,42 @@ void KonqBaseListViewWidget::setComplete()
       setUpdatesEnabled( true );
       triggerUpdate();
    }
+   
+   // Show "cut" icons as such
+   m_pBrowserView->slotClipboardDataChanged();
 }
 
 void KonqBaseListViewWidget::slotStarted()
 {
+   //kdDebug(1202) << k_funcinfo << endl;
+
    if (!m_bTopLevelComplete)
-      emit m_pBrowserView->started(m_dirLister->job());
+      emit m_pBrowserView->started( 0 );
 }
 
 void KonqBaseListViewWidget::slotCompleted()
 {
-   bool complete = m_bTopLevelComplete;
+   //kdDebug(1202) << k_funcinfo << endl;
+
    setComplete();
-   if ( !complete )
+   if ( m_bTopLevelComplete )
        emit m_pBrowserView->completed();
    m_pBrowserView->listingComplete();
 }
 
 void KonqBaseListViewWidget::slotCanceled()
 {
+   //kdDebug(1202) << k_funcinfo << endl;
+
    setComplete();
    emit m_pBrowserView->canceled( QString::null );
 }
 
 void KonqBaseListViewWidget::slotClear()
 {
+   kdDebug(1202) << k_funcinfo << endl;
+
    m_pBrowserView->resetCount();
-   kdDebug(1202) << "KonqBaseListViewWidget::slotClear()" << endl;
    m_pBrowserView->lstPendingMimeIconItems().clear();
 
    viewport()->setUpdatesEnabled( false );
@@ -985,20 +991,17 @@ void KonqBaseListViewWidget::slotClear()
 
 void KonqBaseListViewWidget::slotNewItems( const KFileItemList & entries )
 {
-   //kdDebug(1202) << "KonqBaseListViewWidget::slotNewItems " << entries.count() << endl;
-   for (QListIterator<KFileItem> kit ( entries ); kit.current(); ++kit )
+   //kdDebug(1202) << k_funcinfo << entries.count() << endl;
+
+   for ( QPtrListIterator<KFileItem> kit ( entries ); kit.current(); ++kit )
    {
-      KonqListViewItem * tmp = new KonqListViewItem( this, static_cast<KonqFileItem *>(*kit) );
-      if (m_goToFirstItem==false)
-         if (m_itemFound==false)
-            if (tmp->text(0)==m_itemToGoTo)
-            {
-               setCurrentItem(tmp);
-               ensureItemVisible(tmp);
-               emit selectionChanged();
-               //selectCurrentItemAndEnableSelectedBySimpleMoveMode();
-               m_itemFound=true;
-            };
+      KonqListViewItem * tmp = new KonqListViewItem( this, *kit );
+      if ( !m_itemFound && tmp->text(0) == m_itemToGoTo )
+      {
+         setCurrentItem( tmp );
+         m_itemFound = true;
+      }
+
       if ( !(*kit)->isMimeTypeKnown() )
           m_pBrowserView->lstPendingMimeIconItems().append( tmp );
    }
@@ -1010,12 +1013,14 @@ void KonqBaseListViewWidget::slotNewItems( const KFileItemList & entries )
       setUpdatesEnabled( true );
       triggerUpdate();
    }
+   slotUpdateBackground();
 }
 
 void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
 {
+  kdDebug(1202) << k_funcinfo << "removing " << _fileitem->url().url() << " from tree!" << endl;
+
   m_pBrowserView->deleteItem( _fileitem );
-  kdDebug(1202) << "removing " << _fileitem->url().url() << " from tree!" << endl;
   iterator it = begin();
   for( ; it != end(); ++it )
     if ( (*it).item() == _fileitem )
@@ -1028,11 +1033,19 @@ void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
       emit selectionChanged();
       return;
     }
+
+  if ( !viewport()->isUpdatesEnabled() )
+  {
+    viewport()->setUpdatesEnabled( true );
+    setUpdatesEnabled( true );
+    triggerUpdate();
+  }
+  slotUpdateBackground();
 }
 
 void KonqBaseListViewWidget::slotRefreshItems( const KFileItemList & entries )
 {
-   QListIterator<KFileItem> kit ( entries );
+   QPtrListIterator<KFileItem> kit ( entries );
    for( ; kit.current(); ++kit )
    {
       iterator it = begin();
@@ -1047,22 +1060,18 @@ void KonqBaseListViewWidget::slotRefreshItems( const KFileItemList & entries )
 
 void KonqBaseListViewWidget::slotRedirection( const KURL & url )
 {
+   kdDebug(1202) << k_funcinfo << endl;
+
    if (( columns() <1) || ( url.protocol() != m_url.protocol() ))
    {
       readProtocolConfig( url.protocol() );
       createColumns();
-   };
+   }
    emit m_pBrowserView->extension()->setLocationBarURL( url.prettyURL() );
    m_pBrowserView->m_url=url;
    m_url = url;
 }
 
-void KonqBaseListViewWidget::slotCloseView()
-{
-   kdDebug() << "KonqBaseListViewWidget::slotCloseView" << endl;
-   //delete m_pBrowserView;
-}
-
 KonqBaseListViewWidget::iterator& KonqBaseListViewWidget::iterator::operator++()
 {
    if ( !m_p ) return *this;
@@ -1125,19 +1134,20 @@ KonqBaseListViewWidget::iterator KonqBaseListViewWidget::iterator::operator++(in
 
 void KonqBaseListViewWidget::paintEmptyArea( QPainter *p, const QRect &r )
 {
-   const QPixmap *pm = viewport()->backgroundPixmap();
+   const QPixmap *pm = viewport()->paletteBackgroundPixmap();
 
    if (!pm || pm->isNull())
       p->fillRect(r, viewport()->backgroundColor());
    else
    {
-      int ax = (r.x() + contentsX()) % pm->width();
-      int ay = (r.y() + contentsY()) % pm->height();
-        /*kdDebug() << "KonqBaseListViewWidget::paintEmptyArea "
+       QRect devRect = p->xForm( r );
+       int ax = (devRect.x() + contentsX());
+       int ay = (devRect.y() + contentsY());
+       /* kdDebug() << "KonqBaseListViewWidget::paintEmptyArea "
                   << r.x() << "," << r.y() << " " << r.width() << "x" << r.height()
                   << " drawing pixmap with offset " << ax << "," << ay
                   << endl;*/
-      p->drawTiledPixmap(r, *pm, QPoint(ax, ay));
+       p->drawTiledPixmap(r, *pm, QPoint(ax, ay));
    }
 }
 
@@ -1171,18 +1181,28 @@ void KonqBaseListViewWidget::saveState( QDataStream & ds )
 
 void KonqBaseListViewWidget::restoreState( QDataStream & ds )
 {
+   m_restored = true;
+
    QString str;
    ds >> str;
    if ( !str.isEmpty() )
-   {
       m_itemToGoTo = str;
-      m_goToFirstItem = false;
-   }
+}
 
-   // Store those, because the toplevel completed() erases them (in BE) !
-   // (needed for the treeview)
-   m_xOffset = m_pBrowserView->extension()->urlArgs().xOffset;
-   m_yOffset = m_pBrowserView->extension()->urlArgs().yOffset;
+void KonqBaseListViewWidget::slotUpdateBackground()
+{
+   if ( viewport()->paletteBackgroundPixmap() && !viewport()->paletteBackgroundPixmap()->isNull() )
+   {
+      if ( !m_backgroundTimer )
+      {
+         m_backgroundTimer = new QTimer( this );
+         connect( m_backgroundTimer, SIGNAL( timeout() ), viewport(), SLOT( update() ) );
+      }
+      else
+         m_backgroundTimer->stop();
+
+      m_backgroundTimer->start( 50, true );
+   }
 }
 
 #include "konq_listviewwidget.moc"
