@@ -26,7 +26,7 @@
 #include <qvaluelist.h>
 
 #include <kurl.h>
-#include <konq_fileitem.h>
+#include <kfileitem.h>
 #include <klistview.h>
 #include <kparts/browserextension.h>
 #include <konq_propsview.h>
@@ -35,10 +35,12 @@
 namespace KIO { class Job; }
 class QCursor;
 class QRect;
-class KonqDirLister;
+class KDirLister;
 class KonqFMSettings;
 class ListViewPropertiesExtension;
 class KToggleAction;
+class KonqListView;
+class ListViewBrowserExtension;
 
 class ColumnInfo
 {
@@ -104,7 +106,7 @@ class KonqBaseListViewWidget : public KListView
        */
       KonqPropsView * props() const;
 
-      //QList<ColumnInfo> *columnConfigInfo() {return &confColumns;};
+      //QPtrList<ColumnInfo> *columnConfigInfo() {return &confColumns;};
       ColumnInfo * columnConfigInfo() {return confColumns;};
       QString sortedByColumn;
 
@@ -162,9 +164,12 @@ class KonqBaseListViewWidget : public KListView
       virtual void slotDeleteItem( KFileItem * );
       virtual void slotRefreshItems( const KFileItemList & );
       virtual void slotRedirection( const KURL & );
-      virtual void slotCloseView();
       void slotPopupMenu(KListView* , QListViewItem* );
 
+      // forces a repaint on column size changes / branch expansion
+      // when there is a background pixmap
+      void slotUpdateBackground();
+
    protected:
       //calls KListView::focusInEvent(), otherrwise this is never called,
       //I have no idea why, AleXXX
@@ -205,12 +210,12 @@ class KonqBaseListViewWidget : public KListView
       virtual void popupMenu( const QPoint& _global, bool alwaysForSelectedFiles=false );
 
       //this one is called only by KListView, and this is friend anyways (Alex)
-      //KonqDirLister *dirLister() const { return m_dirLister; }
+      //KDirLister *dirLister() const { return m_dirLister; }
 
       /** The directory lister for this URL */
-      KonqDirLister* m_dirLister;
+      KDirLister* m_dirLister;
 
-      //QList<ColumnInfo> confColumns;
+      //QPtrList<ColumnInfo> confColumns;
       // IMO there is really no need for an advanced data structure
       //we have a fixed number of members,
       //it consumes less memory and access should be faster (Alex)
@@ -235,15 +240,14 @@ class KonqBaseListViewWidget : public KListView
       bool m_bUpdateContentsPosAfterListing:1;
       bool m_bAscending:1;
       bool m_itemFound:1;
-      bool m_goToFirstItem:1;
-
-      int m_xOffset, m_yOffset;
+      bool m_restored:1;
 
       int m_filenameColumn;
 
       KURL m_url;
 
       QString m_itemToGoTo;
+      QTimer *m_backgroundTimer;
 };
 
 #endif
