@@ -18,16 +18,11 @@
 */
 
 #include "konq_textviewitem.h"
-#include "konq_propsview.h"
-#include "konq_listview.h"
 #include "konq_settings.h"
 
-#include <qpixmap.h>
-#include <qimage.h>
-#include <kimageeffect.h>
-#include <kio/global.h>
 #include <assert.h>
 #include <stdio.h>
+#include <kglobal.h>
 
 QString KonqTextViewItem::key( int _column, bool asc) const
 {
@@ -51,7 +46,7 @@ QString KonqTextViewItem::key( int _column, bool asc) const
             }
             else if (cInfo->udsId==KIO::UDS_SIZE)
             {
-               tmp += QString::number( m_fileitem->size() ).rightJustify( 20, '0' );
+               tmp += KIO::number( m_fileitem->size() ).rightJustify( 20, '0' );
                return tmp;
             }
             else break;
