@@ -17,17 +17,29 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include "konqsidebarplugin.h"
 #include "konqsidebarplugin.moc"
 #include <kdebug.h>
 
-KonqSidebar_PluginInterface *KonqSidebarPlugin::getInterfaces(){
-  KonqSidebar_PluginInterface *jw1;
-  kdDebug()<<"getInterfaces()"<<endl;
 
-  jw1=dynamic_cast<KonqSidebar_PluginInterface *> (parent());
+KonqSidebarPlugin::KonqSidebarPlugin(KInstance *instance,QObject *parent,QWidget *widgetParent,QString &desktopName_, const char* name):QObject(parent,name),desktopName(desktopName_){m_parentInstance=instance;}
 
-  if (jw1==0) kdDebug()<<"Kann keine Typumwandlung durchfhren"<<endl; else kdDebug()<<"Translation worked"<<endl;
-  return jw1;
- 
+KonqSidebarPlugin::~KonqSidebarPlugin(){;}
+
+KInstance *KonqSidebarPlugin::parentInstance(){return m_parentInstance;}
+
+void KonqSidebarPlugin::openURL(const KURL& url){handleURL(url);}
+
+void KonqSidebarPlugin::openPreview(const KFileItemList& items)
+{
+  handlePreview(items);
 }
+
+void KonqSidebarPlugin::openPreviewOnMouseOver(const KFileItem& item)
+{
+  handlePreviewOnMouseOver(item);
+}
+
+void KonqSidebarPlugin::handlePreview(const KFileItemList & /*items*/) {}
+
+void KonqSidebarPlugin::handlePreviewOnMouseOver(const KFileItem& /*items*/) {}
+
