@@ -20,9 +20,7 @@
 #include "dirtree_item.h"
 #include "dirtree_module.h"
 #include <konq_operations.h>
-#include <konq_fileitem.h>
 #include <konq_drag.h>
-#include <ksimpleconfig.h>
 #include <kdebug.h>
 #include <kglobalsettings.h>
 #include <kuserprofile.h>
@@ -30,10 +28,13 @@
 #include <qclipboard.h>
 #include <kio/paste.h>
 #include <qfile.h>
+#include <qpainter.h>
+#include <kiconloader.h>
+#include <qcursor.h>
 
 #define MYMODULE static_cast<KonqSidebarDirTreeModule*>(module())
 
-KonqSidebarDirTreeItem::KonqSidebarDirTreeItem( KonqSidebarTreeItem *parentItem, KonqSidebarTreeTopLevelItem *topLevelItem, KonqFileItem *fileItem )
+KonqSidebarDirTreeItem::KonqSidebarDirTreeItem( KonqSidebarTreeItem *parentItem, KonqSidebarTreeTopLevelItem *topLevelItem, KFileItem *fileItem )
     : KonqSidebarTreeItem( parentItem, topLevelItem ), m_fileItem( fileItem )
 {
     if ( m_topLevelItem )
@@ -41,7 +42,7 @@ KonqSidebarDirTreeItem::KonqSidebarDirTreeItem( KonqSidebarTreeItem *parentItem,
     init();
 }
 
-KonqSidebarDirTreeItem::KonqSidebarDirTreeItem( KonqSidebarTree *parent, KonqSidebarTreeTopLevelItem *topLevelItem, KonqFileItem *fileItem )
+KonqSidebarDirTreeItem::KonqSidebarDirTreeItem( KonqSidebarTree *parent, KonqSidebarTreeTopLevelItem *topLevelItem, KFileItem *fileItem )
     : KonqSidebarTreeItem( parent, topLevelItem ), m_fileItem( fileItem )
 {
     if ( m_topLevelItem )
@@ -78,10 +79,24 @@ void KonqSidebarDirTreeItem::setOpen( bool open )
     kdDebug(1201) << "KonqSidebarDirTreeItem::setOpen " << open << endl;
     if ( open & !childCount() && m_bListable )
         MYMODULE->openSubFolder( this );
-
+    else if ( hasStandardIcon() )
+    {
+        int size = KGlobal::iconLoader()->currentSize( KIcon::Small );
+        if ( open )
+            setPixmap( 0, DesktopIcon( "folder_open", size ) );
+        else
+            setPixmap( 0, m_fileItem->pixmap( size ) );
+    }
     KonqSidebarTreeItem::setOpen( open );
 }
 
+bool KonqSidebarDirTreeItem::hasStandardIcon()
+{
+    // The reason why we can't use KFileItem::iconName() is that it doesn't
+    // take custom icons in .directory files into account
+    return m_fileItem->determineMimeType()->icon( m_fileItem->url(), m_fileItem->isLocalFile() ) == "folder";
+}
+
 void KonqSidebarDirTreeItem::paintCell( QPainter *_painter, const QColorGroup & _cg, int _column, int _width, int _alignment )
 {
     if (m_fileItem->isLink())
@@ -100,7 +115,10 @@ KURL KonqSidebarDirTreeItem::externalURL() const
 
 QString KonqSidebarDirTreeItem::externalMimeType() const
 {
-    return m_fileItem->mimetype();
+    if (m_fileItem->isMimeTypeKnown())
+        return m_fileItem->mimetype();
+    else
+        return QString::null;
 }
 
 bool KonqSidebarDirTreeItem::acceptsDrops( const QStrList & formats )
@@ -136,8 +154,7 @@ void KonqSidebarDirTreeItem::itemSelected()
     QMimeSource *data = QApplication::clipboard()->data();
     bool paste = ( data->encodedData( data->format() ).size() != 0 );
 
-    tree()->part()->enableActions( true, true, paste,
-                                                true && !bInTrash, true, true );
+    tree()->enableActions( true, true, paste, true && !bInTrash, true, true );
 }
 
 void KonqSidebarDirTreeItem::middleButtonPressed()
@@ -145,13 +162,14 @@ void KonqSidebarDirTreeItem::middleButtonPressed()
     // Duplicated from KonqDirPart :(
     // Optimisation to avoid KRun to call kfmclient that then tells us
     // to open a window :-)
-    KService::Ptr offer = KServiceTypeProfile::preferredService(m_fileItem->mimetype(), true);
+    KService::Ptr offer = KServiceTypeProfile::preferredService(m_fileItem->mimetype(), "Application");
     if (offer) kdDebug(1201) << "KonqDirPart::mmbClicked: got service " << offer->desktopEntryName() << endl;
     if ( offer && offer->desktopEntryName().startsWith("kfmclient") )
     {
+        kdDebug(1201)<<"Emitting createNewWindow"<<endl;
         KParts::URLArgs args;
         args.serviceType = m_fileItem->mimetype();
-        emit tree()->part()->getInterfaces()->getExtension()->createNewWindow( m_fileItem->url(), args );
+        emit tree()->createNewWindow( m_fileItem->url(), args );
     }
     else
         m_fileItem->run();
@@ -161,7 +179,7 @@ void KonqSidebarDirTreeItem::rightButtonPressed()
 {
     KFileItemList lstItems;
     lstItems.append( m_fileItem );
-    emit tree()->part()->getInterfaces()->getExtension()->popupMenu( QCursor::pos(), lstItems );
+    emit tree()->popupMenu( QCursor::pos(), lstItems );
 }
 
 void KonqSidebarDirTreeItem::paste()
