@@ -21,17 +21,17 @@
 
 #include "konq_sidebartreeitem.h"
 #include <kurl.h>
-#include <konq_fileitem.h>
 class QDropEvent;
+class KFileItem;
 
 class KonqSidebarDirTreeItem : public KonqSidebarTreeItem
 {
 public:
-    KonqSidebarDirTreeItem( KonqSidebarTreeItem *parentItem, KonqSidebarTreeTopLevelItem *topLevelItem, KonqFileItem *fileItem );
-    KonqSidebarDirTreeItem( KonqSidebarTree *parent, KonqSidebarTreeTopLevelItem *topLevelItem, KonqFileItem *fileItem );
+    KonqSidebarDirTreeItem( KonqSidebarTreeItem *parentItem, KonqSidebarTreeTopLevelItem *topLevelItem, KFileItem *fileItem );
+    KonqSidebarDirTreeItem( KonqSidebarTree *parent, KonqSidebarTreeTopLevelItem *topLevelItem, KFileItem *fileItem );
     ~KonqSidebarDirTreeItem();
 
-    KonqFileItem *fileItem() const { return m_fileItem; }
+    KFileItem *fileItem() const { return m_fileItem; }
 
     virtual void setOpen( bool open );
 
@@ -56,10 +56,11 @@ public:
 
     virtual void itemSelected();
 
+    bool hasStandardIcon();
 private:
     void init();
     void delOperation( int method );
-    KonqFileItem *m_fileItem;
+    KFileItem *m_fileItem;
 
 };
 
