@@ -18,26 +18,18 @@
 */
 
 #include "konq_sidebartreemodule.h"
-#include "konq_sidebartree.h"
 #include <qheader.h>
 #include <qdir.h>
-#include <qfile.h>
 #include <qtimer.h>
 #include <kdebug.h>
-#include <kdesktopfile.h>
-#include <kdirnotify_stub.h>
-#include <konq_operations.h>
-#include <kglobalsettings.h>
-#include <kio/global.h>
 #include <kmimetype.h>
-#include <kstddirs.h>
+#include <kdesktopfile.h>
+#include <kglobalsettings.h>
+#include <kstandarddirs.h>
 #include <kurldrag.h>
 #include <stdlib.h>
 #include <assert.h>
-
-//#include <dirtree_module/dirtree_module.h> // TEMPORARY HACK
-//#include <history_module/history_module.h> // TEMPORARY HACK
-//#include <bookmark_module/bookmark_module.h> // TEMPORARY HACK
+#include <kiconloader.h>
 
 
 static const int autoOpenTimeout = 750;
@@ -60,7 +52,7 @@ void KonqSidebarTree::loadModuleFactories()
 					{kdWarning()<<"Bad Configuration file for a dirtree module "<<*it<<endl; continue;}
 
                                 // try to load the library
-                                QString lib_name="lib"+libname;
+                                QString lib_name=libname;
                                 KLibrary *lib = loader->library(QFile::encodeName(lib_name));
                                 if (lib)
                                 {
@@ -71,7 +63,7 @@ void KonqSidebarTree::loadModuleFactories()
                                                 {
 							getModule func=(getModule)create;
 							plugins.insert(name,func);
-							kdDebug()<<"Added a mdoule"<<endl;
+							kdDebug()<<"Added a module"<<endl;
                                                 }
 					 else {kdWarning()<<"No create function found in"<<lib_name<<endl;}
                                 }
@@ -103,6 +95,7 @@ KonqSidebarTree::KonqSidebarTree( KonqSidebar_Tree *parent, QWidget *parentWidge
 
     m_currentBeforeDropItem = 0;
     m_dropItem = 0;
+    m_bOpeningFirstChild=false;
 
     addColumn( QString::null );
     header()->hide();
@@ -135,18 +128,24 @@ KonqSidebarTree::KonqSidebarTree( KonqSidebar_Tree *parent, QWidget *parentWidge
 //    assert( KGlobal::dirs() );
 //    QString dirtreeDir = part->getInterfaces()->getInstance()->dirs()->saveLocation( "data", "konqueror/dirtree/" );
 
-    if (virt==VIRT_Folder) 
+    if (virt==VIRT_Folder)
 		{
 		  m_dirtreeDir.dir.setPath(KGlobal::dirs()->saveLocation("data","konqsidebartng/virtual_folders/"+path+"/"));
 		  m_dirtreeDir.relDir=path;
 		}
-	else	
+	else
 		m_dirtreeDir.dir.setPath( path );
     kdDebug(1201)<<m_dirtreeDir.dir.path()<<endl;
     m_dirtreeDir.type=virt;
     // Initial parsing
     rescanConfiguration();
-    if (firstChild()) firstChild()->setOpen(true);
+  
+    if (firstChild())
+    {
+      m_bOpeningFirstChild = true;
+      firstChild()->setOpen(true);
+      m_bOpeningFirstChild = false;
+    }
 }
 
 KonqSidebarTree::~KonqSidebarTree()
@@ -176,7 +175,7 @@ void KonqSidebarTree::followURL( const KURL &url )
     }
 
     kdDebug(1201) << "KonqDirTree::followURL: " << url.url() << endl;
-    QListIterator<KonqSidebarTreeTopLevelItem> topItem ( m_topLevelItems );
+    QPtrListIterator<KonqSidebarTreeTopLevelItem> topItem ( m_topLevelItems );
     for (; topItem.current(); ++topItem )
     {
         if ( topItem.current()->externalURL().isParentOf( url ) )
@@ -314,7 +313,7 @@ void KonqSidebarTree::contentsMouseReleaseEvent( QMouseEvent *e )
 void KonqSidebarTree::leaveEvent( QEvent *e )
 {
     KListView::leaveEvent( e );
-    m_part->emitStatusBarText( QString::null );
+//    emitStatusBarText( QString::null );
 }
 
 
@@ -346,7 +345,7 @@ void KonqSidebarTree::slotClicked( QListViewItem *item )
 
     args.serviceType = dItem->externalMimeType();
     args.trustedSource = true;
-    emit m_part->getInterfaces()->getExtension()->openURLRequest( dItem->externalURL(), args );
+    openURLRequest( dItem->externalURL(), args );
 }
 
 void KonqSidebarTree::slotMouseButtonPressed(int _button, QListViewItem* _item, const QPoint&, int col)
@@ -387,7 +386,7 @@ void KonqSidebarTree::rescanConfiguration()
 	else
 		{
 			    kdDebug(1201)<<"KonqSidebarTree::rescanConfiguration()-->loadTopLevel"<<endl;
-		            loadTopLevelItem( 0, m_dirtreeDir.dir.path() ); 
+		            loadTopLevelItem( 0, m_dirtreeDir.dir.path() );
 		}
 }
 
@@ -457,8 +456,9 @@ void KonqSidebarTree::scanDir( KonqSidebarTreeItem *parent, const QString &path,
             // Version 2 includes the history
             // Version 3 includes the bookmarks
             // Version 4 includes lan.desktop and floppy.desktop, Alex
-            // Version 5 includes some stuff from Rob Kaper
-            const int currentVersion = 5;
+            // Version 5 includes the audiocd browser
+            // Version 6 includes the printmanager and lan browser
+            const int currentVersion = 6;
             QString key = QString::fromLatin1("X-KDE-DirTreeVersionNumber");
             KSimpleConfig versionCfg( path + "/.directory" );
             int versionNumber = versionCfg.readNumEntry( key, 1 );
@@ -490,7 +490,7 @@ void KonqSidebarTree::scanDir( KonqSidebarTreeItem *parent, const QString &path,
             if ( !dirtree_dir.isEmpty() && dirtree_dir != path )
             {
                 QDir globalDir( dirtree_dir );
-                ASSERT( globalDir.isReadable() );
+                Q_ASSERT( globalDir.isReadable() );
                 // Only copy the entries that don't exist yet in the local dir
                 QStringList globalDirEntries = globalDir.entryList();
                 QStringList::ConstIterator eIt = globalDirEntries.begin();
@@ -612,6 +612,7 @@ void KonqSidebarTree::loadTopLevelItem( KonqSidebarTreeItem *parent,  const QStr
     // Here's where we need to create the right module...
     // ### TODO: make this KTrader/KLibrary based.
     QString moduleName = cfg.readEntry( "X-KDE-TreeModule" );
+    if (moduleName.isEmpty()) moduleName="Directory";
     kdDebug(1201) << "##### Loading module: " << moduleName << " file: " << filename << endl;
 
     getModule func;
@@ -659,11 +660,15 @@ void KonqSidebarTree::slotAnimation()
 }
 
 
-void KonqSidebarTree::startAnimation( KonqSidebarTreeItem * item, const char * iconBaseName, uint iconCount )
+void KonqSidebarTree::startAnimation( KonqSidebarTreeItem * item, const char * iconBaseName, uint iconCount, const QPixmap * originalPixmap )
 {
-    m_mapCurrentOpeningFolders.insert( item, AnimationInfo( iconBaseName, iconCount, *item->pixmap(0) ) );
-    if ( !m_animationTimer->isActive() )
-        m_animationTimer->start( 50 );
+    const QPixmap *pix = originalPixmap ? originalPixmap : item->pixmap(0);
+    if (pix)
+    {
+        m_mapCurrentOpeningFolders.insert( item, AnimationInfo( iconBaseName, iconCount, *pix ) );
+        if ( !m_animationTimer->isActive() )
+            m_animationTimer->start( 50 );
+    }
 }
 
 void KonqSidebarTree::stopAnimation( KonqSidebarTreeItem * item )
@@ -687,10 +692,11 @@ void KonqSidebarTree::slotOnItem( QListViewItem *item )
 {
     KonqSidebarTreeItem *i = static_cast<KonqSidebarTreeItem *>( item );
     const KURL& url = i->externalURL();
+/*
     if ( url.isLocalFile() )
-	m_part->emitStatusBarText( url.path() );
+	emitStatusBarText( url.path() );
     else
-	m_part->emitStatusBarText( url.prettyURL() );
+	emitStatusBarText( url.prettyURL() );*/
 }
 
 void KonqSidebarTree::setContentsPos( int x, int y )
@@ -701,7 +707,7 @@ void KonqSidebarTree::setContentsPos( int x, int y )
 
 void KonqSidebarTree::slotItemRenamed(QListViewItem* item, const QString &name, int col)
 {
-    ASSERT(col==0);
+    Q_ASSERT(col==0);
     if (col != 0) return;
     assert(item);
     KonqSidebarTreeItem * treeItem = static_cast<KonqSidebarTreeItem *>(item);
@@ -714,6 +720,21 @@ void KonqSidebarTree::slotItemRenamed(QListViewItem* item, const QString &name,
         kdWarning() << "slotItemRenamed: rename not implemented for non-toplevel items" << endl;
 }
 
+
+void KonqSidebarTree::enableActions( bool copy, bool cut, bool paste,
+                        bool trash, bool del, bool shred,
+                        bool rename)
+{
+    enableAction( "copy", copy );
+    enableAction( "cut", cut );
+    enableAction( "paste", paste );
+    enableAction( "trash", trash );
+    enableAction( "del", del );
+    enableAction( "shred", shred );
+    enableAction( "rename", rename );
+}
+
+
 ///////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////
 
@@ -728,4 +749,7 @@ void KonqSidebarTreeToolTip::maybeTip( const QPoint &point )
     }
 }
 
+
+
+
 #include "konq_sidebartree.moc"
