@@ -26,9 +26,7 @@
 #define __DESKTOP_H
 
 #include <qwidget.h>
-/*#include <qpainter.h>
-#include <qpoint.h>
-*/
+#include <qintdict.h>
 #include <kwin.h>
 
 class KSharedPixmap;
@@ -77,6 +75,7 @@ public:
 	static void removeCachedPixmap(int nWin) { m_windowPixmaps.remove(nWin); };
 
   QSize sizeHint() const;
+  void paintFrame();
  
   bool m_grabWindows;
 public slots:
@@ -84,8 +83,6 @@ public slots:
 
   void loadBgPixmap();
 
-protected slots:
-
 protected:
   void mousePressEvent( QMouseEvent *ev );
   void mouseMoveEvent( QMouseEvent *ev );
