@@ -5,7 +5,7 @@
 			Matthias Ettrich
 			Matthias Elter
 
-    $Id: kpager.cpp,v 1.31 2001/05/02 20:35:23 lunakl Exp $
+    $Id: kpager.cpp,v 1.44 2002/03/18 05:32:30 waba Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,12 +38,16 @@
 #include <config.h>
 #endif
 
+
+#include "kpager.h"
+
 #include <qintdict.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qlayout.h>
 #include <qtooltip.h>
+#include <qtimer.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kconfig.h>
 #include <kdebug.h>
@@ -51,13 +55,15 @@
 #include <kwin.h>
 #include <kwinmodule.h>
 #include <netwm.h>
-
-#include "kpager.h"
 #include "desktop.h"
+#include <qpopupmenu.h>
+#include <kpopupmenu.h>
 
 KPagerMainWindow::KPagerMainWindow(QWidget *parent, const char *name)
-	: KMainWindow(parent, name)
+	: KMainWindow(parent, name), DCOPObject("KPagerIface")
 {
+    m_reallyClose=false;
+
     m_pPager = new KPager(this, 0);
     setCentralWidget(m_pPager);
 
@@ -69,7 +75,7 @@ KPagerMainWindow::KPagerMainWindow(QWidget *parent, const char *name)
     int h = cfg->readNumEntry(m_pPager->lHeight(),-1);
     if (w > 0 && h > 0)
         resize(w,h);
-    else 
+    else
         resize(m_pPager->sizeHint());
     //  resize(cfg->readNumEntry(lWidth(),200),cfg->readNumEntry(lHeight(),90));
 
@@ -85,8 +91,7 @@ KPagerMainWindow::KPagerMainWindow(QWidget *parent, const char *name)
 //	  rect.pos.y+rect.size.height-m_pPager->height());
 // antonio:The above lines don't work. I should look at them when I have
 // more time
-        move(kapp->desktop()->width()-m_pPager->width()-5,kapp->desktop()->height()-m_pPager->height()-25);
-
+        move(kapp->desktop()->width()-m_pPager->sizeHint().width()-5,kapp->desktop()->height()-m_pPager->sizeHint().height()-25);
     }
 
     // Set the wm flags to this window
@@ -99,6 +104,9 @@ KPagerMainWindow::KPagerMainWindow(QWidget *parent, const char *name)
     hints.flags = InputHint;
 
     XSetWMHints(x11Display(), winId(), &hints);
+
+    timeout=new QTimer(this,"timeoutToQuit");
+    connect(timeout,SIGNAL(timeout()),this, SLOT(reallyClose()));
 }
 
 KPagerMainWindow::~KPagerMainWindow()
@@ -117,29 +125,61 @@ bool KPagerMainWindow::queryClose()
     cfg->writeEntry("yPos",y());
     cfg->sync();
 
-    return true;
+    if (m_reallyClose) return true;
+
+    hide();
+    timeout->start(10 /*minutes*/ *60000, true);
+
+    return false;
 }
 
-KPager::KPager(QWidget *parent, const char *name, WId parentWId)
+void KPagerMainWindow::showEvent( QShowEvent *ev )
+{
+  timeout->stop();
+  KMainWindow::showEvent(ev); 
+}
+
+void KPagerMainWindow::reallyClose()
+{
+  m_reallyClose=true;
+  close();
+}
+
+void KPagerMainWindow::showAt(int x, int y)
+{
+  // Just in case we lost the sticky bit... (as when a window is hidden)
+  KWin::setOnAllDesktops( winId(), true);
+  
+  if (x>kapp->desktop()->width()/2) // Right
+    x-=m_pPager->width()+5;
+  if (y>kapp->desktop()->height()/2) // Bottom
+    y-=m_pPager->height()+25;
+  move(x,y);
+  show();
+}
+
+void KPagerMainWindow::toggleShow(int x, int y)
+{
+  if (isVisible())
+  {
+    hide();
+    timeout->start(10 /*minutes*/ *60000, true);
+  }
+  else 
+    showAt(x,y);
+}
+
+KPager::KPager(QWidget *parent, const char *name)
 	: QFrame (parent, name, WStyle_Customize | WStyle_NoBorder | WStyle_Tool)
     , m_layout(0)
     , m_mnu(0)
     , m_smnu(0)
     , m_dmnu(0)
-    , m_bIsEmbedded(false)
 {
     Window rr;
     int x, y;
     unsigned int nWd, nHg, b, d;
 
-    if (parentWId)
-    {
-        m_bIsEmbedded = true;
-
-        XGetGeometry(qt_xdisplay(), parentWId, &rr, &x, &y, &nWd, &nHg, &b, &d);
-        XReparentWindow(qt_xdisplay(), winId(), parentWId, 2, 2);
-    }
-
     m_windows.setAutoDelete(true); // delete windows info after removal
 
     setBackgroundColor( black );
@@ -149,7 +189,7 @@ KPager::KPager(QWidget *parent, const char *name, WId parentWId)
     m_grabWinTimer=new QTimer(this,"grabWinTimer");
     connect(m_grabWinTimer, SIGNAL(timeout()), this, SLOT(slotGrabWindows()));
 
-    KPagerConfigDialog::initConfiguration(m_bIsEmbedded);
+    KPagerConfigDialog::initConfiguration();
 
     KConfig *cfg = kapp->config();
     cfg->setGroup("KPager");
@@ -185,15 +225,16 @@ KPager::KPager(QWidget *parent, const char *name, WId parentWId)
 
     QFont defFont("Helvetica", 10, QFont::Bold);
     defFont = cfg->readFontEntry("Font", &defFont);
+#if QT_VERSION < 300
     setFontPropagation(AllChildren);
+#else
+#ifdef __GNUC__
+#warning FIXME!
+#endif
+#endif
     setFont(defFont);
 
     updateLayout();
-
-    if (m_bIsEmbedded)
-    {
-        setGeometry(2, 2, nWd - 4, nHg - 4);
-    }
 }
 
 KPager::~KPager()
@@ -239,16 +280,17 @@ void KPager::updateLayout()
     int i,j;
     i=j=0;
     int ndesks=0;
+    int halfdesks = (m_desktops.count() + 1) / 2;
     for( it = m_desktops.begin(); it != m_desktops.end(); ++it )
     {
         m_layout->addWidget(*it,i,j);
+        ndesks++;
         switch (m_layoutType)
         {
-            case (Classical) :  i=(i%2)? j++, 0: i+1; break;
+            case (Classical) :  i= ndesks / halfdesks; j = ndesks % halfdesks; break;
             case (Horizontal) : j++; break;
             case (Vertical) :   i++; break;
         };
-        ndesks++;
     }
 
     m_layout->activate();
@@ -265,9 +307,6 @@ void KPager::updateLayout()
 
 void KPager::showPopupMenu( WId wid, QPoint pos)
 {
-    if (m_bIsEmbedded) // no popup menu for embedded pager
-        return;
-
     if (wid <= 0) {
 	if(!m_smnu) {
 	    m_smnu = new QPopupMenu(this);
@@ -298,7 +337,7 @@ void KPager::showPopupMenu( WId wid, QPoint pos)
                 m_mnu->insertItem( QString("&Sticky"), StickyOp );  // Add translation
             m_mnu->insertSeparator();
 
-            m_mnu->insertItem(i18n("&To desktop"), m_dmnu );
+            m_mnu->insertItem(i18n("&To Desktop"), m_dmnu );
             m_mnu->insertSeparator();
 
             m_mnu->insertItem(i18n("&Close"), CloseOp);
@@ -317,23 +356,21 @@ void KPager::configureDialog()
     if (dialog->exec())
     {
         m_layoutType=static_cast<enum KPager::LayoutTypes>(KPagerConfigDialog::m_layoutType);
-        if (!m_bIsEmbedded)
-        {
-            KConfig *cfg=KGlobal::config();
-            int nWd = (parent() ? ((QWidget *)parent())->width() : width());
-            int nHg = (parent() ? ((QWidget *)parent())->width() : width());
+	KConfig *cfg=KGlobal::config();
+	int nWd = (parent() ? ((QWidget *)parent())->width() : width());
+	int nHg = (parent() ? ((QWidget *)parent())->width() : width());
 
-						cfg->setGroup("KPager");
+	cfg->setGroup("KPager");
+
+	cfg->writeEntry(lWidth(),nWd);
+	cfg->writeEntry(lHeight(),nHg);
+	cfg->writeEntry("windowDrawMode",KPagerConfigDialog::m_windowDrawMode);
+	cfg->writeEntry("layoutType",KPagerConfigDialog::m_layoutType);
+	cfg->writeEntry("showNumber",KPagerConfigDialog::m_showNumber);
+	cfg->writeEntry("showName",KPagerConfigDialog::m_showName);
+	cfg->writeEntry("showWindows",KPagerConfigDialog::m_showWindows);
+	cfg->writeEntry("showBackground",KPagerConfigDialog::m_showBackground);
 
-            cfg->writeEntry(lWidth(),nWd);
-            cfg->writeEntry(lHeight(),nHg);
-            cfg->writeEntry("windowDrawMode",KPagerConfigDialog::m_windowDrawMode);
-            cfg->writeEntry("layoutType",KPagerConfigDialog::m_layoutType);
-            cfg->writeEntry("showNumber",KPagerConfigDialog::m_showNumber);
-            cfg->writeEntry("showName",KPagerConfigDialog::m_showName);
-            cfg->writeEntry("showWindows",KPagerConfigDialog::m_showWindows);
-            cfg->writeEntry("showBackground",KPagerConfigDialog::m_showBackground);
-        }
         updateLayout();
         for( QValueList <Desktop *>::Iterator it = m_desktops.begin(); it != m_desktops.end(); ++it )
             (*it)->repaint();
@@ -450,7 +487,7 @@ void KPager::slotWindowChanged( WId win , unsigned int prop)
 	}
       }
       prop &= ~NET::WMName;
-    } 
+    }
 
     if (prop & NET::WMVisibleName) prop &= ~NET::WMVisibleName;
       // XXX Should update the VisibleName property ?
@@ -464,7 +501,7 @@ void KPager::slotWindowChanged( WId win , unsigned int prop)
       repaint=true;
     }
 
-    if (prop) 
+    if (prop)
     {
       m_windows.remove( (long) win );
       inf = info( win );
@@ -546,8 +583,10 @@ void KPager::slotNumberOfDesktopsChanged(int ndesktops)
 void KPager::slotCurrentDesktopChanged(int desk)
 {
     if (m_currentDesktop==desk) return;
-    m_desktops[m_currentDesktop-1]->repaint();
-    m_desktops[desk-1]->repaint();
+    m_desktops[m_currentDesktop-1]->paintFrame();
+    m_desktops[desk-1]->paintFrame();
+//    m_desktops[m_currentDesktop-1]->repaint();
+//    m_desktops[desk-1]->repaint();
 
     m_currentDesktop=desk;
 
@@ -589,7 +628,7 @@ void KPager::desktopPopupAboutToShow()
     if (!m_dmnu) return;
 
     m_dmnu->clear();
-    m_dmnu->insertItem( i18n("&All desktops"), 0 );
+    m_dmnu->insertItem( i18n("&All Desktops"), 0 );
     m_dmnu->insertSeparator();
 
     if (m_winfo.onAllDesktops)
@@ -654,7 +693,7 @@ void KPager::slotGrabWindows()
 
 QSize KPager::sizeHint() const
 {
-    int n=m_desktops.count();   
+    int n=m_desktops.count();
     int w=-1,h=-1;
 
     QSize size=m_desktops[0]->sizeHint();
