@@ -46,7 +46,7 @@ either KDE, CDE, win or mac and pre-sets the style.
   void presetStyle(const QString& style);
 
   private:
-    QString currTheme;
+    QString origStyle;
   struct colorSet{
     QString colorFile, bgMode;
     int contrast;
