@@ -12,14 +12,11 @@ Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 #include <errno.h>
 #include <string.h>
 
-#undef Unsorted // for --enable-final
-
+#include <dcopclient.h>
 #include <qmessagebox.h>
 #include <qdir.h>
 
-#include <dcopclient.h>
-
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kdebug.h>
@@ -28,6 +25,7 @@ Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 #include <kconfig.h>
 #include "server.h"
 
+
 static const char *version = "0.4";
 static const char *description = I18N_NOOP( "The reliable KDE session manager that talks the standard X11R6 \nsession management protocol (XSMP)." );
 
@@ -100,7 +98,7 @@ void sanity_check( int argc, char* argv[] )
   if (msg.isEmpty())
   {
      path += "/.ICEauthority";
- 
+
      if (access(path.data(), W_OK) && (errno != ENOENT))
         msg = "No write access to '%s'.";
      else if (access(path.data(), R_OK) && (errno != ENOENT))
@@ -109,7 +107,7 @@ void sanity_check( int argc, char* argv[] )
   if (msg.isEmpty())
   {
      path = getenv("KDETMP");
-     if (path.isEmpty()) 
+     if (path.isEmpty())
         path = "/tmp";
      if (!writeTest(path))
      {
@@ -142,7 +140,7 @@ void sanity_check( int argc, char* argv[] )
   }
   if (!msg.isEmpty())
   {
-    const char *msg_pre = 
+    const char *msg_pre =
              "The following installation problem was detected\n"
              "while trying to start KDE:"
              "\n\n    ";
@@ -150,11 +148,11 @@ void sanity_check( int argc, char* argv[] )
     fprintf(stderr, msg_pre);
     fprintf(stderr, msg.data(), path.data());
     fprintf(stderr, msg_post);
- 
+
     QApplication a(argc, argv);
     QCString qmsg(256+path.length());
     qmsg.sprintf(msg.data(), path.data());
-    qmsg = msg_pre+qmsg+msg_post; 
+    qmsg = msg_pre+qmsg+msg_post;
     QMessageBox::critical(0, "KDE Installation Problem!",
         QString::fromLatin1(qmsg.data()));
     exit(255);
@@ -177,6 +175,7 @@ int main( int argc, char* argv[] )
     KApplication a(false, true); // Disable styles until we need them.
     fcntl(ConnectionNumber(qt_xdisplay()), F_SETFD, 1);
 
+
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     kapp->dcopClient()->registerAs("ksmserver", false);
@@ -203,12 +202,14 @@ int main( int argc, char* argv[] )
 #endif
 
     KSMServer *server = new KSMServer( QString::fromLatin1(wm), only_local);
-    IceSetIOErrorHandler (IoErrorHandler );
+    IceSetIOErrorHandler( IoErrorHandler );
 
     KConfig *config = KGlobal::config();
+    config->setGroup( "General" );
 
+    int realScreenCount = ScreenCount( qt_xdisplay() );
     bool screenCountChanged =
-         (config->readNumEntry("screenCount") != ScreenCount(qt_xdisplay()));
+         ( config->readNumEntry( "screenCount", realScreenCount ) != realScreenCount );
 
     if ( args->isSet("restore") && ! screenCountChanged )
 	server->restoreSession();
