@@ -58,7 +58,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qdatastream.h>
-#include <qstack.h>
+#include <qptrstack.h>
 #include <qpushbutton.h>
 #include <qmessagebox.h>
 #include <qguardedptr.h>
@@ -66,9 +66,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <klocale.h>
 #include <kglobal.h>
 #include <kconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <unistd.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <knotifyclient.h>
 #include <kstaticdeleter.h>
 #include <dcopclient.h>
@@ -80,6 +80,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "server.moc"
 
 #include <kdebug.h>
+#include <qregexp.h>
 
 extern "C" {
     /* int umask(...); */
@@ -114,7 +115,7 @@ KSMClient::~KSMClient()
 
 SmProp* KSMClient::property( const char* name ) const
 {
-    for ( QListIterator<SmProp> it( properties ); it.current(); ++it ) {
+    for ( QPtrListIterator<SmProp> it( properties ); it.current(); ++it ) {
 	if ( !qstrcmp( it.current()->name, name ) )
 	    return it.current();
     }
@@ -141,7 +142,7 @@ char * safeSmsGenerateClientID( SmsConn c )
     if (!ret) {
         static QString *my_addr = 0;
        if (!my_addr) {
-           qDebug("Can't get own host name. Your system is severely misconfigured\n");
+           qWarning("Can't get own host name. Your system is severely misconfigured\n");
            my_addr = smy_addr.setObject(new QString);
 
            /* Faking our IP address, the 0 below is "unknown" address format
@@ -309,16 +310,27 @@ void KSMInteractDoneProc (
 }
 
 void KSMSaveYourselfRequestProc (
-    SmsConn		/* smsConn */,
+    SmsConn		smsConn ,
     SmPointer		/* managerData */,
-    int  		/* saveType */,
-    Bool		/* shutdown */,
-    int			/* interactStyle */,
+    int  		saveType,
+    Bool		shutdown,
+    int			interactStyle,
     Bool		fast,
-    Bool		/* global */
+    Bool		global
 )
 {
-    the_server->shutdown( fast );
+    if ( shutdown ) {
+	the_server->shutdown( fast ?
+			      KApplication::ShutdownConfirmNo :
+			      KApplication::ShutdownConfirmDefault,
+			      KApplication::ShutdownTypeDefault,
+			      KApplication::ShutdownModeDefault );
+    } else if ( !global ) {
+	SmsSaveYourself( smsConn, saveType, FALSE, interactStyle, fast );
+	SmsSaveComplete( smsConn );
+    } 
+    // else checkpoint only, ksmserver does not yet support this
+    // mode. Will come for KDE 3.1
 }
 
 void KSMSaveYourselfPhase2RequestProc (
@@ -364,8 +376,10 @@ void KSMSetPropertiesProc (
     KSMClient* client = ( KSMClient* ) managerData;
     for ( int i = 0; i < numProps; i++ ) {
 	SmProp *p = client->property( props[i]->name );
-	if ( p )
+	if ( p ) {
 	    client->properties.removeRef( p );
+	    SmFreeProperty( p );
+	}
 	client->properties.append( props[i] );
 	if ( !qstrcmp( props[i]->name, SmProgram ) )
 	    the_server->clientSetProgram( client );
@@ -386,8 +400,10 @@ void KSMDeletePropertiesProc (
     KSMClient* client = ( KSMClient* ) managerData;
     for ( int i = 0; i < numProps; i++ ) {
 	SmProp *p = client->property( propNames[i] );
-	if ( p )
+	if ( p ) {
 	    client->properties.removeRef( p );
+	    SmFreeProperty( p );
+	}
     }
 }
 
@@ -796,8 +812,11 @@ KSMServer::KSMServer( const QString& windowManager, bool _only_local )
         QCString display = ::getenv("DISPLAY");
 	// strip the screen number from the display
 	display.replace(QRegExp("\\.[0-9]+$"), "");
+        int i;
+        while( (i = display.find(':')) >= 0)
+           display[i] = '_';
 
-        fName += "-"+display;
+        fName += "_"+display;
 	FILE *f;
 	f = ::fopen(fName.data(), "w+");
 	if (!f)
@@ -866,8 +885,11 @@ void KSMServer::cleanUp()
     QCString display = ::getenv("DISPLAY");
     // strip the screen number from the display
     display.replace(QRegExp("\\.[0-9]+$"), "");
+    int i;
+    while( (i = display.find(':')) >= 0)
+         display[i] = '_';
 
-    fName += "-"+display;
+    fName += "_"+display;
     ::unlink(fName.data());
 
     FreeAuthenticationData(numTransports, authDataEntries);
@@ -894,7 +916,7 @@ void KSMServer::removeConnection( KSMConnection* conn )
 /*!
   Called from our IceIoErrorHandler
  */
-void KSMServer::ioError( IceConn /* iceConn */ )
+void KSMServer::ioError( IceConn iceConn  )
 {
 }
 
@@ -904,10 +926,9 @@ void KSMServer::processData( int /*socket*/ )
     IceProcessMessagesStatus status = IceProcessMessages( iceConn, 0, 0 );
     if ( status == IceProcessMessagesIOError ) {
 	IceSetShutdownNegotiation( iceConn, False );
-	QListIterator<KSMClient> it ( clients );
+	QPtrListIterator<KSMClient> it ( clients );
 	while ( it.current() &&SmsGetIceConnection( it.current()->connection() ) != iceConn )
 	    ++it;
-
 	if ( it.current() ) {
 	    SmsConn smsConn = it.current()->connection();
 	    deleteClient( it.current() );
@@ -958,70 +979,125 @@ void KSMServer::newConnection( int /*socket*/ )
 
     if (cstatus != IceConnectAccepted) {
 	if (cstatus == IceConnectIOError)
-	    qWarning ("IO error opening ICE Connection!\n");
+	    kdDebug() << "IO error opening ICE Connection!" << endl;
 	else
-	    qWarning ("ICE Connection rejected!\n");
+	    kdDebug() << "ICE Connection rejected!" << endl;
 	(void )IceCloseConnection (iceConn);
     }
 }
 
 
-void KSMServer::shutdown()
-    { shutdown( false ); }
-
-void KSMServer::shutdown( bool bFast )
+void KSMServer::shutdown( KApplication::ShutdownConfirm confirm,
+    KApplication::ShutdownType sdtype, KApplication::ShutdownMode sdmode )
 {
     if ( state != Idle )
 	return;
     if ( dialogActive )
-        return;
+	return;
     dialogActive = true;
 
+    bool maysd, maynuke;
+    KApplication::ShutdownMode defsdmode;
+    QString fifoname;
+    QStringList dmopt =
+	QStringList::split( QChar( ',' ),
+			    QString::fromLatin1( ::getenv( "XDM_MANAGED" ) ) );
+    if ( dmopt.isEmpty() || dmopt.first()[0] != QChar( '/' ) ) {
+	fifoname = QString::null;
+	maysd = maynuke = false;
+	defsdmode = KApplication::ShutdownModeSchedule;
+    } else {
+	fifoname = dmopt.first();
+	maysd = dmopt.contains( QString::fromLatin1( "maysd" ) ) != 0;
+	maynuke = dmopt.contains( QString::fromLatin1( "mayfn" ) ) != 0;
+	if ( dmopt.contains( QString::fromLatin1( "fn" ) ) != 0 )
+	    defsdmode = KApplication::ShutdownModeForceNow;
+	else if ( dmopt.contains( QString::fromLatin1( "tn" ) ) != 0 )
+	    defsdmode = KApplication::ShutdownModeTryNow;
+	else
+	    defsdmode = KApplication::ShutdownModeSchedule;
+    }
+
     // don't use KGlobal::config here! config may have changed!
     KConfig *cfg = new KConfig("ksmserverrc", false, false);
     cfg->setGroup("General" );
     bool old_saveSession = saveSession =
-	cfg->readBoolEntry( "saveSession", FALSE );
-    bool confirmLogout = !bFast && cfg->readBoolEntry( "confirmLogout", TRUE );
+			   cfg->readBoolEntry( "saveSession", true );
+    bool logoutConfirmed =
+	(confirm == KApplication::ShutdownConfirmYes) ? false :
+       (confirm == KApplication::ShutdownConfirmNo) ? true :
+		  !cfg->readBoolEntry( "confirmLogout", true );
+    KApplication::ShutdownType old_sdtype = (KApplication::ShutdownType)
+					    cfg->readNumEntry( "shutdownType",
+							       (int)KApplication::ShutdownTypeNone );
+    if (sdtype == KApplication::ShutdownTypeDefault)
+	sdtype = old_sdtype;
+    KApplication::ShutdownMode old_sdmode = (KApplication::ShutdownMode)
+					    cfg->readNumEntry( "shutdownMode", (int)defsdmode );
+    if (sdmode == KApplication::ShutdownModeDefault)
+	sdmode = old_sdmode;
     delete cfg;
- 
-    if ( confirmLogout ) {
-        KSMShutdownFeedback::start(); // make the screen gray
-        connect( KSMShutdownFeedback::self(), SIGNAL( aborted() ), SLOT( cancelShutdown() ) );
+
+    if (!maysd)
+	sdtype = KApplication::ShutdownTypeNone;
+    if (!maynuke && sdmode == KApplication::ShutdownModeForceNow)
+	sdmode = KApplication::ShutdownModeSchedule;
+
+    if ( !logoutConfirmed ) {
+  	KSMShutdownFeedback::start(); // make the screen gray
+	logoutConfirmed =
+	    KSMShutdownDlg::confirmShutdown( saveSession,
+					     maysd, maynuke, sdtype, sdmode );
+	// ###### We can't make the screen remain gray while talking to the apps,
+	// because this prevents interaction ("do you want to save", etc.)
+	// TODO: turn the feedback widget into a list of apps to be closed,
+	// with an indicator of the current status for each.
+  	KSMShutdownFeedback::stop(); // make the screen become normal again
     }
 
-    if ( !confirmLogout || KSMShutdownDlg::confirmShutdown( saveSession ) ) {
+    if ( logoutConfirmed ) {
 	// Set the real desktop background to black so that exit looks
 	// clean regardless of what was on "our" desktop.
 	kapp->desktop()->setBackgroundColor( Qt::black );
 	KNotifyClient::event( "exitkde" ); // KDE says good bye
-	if (saveSession != old_saveSession) {
+	if (saveSession != old_saveSession ||
+	    sdtype != old_sdtype || sdmode != old_sdmode) {
 	    KConfig* config = KGlobal::config();
 	    config->setGroup("General" );
 	    config->writeEntry( "saveSession", saveSession);
+	    config->writeEntry( "shutdownType", (int)sdtype);
+	    config->writeEntry( "shutdownMode", (int)sdmode);
 	}
 	if ( saveSession )
-	    discardSession();
+	    discardStoredSession();
 	state = Shutdown;
 	startProtection();
 	for ( KSMClient* c = clients.first(); c; c = clients.next() ) {
 	    c->resetState();
 	    SmsSaveYourself( c->connection(), saveSession?SmSaveBoth: SmSaveGlobal,
 			     TRUE, SmInteractStyleAny, FALSE );
+
 	}
 	if ( clients.isEmpty() )
 	    completeShutdown();
+	if ( sdtype != KApplication::ShutdownTypeNone ) {
+	    QFile fifo( fifoname );
+	    if ( fifo.open( IO_WriteOnly | IO_Raw ) ) {
+		QCString cmd( "shutdown\t" );
+		cmd.append( sdtype == KApplication::ShutdownTypeReboot ?
+			    "reboot\t" : "halt\t" );
+		cmd.append( sdmode == KApplication::ShutdownModeForceNow ?
+			    "forcenow\n" :
+			    sdmode == KApplication::ShutdownModeTryNow ?
+			    "trynow\n" : "schedule\n" );
+		fifo.writeBlock( cmd.data(), cmd.length() );
+		fifo.close();
+	    }
+	}
     }
-    // ###### We can't make the screen remain gray while talking to the apps,
-    // because this prevents interaction ("do you want to save", etc.)
-    // TODO: turn the feedback widget into a list of apps to be closed,
-    // with an indicator of the current status for each.
-    //else
-        KSMShutdownFeedback::stop(); // so that the screen becomes normal again
     dialogActive = false;
 }
 
-
 // callbacks
 void KSMServer::saveYourselfDone( KSMClient* client, bool success )
 {
@@ -1098,7 +1174,6 @@ void KSMServer::cancelShutdown()
     for ( KSMClient* c = clients.first(); c; c = clients.next() )
  	SmsShutdownCancelled( c->connection() );
     state = Idle;
-    KSMShutdownFeedback::stop(); // so that the screen becomes normal again
 }
 
 /*
@@ -1153,7 +1228,9 @@ void KSMServer::completeShutdown()
 	return;
 
     if ( saveSession )
-	storeSesssion();
+	storeSession();
+    else
+	discardSession();
 
     // kill all clients
     state = Killing;
@@ -1172,7 +1249,7 @@ void KSMServer::completeShutdown()
 
 void KSMServer::completeKilling()
 {
-    kdDebug(0) << "KSMServer::completeKilling clients.count()=" <<
+    kdDebug() << "KSMServer::completeKilling clients.count()=" <<
 	clients.count() << endl;
     if ( state != Killing ) {
 // 	kdWarning() << "Not Killing !!! state=" << state << endl;
@@ -1180,7 +1257,7 @@ void KSMServer::completeKilling()
     }
 
     if ( clients.isEmpty() ) {
-	kdDebug(0) << "Calling qApp->quit()" << endl;
+	kdDebug() << "Calling qApp->quit()" << endl;
 	qApp->quit();
     } else {
 	for (KSMClient *c = clients.first(); c; c = clients.next()) {
@@ -1188,8 +1265,9 @@ void KSMServer::completeKilling()
 		return;
 	}
 	// the wm was not killed yet, do it
-	for (KSMClient *c = clients.first(); c; c = clients.next())
+	for (KSMClient *c = clients.first(); c; c = clients.next()) {
 	    SmsDie( c->connection() );
+	}
     }
 }
 
@@ -1198,7 +1276,7 @@ void KSMServer::timeoutQuit()
     qApp->quit();
 }
 
-void KSMServer::discardSession()
+void KSMServer::discardStoredSession()
 {
     KConfig* config = KGlobal::config();
     config->setGroup("Session" );
@@ -1207,10 +1285,20 @@ void KSMServer::discardSession()
 	QString n = QString::number(i);
 	executeCommand( config->readListEntry( QString("discardCommand")+n ) );
     }
-    config->writeEntry( "count", 0 );
+    config->deleteGroup("Session");
 }
 
-void KSMServer::storeSesssion()
+void KSMServer::discardSession()
+{
+    for ( KSMClient* c = clients.first(); c; c = clients.next() ) {
+	QStringList discardCommand = c->discardCommand();
+	if ( discardCommand.isEmpty())
+	    continue;
+	executeCommand( discardCommand );
+    }
+}
+
+void KSMServer::storeSession()
 {
     KConfig* config = KGlobal::config();
     config->setGroup("Session" );
@@ -1246,7 +1334,7 @@ void KSMServer::storeSesssion()
  */
 void KSMServer::restoreSession()
 {
-    kdDebug(0) << "KSMServer::restoreSession" << endl;
+    kdDebug() << "KSMServer::restoreSession" << endl;
     upAndRunning( "restore session");
     KConfig* config = KGlobal::config();
     config->setGroup("Session" );
@@ -1290,9 +1378,9 @@ void KSMServer::restoreSession()
  */
 void KSMServer::startDefaultSession()
 {
-    upAndRunning( "start session" );
-    progress = 1;
-    publishProgress( progress, true );
+    progress = 0;
+    upAndRunning( "session ready" );
+    publishProgress( progress );
     startApplication( wm );
     QTimer::singleShot( 4000, this, SLOT( autoStart() ) );
 }
@@ -1306,9 +1394,44 @@ bool KSMServer::process(const QCString &fun, const QByteArray &data,
        replyType = "void";
        return true;
     }
+    if (fun == "restoreSessionDone()")
+    {
+       restoreSessionDone();
+       replyType = "void";
+       return true;
+    }
+    else if (fun == "logout(int,int,int)")
+    {
+	int confirm, sdtype, sdmode;
+	QDataStream arg( data, IO_ReadOnly );
+	arg >> confirm;
+	arg >> sdtype;
+	arg >> sdmode;
+        shutdown( (KApplication::ShutdownConfirm)confirm,
+                  (KApplication::ShutdownType)sdtype,
+                  (KApplication::ShutdownMode)sdmode );
+	replyType = "void";
+        return true;
+    }
     return DCOPObject::process(fun, data, replyType, replyData);
 }
 
+/*
+QCStringList KSMServer::interfaces()
+{
+    QCStringList ifaces = DCOPObject::interfaces();
+    ifaces += "ksmserver";
+    return ifaces;
+}
+*/
+
+QCStringList KSMServer::functions()
+{
+    QCStringList funcs = DCOPObject::functions();
+    funcs << "void logout(int,int,int)";
+    return funcs;
+}
+
 void KSMServer::autoStart()
 {
     static bool beenThereDoneThat = FALSE;
@@ -1316,7 +1439,23 @@ void KSMServer::autoStart()
 	return;
     beenThereDoneThat = TRUE;
 
-    kapp->dcopClient()->send("klauncher", "klauncher", "autoStart()", QByteArray());
+    QByteArray data;
+    QDataStream arg(data, IO_WriteOnly);
+    arg << (int)1;
+    kapp->dcopClient()->send("klauncher", "klauncher", "autoStart(int)", data);
+}
+
+void KSMServer::autoStart2()
+{
+    static bool beenThereDoneThat = FALSE;
+    if ( beenThereDoneThat )
+	return;
+    beenThereDoneThat = TRUE;
+
+    QByteArray data;
+    QDataStream arg(data, IO_WriteOnly);
+    arg << (int)2;
+    kapp->dcopClient()->send("klauncher", "klauncher", "autoStart(int)", data);
 }
 
 
@@ -1348,6 +1487,17 @@ void KSMServer::restoreSessionInternal()
 
 	startApplication( restartCommand );
     }
+
+    connectDCOPSignal( "klauncher", "klauncher", "autoStart2Done()",
+                       "restoreSessionDone()", true);
+    autoStart2();
+}
+
+
+void KSMServer::restoreSessionDone()
+{
+    disconnectDCOPSignal( "klauncher", "klauncher", "autoStart2Done()",
+                          "restoreSessionDone()");
     if (progress == 0) {
 	publishProgress( progress );
 	upAndRunning( "session ready" );
