@@ -12,7 +12,7 @@ Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 #include <qobject.h>
 #include <qstring.h>
 #include <qsocketnotifier.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qvaluelist.h>
 #include <qcstring.h>
 #include <qdict.h>
@@ -33,7 +33,7 @@ extern "C" {
 #include <X11/SM/SMlib.h>
 }
 
-#include "dcopobject.h"
+#include <dcopobject.h>
 
 typedef QValueList<QCString> QCStringList;
 class KSMListener;
@@ -53,7 +53,7 @@ public:
     uint waitForPhase2 : 1;
     uint wasPhase2 : 1;
 
-    QList<SmProp> properties;
+    QPtrList<SmProp> properties;
     SmProp* property( const char* name ) const;
 
     QString program() const;
@@ -67,7 +67,7 @@ private:
     SmsConn smsConn;
 };
 
-class KSMServer : public QObject, DCOPObject
+class KSMServer : public QObject, public DCOPObject
 {
 Q_OBJECT
 public:
@@ -90,8 +90,9 @@ public:
     void ioError( IceConn iceConn );
 
     // DCOP processing
-    bool process(const QCString &, const QByteArray &,
-                 QCString&, QByteArray &);
+    bool process( const QCString &, const QByteArray &,
+                  QCString&, QByteArray & );
+    QCStringList functions();
 
     // notification
     void clientSetProgram( KSMClient* client );
@@ -99,13 +100,11 @@ public:
     // public API
     void restoreSession();
     void startDefaultSession();
+    void shutdown( KApplication::ShutdownConfirm confirm,
+                   KApplication::ShutdownType sdtype,
+                   KApplication::ShutdownMode sdmode );
 
 public slots:
-    void shutdown();
-    // If fast shutdown is select, the confirmation dialog will be skipped.
-    // This allows users whose default is to confirm to shutdown immediately.
-    // It does not yet allow for confirmation when immediate shutdown is the default.
-    void shutdown( bool bFast );
     void cleanUp();
 
 private slots:
@@ -113,9 +112,9 @@ private slots:
     void processData( int socket );
     void timeoutQuit();
     void restoreSessionInternal();
+    void restoreSessionDone();
 
     void protectionTimeout();
-    void cancelShutdown();
 
     void autoStart();
 
@@ -123,9 +122,11 @@ private:
     void handlePendingInteractions();
     void completeShutdown();
     void completeKilling();
+    void cancelShutdown();
 
     void discardSession();
-    void storeSesssion();
+    void storeSession();
+    void discardStoredSession();
 
     void startProtection();
     void endProtection();
@@ -133,9 +134,11 @@ private:
     void startApplication( const QStringList& command );
     void executeCommand( const QStringList& command );
 
+    void autoStart2();
+
  private:
-    QList<KSMListener> listener;
-    QList<KSMClient> clients;
+    QPtrList<KSMListener> listener;
+    QPtrList<KSMClient> clients;
 
     enum State { Idle, Shutdown, Killing }; // KSMServer does not support pure checkpoints yet.
     State state;
