@@ -10,55 +10,53 @@ Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 #include <qpixmap.h>
 #include <qdialog.h>
 class QCheckBox;
+class QRadioButton;
+class QVButtonGroup;
+
+#include <kapplication.h>
 
 // The (singleton) widget that makes the desktop gray.
 class KSMShutdownFeedback : public QWidget
 {
     Q_OBJECT
-protected:
-    KSMShutdownFeedback();
+
 public:
-    static KSMShutdownFeedback * self() {
-        if ( !s_pSelf )
-            s_pSelf = new KSMShutdownFeedback;
-        return s_pSelf;
-    }
+    static void start() { s_pSelf = new KSMShutdownFeedback(); s_pSelf->show(); }
+    static void stop() { delete s_pSelf; s_pSelf = 0L; }
+    static KSMShutdownFeedback * self() { return s_pSelf; }
+
+
+protected:
     ~KSMShutdownFeedback() {}
 
-    static void start();
-    static void stop() { delete s_pSelf; s_pSelf = 0L; }
-
-    // TODO more feedback (which apps have saved themselves, etc.)
-
-signals:
-    void aborted();
-
 private:
-    //virtual void paintEvent( QPaintEvent *event );
-    virtual void keyPressEvent( QKeyEvent * event );
+    void paintEvent( QPaintEvent* );
     static KSMShutdownFeedback * s_pSelf;
+    KSMShutdownFeedback();
 };
 
 // The confirmation dialog
 class KSMShutdownDlg : public QDialog
 {
     Q_OBJECT
+
 public:
-    KSMShutdownDlg( QWidget* parent = 0 );
-    ~KSMShutdownDlg() {}
+    static bool confirmShutdown( bool& saveSession, bool maysd, bool maynuke, KApplication::ShutdownType& sdtype, KApplication::ShutdownMode& sdmode );
 
-    static bool confirmShutdown( bool& saveSession );
+public slots:
+    void slotSdMode(int);
 
-    const QPixmap & pixmap() { return pm; }
-
-private slots:
-    void requestFocus();
+protected:
+    ~KSMShutdownDlg() {};
 
 private:
-    virtual void mousePressEvent( QMouseEvent * ){}
-    virtual void showEvent( QShowEvent * e );
+    KSMShutdownDlg( QWidget* parent, bool saveSession, bool maysd, bool maynuke, KApplication::ShutdownType sdtype, KApplication::ShutdownMode sdmode );
     QCheckBox* checkbox;
-    QPixmap pm;
+    QRadioButton *rLogout, *rHalt, *rReboot;
+#if 0
+    , *rSched, *rTry, *rForce;
+    QVButtonGroup *mgrp;
+#endif
 };
 
 #endif
