@@ -1,6 +1,7 @@
 #ifndef KSPLASH_H
 #define KSPLASH_H
 
+#include <config.h>
 #include <qvbox.h>
 #include <qlabel.h>
 #include <dcopobject.h>
@@ -17,7 +18,7 @@ class KSplash : public QVBox, public DCOPObject
 
 public:
     KSplash( const char* name );
-    ~KSplash() {}
+    ~KSplash() ;
 
 k_dcop:
     ASYNC upAndRunning( QString );
