@@ -19,31 +19,30 @@
 	KSysGuard is currently maintained by Chris Schlaeger <cs@kde.org>. Please do
 	not commit any changes without consulting me first. Thanks!
 
-	$Id: ksysguard.h,v 1.13 2001/06/04 18:06:06 cschlaeg Exp $
+	$Id: ksysguard.h,v 1.15 2001/12/28 09:46:50 tokoe Exp $
 */
 
 #ifndef _ktop_h_
 #define _ktop_h_
 
+#include <qevent.h>
 #include <qpopupmenu.h>
 #include <qsplitter.h>
-#include <qevent.h>
 
+#include <dcopclient.h>
+#include <dcopobject.h>
 #include <kapp.h>
 #include <kmainwindow.h>
 #include <kstatusbar.h>
-#include <dcopobject.h>
-#include <dcopclient.h>
 
-#include "SensorClient.h"
+#include <ksgrd/SensorClient.h>
 
 class KRecentFilesAction;
 class KToggleAction;
-class SensorAgent;
 class SensorBrowser;
 class Workspace;
 
-class TopLevel : public KMainWindow, public SensorClient, public DCOPObject
+class TopLevel : public KMainWindow, public KSGRD::SensorClient, public DCOPObject
 {
 	Q_OBJECT
 	K_DCOP
@@ -92,7 +91,7 @@ private:
 
 	KStatusBar* statusbar;
 
-	QList<DCOPClientTransaction> dcopFIFO;
+	QPtrList<DCOPClientTransaction> dcopFIFO;
 
 	QSplitter* splitter;
 	KRecentFilesAction* openRecent;
@@ -108,7 +107,7 @@ extern TopLevel* Toplevel;
 
 /*
    since there is only a forward declaration of DCOPClientTransaction
-   in dcopclient.h we have to redefine it here, otherwise QList
+   in dcopclient.h we have to redefine it here, otherwise QPtrList
    causes errors
 */
 typedef unsigned long CARD32;
