@@ -1,7 +1,7 @@
 /*
-    KTop, the KDE Task Manager
+    KSysGuard, the KDE System Guard
    
-	Copyright (c) 1999, 2000 Chris Schlaeger <cs@kde.org>
+	Copyright (c) 1999 - 2000 Chris Schlaeger <cs@kde.org>
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: ProcessList.h,v 1.3 2000/12/10 23:58:25 cschlaeg Exp $
+	$Id: ProcessList.h,v 1.6 2002/03/02 23:03:39 cschlaeg Exp $
 */
 
 #ifndef _ProcessList_H_
@@ -25,6 +25,9 @@
 
 void initProcessList(void);
 void exitProcessList(void);
+
+int updateProcessList(void);
+
 void printProcessList(const char*);
 void printProcessListInfo(const char*);
 void printProcessCount(const char* cmd);
