@@ -16,18 +16,18 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: apm.c,v 1.7 2001/05/28 16:38:45 cschlaeg Exp $
+	$Id: apm.c,v 1.8 2001/09/24 08:01:28 tokoe Exp $
 */
 
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
-#include <unistd.h>
 #include <stdio.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
-#include "ksysguardd.h"
 #include "Command.h"
 #include "apm.h"
+#include "ksysguardd.h"
 
 static int ApmOK = 0;
 static int BatFill, BatTime;
@@ -74,8 +74,6 @@ exitApm(void)
 int
 updateApm(void)
 {
-	/* ATTENTION: This function is called from a signal handler! Rules for
-	 * signal handlers must be obeyed! */
 	size_t n;
 	int fd;
 
