@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: loadavg.c,v 1.6 2001/05/28 16:38:45 cschlaeg Exp $
+	$Id: loadavg.c,v 1.7 2001/09/24 08:01:28 tokoe Exp $
 */
 
 #include <sys/types.h>
@@ -75,8 +75,6 @@ exitLoadAvg(void)
 int
 updateLoadAvg(void)
 {
-	/* ATTENTION: This function is called from a signal handler! Rules for
-	 * signal handlers must be obeyed! */
 	size_t n;
 	int fd;
 
