@@ -1,7 +1,7 @@
 /*
-    KTop, the KDE Task Manager
+    KSysGuard, the KDE System Guard
    
-	Copyright (c) 1999, 2000 Chris Schlaeger <cs@kde.org>
+	Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
     
     This program is free software; you can redistribute it and/or
     modify it under the terms of version 2 of the GNU General Public
@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: netdev.c,v 1.11 2001/02/19 22:27:06 cschlaeg Exp $
+	$Id: netdev.c,v 1.22 2001/09/24 08:01:28 tokoe Exp $
 */
 
 #include <sys/types.h>
@@ -27,25 +27,81 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <Command.h>
+#include "ksysguardd.h"
+#include "Command.h"
 #include "netdev.h"
 
-/* Special version of perror for use in signal handler functions. */
-#define perror(a) write(STDERR_FILENO, (a), strlen(a))
+#define CALC(a, b, c, d, e) \
+{ \
+	NetDevs[i].a = a - NetDevs[i].Old##a; \
+	NetDevs[i].Old##a = a; \
+}
+
+#define REGISTERSENSOR(a, b, c, d, e) \
+{ \
+	sprintf(mon, "network/interfaces/%s/%s", tag, b); \
+	registerMonitor(mon, "integer", printNetDev##a, \
+					printNetDev##a##Info); \
+}
+
+#define UNREGISTERSENSOR(a, b, c, d, e) \
+{ \
+	sprintf(mon, "network/interfaces/%s/%s", NetDevs[i].name, b); \
+	removeMonitor(mon); \
+}
+
+#define DEFMEMBERS(a, b, c, d, e) \
+unsigned long Old##a; \
+unsigned long a; \
+unsigned long a##Scale;
+
+#define DEFVARS(a, b, c, d, e) \
+unsigned long a;
+
+#define FORALL(a) \
+	a(recBytes, "receiver/data", "Received Data", "kBytes/s", 1024) \
+	a(recPacks, "receiver/packets", "Received Packets", "1/s", 1) \
+	a(recErrs, "receiver/errors", "Receiver Errors", "1/s", 1) \
+	a(recDrop, "receiver/drops", "Receiver Drops", "1/s", 1) \
+	a(recFifo, "receiver/fifo", "Receiver FIFO Overruns", "1/s", 1) \
+	a(recFrame, "receiver/frame", "Receiver Frame Errors", "1/s", 1) \
+	a(recCompressed, "receiver/compressed", "Received Compressed Packets", \
+	  "1/s", 1) \
+	a(recMulticast, "receiver/multicast", "Received Multicast Packets", \
+	  "1/s", 1) \
+	a(sentBytes, "transmitter/data", "Sent Data", "kBytes/s", 1024) \
+	a(sentPacks, "transmitter/packets", "Sent Packets", "1/s", 1) \
+	a(sentErrs, "transmitter/errors", "Transmitter Errors", "1/s", 1) \
+	a(sentDrop, "transmitter/drops", "Transmitter Drops", "1/s", 1) \
+	a(sentFifo, "transmitter/fifo", "Transmitter FIFO overruns", "1/s", 1) \
+	a(sentColls, "transmitter/collisions", "Transmitter Collisions", \
+	  "1/s", 1) \
+	a(sentCarrier, "transmitter/carrier", "Transmitter Carrier losses", \
+	  "1/s", 1) \
+	a(sentCompressed, "transmitter/compressed", \
+	  "Transmitter Compressed Packets", "1/s", 1)
+
+#define SETZERO(a, b, c, d, e) \
+a = 0;
+
+#define SETMEMBERZERO(a, b, c, d, e) \
+NetDevs[i].a = 0; \
+NetDevs[i].a##Scale = e;
+
+#define DECLAREFUNC(a, b, c, d, e) \
+void printNetDev##a(const char* cmd); \
+void printNetDev##a##Info(const char* cmd);
 
 typedef struct
 {
-	long OldRxBytes;
-	long OldTxBytes;
-	long rxBytes;
-	long txBytes;
+	FORALL(DEFMEMBERS);
 	char name[32];
 } NetDevInfo;
 
 /* We have observed deviations of up to 5% in the accuracy of the timer
  * interrupts. So we try to measure the interrupt interval and use this
  * value to calculate timing dependant values. */
-static float timeInterval = TIMERINTERVAL;
+static float timeInterval = 0;
 static struct timeval lastSampling;
 static struct timeval currSampling;
 
@@ -59,6 +115,8 @@ static long OldHash = 0;
 #define MAXNETDEVS 64
 static NetDevInfo NetDevs[MAXNETDEVS];
 
+FORALL(DECLAREFUNC)
+
 static int
 processNetDev_(void)
 {
@@ -90,13 +148,16 @@ processNetDev_(void)
 			char* pos = strchr(tag, ':');
 			if (pos)
 			{
-				unsigned long rxBytes, txBytes, rxPacks, txPacks;
+				FORALL(DEFVARS);
 				*pos = '\0';
-				rxBytes = txBytes = rxPacks = txPacks = 0;
+				FORALL(SETZERO);
 				sscanf(buf + 7,
-					   "%lu %lu %*d %*d %*d %*d %*d %*d " 
-					   "%lu %lu %*d %*d %*d %*d %*d %*d",
-					   &rxBytes, &rxPacks, &txBytes, &txPacks);
+					   "%lu %lu %lu %lu %lu %lu %lu %lu " 
+					   "%lu %lu %lu %lu %lu %lu %lu %lu",
+					   &recBytes, &recPacks, &recErrs, &recDrop, &recFifo,
+					   &recFrame, &recCompressed, &recMulticast,
+					   &sentBytes, &sentPacks, &sentErrs, &sentDrop,
+					   &sentFifo, &sentColls, &sentCarrier, &sentCompressed);
 
 				if (i >= NetDevCnt || strcmp(NetDevs[i].name, tag) != 0)
 				{
@@ -106,10 +167,7 @@ processNetDev_(void)
 				}
 				else
 				{
-					NetDevs[i].rxBytes = rxBytes - NetDevs[i].OldRxBytes;
-					NetDevs[i].txBytes = txBytes - NetDevs[i].OldTxBytes;
-					NetDevs[i].OldRxBytes = rxBytes;
-					NetDevs[i].OldTxBytes = txBytes;
+					FORALL(CALC);
 				}
 			}
 		}
@@ -118,9 +176,9 @@ processNetDev_(void)
 		return (-1);
 
 	/* save exact time inverval between this and the last read of
-	 * /proc/stat */
-	timeInterval = currSampling.tv_sec + currSampling.tv_usec / 100000.0 -
-		lastSampling.tv_sec - lastSampling.tv_usec / 100000.0;
+	 * /proc/net/dev */
+	timeInterval = currSampling.tv_sec - lastSampling.tv_sec +
+		(currSampling.tv_usec - lastSampling.tv_usec) / 1000000.0;
 	lastSampling = currSampling;
 
 	Dirty = 0;
@@ -184,18 +242,28 @@ initNetDev(void)
 				char mon[128];
 				*pos = '\0';
 				strcpy(NetDevs[i].name, tag);
-				sprintf(mon, "network/%s/recBytes", tag);
-				registerMonitor(mon, "integer", printNetDevRecBytes,
-								printNetDevRecBytesInfo);
-				sprintf(mon, "network/%s/sentBytes", tag);
-				registerMonitor(mon, "integer", printNetDevSentBytes,
-								printNetDevRecBytesInfo);
-				sscanf(pos + 1, "%ld %*d %*d %*d %*d %*d %*d %*d" 
-					   "%ld %*d %*d %*d %*d %*d %*d %*d",
-					   &NetDevs[i].OldRxBytes, &NetDevs[i].OldTxBytes);
+				FORALL(REGISTERSENSOR);
+				sscanf(pos + 1, "%lu %lu %lu %lu %lu %lu %lu %lu" 
+					   "%lu %lu %lu %lu %lu %lu %lu %lu",
+					   &NetDevs[i].recBytes,
+					   &NetDevs[i].recPacks,
+					   &NetDevs[i].recErrs,
+					   &NetDevs[i].recDrop,
+					   &NetDevs[i].recFifo,
+					   &NetDevs[i].recFrame,
+					   &NetDevs[i].recCompressed,
+					   &NetDevs[i].recMulticast,
+					   &NetDevs[i].sentBytes,
+					   &NetDevs[i].sentPacks,
+					   &NetDevs[i].sentErrs,
+					   &NetDevs[i].sentDrop,
+					   &NetDevs[i].sentFifo,
+					   &NetDevs[i].sentColls,
+					   &NetDevs[i].sentCarrier,
+					   &NetDevs[i].sentCompressed);
 				NetDevCnt++;
 			}
-			NetDevs[i].rxBytes = NetDevs[i].txBytes = 0;
+			FORALL(SETMEMBERZERO);
 		}
 	}
 
@@ -211,10 +279,7 @@ exitNetDev(void)
 	for (i = 0; i < NetDevCnt; ++i)
 	{
 		char mon[128];
-		sprintf(mon, "network/%s/recBytes", NetDevs[i].name);
-		removeMonitor(mon);
-		sprintf(mon, "network/%s/sentBytes", NetDevs[i].name);
-		removeMonitor(mon);
+		FORALL(UNREGISTERSENSOR);
 	}
 	NetDevCnt = 0;
 }
@@ -222,9 +287,6 @@ exitNetDev(void)
 int
 updateNetDev(void)
 {
-	/* ATTENTION: This function is called from a signal handler! Rules for
-	 * signal handlers must be obeyed! */
-
 	/* We read the information about the network interfaces from
 	   /proc/net/dev. The file should look like this:
 
@@ -254,8 +316,7 @@ Inter-|   Receive                                                |  Transmit
 	}
 	if ((n = read(fd, NetDevBuf, NETDEVBUFSIZE - 1)) == NETDEVBUFSIZE - 1)
 	{
-		perror("ERROR: Internal buffer too small to read "
-			   "/proc/net/dev!");
+		log_error("Internal buffer too small to read \'/proc/net/dev\'");
 		NetDevOk = -1;
 		return (-1);
 	}
@@ -273,7 +334,7 @@ Inter-|   Receive                                                |  Transmit
 
 	if (OldHash != 0 && OldHash != hash)
 	{
-		perror("RECONFIGURE\n");
+		print_error("RECONFIGURE\n");
 		CheckSetupFlag = 1;
 	}
 	OldHash = hash;
@@ -292,64 +353,37 @@ checkNetDev(void)
 	initNetDev();
 }
 
-void
-printNetDevRecBytes(const char* cmd)
-{
-	int i;
-	char* beg;
-	char* end;
-	char dev[64];
-
-	beg = strchr(cmd, '/');
-	end = strchr(beg + 1, '/');
-	strncpy(dev, beg + 1, end - beg - 1);
-	dev[end - beg - 1] = '\0';
-	if (Dirty)
-		processNetDev();
-	for (i = 0; i < MAXNETDEVS; ++i)
-		if (strcmp(NetDevs[i].name, dev) == 0)
-		{
-			printf("%lu\n", (unsigned long)
-				   (NetDevs[i].rxBytes / (1024 * timeInterval)));
-			return;
-		}
-
-	printf("0\n");
+#define PRINTFUNC(a, b, c, d, e) \
+void \
+printNetDev##a(const char* cmd) \
+{ \
+	int i; \
+	char* beg; \
+	char* end; \
+	char dev[64]; \
+ \
+	beg = strchr(cmd, '/'); \
+	beg = strchr(beg + 1, '/'); \
+	end = strchr(beg + 1, '/'); \
+	strncpy(dev, beg + 1, end - beg - 1); \
+	dev[end - beg - 1] = '\0'; \
+	if (Dirty) \
+		processNetDev(); \
+	for (i = 0; i < MAXNETDEVS; ++i) \
+		if (strcmp(NetDevs[i].name, dev) == 0) \
+		{ \
+			fprintf(CurrentClient, "%lu\n", (unsigned long) \
+				   (NetDevs[i].a / (NetDevs[i].a##Scale * timeInterval))); \
+			return; \
+		} \
+ \
+	fprintf(CurrentClient, "0\n"); \
+} \
+ \
+void \
+printNetDev##a##Info(const char* cmd) \
+{ \
+	fprintf(CurrentClient, "%s\t0\t0\t%s\n", c, d); \
 }
 
-void
-printNetDevRecBytesInfo(const char* cmd)
-{
-	printf("Received Bytes\t0\t0\tkBytes/s\n");
-}
-
-void
-printNetDevSentBytes(const char* cmd)
-{
-	int i;
-	char* beg;
-	char* end;
-	char dev[64];
-
-	beg = strchr(cmd, '/');
-	end = strchr(beg + 1, '/');
-	strncpy(dev, beg + 1, end - beg - 1);
-	dev[end - beg - 1] = '\0';
-	if (Dirty)
-		processNetDev();
-	for (i = 0; i < MAXNETDEVS; ++i)
-		if (strcmp(NetDevs[i].name, dev) == 0)
-		{
-			printf("%lu\n", (unsigned long)
-				   (NetDevs[i].txBytes / (1024 * timeInterval)));
-			return;
-		}
-
-	printf("0\n");
-}
-
-void
-printNetDevRecSendInfo(const char* cmd)
-{
-	printf("Send Bytes\t0\t0\tkBytes/s\n");
-}
+FORALL(PRINTFUNC)
