@@ -1,5 +1,5 @@
 /*
-    KTop, the KDE Task Manager
+    KSysGuard, the KDE System Guard
    
 	Copyright (c) 1999, 2000 Chris Schlaeger <cs@kde.org>
     
@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: stat.c,v 1.10 2001/02/18 23:18:43 cschlaeg Exp $
+	$Id: stat.c,v 1.20 2002/02/08 20:05:30 waba Exp $
 */
 
 #include <sys/types.h>
@@ -30,11 +30,9 @@
 #include <ctype.h>
 
 #include "stat.h"
+#include "ksysguardd.h"
 #include "Command.h"
 
-/* Special version of perror for use in signal handler functions. */
-#define perror(a) write(STDERR_FILENO, (a), strlen(a))
-
 typedef struct
 {
 	/* A CPU can be loaded with user processes, reniced processes and
@@ -79,14 +77,14 @@ typedef struct DiskIOInfo
 	struct DiskIOInfo* next;
 } DiskIOInfo;
 
-#define STATBUFSIZE 2048
+#define STATBUFSIZE 4096
 static char StatBuf[STATBUFSIZE];
 static int Dirty = 0;
 
 /* We have observed deviations of up to 5% in the accuracy of the timer
  * interrupts. So we try to measure the interrupt interval and use this
  * value to calculate timing dependant values. */
-static float timeInterval = TIMERINTERVAL;
+static float timeInterval = 0;
 static struct timeval lastSampling;
 static struct timeval currSampling;
 
@@ -207,76 +205,97 @@ static int
 processDiskIO(const char* buf)
 {
 	/* Process disk_io lines as provided by 2.4.x kernels.
-	 * disk_io: (3,0):(524392,341664,14532074,182728,11468624) */
+	 * disk_io: (2,0):(3,3,6,0,0) (3,0):(1413012,511622,12155382,901390,26486215) */
 	int major, minor;
 	unsigned long total, rblk, rio, wblk, wio;
 	DiskIOInfo* ptr = DiskIO;
 	DiskIOInfo* last = 0;
 	char sensorName[128];
+	const char* p;
 
-	if (sscanf(buf, "disk_io: (%d,%d):(%lu,%lu,%lu,%lu,%lu)", &major, &minor,
-			   &total, &rio, &rblk, &wio, &wblk) != 7)
-		return (-1);
-
-	while (ptr)
+	p = buf + strlen("disk_io: ");
+	while (p && *p)
 	{
-		if (ptr->major == major && ptr->minor == minor)
+		if (sscanf(p, "(%d,%d):(%lu,%lu,%lu,%lu,%lu)", &major, &minor,
+				   &total, &rio, &rblk, &wio, &wblk) != 7)
+			return (-1);
+
+		last = 0;
+		ptr = DiskIO;
+		while (ptr)
 		{
-			/* The IO device has already been registered. */
-			ptr->total.delta = total - ptr->total.old;
+			if (ptr->major == major && ptr->minor == minor)
+			{
+				/* The IO device has already been registered. */
+				ptr->total.delta = total - ptr->total.old;
+				ptr->total.old = total;
+				ptr->rio.delta = rio - ptr->rio.old;
+				ptr->rio.old = rio;
+				ptr->wio.delta = wio - ptr->wio.old;
+				ptr->wio.old = wio;
+				ptr->rblk.delta = rblk - ptr->rblk.old;
+				ptr->rblk.old = rblk;
+				ptr->wblk.delta = wblk - ptr->wblk.old;
+				ptr->wblk.old = wblk;
+				ptr->alive = 1;
+				break;
+			}
+			last = ptr;
+			ptr = ptr->next;
+		}
+
+		if (!ptr)
+		{
+			/* The IO device has not been registered yet. We need to add it. */
+			ptr = (DiskIOInfo*) malloc(sizeof(DiskIOInfo));
+			ptr->major = major;
+			ptr->minor = minor;
+			ptr->total.delta = 0;
 			ptr->total.old = total;
-			ptr->rio.delta = rio - ptr->rio.old;
+			ptr->rio.delta = 0;
 			ptr->rio.old = rio;
-			ptr->wio.delta = wio - ptr->wio.old;
+			ptr->wio.delta = 0;
 			ptr->wio.old = wio;
-			ptr->rblk.delta = rblk - ptr->rblk.old;
+			ptr->rblk.delta = 0;
 			ptr->rblk.old = rblk;
-			ptr->wblk.delta = wblk - ptr->wblk.old;
+			ptr->wblk.delta = 0;
 			ptr->wblk.old = wblk;
 			ptr->alive = 1;
-			return (0);
+			ptr->next = 0;
+			if (last)
+			{
+				/* Append new entry at end of list. */
+				last->next = ptr;
+			}
+			else
+			{
+				/* List is empty, so we insert the fist element into
+                 * the list. */
+				DiskIO = ptr;
+			}
+			sprintf(sensorName, "disk/%d:%d/total", major, minor);
+			registerMonitor(sensorName, "integer", printDiskIO,
+							printDiskIOInfo);
+			sprintf(sensorName, "disk/%d:%d/rio", major, minor);
+			registerMonitor(sensorName, "integer", printDiskIO,
+							printDiskIOInfo);
+			sprintf(sensorName, "disk/%d:%d/wio", major, minor);
+			registerMonitor(sensorName, "integer", printDiskIO,
+							printDiskIOInfo);
+			sprintf(sensorName, "disk/%d:%d/rblk", major, minor);
+			registerMonitor(sensorName, "integer", printDiskIO,
+							printDiskIOInfo);
+			sprintf(sensorName, "disk/%d:%d/wblk", major, minor);
+			registerMonitor(sensorName, "integer", printDiskIO,
+							printDiskIOInfo);
 		}
-		last = ptr;
-		ptr = ptr->next;
+		/* Move p after the sencond ')'. We can safely asume that
+		 * those two ')' exist. */
+		p = strchr(p, ')') + 1;
+		p = strchr(p, ')') + 1;
+		if (p && *p)
+			p = strchr(p, '(');
 	}
-
-	/* The IO device has not been registered yet. We need to add it. */
-	ptr = (DiskIOInfo*) malloc(sizeof(DiskIOInfo));
-	ptr->major = major;
-	ptr->minor = minor;
-	ptr->total.delta = 0;
-	ptr->total.old = total;
-	ptr->rio.delta = 0;
-	ptr->rio.old = rio;
-	ptr->wio.delta = 0;
-	ptr->wio.old = wio;
-	ptr->rblk.delta = 0;
-	ptr->rblk.old = rblk;
-	ptr->wblk.delta = 0;
-	ptr->wblk.old = wblk;
-	ptr->alive = 1;
-	ptr->next = 0;
-	if (last)
-	{
-		/* Append new entry at end of list. */
-		last->next = ptr;
-	}
-	else
-	{
-		/* List is empty, so we insert the fist element into the list. */
-		DiskIO = ptr;
-	}
-	sprintf(sensorName, "disk/%d:%d/total", major, minor);
-	registerMonitor(sensorName, "integer", printDiskIO, printDiskIOInfo);
-	sprintf(sensorName, "disk/%d:%d/rio", major, minor);
-	registerMonitor(sensorName, "integer", printDiskIO, printDiskIOInfo);
-	sprintf(sensorName, "disk/%d:%d/wio", major, minor);
-	registerMonitor(sensorName, "integer", printDiskIO, printDiskIOInfo);
-	sprintf(sensorName, "disk/%d:%d/rblk", major, minor);
-	registerMonitor(sensorName, "integer", printDiskIO, printDiskIOInfo);
-	sprintf(sensorName, "disk/%d:%d/wblk", major, minor);
-	registerMonitor(sensorName, "integer", printDiskIO, printDiskIOInfo);
-
 	return (0);
 }
 
@@ -407,8 +426,8 @@ processStat(void)
 	}
 
 	/* save exact time inverval between this and the last read of /proc/stat */
-	timeInterval = currSampling.tv_sec + currSampling.tv_usec / 100000.0 -
-		lastSampling.tv_sec - lastSampling.tv_usec / 100000.0;
+	timeInterval = currSampling.tv_sec - lastSampling.tv_sec +
+		(currSampling.tv_usec - lastSampling.tv_usec) / 1000000.0;
 	lastSampling = currSampling;
 
 	cleanupDiskList();
@@ -452,29 +471,20 @@ initStat(void)
 	 */
 
 	char format[32];
+	char tagFormat[16];
 	char buf[1024];
-	FILE* stat = 0;
+	char tag[32];
+	char* statBufP = StatBuf;
 
-	if ((stat = fopen("/proc/stat", "r")) == NULL)
-	{
-		fprintf(stderr, "ERROR: Cannot open file \'/proc/stat\'!\n"
-				"The kernel needs to be compiled with support\n"
-				"for /proc filesystem enabled!");
-		return;
-	}
-
-	/* Use unbuffered input for /proc/stat file. */
-    setvbuf(stat, NULL, _IONBF, 0);
+	updateStat();
 
 	sprintf(format, "%%%d[^\n]\n", (int) sizeof(buf) - 1);
+	sprintf(tagFormat, "%%%ds", (int) sizeof(tag) - 1);
 
-	while (fscanf(stat, format, buf) == 1)
+	while (sscanf(statBufP, format, buf) == 1)
 	{
-		char tag[32];
-		char tagFormat[16];
-		
 		buf[sizeof(buf) - 1] = '\0';
-		sprintf(tagFormat, "%%%ds", (int) sizeof(tag) - 1);
+		statBufP += strlen(buf) + 1;	/* move statBufP to next line */
 		sscanf(buf, tagFormat, tag);
 
 		if (strcmp("cpu", tag) == 0)
@@ -589,13 +599,11 @@ initStat(void)
 							printCtxtInfo);
 		}
 	}
-	fclose(stat);
+	if (CPUCount > 0)
+		SMPLoad = (CPULoadInfo*) malloc(sizeof(CPULoadInfo) * CPUCount);
 
 	/* Call processStat to eliminate initial peek values. */
 	processStat();
-
-	if (CPUCount > 0)
-		SMPLoad = (CPULoadInfo*) malloc(sizeof(CPULoadInfo) * CPUCount);
 }
 
 void
@@ -614,22 +622,19 @@ exitStat(void)
 int
 updateStat(void)
 {
-	/* ATTENTION: This function is called from a signal handler! Rules for
-	 * signal handlers must be obeyed! */
 	size_t n;
 	int fd;
 
 	if ((fd = open("/proc/stat", O_RDONLY)) < 0)
 	{
-		perror("ERROR: Cannot open file \'/proc/stat\'!\n"
+		print_error("Cannot open file \'/proc/stat\'!\n"
 			   "The kernel needs to be compiled with support\n"
-			   "for /proc filesystem enabled!");
+			   "for /proc filesystem enabled!\n");
 		return (-1);
 	}
 	if ((n = read(fd, StatBuf, STATBUFSIZE - 1)) == STATBUFSIZE - 1)
 	{
-		perror("ERROR: Internal buffer too small to read "
-			   "/proc/stat!");
+		log_error("Internal buffer too small to read \'/proc/stat\'");
 		return (-1);
 	}
 	gettimeofday(&currSampling, 0);
@@ -646,13 +651,13 @@ printCPUUser(const char* cmd)
 {
 	if (Dirty)
 		processStat();
-	printf("%d\n", CPULoad.userLoad);
+	fprintf(CurrentClient, "%d\n", CPULoad.userLoad);
 }
 
 void 
 printCPUUserInfo(const char* cmd)
 {
-	printf("CPU User Load\t0\t100\t%%\n");
+	fprintf(CurrentClient, "CPU User Load\t0\t100\t%%\n");
 }
 
 void
@@ -660,13 +665,13 @@ printCPUNice(const char* cmd)
 {
 	if (Dirty)
 		processStat();
-	printf("%d\n", CPULoad.niceLoad);
+	fprintf(CurrentClient, "%d\n", CPULoad.niceLoad);
 }
 
 void 
 printCPUNiceInfo(const char* cmd)
 {
-	printf("CPU Nice Load\t0\t100\t%%\n");
+	fprintf(CurrentClient, "CPU Nice Load\t0\t100\t%%\n");
 }
 
 void
@@ -674,13 +679,13 @@ printCPUSys(const char* cmd)
 {
 	if (Dirty)
 		processStat();
-	printf("%d\n", CPULoad.sysLoad);
+	fprintf(CurrentClient, "%d\n", CPULoad.sysLoad);
 }
 
 void 
 printCPUSysInfo(const char* cmd)
 {
-	printf("CPU System Load\t0\t100\t%%\n");
+	fprintf(CurrentClient, "CPU System Load\t0\t100\t%%\n");
 }
 
 void
@@ -688,13 +693,13 @@ printCPUIdle(const char* cmd)
 {
 	if (Dirty)
 		processStat();
-	printf("%d\n", CPULoad.idleLoad);
+	fprintf(CurrentClient, "%d\n", CPULoad.idleLoad);
 }
 
 void 
 printCPUIdleInfo(const char* cmd)
 {
-	printf("CPU Idle Load\t0\t100\t%%\n");
+	fprintf(CurrentClient, "CPU Idle Load\t0\t100\t%%\n");
 }
 
 void
@@ -705,7 +710,7 @@ printCPUxUser(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + 3, "%d", &id);
-	printf("%d\n", SMPLoad[id].userLoad);
+	fprintf(CurrentClient, "%d\n", SMPLoad[id].userLoad);
 }
 
 void 
@@ -714,7 +719,7 @@ printCPUxUserInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 3, "%d", &id);
-	printf("CPU%d User Load\t0\t100\t%%\n", id);
+	fprintf(CurrentClient, "CPU%d User Load\t0\t100\t%%\n", id);
 }
 
 void
@@ -725,7 +730,7 @@ printCPUxNice(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + 3, "%d", &id);
-	printf("%d\n", SMPLoad[id].niceLoad);
+	fprintf(CurrentClient, "%d\n", SMPLoad[id].niceLoad);
 }
 
 void 
@@ -734,7 +739,7 @@ printCPUxNiceInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 3, "%d", &id);
-	printf("CPU%d Nice Load\t0\t100\t%%\n", id);
+	fprintf(CurrentClient, "CPU%d Nice Load\t0\t100\t%%\n", id);
 }
 
 void
@@ -745,7 +750,7 @@ printCPUxSys(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + 3, "%d", &id);
-	printf("%d\n", SMPLoad[id].sysLoad);
+	fprintf(CurrentClient, "%d\n", SMPLoad[id].sysLoad);
 }
 
 void 
@@ -754,7 +759,7 @@ printCPUxSysInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 3, "%d", &id);
-	printf("CPU%d System Load\t0\t100\t%%\n", id);
+	fprintf(CurrentClient, "CPU%d System Load\t0\t100\t%%\n", id);
 }
 
 void
@@ -765,7 +770,7 @@ printCPUxIdle(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + 3, "%d", &id);
-	printf("%d\n", SMPLoad[id].idleLoad);
+	fprintf(CurrentClient, "%d\n", SMPLoad[id].idleLoad);
 }
 
 void 
@@ -774,7 +779,7 @@ printCPUxIdleInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 3, "%d", &id);
-	printf("CPU%d Idle Load\t0\t100\t%%\n", id);
+	fprintf(CurrentClient, "CPU%d Idle Load\t0\t100\t%%\n", id);
 }
 
 void
@@ -785,7 +790,7 @@ printDiskTotal(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + 9, "%d", &id);
-	printf("%lu\n", (unsigned long) (DiskLoad[id].s[0].delta / timeInterval));
+	fprintf(CurrentClient, "%lu\n", (unsigned long) (DiskLoad[id].s[0].delta / timeInterval));
 }
 
 void
@@ -794,7 +799,7 @@ printDiskTotalInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 9, "%d", &id);
-	printf("Disk%d Total Load\t0\t0\tkBytes/s\n", id);
+	fprintf(CurrentClient, "Disk%d Total Load\t0\t0\tkBytes/s\n", id);
 }
 
 void
@@ -805,7 +810,7 @@ printDiskRIO(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + 9, "%d", &id);
-	printf("%lu\n", (unsigned long ) (DiskLoad[id].s[1].delta / timeInterval));
+	fprintf(CurrentClient, "%lu\n", (unsigned long ) (DiskLoad[id].s[1].delta / timeInterval));
 }
 
 void
@@ -814,7 +819,7 @@ printDiskRIOInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 9, "%d", &id);
-	printf("Disk%d Read\t0\t0\tkBytes/s\n", id);
+	fprintf(CurrentClient, "Disk%d Read\t0\t0\tkBytes/s\n", id);
 }
 
 void
@@ -825,7 +830,7 @@ printDiskWIO(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + 9, "%d", &id);
-	printf("%lu\n", (unsigned long) (DiskLoad[id].s[2].delta / timeInterval));
+	fprintf(CurrentClient, "%lu\n", (unsigned long) (DiskLoad[id].s[2].delta / timeInterval));
 }
 
 void
@@ -834,7 +839,7 @@ printDiskWIOInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 9, "%d", &id);
-	printf("Disk%d Write\t0\t0\tkBytes/s\n", id);
+	fprintf(CurrentClient, "Disk%d Write\t0\t0\tkBytes/s\n", id);
 }
 
 void
@@ -846,7 +851,7 @@ printDiskRBlk(const char* cmd)
 		processStat();
 	sscanf(cmd + 9, "%d", &id);
 	/* a block is 512 bytes or 1/2 kBytes */
-	printf("%lu\n", (unsigned long)
+	fprintf(CurrentClient, "%lu\n", (unsigned long)
 		   (DiskLoad[id].s[3].delta / timeInterval * 2));
 }
 
@@ -856,7 +861,7 @@ printDiskRBlkInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 9, "%d", &id);
-	printf("Disk%d Read Data\t0\t0\tkBytes/s\n", id);
+	fprintf(CurrentClient, "Disk%d Read Data\t0\t0\tkBytes/s\n", id);
 }
 
 void
@@ -868,7 +873,7 @@ printDiskWBlk(const char* cmd)
 		processStat();
 	sscanf(cmd + 9, "%d", &id);
 	/* a block is 512 bytes or 1/2 kBytes */
-	printf("%lu\n", (unsigned long)
+	fprintf(CurrentClient, "%lu\n", (unsigned long)
 		   (DiskLoad[id].s[4].delta / timeInterval * 2));
 }
 
@@ -878,7 +883,7 @@ printDiskWBlkInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + 9, "%d", &id);
-	printf("Disk%d Write Data\t0\t0\tkBytes/s\n", id);
+	fprintf(CurrentClient, "Disk%d Write Data\t0\t0\tkBytes/s\n", id);
 }
 
 void
@@ -886,13 +891,13 @@ printPageIn(const char* cmd)
 {
 	if (Dirty)
 		processStat();
-	printf("%lu\n", (unsigned long) (PageIn / timeInterval));
+	fprintf(CurrentClient, "%lu\n", (unsigned long) (PageIn / timeInterval));
 }
 
 void
 printPageInInfo(const char* cmd)
 {
-	printf("Paged in Pages\t0\t0\t1/s\n");
+	fprintf(CurrentClient, "Paged in Pages\t0\t0\t1/s\n");
 }
 
 void
@@ -900,13 +905,13 @@ printPageOut(const char* cmd)
 {
 	if (Dirty)
 		processStat();
-	printf("%lu\n", (unsigned long) (PageOut / timeInterval));
+	fprintf(CurrentClient, "%lu\n", (unsigned long) (PageOut / timeInterval));
 }
 
 void
 printPageOutInfo(const char* cmd)
 {
-	printf("Paged out Pages\t0\t0\t1/s\n");
+	fprintf(CurrentClient, "Paged out Pages\t0\t0\t1/s\n");
 }
 
 void
@@ -917,7 +922,7 @@ printInterruptx(const char* cmd)
 	if (Dirty)
 		processStat();
 	sscanf(cmd + strlen("cpu/interrupts/int"), "%d", &id);
-	printf("%lu\n", (unsigned long) (Intr[id] / timeInterval));
+	fprintf(CurrentClient, "%lu\n", (unsigned long) (Intr[id] / timeInterval));
 }
 
 void
@@ -926,7 +931,7 @@ printInterruptxInfo(const char* cmd)
 	int id;
 
 	sscanf(cmd + strlen("cpu/interrupt/int"), "%d", &id);
-	printf("Interrupt %d\t0\t0\t1/s\n", id);
+	fprintf(CurrentClient, "Interrupt %d\t0\t0\t1/s\n", id);
 }
 
 void
@@ -934,13 +939,13 @@ printCtxt(const char* cmd)
 {
 	if (Dirty)
 		processStat();
-	printf("%lu\n", (unsigned long) (Ctxt / timeInterval));
+	fprintf(CurrentClient, "%lu\n", (unsigned long) (Ctxt / timeInterval));
 }
 
 void
 printCtxtInfo(const char* cmd)
 {
-	printf("Context switches\t0\t0\t1/s\n");
+	fprintf(CurrentClient, "Context switches\t0\t0\t1/s\n");
 }
 
 void
@@ -948,34 +953,44 @@ printDiskIO(const char* cmd)
 {
 	int major, minor;
 	char name[16];
-	DiskIOInfo* ptr = DiskIO;
+	DiskIOInfo* ptr;
 
 	sscanf(cmd, "disk/%d:%d/%s", &major, &minor, name);
 
-	while (ptr && ptr->major != major && ptr->minor != minor)
+	if (Dirty)
+		processStat();
+
+	ptr = DiskIO;
+	while (ptr && (ptr->major != major || ptr->minor != minor))
 		ptr = ptr->next;
 
 	if (!ptr)
 	{
-		fprintf(stderr, "Disk device disappeared\n");
+		print_error("RECONFIGURE");
+		fprintf(CurrentClient, "0\n");
+
+		log_error("Disk device disappeared");
 		return;
 	}
 	if (strcmp(name, "total") == 0)
-		printf("%lu\n", (unsigned long) (ptr->total.delta / timeInterval));
+		fprintf(CurrentClient, "%lu\n",
+				(unsigned long) (ptr->total.delta / timeInterval));
 	else if (strcmp(name, "rio") == 0)
-		printf("%lu\n", (unsigned long) (ptr->rio.delta / timeInterval));
+		fprintf(CurrentClient, "%lu\n",
+				(unsigned long) (ptr->rio.delta / timeInterval));
 	else if (strcmp(name, "wio") == 0)
-		printf("%lu\n", (unsigned long) (ptr->wio.delta / timeInterval));
+		fprintf(CurrentClient, "%lu\n",
+				(unsigned long) (ptr->wio.delta / timeInterval));
 	else if (strcmp(name, "rblk") == 0)
-		printf("%lu\n", (unsigned long)
+		fprintf(CurrentClient, "%lu\n", (unsigned long)
 			   (ptr->rblk.delta / (timeInterval * 2)));
 	else if (strcmp(name, "wblk") == 0)
-		printf("%lu\n", (unsigned long)
+		fprintf(CurrentClient, "%lu\n", (unsigned long)
 			   (ptr->wblk.delta / (timeInterval * 2)));
 	else
 	{
-		printf("0\n");
-		fprintf(stderr, "ERROR: unknown disk device property %s\n", name);
+		fprintf(CurrentClient, "0\n");
+		log_error("Unknown disk device property \'%s\'", name);
 	}
 }
 
@@ -988,32 +1003,37 @@ printDiskIOInfo(const char* cmd)
 
 	sscanf(cmd, "disk/%d:%d/%s", &major, &minor, name);
 
-	while (ptr && ptr->major != major && ptr->minor != minor)
+	while (ptr && (ptr->major != major || ptr->minor != minor))
 		ptr = ptr->next;
 
 	if (!ptr)
 	{
 		/* Disk device has disappeared. Print a dummy answer. */
-		printf("Dummy\t0\t0\t\n");
+		fprintf(CurrentClient, "Dummy\t0\t0\t\n");
 		return;
 	}
 	/* remove trailing '?' */
 	name[strlen(name) - 1] = '\0';
 
 	if (strcmp(name, "total") == 0)
-		printf("Total accesses device %d, %d\t0\t0\t1/s\n", major, minor);
+		fprintf(CurrentClient, "Total accesses device %d, %d\t0\t0\t1/s\n",
+				major, minor);
 	else if (strcmp(name, "rio") == 0)
-		printf("Read data device %d, %d\t0\t0\t1/s\n", major, minor);
+		fprintf(CurrentClient, "Read data device %d, %d\t0\t0\t1/s\n",
+				major, minor);
 	else if (strcmp(name, "wio") == 0)
-		printf("Write data device %d, %d\t0\t0\t1/s\n", major, minor);
+		fprintf(CurrentClient, "Write data device %d, %d\t0\t0\t1/s\n",
+				major, minor);
 	else if (strcmp(name, "rblk") == 0)
-		printf("Read accesses device %d, %d\t0\t0\tkBytes/s\n", major, minor);
+		fprintf(CurrentClient, "Read accesses device %d, %d\t0\t0\tkBytes/s\n",
+				major, minor);
 	else if (strcmp(name, "wblk") == 0)
-		printf("Write accesses device %d, %d\t0\t0\tkBytes/s\n", major, minor);
+		fprintf(CurrentClient,
+				"Write accesses device %d, %d\t0\t0\tkBytes/s\n",
+				major, minor);
 	else
 	{
-		printf("Dummy\t0\t0\t\n");
-		fprintf(stderr, "ERROR: Request for unknown device property %s\n",
-				name);
+		fprintf(CurrentClient, "Dummy\t0\t0\t\n");
+		log_error("Request for unknown device property \'%s\'",	name);
 	}
 }
