@@ -36,9 +36,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qtextstream.h>
 #include <qhbox.h>
 
-#include <kapp.h>
-#include <kuniqueapp.h>
+#include <kapplication.h>
+#include <kuniqueapplication.h>
 #include <kaboutdata.h>
+#include <kdebug.h>
 #include <kcmdlineargs.h>
 #include <kglobal.h>
 #include <klocale.h>
@@ -46,10 +47,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kmessagebox.h>
 #include <kiconloader.h>
 #include <kseparator.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kwin.h>
-#include <kdesktopwidget.h>
+#include <qdesktopwidget.h>
+#include <qcursor.h>
 
+#include <kdebug.h>
 
 #include "ktipwindow.moc"
 
@@ -58,7 +61,7 @@ TipWindow::TipWindow()
   : QDialog(0,0,false)
 {
     KWin::setState( winId(), NET::StaysOnTop );
-    setCaption(i18n("Kandalf's useful tips"));
+    setCaption(i18n("Kandalf's Useful Tips"));
 
     QVBoxLayout *vbox = new QVBoxLayout(this, 4);
 
@@ -70,6 +73,8 @@ TipWindow::TipWindow()
     QHBox *tl = new QHBox(hbox);
     tl->setMargin(7);
     tl->setBackgroundColor(QColor(49, 121, 172));
+    tl->setMinimumWidth(380);
+    hbox->setStretchFactor(tl, 3);
 
     QHBox *topLeft = new QHBox(tl);
     topLeft->setMargin(15);
@@ -80,27 +85,32 @@ TipWindow::TipWindow()
     text->mimeSourceFactory()->addFilePath(KGlobal::dirs()->findResourceDir("data", "kdewizard/pics")+"kdewizard/pics/");
     text->setFrameStyle(QFrame::NoFrame | QFrame::Plain);
     text->setHScrollBarMode(QScrollView::AlwaysOff);
+    text->installEventFilter(this);
     QStringList icons = KGlobal::dirs()->resourceDirs("icon");
     QStringList::Iterator it;
     for (it = icons.begin(); it != icons.end(); ++it)
         text->mimeSourceFactory()->addFilePath(*it);
+#if QT_VERSION < 300
+#warning ### set colors
     QColorGroup colors;
     colors.setBrush(QColorGroup::Base, QBrush(bgColor));
     colors.setColor(QColorGroup::Highlight, QColor(49, 121, 172));
     colors.setColor(QColorGroup::HighlightedText, Qt::white);
     text->setPaperColorGroup(colors);
+#endif
 
     QLabel *l = new QLabel(hbox);
     l->setPixmap(locate("data", "kdewizard/pics/wizard_small.png"));
     l->setBackgroundColor(QColor(49, 121, 172));
     l->setAlignment(Qt::AlignRight | Qt::AlignBottom);
+    hbox->setStretchFactor(l, 1);
 
     KSeparator* sep = new KSeparator( KSeparator::HLine, this);
     vbox->addWidget(sep);
 
     QHBoxLayout *hbox2 = new QHBoxLayout(vbox, 4);
 
-    startup = new QCheckBox(i18n("Run on startup"), this);
+    startup = new QCheckBox(i18n("&Show Tips on Startup"), this);
     hbox2->addWidget(startup, 1);
 
     prev = new QPushButton(i18n("&Previous"), this);
@@ -119,12 +129,11 @@ TipWindow::TipWindow()
 
     connect(startup, SIGNAL(clicked()), this, SLOT(startupClicked()));
 
-    resize(550, 230);
     QSize sh = sizeHint();
-    QRect rect = KApplication::desktop()->screenGeometry();
-    move(rect.x() + (rect.width() - sh.width())/2,
-         rect.y() + (rect.height() - sh.height())/2);
-
+    QRect rect = QApplication::desktop()->screenGeometry(QApplication::desktop()->screenNumber(QCursor::pos()));
+    int w = rect.x() + (rect.width() - sh.width())/2;
+    int h = rect.y() + (rect.height() - sh.height())/2;
+    move(w, h);
     loadTips();
 
     KConfig *config = new KConfig("kdewizardrc", true);
@@ -161,51 +170,36 @@ void TipWindow::startupClicked()
 // text as done here.
 void TipWindow::loadTips()
 {
-    QString fname;
+    QString fileName = locate("data", QString("kdewizard/tips"));
 
-    fname = locate("data", QString("kdewizard/tips"));
-
-    if (fname.isEmpty())
+    if (fileName.isEmpty())
+    {
+	kdDebug() << "can't find 'kdewizard/tips' in standard dirs" << endl;
         return;
+    }
+
+    QFile file(fileName);
+    if (!file.open(IO_ReadOnly))
+    {
+	kdDebug() << "can't open '" << fileName << "' for reading" << endl;
+	return;
+    }
 
     tips.clear();
 
-    QFile f(fname);
-    if (f.open(IO_ReadOnly))
+    QString content = file.readAll();
+
+    int pos = -1;
+    while ((pos = content.find("<html>", pos + 1, false)) != -1)
     {
-        QTextStream ts(&f);
-
-        QString line, tag, tip;
-        bool inTip = false;
-        while (!ts.eof())
-	{
-            line = ts.readLine();
-            tag = line.stripWhiteSpace().lower();
-
-            if (tag == "<html>")
-	    {
-                inTip = true;
-                tip = QString::null;
-                continue;
-	    }
-
-            if (inTip)
-	    {
-                if (tag == "</html>")
-		{
-                    tips.append(tip);
-                    inTip = false;
-		}
-                else
-                    tip.append(line).append("\n");
-	    }
-
-	}
-
-        f.close();
+	QString tip = content.mid(pos + 6, content.find("</html>", pos, false) - pos - 6);
+	if (tip.startsWith("\n"))
+	    tip = tip.mid(1);
+	tips.append(tip);
     }
-}
 
+    file.close();    
+}
 
 void TipWindow::nextTip()
 {
@@ -214,7 +208,7 @@ void TipWindow::nextTip()
     current += 1;
     if (current >= (int) tips.count())
         current = 0;
-    text->setText(QString("<html>%1</html>").arg(i18n(tips[current].latin1())));
+    text->setText(QString("<qt bgcolor=\"%1\">%2</qt>").arg(colorGroup().color(QColorGroup::Base).name()).arg(i18n(tips[current].utf8())));
 }
 
 
@@ -225,9 +219,23 @@ void TipWindow::prevTip()
     current -= 1;
     if (current < 0)
         current = tips.count()-1;
-    text->setText(QString("<html>%1</html>").arg(i18n(tips[current].latin1())));
+    text->setText(QString("<qt bgcolor=\"%1\">%2</qt>").arg(colorGroup().color(QColorGroup::Base).name()).arg(i18n(tips[current].utf8())));
 }
 
+bool TipWindow::eventFilter(QObject *o, QEvent *e)
+{
+    if ( e->type()== QEvent::KeyPress && 
+     ( ( (QKeyEvent *)e)->key() == Key_Return ||
+       ( (QKeyEvent *)e)->key() == Key_Space ) )
+        accept();
+
+    // If the user presses Return or Space, we close the dialog as if the
+    // default button was pressed even if the KTextBrowser has the keyboard
+    // focus. This could have the bad side-effect that the user cannot use the
+    // keyboard to open urls in the KTextBrowser, so we just let it handle
+    // the key event _additionally_. (Antonio)
+    return QWidget::eventFilter( o, e );
+}
 
 TipApp::TipApp() : KUniqueApplication()
 {
