@@ -53,6 +53,8 @@ public slots:
   void prevTip();
   void startupClicked();
 
+protected:
+  bool eventFilter(QObject *text, QEvent *ev );
 
 private:
 
