@@ -16,10 +16,16 @@ class KWinInterface : virtual public DCOPObject
   virtual void refresh() = 0;
   virtual void doNotManage(QString)= 0;
   virtual void showWindowMenuAt(unsigned long winId, int x, int y)= 0;
+  virtual void setDesktopLayout(int orientation, int x, int y)= 0;
   virtual void setCurrentDesktop(int)= 0;
   virtual int currentDesktop() const = 0;
   virtual void nextDesktop() = 0;
   virtual void previousDesktop() = 0;
+  virtual void circulateDesktopApplications() = 0;
+
+  k_dcop_signals:
+  
+  virtual void dcopResetAllClients();
 };
 
 #endif
