@@ -45,10 +45,13 @@ Atoms::Atoms()
     atoms[n] = &kde_wm_change_state;
     names[n++] = (char *) "_KDE_WM_CHANGE_STATE";
 
+    atoms[n] = &kde_net_user_time;
+    names[n++] = (char *) "_KDE_NET_USER_TIME";
+
     Atom fake;
     atoms[n] = &fake;
-    names[n++] = (char *) "DT_SM_WINDOW_INFO";
-    
+    names[n++] = (char *) "_DT_SM_WINDOW_INFO";
+
     XInternAtoms( qt_xdisplay(), names, n, FALSE, atoms_return );
     for (int i = 0; i < n; i++ )
 	*atoms[i] = atoms_return[i];
