@@ -17,10 +17,13 @@ public:
     Atom wm_delete_window;
     Atom wm_take_focus;
     Atom wm_change_state;
+    Atom wm_client_leader;
+    Atom wm_save_yourself;
 
     Atom motif_wm_hints;
     Atom net_wm_context_help;
     Atom kde_wm_change_state;
+    Atom kde_net_user_time;
 
 };
 
