@@ -50,7 +50,7 @@ public:
 
 protected:
     void resizeEvent( QResizeEvent * );
-    bool x11Event( XEvent * );		// X11 event
+    bool x11Event( XEvent * );          // X11 event
 
 private slots:
     void deferredResize();
@@ -80,7 +80,7 @@ public:
     WId window() const;
     WindowWrapper* windowWrapper() const;
     Workspace* workspace() const;
-    void releaseWindow();
+    void releaseWindow( bool withdraw = FALSE );
     void invalidateWindow();
     WId transientFor() const;
     bool isTransient() const;
@@ -105,15 +105,15 @@ public:
 
     // is the window in withdrawn state?
     bool isWithdrawn(){
-	return state == WithdrawnState;
+        return state == WithdrawnState;
     }
     // is the window in iconic state?
     bool isIconified(){
-	return state == IconicState;
+        return state == IconicState;
     }
     // is the window in normal state?
     bool isNormal(){
-	return state == NormalState;
+        return state == NormalState;
     }
 
     bool isActive() const;
@@ -125,7 +125,6 @@ public:
 
     bool isShade() const;
     virtual void setShade( bool , int = 0 );
-    void giveUpShade();
 
     bool isMaximized() const;
     enum MaximizeMode { MaximizeRestore = 0, MaximizeVertical = 1, MaximizeHorizontal = 2, MaximizeFull = 3,  MaximizeAdjust };
@@ -209,6 +208,12 @@ public:
     QString caption() const;
     void setCaption( const QString &);
 
+    void keyPressEvent( uint key_code );
+
+    void updateUserTime();
+
+  const QPoint gravitate( bool invert ) const;
+
 public slots:
     void iconify();
     void closeWindow();
@@ -226,13 +231,12 @@ protected:
     void mousePressEvent( QMouseEvent * );
     void mouseReleaseEvent( QMouseEvent * );
     void mouseMoveEvent( QMouseEvent * );
-    void keyPressEvent( QKeyEvent * );
     void resizeEvent( QResizeEvent * );
     virtual void windowWrapperShowEvent( QShowEvent* ){}
     virtual void windowWrapperHideEvent( QHideEvent* ){}
     void enterEvent( QEvent * );
     void leaveEvent( QEvent * );
-    bool x11Event( XEvent * );		// X11 event
+    bool x11Event( XEvent * );          // X11 event
 
     virtual void activateLayout();
 
@@ -249,7 +253,7 @@ protected:
 
 
     enum MousePosition {
-	Nowhere, TopLeft , BottomRight, BottomLeft, TopRight, Top, Bottom, Left, Right, Center
+        Nowhere, TopLeft , BottomRight, BottomLeft, TopRight, Top, Bottom, Left, Right, Center
     };
 
     virtual MousePosition mousePosition( const QPoint& ) const;
@@ -273,8 +277,11 @@ private:
     QSize sizeForWindowSize( const QSize&, bool ignore_height = FALSE ) const;
     void getWmNormalHints();
     void fetchName();
-    void gravitate( bool invert );
 
+    unsigned long userTime();
+
+    void startMoveResize();
+    void stopMoveResize();
 
     WId win;
     WindowWrapper* wwrap;
@@ -283,10 +290,10 @@ private:
     bool buttonDown;
     bool moveResizeMode;
     bool isMove() const {
-	return moveResizeMode && mode == Center;
+        return moveResizeMode && mode == Center;
     }
     bool isResize() const {
-	return moveResizeMode && !isMove();
+        return moveResizeMode && !isMove();
     }
     MousePosition mode;
     QPoint moveOffset;
@@ -339,7 +346,7 @@ private:
     static QCString staticWmCommand(WId);
     static QCString staticWmClientMachine(WId);
     static Window   staticWmClientLeader(WId);
-    
+
  private:
     ClientPrivate* d;
 
