@@ -1,5 +1,5 @@
 /*
- *	$Id: config.cpp,v 1.3 2001/07/15 12:14:54 livne Exp $
+ *	$Id: config.cpp,v 1.4 2002/02/19 16:56:14 coolo Exp $
  *
  *	KDE2 Default configuration widget
  *
@@ -31,7 +31,7 @@ extern "C"
 KDEDefaultConfig::KDEDefaultConfig( KConfig* conf, QWidget* parent )
 	: QObject( parent )
 {
-	KGlobal::locale()->insertCatalogue("libkwindefault_config");
+	KGlobal::locale()->insertCatalogue("kwin_default_config");
 	highcolor = QPixmap::defaultDepth() > 8;
 	gb = new QGroupBox( 1, Qt::Horizontal, 
 		i18n("Decoration Settings"), parent );
