@@ -1,5 +1,5 @@
 /*
- *	$Id: kdedefault.cpp,v 1.6 2001/07/28 11:43:50 rikkus Exp $
+ *	$Id: kdedefault.cpp,v 1.11 2001/10/30 18:31:52 lunakl Exp $
  *
  *	KDE2 Default KWin client
  *
@@ -14,6 +14,7 @@
 #include <kconfig.h>
 #include <kglobal.h>
 #include <kpixmapeffect.h>
+#include <kimageeffect.h>
 #include <kdrawutil.h>
 #include <klocale.h>
 #include <qlayout.h>
@@ -22,6 +23,7 @@
 #include "../../workspace.h"
 #include "../../options.h"
 #include "kdedefault.h"
+#include <qimage.h>
 
 using namespace KWinInternal;
 
@@ -531,12 +533,7 @@ void KDEDefaultButton::drawButton(QPainter *p)
 
 		// Intensify the image if required
 		if (isMouseOver) {
-			const QBitmap* mask = btnpix.mask();
-			if( mask != 0 ) {
-				btnpix.detach();
-				btnpix = KPixmapEffect::intensity(btnpix, 0.8);
-				btnpix.setMask( *mask );
-			}
+                    btnpix = KPixmapEffect::intensity(btnpix, 0.8);
 		}
 
 		// Smooth scale the pixmap for small titlebars
@@ -595,7 +592,7 @@ void KDEDefaultButton::mouseReleaseEvent( QMouseEvent* e )
 
 KDEDefaultClient::KDEDefaultClient( Workspace *ws, WId w, QWidget *parent,
 									const char *name )
-    : Client( ws, w, parent, name, WResizeNoErase | WNorthWestGravity |
+    : Client( ws, w, parent, name, WResizeNoErase | WStaticContents |
 								   WRepaintNoErase )
 {
 	// No flicker thanks
@@ -978,7 +975,6 @@ void KDEDefaultClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
 	if (titlebar->geometry().contains( e->pos() ) )
 		workspace()->performWindowOperation( this, options->operationTitlebarDblClick() );
-	workspace()->requestFocus( this );
 }
 
 
