@@ -1,5 +1,5 @@
 /*
-  $Id: icewm.cpp,v 1.13 2001/07/02 05:37:25 gallium Exp $
+  $Id: icewm.cpp,v 1.17 2001/12/29 17:27:17 mueller Exp $
   
   Gallium-IceWM themeable KWin client
 
@@ -41,7 +41,7 @@
 */
 
 #include <kconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdrawutil.h>
@@ -50,6 +50,7 @@
 #include <qdatetime.h>
 #include <qbitmap.h>
 #include <qstring.h>
+#include <qregexp.h>
 #include "../../workspace.h"
 #include "../../options.h"
 #include "icewm.h"
@@ -702,7 +703,7 @@ void IceWMButton::mouseReleaseEvent( QMouseEvent* e )
 ////////////////////////////////////////////////////////////////////////////////////////////
 
 IceWMClient::IceWMClient( Workspace *ws, WId w, QWidget *parent, const char *name )
-    : Client( ws, w, parent, name, WResizeNoErase | WNorthWestGravity | WRepaintNoErase )
+    : Client( ws, w, parent, name, WResizeNoErase | WStaticContents | WRepaintNoErase )
 {
 	// Set button pointers to null so we can track things
 	for(int i= IceWMClient::BtnSysMenu; i < IceWMClient::BtnCount; i++)
@@ -1198,7 +1199,6 @@ void IceWMClient::mouseDoubleClickEvent( QMouseEvent * e )
 	if ( r.contains( e->pos() ) )
 		workspace()->performWindowOperation( this, options->operationTitlebarDblClick() );
 
-	workspace()->requestFocus( this );
 }
 
 
