@@ -3,11 +3,13 @@
 #include <kglobal.h>
 #include <qlayout.h>
 #include <qdrawutil.h>
+#include <qpainter.h>
 #include <kpixmapeffect.h>
-#include <kstddirs.h>
-#include <kglobal.h>
+#include <kstandarddirs.h>
+#include <kdebug.h>
 #include <klocale.h>
 #include <qbitmap.h>
+#include <qstyle.h>
 #include "../../workspace.h"
 #include "../../options.h"
 
@@ -90,14 +92,14 @@ static void create_pixmaps()
         framePixmaps[i] = new QPixmap(locate("appdata",
                                       "pics/"+config->readEntry(keys[i], " ")));
         if(framePixmaps[i]->isNull())
-            qWarning("Unable to load frame pixmap for %s", keys[i]);
+            kdWarning() << "Unable to load frame pixmap for " << keys[i] << endl;
     }
-
+/*
     *framePixmaps[FrameTop] = stretchPixmap(*framePixmaps[FrameTop], false);
     *framePixmaps[FrameBottom] = stretchPixmap(*framePixmaps[FrameBottom], false);
     *framePixmaps[FrameLeft] = stretchPixmap(*framePixmaps[FrameLeft], true);
     *framePixmaps[FrameRight] = stretchPixmap(*framePixmaps[FrameRight], true);
-
+*/
     maxExtent = framePixmaps[FrameTop]->height();
     if(framePixmaps[FrameBottom]->height() > maxExtent)
         maxExtent = framePixmaps[FrameBottom]->height();
@@ -233,15 +235,21 @@ void MyButton::drawButtonLabel(QPainter *p)
 	// some visual notification of button presses. i.e. for MGBriezh
 	int offset = (isDown() && ((pixmap()->width() >= width()) || 
                          (pixmap()->height() >= height()))) ? 1 : 0;
+#if QT_VERSION < 300
         style().drawItem(p, offset, offset, width(), height(), 
                          AlignCenter, colorGroup(),
                          true, pixmap(), QString::null);
+#else
+        style().drawItem(p, QRect( offset, offset, width(), height() ), 
+                         AlignCenter, colorGroup(),
+                         true, pixmap(), QString::null);
+#endif
     }
 }
 
 KWMThemeClient::KWMThemeClient( Workspace *ws, WId w, QWidget *parent,
                             const char *name )
-    : Client( ws, w, parent, name, WResizeNoErase | WNorthWestGravity)
+    : Client( ws, w, parent, name, WResizeNoErase | WStaticContents )
 {
     stickyBtn = maxBtn = mnuBtn = 0;
     connect(options, SIGNAL(resetClients()), this, SLOT(slotReset())); 
@@ -324,7 +332,7 @@ KWMThemeClient::KWMThemeClient( Workspace *ws, WId w, QWidget *parent,
             if((val != "Off") && 
                ((val == "Iconify") && !isMinimizable()) &&
                ((val == "Maximize") && !isMaximizable()))
-                qWarning("KWin: Unrecognized button value: %s", val.latin1());
+                kdWarning() << "KWin: Unrecognized button value: " << val << endl;
 
         }
     }
