@@ -1,30 +1,20 @@
 
 #include <kconfig.h> // up here to avoid X11 header conflict :P
 #include "laptopclient.h"
-#include <qapplication.h>
-#include <qcursor.h>
 #include <qabstractlayout.h>
 #include <qlayout.h>
-#include <qtoolbutton.h>
-#include <qlabel.h>
 #include <qdrawutil.h>
 #include <kpixmapeffect.h>
 #include <kdrawutil.h>
 #include <kglobal.h>
-#include <kapp.h>
+#include <kapplication.h>
+#include <klocale.h>
 #include <qbitmap.h>
 #include "../../workspace.h"
 #include "../../options.h"
 
 using namespace KWinInternal;
 
-extern "C"
-{
-    Client *allocate(Workspace *ws, WId w, int)
-    {
-        return(new LaptopClient(ws, w));
-    }
-}
 
 
 static unsigned char iconify_bits[] = {
@@ -210,10 +200,29 @@ static void create_pixmaps()
         btnForeground = Qt::white;
 }
 
+static void delete_pixmaps()
+{
+    delete titlePix;
+    if(aUpperGradient){
+        delete aUpperGradient;
+        delete iUpperGradient;
+        delete btnPix1;
+        delete btnDownPix1;
+        delete iBtnPix1;
+        delete iBtnDownPix1;
+        delete btnPix2;
+        delete btnDownPix2;
+        delete iBtnPix2;
+        delete iBtnDownPix2;
+    }
+    pixmaps_created = false;
+}
 
-LaptopClientButton::LaptopClientButton(int w, int h, Client *parent, const char *name,
-                           const unsigned char *bitmap)
-    : QButton(parent, name)
+
+LaptopClientButton::LaptopClientButton(int w, int h, Client *parent, 
+        const char *name, const unsigned char *bitmap, 
+        const QString& tip)
+    : KWinButton(parent, name, tip)
 {
     client = parent;
     defaultSize = QSize(w, h);
@@ -280,21 +289,6 @@ void LaptopClientButton::drawButton(QPainter *p)
 
 void LaptopClient::slotReset()
 {
-    delete titlePix;
-    if(aUpperGradient){
-        delete aUpperGradient;
-        delete iUpperGradient;
-        delete btnPix1;
-        delete btnDownPix1;
-        delete iBtnPix1;
-        delete iBtnDownPix1;
-        delete btnPix2;
-        delete btnDownPix2;
-        delete iBtnPix2;
-        delete iBtnDownPix2;
-    }
-    pixmaps_created = false;
-    create_pixmaps();
     int i;
     for(i=0; i < 5; ++i){
         if(button[i])
@@ -305,12 +299,11 @@ void LaptopClient::slotReset()
 
 LaptopClient::LaptopClient( Workspace *ws, WId w, QWidget *parent,
                             const char *name )
-    : Client( ws, w, parent, name, WResizeNoErase | WNorthWestGravity )
+    : Client( ws, w, parent, name, WResizeNoErase | WStaticContents )
 {
     lastButtonWidth = 0;
     lastBufferWidth = 0;
 
-    create_pixmaps();
     connect(options, SIGNAL(resetClients()), this, SLOT(slotReset()));
     bool help = providesContextHelp();
 
@@ -329,19 +322,21 @@ LaptopClient::LaptopClient( Workspace *ws, WId w, QWidget *parent,
     if ( isTool() )
 	th -= 2;
 
-    button[BtnClose] = new LaptopClientButton(27, th, this, "close", close_bits);
-    button[BtnSticky] = new LaptopClientButton(17, th, this, "sticky");
+    button[BtnClose] = new LaptopClientButton(27, th, this, "close", 
+                                 close_bits, i18n("Close"));
+    button[BtnSticky] = new LaptopClientButton(17, th, this, "sticky",
+                                 NULL, i18n("Sticky"));
     if(isSticky())
         button[BtnSticky]->setBitmap(unsticky_bits);
     else
         button[BtnSticky]->setBitmap(sticky_bits);
     button[BtnIconify] = new LaptopClientButton(27, th, this, "iconify",
-                                          iconify_bits);
+                                          iconify_bits, i18n("Minimize"));
     button[BtnMax] = new LaptopClientButton(27, th, this, "maximize",
-                                      maximize_bits);
+                                      maximize_bits, i18n("Maximize"));
     if(help){
         button[BtnHelp] = new LaptopClientButton(17, th, this, "help",
-                                     question_bits);
+                                     question_bits, i18n("Help"));
         connect(button[BtnHelp], SIGNAL( clicked() ), this, ( SLOT( contextHelp() ) ) );
     }
     else
@@ -532,17 +527,18 @@ void LaptopClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
     if (titlebar->geometry().contains( e->pos() ) )
 	workspace()->performWindowOperation( this, options->operationTitlebarDblClick() );
-    workspace()->requestFocus( this );
 }
 
 void LaptopClient::stickyChange(bool on)
 {
     button[BtnSticky]->setBitmap(on ? unsticky_bits : sticky_bits);
+    button[BtnSticky]->setTipText(on ? i18n("Un-Sticky") : i18n("Sticky"));
 }
 
 void LaptopClient::maximizeChange(bool m)
 {
     button[BtnMax]->setBitmap(m ? minmax_bits : maximize_bits);
+    button[BtnMax]->setTipText(m ? i18n("Restore") : i18n("Maximize"));
 }
 
 void LaptopClient::init()
@@ -685,4 +681,27 @@ LaptopClient::mousePosition( const QPoint& p ) const
   return m;
 }
 
+extern "C"
+{
+    Client *allocate(Workspace *ws, WId w, int)
+    {
+        return(new LaptopClient(ws, w));
+    }
+    void init()
+    {
+       create_pixmaps();
+    }
+    void reset()
+    {
+       delete_pixmaps();
+       create_pixmaps();
+       // Ensure change in tooltip state gets applied
+       Workspace::self()->slotResetAllClientsDelayed();
+    }
+    void deinit()
+    {
+       delete_pixmaps();
+    }
+}
+
 #include "laptopclient.moc"
