@@ -1,59 +1,52 @@
-#include "modernsys.h"
-#include <qapplication.h>
-#include <qcursor.h>
-#include <qabstractlayout.h>
+// $Id: modernsys.cpp,v 1.28 2001/10/12 12:29:15 faure Exp $
+// Daniel M. DULEY <mosfet@kde.org>               original work
+// Melchior FRANZ  <a8603365@unet.univie.ac.at>   configuration options
+
+#include <kconfig.h>
+#include <kglobal.h>
+#include <klocale.h>
 #include <qlayout.h>
-#include <qtoolbutton.h>
-#include <qlabel.h>
 #include <qdrawutil.h>
 #include <kpixmapeffect.h>
 #include <kdrawutil.h>
-#include <kapp.h>
 #include <qbitmap.h>
 #include "../../workspace.h"
 #include "../../options.h"
+#include "modernsys.h"
 
 #include "buttondata.h"
 #include "btnhighcolor.h"
+#include <qimage.h>
 
 using namespace KWinInternal;
 
-extern "C"
-{
-    Client *allocate(Workspace *ws, WId w, int)
-    {
-        return(new ModernSys(ws, w));
-    }
-}
-
 
 static unsigned char iconify_bits[] = {
-  0x00, 0x00, 0xff, 0xff, 0x7e, 0x3c, 0x18, 0x00};
+    0x00, 0x00, 0xff, 0xff, 0x7e, 0x3c, 0x18, 0x00};
 
-/* not used currently
 static unsigned char close_bits[] = {
-    0xc3, 0x66, 0x3c, 0x18, 0x3c, 0x66, 0xc3, 0x00};
-*/
+    0x00, 0x66, 0x7e, 0x3c, 0x3c, 0x7e, 0x66, 0x00};
+
 static unsigned char maximize_bits[] = {
-  0x00, 0x18, 0x3c, 0x7e, 0xff, 0xff, 0x00, 0x00};
+    0x00, 0x18, 0x3c, 0x7e, 0xff, 0xff, 0x00, 0x00};
 
 static unsigned char minmax_bits[] = {
     0x0c, 0x18, 0x33, 0x67, 0xcf, 0x9f, 0x3f, 0x3f};
 
 static unsigned char unsticky_bits[] = {
-   0x3c, 0x42, 0x99, 0xbd, 0xbd, 0x99, 0x42, 0x3c};
+    0x3c, 0x42, 0x99, 0xbd, 0xbd, 0x99, 0x42, 0x3c};
 
 static unsigned char sticky_bits[] = {
-   0x3c, 0x42, 0x81, 0x81, 0x81, 0x81, 0x42, 0x3c};
+    0x3c, 0x42, 0x81, 0x81, 0x81, 0x81, 0x42, 0x3c};
 
 static unsigned char question_bits[] = {
     0x3c, 0x66, 0x60, 0x30, 0x18, 0x00, 0x18, 0x18};
 
 static unsigned char btnhighcolor_mask_bits[] = {
- 0xe0,0x41,0xf8,0x07,0xfc,0x0f,0xfe,0xdf,0xfe,0x1f,0xff,0x3f,0xff,0xff,0xff,
- 0x3f,0xff,0x3f,0xff,0xff,0xff,0xff,0xfe,0x9f,0xfe,0x1f,0xfc,0x0f,0xf0,0x03,
- 0x00,0x40,0x80,0x00,0x00,0x00,0x39,0x00,0x00,0x00,0x20,0x99,0x0f,0x08,0xc4,
- 0x00,0x00,0x00,0x67,0x00,0x00,0x00,0x58,0x5f,0x43,0x68,0x61,0x6e,0x67,0x65 };
+    0xe0,0x41,0xf8,0x07,0xfc,0x0f,0xfe,0xdf,0xfe,0x1f,0xff,0x3f,0xff,0xff,0xff,
+    0x3f,0xff,0x3f,0xff,0xff,0xff,0xff,0xfe,0x9f,0xfe,0x1f,0xfc,0x0f,0xf0,0x03,
+    0x00,0x40,0x80,0x00,0x00,0x00,0x39,0x00,0x00,0x00,0x20,0x99,0x0f,0x08,0xc4,
+    0x00,0x00,0x00,0x67,0x00,0x00,0x00,0x58,0x5f,0x43,0x68,0x61,0x6e,0x67,0x65 };
 
 static KPixmap *aUpperGradient=0;
 static KPixmap *iUpperGradient=0;
@@ -62,17 +55,22 @@ static QPixmap *buttonPixDown=0;
 static QPixmap *iButtonPix=0;
 static QPixmap *iButtonPixDown=0;
 
-static QColor buttonFg;
+static QColor *buttonFg;
 static bool pixmaps_created = false;
 
+static QBitmap *lcDark1;
+static QBitmap *lcDark2;
+static QBitmap *lcDark3;
+static QBitmap *lcLight1;
+static QImage *btnSource;
+
+static QString *button_pattern = NULL;
+static bool show_handle;
+static int handle_size;
+static int handle_width;
+
 static void make_button_fx(const QColorGroup &g, QPixmap *pix, bool light=false)
 {
-    static QBitmap lcDark1(14, 15, lowcolor_6a696a_bits, true);
-    static QBitmap lcDark2(14, 15, lowcolor_949194_bits, true);
-    static QBitmap lcDark3(14, 15, lowcolor_b4b6b4_bits, true);
-    static QBitmap lcLight1(14, 15, lowcolor_e6e6e6_bits, true);
-    static QImage btnSource(btnhighcolor_xpm);
-
     pix->fill(g.background());
     QPainter p(pix);
 
@@ -80,17 +78,17 @@ static void make_button_fx(const QColorGroup &g, QPixmap *pix, bool light=false)
         int i, destH, destS, destV, srcH, srcS, srcV;
         QColor btnColor = g.background();
 
-        if(btnSource.depth() < 32)
-            btnSource = btnSource.convertDepth(32);
+        if(btnSource->depth() < 32)
+            *btnSource = btnSource->convertDepth(32);
         if(light)
             btnColor = btnColor.light(120);
         btnColor.hsv(&destH, &destS, &destV);
         QImage btnDest(14, 15, 32);
 
-        unsigned int *srcData = (unsigned int *)btnSource.bits();
+        unsigned int *srcData = (unsigned int *)btnSource->bits();
         unsigned int *destData = (unsigned int *)btnDest.bits();
         QColor srcColor;
-        for(i=0; i < btnSource.width()*btnSource.height(); ++i){
+        for(i=0; i < btnSource->width()*btnSource->height(); ++i){
             srcColor.setRgb(srcData[i]);
             srcColor.hsv(&srcH, &srcS, &srcV);
             srcColor.setHsv(destH, destS, srcV);
@@ -100,19 +98,19 @@ static void make_button_fx(const QColorGroup &g, QPixmap *pix, bool light=false)
 
     }
     else{
-        if(!lcDark1.mask()){
-            lcDark1.setMask(lcDark1);
-            lcDark2.setMask(lcDark2);
-            lcDark3.setMask(lcDark3);
-            lcLight1.setMask(lcLight1);
+        if(!lcDark1->mask()){
+            lcDark1->setMask(*lcDark1);
+            lcDark2->setMask(*lcDark2);
+            lcDark3->setMask(*lcDark3);
+            lcLight1->setMask(*lcLight1);
         }
         p.setPen(g.dark());
-        p.drawPixmap(0, 0, lcDark2);
-        p.drawPixmap(0, 0, lcDark1);
+        p.drawPixmap(0, 0, *lcDark2);
+        p.drawPixmap(0, 0, *lcDark1);
         p.setPen(g.mid());
-        p.drawPixmap(0, 0, lcDark3);
+        p.drawPixmap(0, 0, *lcDark3);
         p.setPen(g.light());
-        p.drawPixmap(0, 0, lcLight1);
+        p.drawPixmap(0, 0, *lcLight1);
     }
 }
 
@@ -123,6 +121,12 @@ static void create_pixmaps()
         return;
     pixmaps_created = true;
 
+    lcDark1 = new QBitmap(14, 15, lowcolor_6a696a_bits, true);
+    lcDark2 = new QBitmap(14, 15, lowcolor_949194_bits, true);
+    lcDark3 = new QBitmap(14, 15, lowcolor_b4b6b4_bits, true);
+    lcLight1 = new QBitmap(14, 15, lowcolor_e6e6e6_bits, true);
+    btnSource = new QImage(btnhighcolor_xpm);
+
     if(QPixmap::defaultDepth() > 8){
         aUpperGradient = new KPixmap;
         aUpperGradient->resize(32, 18);
@@ -152,15 +156,73 @@ static void create_pixmaps()
 
 
     if(qGray(btnColor.background().rgb()) < 150)
-        buttonFg = Qt::white;
+        buttonFg = new QColor(Qt::white);
     else
-        buttonFg = Qt::black;
+        buttonFg = new QColor(Qt::black);
+
+    delete lcDark1;
+    delete lcDark2;
+    delete lcDark3;
+    delete lcLight1;
+    delete btnSource;
+}
+
+static void delete_pixmaps()
+{
+    if(aUpperGradient){
+        delete aUpperGradient;
+        delete iUpperGradient;
+    }
+    delete buttonPix;
+    delete buttonPixDown;
+    delete iButtonPix;
+    delete iButtonPixDown;
+
+    delete buttonFg;
+
+    pixmaps_created = false;
+}
+
+static bool read_config()
+{
+    bool showh;
+    int hsize, hwidth;
+    QString bpatt;
+
+    KConfig c("kwinmodernsysrc");
+    c.setGroup("General");
+    showh = c.readBoolEntry("ShowHandle", true);
+
+    hwidth = c.readUnsignedNumEntry("HandleWidth", 6);
+    hsize = c.readUnsignedNumEntry("HandleSize", 30);
+    if (!(showh && hsize && hwidth)) {
+        showh = false;
+        hwidth = hsize = 0;
+    }
+
+    if (options->customButtonPositions()) {
+        bpatt = "2" + options->titleButtonsLeft() + "3t3"
+                + options->titleButtonsRight() + "2";
+    }
+    else
+        bpatt = "2X3t3HSIA2";
+
+    if (showh == show_handle && hwidth == handle_width && hsize == handle_size
+            && bpatt == *button_pattern)
+        return false;
+    
+    show_handle = showh;
+    handle_width = hwidth;
+    handle_size = hsize;
+    *button_pattern = bpatt;
+    return true;
 }
 
 ModernButton::ModernButton(Client *parent, const char *name,
-                           const unsigned char *bitmap)
-    : QButton(parent, name)
+                           const unsigned char *bitmap, const QString& tip)
+    : KWinButton(parent, name, tip)
 {
+    setBackgroundMode( NoBackground );
     QBitmap mask(14, 15, QPixmap::defaultDepth() > 8 ?
                  btnhighcolor_mask_bits : lowcolor_mask_bits, true);
     resize(14, 15);
@@ -168,7 +230,8 @@ ModernButton::ModernButton(Client *parent, const char *name,
     if(bitmap)
         setBitmap(bitmap);
     setMask(mask);
-    client = parent;
+    hide();
+	client = parent;
 }
 
 QSize ModernButton::sizeHint() const
@@ -199,7 +262,7 @@ void ModernButton::drawButton(QPainter *p)
             p->drawPixmap(0, 0, isDown() ? *iButtonPixDown : *iButtonPix);
     }
     if(!deco.isNull()){
-        p->setPen(buttonFg);
+        p->setPen(*buttonFg);
         p->drawPixmap(isDown() ? 4 : 3, isDown() ? 5 : 4, deco);
     }
 }
@@ -208,37 +271,22 @@ void ModernButton::mousePressEvent( QMouseEvent* e )
 {
     last_button = e->button();
     QMouseEvent me ( e->type(), e->pos(), e->globalPos(), LeftButton, e->state() );
-    QButton::mousePressEvent( &me );
+    KWinButton::mousePressEvent( &me );
 }
 
 void ModernButton::mouseReleaseEvent( QMouseEvent* e )
 {
     QMouseEvent me ( e->type(), e->pos(), e->globalPos(), LeftButton, e->state() );
-    QButton::mouseReleaseEvent( &me );
+    KWinButton::mouseReleaseEvent( &me );
 }
 
 
 void ModernSys::slotReset()
 {
-    if(aUpperGradient){
-        delete aUpperGradient;
-        delete iUpperGradient;
-    }
-    delete buttonPix;
-    delete buttonPixDown;
-    delete iButtonPix;
-    delete iButtonPixDown;
-
-    pixmaps_created = false;
-    create_pixmaps();
+    workspace()->slotResetAllClientsDelayed();
     titleBuffer.resize(0, 0);
     recalcTitleBuffer();
-    button[0]->reset();
-    button[1]->reset();
-    button[2]->reset();
-    button[3]->reset();
-    if(button[4])
-        button[4]->reset();
+    for (int i = 0; i < 5; button[i++]->reset());
     repaint();
 }
 
@@ -246,7 +294,6 @@ ModernSys::ModernSys( Workspace *ws, WId w, QWidget *parent,
                             const char *name )
     : Client( ws, w, parent, name, WResizeNoErase )
 {
-    create_pixmaps();
     connect(options, SIGNAL(resetClients()), this, SLOT(slotReset()));
     bool help = providesContextHelp();
 
@@ -256,59 +303,76 @@ ModernSys::ModernSys( Workspace *ws, WId w, QWidget *parent,
     g->addItem( new QSpacerItem( 0, 0, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
 
     g->addColSpacing(0, 2);
-    g->addColSpacing(2, 8);
+    g->addColSpacing(2, 2 + handle_width);
 
-    g->addRowSpacing(2, 8);
-
-    button[0] = new ModernButton(this, "close"/*, close_bits*/);
-    button[1] = new ModernButton(this, "sticky");
-    if(isSticky())
-        button[1]->setBitmap(unsticky_bits);
-    else
-        button[1]->setBitmap(sticky_bits);
-    button[2] = new ModernButton(this, "iconify", iconify_bits);
-    button[3] = new ModernButton(this, "maximize", maximize_bits);
-    if(help){
-        button[4] = new ModernButton(this, "help", question_bits);
-        connect( button[4], SIGNAL( clicked() ), this, ( SLOT( contextHelp() ) ) );
-    }
-    else
-        button[4] = NULL;
-
-    connect( button[0], SIGNAL( clicked() ), this, ( SLOT( closeWindow() ) ) );
-    connect( button[1], SIGNAL( clicked() ), this, ( SLOT( toggleSticky() ) ) );
-    connect( button[2], SIGNAL( clicked() ), this, ( SLOT( iconify() ) ) );
-    connect( button[3], SIGNAL( clicked() ), this, ( SLOT( maxButtonClicked() ) ) );
+    g->addRowSpacing(2, 2 + handle_width);
 
     QHBoxLayout* hb = new QHBoxLayout(0);
     hb->setResizeMode(QLayout::FreeResize);
-    g->addLayout( hb, 0, 1 );
-    //hb->addSpacing(3);
-    hb->addWidget( button[0]);
     titlebar = new QSpacerItem(10, 16, QSizePolicy::Expanding,
                                QSizePolicy::Minimum);
-    hb->addSpacing(3);
-    hb->addItem(titlebar);
-    hb->addSpacing(3);
-    if(help){
-        hb->addWidget( button[4]);
-        hb->addSpacing(1);
-    }
-    hb->addWidget( button[1]);
-    hb->addSpacing(1);
-    hb->addWidget( button[2]);
-    hb->addSpacing(1);
-    hb->addWidget( button[3]);
-    hb->addSpacing(2);
 
+    button[BtnClose] = new ModernButton(this, "close", close_bits, i18n("Close"));
+    button[BtnSticky] = new ModernButton(this, "sticky", NULL, i18n("Sticky"));
+    button[BtnMinimize] = new ModernButton(this, "iconify", iconify_bits, i18n("Minimize"));
+    button[BtnMaximize] = new ModernButton(this, "maximize", maximize_bits, i18n("Maximize"));
+    button[BtnHelp] = new ModernButton(this, "help", question_bits, i18n("Help"));
+
+    connect( button[BtnClose], SIGNAL(clicked()), this, SLOT( closeWindow() ) );
+    connect( button[BtnSticky], SIGNAL(clicked()), this, SLOT( toggleSticky() ) );
+    connect( button[BtnMinimize], SIGNAL(clicked()), this, SLOT( iconify() ) );
+    connect( button[BtnMaximize], SIGNAL(clicked()), this, SLOT( maxButtonClicked() ) );
+    connect( button[BtnHelp], SIGNAL(clicked()), this, SLOT( contextHelp() ) );
+
+    for (int i = 0; i < (int)button_pattern->length();) {
+        QChar c = (*button_pattern)[i++];
+        if (c == '_')
+            c = '3';
+
+        if (c.isDigit()) {
+            hb->addSpacing(int(c - '0'));
+            continue;
+        }
+        else if (c == 'X') {
+            hb->addWidget(button[BtnClose]);
+            button[BtnClose]->show();
+        }
+        else if (c == 'S') {
+            if(isSticky())
+                button[BtnSticky]->setBitmap(unsticky_bits);
+            else
+                button[BtnSticky]->setBitmap(sticky_bits);
+            hb->addWidget(button[BtnSticky]);
+            button[BtnSticky]->show();
+        }
+        else if (c == 'I' && isMinimizable()) {
+            hb->addWidget(button[BtnMinimize]);
+            button[BtnMinimize]->show();
+        }
+        else if (c == 'A' && isMaximizable()) {
+            hb->addWidget(button[BtnMaximize]);
+            button[BtnMaximize]->show();
+        }
+        else if (help && c == 'H') {
+            hb->addWidget(button[BtnHelp]);
+            button[BtnHelp]->show();
+        }
+        else if (c == 't')
+            hb->addItem(titlebar);
+
+        if ((*button_pattern)[i] >= 'A' && (*button_pattern)[i] <= 'Z')
+            hb->addSpacing(1);
+    }
+
+    g->addLayout( hb, 0, 1 );
     setBackgroundMode(NoBackground);
     recalcTitleBuffer();
-
 }
 
+
 void ModernSys::maxButtonClicked( )
 {
-    switch ( button[3]->last_button ) {
+    switch ( button[BtnMaximize]->last_button ) {
     case MidButton:
        maximize( MaximizeVertical );
        break;
@@ -321,23 +385,10 @@ void ModernSys::maxButtonClicked( )
     }
 }
 
-
-
 void ModernSys::resizeEvent( QResizeEvent* )
 {
-    //Client::resizeEvent( e );
     recalcTitleBuffer();
     doShape();
-    /*
-    if ( isVisibleToTLW() && !testWFlags( WNorthWestGravity )) {
-        QPainter p( this );
-	QRect t = titlebar->geometry();
-	t.setTop( 0 );
-	QRegion r = rect();
-	r = r.subtract( t );
-	p.setClipRegion( r );
-	p.eraseRect( rect() );
-        }*/
 }
 
 void ModernSys::recalcTitleBuffer()
@@ -357,7 +408,7 @@ void ModernSys::recalcTitleBuffer()
 
     QRect t = titlebar->geometry();
     t.setTop( 2 );
-    t.setLeft( t.left() + 4 );
+    t.setLeft( t.left() );
     t.setRight( t.right() - 2 );
 
     QRegion r(t.x(), 0, t.width(), 18);
@@ -397,6 +448,9 @@ void ModernSys::drawRoundFrame(QPainter &p, int x, int y, int w, int h)
 
 void ModernSys::paintEvent( QPaintEvent* )
 {
+    int hs = handle_size;
+    int hw = handle_width;
+
     QPainter p( this );
     QRect t = titlebar->geometry();
 
@@ -409,11 +463,11 @@ void ModernSys::paintEvent( QPaintEvent* )
     p.fillRect(width()-6, 0, width()-1, height(), fillBrush);
 
     t.setTop( 2 );
-    t.setLeft( t.left() + 4 );
+    t.setLeft( t.left() );
     t.setRight( t.right() - 2 );
 
-    int w = width()-6; // exclude handle
-    int h = height()-6;
+    int w = width() - hw; // exclude handle
+    int h = height() - hw;
 
     // titlebar
     QColorGroup g = options->colorGroup(Options::TitleBar, isActive());
@@ -450,44 +504,49 @@ void ModernSys::paintEvent( QPaintEvent* )
 
     qDrawShadePanel(&p, 3, 19, w-6, h-22, g, true);
 
-    // handle
-    p.setPen(g.dark());
-    p.drawLine(width()-3, height()-29, width()-3, height()-3);
-    p.drawLine(width()-29, height()-3, width()-3, height()-3);
+    if (show_handle) {
+        p.setPen(g.dark());
+        p.drawLine(width()-3, height()-hs-1, width()-3, height()-3);
+        p.drawLine(width()-hs-1, height()-3, width()-3, height()-3);
 
-    p.setPen(g.light());
-    p.drawLine(width()-6, height()-29, width()-6, height()-6);
-    p.drawLine(width()-29, height()-6, width()-6, height()-6);
-    p.drawLine(width()-6, height()-29, width()-4, height()-29);
-    p.drawLine(width()-29, height()-6, width()-29, height()-4);
-
-
-    p.setPen(Qt::black);
-    p.drawRect(0, 0, w, h);
-
-    // handle outline
-    p.drawLine(width()-6, height()-30, width(), height()-30);
-    p.drawLine(width()-2, height()-30, width()-2, height()-2);
-    p.drawLine(width()-30, height()-2, width()-2, height()-2);
-    p.drawLine(width()-30, height()-6, width()-30, height()-2);
+        p.setPen(g.light());
+        p.drawLine(width()-hw, height()-hs-1, width()-hw, height()-hw);
+        p.drawLine(width()-hs-1, height()-hw, width()-hw, height()-hw);
+        p.drawLine(width()-hw, height()-hs-1, width()-4, height()-hs-1);
+        p.drawLine(width()-hs-1, height()-hw, width()-hs-1, height()-4);
 
+        p.setPen(Qt::black);
+        p.drawRect(0, 0, w, h);
 
+        // handle outline
+        p.drawLine(width()-hw, height()-hs, width(), height()-hs);
+        p.drawLine(width()-2, height()-hs, width()-2, height()-2);
+        p.drawLine(width()-hs, height()-2, width()-2, height()-2);
+        p.drawLine(width()-hs, height()-hw, width()-hs, height()-2);
+    } else {
+        p.setPen(Qt::black);
+        p.drawRect(0, 0, w, h);
+    }
 }
 
-#define QCOORDARRLEN(x) sizeof(x)/(sizeof(QCOORD)*2)
-
 void ModernSys::doShape()
 {
+    int hs = handle_size;
+    int hw = handle_width;
     QRegion mask;
-    mask += QRect(0, 0, width()-6, height()-6);
-    mask += QRect(width()-30, height()-30, 29, 29);
+    mask += QRect(0, 0, width()-hw, height()-hw);
     //single points
     mask -= QRect(0, 0, 1, 1);
-    mask -= QRect(width()-7, 0, 1, 1);
-    mask -= QRect(0, height()-7, 1, 1);
-    mask -= QRect(width()-2, height()-2, 1, 1);
-    mask -= QRect(width()-2, height()-30, 1, 1);
-    mask -= QRect(width()-30, height()-2, 1, 1);
+    mask -= QRect(width()-hw-1, 0, 1, 1);
+    mask -= QRect(0, height()-hw-1, 1, 1);
+
+    if (show_handle) {
+        mask += QRect(width()-hs, height()-hs, hs-1, hs-1);
+        mask -= QRect(width()-2, height()-2, 1, 1);
+        mask -= QRect(width()-2, height()-hs, 1, 1);
+        mask -= QRect(width()-hs, height()-2, 1, 1);
+    } else
+        mask -= QRect(width()-1, height()-1, 1, 1);
 
     setMask(mask);
 }
@@ -507,18 +566,19 @@ void ModernSys::windowWrapperShowEvent( QShowEvent* )
 void ModernSys::mouseDoubleClickEvent( QMouseEvent * e )
 {
     if (titlebar->geometry().contains( e->pos() ) )
-	workspace()->performWindowOperation( this, options->operationTitlebarDblClick() );
-    workspace()->requestFocus( this );
+        workspace()->performWindowOperation( this, options->operationTitlebarDblClick() );
 }
 
 void ModernSys::stickyChange(bool on)
 {
-    button[1]->setBitmap(on ? unsticky_bits : sticky_bits);
+    button[BtnSticky]->setBitmap(on ? unsticky_bits : sticky_bits);
+    button[BtnSticky]->setTipText(on ? i18n("Un-Sticky") : i18n("Sticky"));
 }
 
 void ModernSys::maximizeChange(bool m)
 {
-    button[3]->setBitmap(m ? minmax_bits : maximize_bits);
+    button[BtnMaximize]->setBitmap(m ? minmax_bits : maximize_bits);
+    button[BtnMaximize]->setTipText(m ? i18n("Restore") : i18n("Maximize"));
 }
 
 void ModernSys::init()
@@ -529,12 +589,7 @@ void ModernSys::init()
 void ModernSys::activeChange(bool)
 {
     repaint(false);
-    button[0]->reset();
-    button[1]->reset();
-    button[2]->reset();
-    button[3]->reset();
-    if(button[4])
-        button[4]->reset();
+    for (int i = 0; i < 5; button[i++]->reset());
 }
 
 
@@ -542,13 +597,47 @@ Client::MousePosition ModernSys::mousePosition( const QPoint& p) const
 {
     MousePosition m = Client::mousePosition( p );
 
-    if ( m == Center ) {
-	int border = 10;
-	if ( p.y() >= height()-border )
-	    m =  Bottom;
-	else if ( p.x() >= width()-border )
-	    m =  Right;
+    if ( show_handle && m == Center ) {
+       int border = handle_width + 4;
+	   bool hx = (p.x() >= width() - border);
+	   bool hy = (p.y() >= height() - border);
+
+       if (hx && hy)
+           m = BottomRight;
+       else if (hx)
+           m =  Right;
+       else if (hy)
+           m =  Bottom;
     }
     return m;
 }
+
+
+// KWin extended plugin interface
+extern "C"
+{
+    Client *allocate(Workspace *ws, WId w, int)
+    {
+        return(new ModernSys(ws, w));
+    }
+    void init()
+    {
+        button_pattern = new QString;
+        create_pixmaps();
+        read_config();
+    }
+    void reset()
+    {
+        read_config();
+		delete_pixmaps();
+		create_pixmaps();
+    }
+    void deinit()
+    {
+        delete_pixmaps();
+        delete button_pattern;
+    }
+}
+
 #include "modernsys.moc"
+// vim:ts=4:sw=4
