@@ -1,6 +1,6 @@
 /*
   RISC OS KWin client
-  
+
   Copyright 2000
     Rik Hemsley <rik@kde.org>
 
@@ -22,13 +22,13 @@
 
 // for enable-final
 #ifdef Bool
-#undef Bool 
+#undef Bool
 #endif
 
 #include <qimage.h>
 #include <qpixmap.h>
 #include <qpainter.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 #include <ksimpleconfig.h>
 
@@ -86,7 +86,7 @@ Static::_drawBorder(QPixmap & pix, int w, int h)
 
   painter_.setPen(c0);
   painter_.drawPoint(0, 0);
-  
+
   painter_.setPen(c1);
   painter_.drawPoint(1, 1);
   painter_.drawLine(1, 0, w - 1, 0);
@@ -118,7 +118,7 @@ Static::_drawBorder(QPixmap & pix, int w, int h)
   painter_.setPen(c7);
   painter_.drawPoint(w - 1, h - 1);
   painter_.drawPoint(w, h);
-  
+
   painter_.end();
 
   painter_.resetXForm();
@@ -198,8 +198,9 @@ Static::_createTexture(QPixmap & px, int t, bool active)
 
   QColor c(options->color(Options::ColorType(t), active));
 
-  QRgb light(c.light(110).rgb());
-  QRgb dark (c.dark(110).rgb());
+  QRgb mid    (c.rgb());
+  QRgb light  (c.light(110).rgb());
+  QRgb dark   (c.dark(110).rgb());
 
   QRgb * data(reinterpret_cast<QRgb *>(texture.bits()));
 
@@ -208,6 +209,8 @@ Static::_createTexture(QPixmap & px, int t, bool active)
       data[x] = light;
     else if (data[x] == b)
       data[x] = dark;
+    else
+      data[x] = mid;
 
   px.convertFromImage(texture);
 }
