@@ -1,27 +1,17 @@
 #include "systemclient.h"
-#include <qapplication.h>
-#include <qcursor.h>
 #include <qabstractlayout.h>
 #include <qlayout.h>
-#include <qtoolbutton.h>
-#include <qlabel.h>
 #include <qdrawutil.h>
 #include <kpixmapeffect.h>
 #include <kdrawutil.h>
-#include <kapp.h>
+#include <klocale.h>
+#include <kapplication.h>
 #include <qbitmap.h>
 #include "../../workspace.h"
 #include "../../options.h"
 
 using namespace KWinInternal;
 
-extern "C"
-{
-    Client *allocate(Workspace *ws, WId w, int)
-    {
-        return(new SystemClient(ws, w));
-    }
-}
 
 static unsigned char iconify_bits[] = {
     0x00, 0x00, 0xff, 0xff, 0x7e, 0x3c, 0x18, 0x00};
@@ -48,7 +38,7 @@ static KPixmap *btnPix=0;
 static KPixmap *btnPixDown=0;
 static KPixmap *iBtnPix=0;
 static KPixmap *iBtnPixDown=0;
-static QColor btnForeground;
+static QColor *btnForeground;
 
 static bool pixmaps_created = false;
 
@@ -79,7 +69,7 @@ static void create_pixmaps()
         aUpperGradient->resize(32, 18);
         iUpperGradient = new KPixmap;
         iUpperGradient->resize(32, 18);
-        QColor bgColor = kapp->palette().normal().background();
+        QColor bgColor = kapp->palette().active().background();
         KPixmapEffect::gradient(*aUpperGradient,
                                 options->color(Options::Frame, true).light(130),
                                 bgColor,
@@ -169,16 +159,31 @@ static void create_pixmaps()
                                                          false));
     }
     if(qGray(options->color(Options::ButtonBg, true).rgb()) > 128)
-        btnForeground = Qt::black;
+        btnForeground = new QColor(Qt::black);
     else
-        btnForeground = Qt::white;
+        btnForeground = new QColor(Qt::white);
 }
 
+static void delete_pixmaps()
+{
+    if(aUpperGradient){
+        delete aUpperGradient;
+        delete iUpperGradient;
+        delete btnPix;
+        delete btnPixDown;
+        delete iBtnPix;
+        delete iBtnPixDown;
+        aUpperGradient = 0;
+    }
+    delete btnForeground;
+    pixmaps_created = false;
+}
 
 SystemButton::SystemButton(Client *parent, const char *name,
-                           const unsigned char *bitmap)
-    : QToolButton(parent, name)
+             const unsigned char *bitmap, const QString& tip)
+    : KWinButton(parent, name, tip)
 {
+    setBackgroundMode( NoBackground );
     resize(14, 14);
     connect( this, SIGNAL( clicked() ), this, SLOT( handleClicked() ) );
     if(bitmap)
@@ -238,24 +243,22 @@ void SystemButton::drawButton(QPainter *p)
     }
 
     if(!deco.isNull()){
-        p->setPen(btnForeground);
+        p->setPen(*btnForeground);
         p->drawPixmap(isDown() ? 4 : 3, isDown() ? 4 : 3, deco);
     }
-
-    
 }
 
 void SystemButton::mousePressEvent( QMouseEvent* e )
 {
     last_button = e->button();
     QMouseEvent me ( e->type(), e->pos(), e->globalPos(), LeftButton, e->state() );
-    QToolButton::mousePressEvent( &me );
+    KWinButton::mousePressEvent( &me );
 }
 
 void SystemButton::mouseReleaseEvent( QMouseEvent* e )
 {
     QMouseEvent me ( e->type(), e->pos(), e->globalPos(), LeftButton, e->state() );
-    QToolButton::mouseReleaseEvent( &me );
+    KWinButton::mouseReleaseEvent( &me );
 }
 
 void SystemButton::handleClicked()
@@ -266,16 +269,6 @@ void SystemButton::handleClicked()
 
 void SystemClient::slotReset()
 {
-    if(aUpperGradient){
-        delete aUpperGradient;
-        delete iUpperGradient;
-        delete btnPix;
-        delete btnPixDown;
-        delete iBtnPix;
-        delete iBtnPixDown;
-    }
-    pixmaps_created = false;
-    create_pixmaps();
     titleBuffer.resize(0, 0);
     recalcTitleBuffer();
     repaint();
@@ -306,7 +299,6 @@ SystemClient::SystemClient( Workspace *ws, WId w, QWidget *parent,
                             const char *name )
     : Client( ws, w, parent, name, WResizeNoErase )
 {
-    create_pixmaps();
     connect(options, SIGNAL(resetClients()), this, SLOT(slotReset()));
     bool help = providesContextHelp();
 
@@ -319,16 +311,17 @@ SystemClient::SystemClient( Workspace *ws, WId w, QWidget *parent,
     g->addColSpacing(2, 2);
     g->addRowSpacing(2, 6);
 
-    button[0] = new SystemButton(this, "close"/*, close_bits*/);
-    button[1] = new SystemButton(this, "sticky");
+    button[0] = new SystemButton(this, "close", NULL, i18n("Close"));
+    button[1] = new SystemButton(this, "sticky", NULL, i18n("Sticky"));
     if(isSticky())
         button[1]->setBitmap(unsticky_bits);
     else
         button[1]->setBitmap(sticky_bits);
-    button[2] = new SystemButton(this, "iconify", iconify_bits);
-    button[3] = new SystemButton(this, "maximize", maximize_bits);
+
+    button[2] = new SystemButton(this, "iconify", iconify_bits, i18n("Minimize"));
+    button[3] = new SystemButton(this, "maximize", maximize_bits, i18n("Maximize"));
     if(help){
-        button[4] = new SystemButton(this, "help", question_bits);
+        button[4] = new SystemButton(this, "help", question_bits, i18n("Help"));
         connect( button[4], SIGNAL( clicked() ), this, ( SLOT( contextHelp() ) ) );
     }
     else
@@ -355,10 +348,18 @@ SystemClient::SystemClient( Workspace *ws, WId w, QWidget *parent,
     }
     hb->addWidget( button[1]);
     hb->addSpacing(1);
-    hb->addWidget( button[2]);
-    hb->addSpacing(1);
-    hb->addWidget( button[3]);
-    hb->addSpacing(3);
+
+    if (isMinimizable()) {
+         hb->addWidget(button[2]);
+         hb->addSpacing(1);
+    } else
+         button[2]->hide();
+
+    if (isMaximizable()) {
+         hb->addWidget(button[3]);
+         hb->addSpacing(3);
+    } else
+         button[3]->hide();
 
     setBackgroundMode(NoBackground);
     recalcTitleBuffer();
@@ -371,7 +372,7 @@ void SystemClient::resizeEvent( QResizeEvent* )
     recalcTitleBuffer();
     doShape();
     /*
-    if ( isVisibleToTLW() && !testWFlags( WNorthWestGravity )) {
+    if ( isVisibleToTLW() && !testWFlags( WStaticContents )) {
         QPainter p( this );
 	QRect t = titlebar->geometry();
 	t.setTop( 0 );
@@ -505,17 +506,18 @@ void SystemClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
     if (titlebar->geometry().contains( e->pos() ) )
 	workspace()->performWindowOperation( this, options->operationTitlebarDblClick() );
-    workspace()->requestFocus( this );
 }
 
 void SystemClient::stickyChange(bool on)
 {
     button[1]->setBitmap(on ? unsticky_bits : sticky_bits);
+    button[1]->setTipText(on ? i18n("Un-Sticky") : i18n("Sticky"));
 }
 
 void SystemClient::maximizeChange(bool m)
 {
     button[3]->setBitmap(m ? minmax_bits : maximize_bits);
+    button[3]->setTipText(m ? i18n("Restore") : i18n("Maximize"));
 }
 
 void SystemClient::init()
@@ -534,5 +536,27 @@ void SystemClient::activeChange(bool)
         button[4]->reset();
 }
 
+extern "C"
+{
+    Client *allocate(Workspace *ws, WId w, int)
+    {
+        return(new SystemClient(ws, w));
+    }
+    void init()
+    {
+       create_pixmaps();
+    }
+    void reset()
+    {
+       delete_pixmaps();
+       create_pixmaps();
+       // Ensure changes in tooltip state get applied
+       Workspace::self()->slotResetAllClientsDelayed();
+    }
+    void deinit()
+    {
+       delete_pixmaps();
+    }
+}
 
 #include "systemclient.moc"
