@@ -37,10 +37,13 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 
 using namespace KWinInternal;
 
+namespace KWinInternal {
 Options* options;
+};
+
 Atoms* atoms;
 
-Time kwin_time = CurrentTime;
+extern Time qt_x_time;
 int kwin_screen_number = -1;
 
 static bool initting = FALSE;
@@ -63,7 +66,7 @@ int x11ErrorHandler(Display *d, XErrorEvent *e){
 	 || e->request_code == X_GrabKey
 	 )
 	&& (e->error_code == BadAccess)) {
-	fprintf(stderr, i18n("kwin: it looks like there's already a window manager running. kwin not started").local8Bit());
+	fprintf(stderr, i18n("kwin: it looks like there's already a window manager running. kwin not started.\n").local8Bit());
 	exit(1);
     }
 
@@ -77,14 +80,14 @@ int x11ErrorHandler(Display *d, XErrorEvent *e){
     fprintf(stderr, "kwin: %s(0x%lx): %s\n", req, e->resourceid, msg);
 
     if (initting) {
-        fprintf(stderr, i18n("kwin: failure during initialisation; aborting").local8Bit());
+        fprintf(stderr, i18n("kwin: failure during initialization; aborting").local8Bit());
         exit(1);
     }
     return 0;
 }
 
 /*!
-  Updates kwin_time by receiving a current timestamp from the server.
+  Updates qt_x_time by receiving a current timestamp from the server.
 
   Use this function only when really necessary. Keep in mind that it's
   a roundtrip to the X-Server.
@@ -99,7 +102,7 @@ void kwin_updateTime()
 		    PropModeAppend, (unsigned char*) &data, 1);
     XEvent ev;
     XWindowEvent( qt_xdisplay(), w->winId(), PropertyChangeMask, &ev );
-    kwin_time = ev.xproperty.time;
+    qt_x_time = ev.xproperty.time;
 }
 
 
@@ -121,8 +124,8 @@ Application::Application( )
     options = new Options;
     atoms = new Atoms;
 
-    // create a workspace.
-    workspaces += new Workspace( isSessionRestored() );
+    // create workspace.
+    (void) new Workspace( isSessionRestored() );
 
     syncX(); // trigger possible errors, there's still a chance to abort
 
@@ -133,41 +136,16 @@ Application::Application( )
 
 Application::~Application()
 {
-     for ( WorkspaceList::Iterator it = workspaces.begin(); it != workspaces.end(); ++it) {
-	 delete (*it);
-     }
+     delete Workspace::self();
      delete options;
 }
 
 
+
 bool Application::x11EventFilter( XEvent *e )
 {
-    switch ( e->type ) {
-    case ButtonPress:
-    case ButtonRelease:
-	kwin_time = e->xbutton.time;
-	break;
-    case MotionNotify:
-	kwin_time = e->xmotion.time;
-	break;
-    case KeyPress:
-    case KeyRelease:
-	kwin_time = e->xkey.time;
-	break;
-    case PropertyNotify:
-	kwin_time = e->xproperty.time;
-	break;
-    case EnterNotify:
-    case LeaveNotify:
-	kwin_time = e->xcrossing.time;
-    default:
-	break;
-    }
-
-     for ( WorkspaceList::Iterator it = workspaces.begin(); it != workspaces.end(); ++it) {
-	 if ( (*it)->workspaceEvent( e ) )
+    if ( Workspace::self()->workspaceEvent( e ) )
 	     return TRUE;
-     }
      return KApplication::x11EventFilter( e );
 }
 
@@ -192,7 +170,7 @@ void Application::saveState( QSessionManager& sm )
 	return;
     }
 
-    workspaces.first()->storeSession( kapp->sessionConfig() );
+    Workspace::self()->storeSession( kapp->sessionConfig() );
     kapp->sessionConfig()->sync();
 }
 
@@ -201,7 +179,7 @@ static void sighandler(int) {
     QApplication::exit();
 }
 
-static const char *version = "0.9";
+static const char *version = "0.95";
 static const char *description = I18N_NOOP( "The KDE window manager." );
 
 extern "C" { int kdemain(int, char *[]); }
@@ -215,15 +193,14 @@ int kdemain( int argc, char * argv[] )
             break;
         }
     }
-    
-    QCString envir;
+
     if (! restored) {
         // we only do the multihead fork if we are not restored by the session
 	// manager, since the session manager will register multiple kwins,
         // one for each screen...
         QCString multiHead = getenv("KDE_MULTIHEAD");
-        if (multiHead.lower() == "true")
-        {
+        if (multiHead.lower() == "true") {
+	
 	    Display* dpy = XOpenDisplay( NULL );
 	    if ( !dpy ) {
 		fprintf(stderr, "%s: FATAL ERROR while trying to open display %s\n",
@@ -241,6 +218,7 @@ int kdemain( int argc, char * argv[] )
 	    if ((pos = display_name.findRev('.')) != -1 )
 		display_name.remove(pos,10); // 10 is enough to be sure we removed ".s"
 
+	    QCString envir;
 	    if (number_of_screens != 1) {
 		for (int i = 0; i < number_of_screens; i++ ) {
 		    // if execution doesn't pass by here, then kwin
@@ -256,7 +234,7 @@ int kdemain( int argc, char * argv[] )
 		//   number. If it had it, it was removed at the "pos" check
 		envir.sprintf("DISPLAY=%s.%d", display_name.data(), kwin_screen_number);
 
-		if (putenv(envir.data())) {
+		if (putenv( strdup(envir.data())) ) {
 		    fprintf(stderr,
 			    "%s: WARNING: unable to set DISPLAY environment variable\n",
 			    argv[0]);
@@ -268,7 +246,7 @@ int kdemain( int argc, char * argv[] )
 
     KAboutData aboutData( "kwin", I18N_NOOP("KWin"),
 			  version, description, KAboutData::License_BSD,
-			  "(c) 1999-2000, The KDE Developers");
+			  I18N_NOOP("(c) 1999-2001, The KDE Developers"));
     aboutData.addAuthor("Matthias Ettrich",0, "ettrich@kde.org");
     aboutData.addAuthor("Daniel M. Duley",0, "mosfet@kde.org");
 
@@ -282,7 +260,7 @@ int kdemain( int argc, char * argv[] )
 	signal(SIGHUP, SIG_IGN);
 
     Application a;
-    KCrash::setCrashHandler(crashHandler); // Try to restart on crash
+//     KCrash::setCrashHandler(crashHandler); // Try to restart on crash
     fcntl(ConnectionNumber(qt_xdisplay()), F_SETFD, 1);
 
     QCString appname;
