@@ -9,7 +9,6 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 #include <kapp.h>
 #include "workspace.h"
 
-typedef QValueList<KWinInternal::Workspace*> WorkspaceList;
 class Application : public  KApplication
 {
 public:
@@ -21,9 +20,6 @@ public:
     
 protected:
     bool x11EventFilter( XEvent * );
-
-private:
-    WorkspaceList workspaces;
 };
 
 
