@@ -5,8 +5,9 @@ Copyright (C) 1999, 2000    Daniel M. Duley <mosfet@kde.org>
 ******************************************************************/
 #include <kglobal.h>
 #include <kconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdesktopfile.h>
+#include <kdebug.h>
 #include <ksimpleconfig.h>
 #include <klocale.h>
 #include <klibloader.h>
@@ -19,33 +20,32 @@ Copyright (C) 1999, 2000    Daniel M. Duley <mosfet@kde.org>
 
 #include "plugins.h"
 
-#if 0
-#define lt_ptr lt_ptr_t
-#endif
-
 using namespace KWinInternal;
 
-const char* defaultPlugin = "libkwindefault";
+const char* defaultPlugin = "kwin_default";
 
 
 PluginMgr::PluginMgr()
     : QObject()
 {
     alloc_ptr = NULL;
-    handle = 0;
+    library = 0;
     pluginStr = "kwin_undefined";
 
-    updatePlugin();
+    KConfig *config = KGlobal::config();
+    config->setGroup("Style");
+    loadPlugin( config->readEntry("PluginLib", defaultPlugin) );
 }
 
 PluginMgr::~PluginMgr()
 {
-    if(handle) {
+    if(library) {
         // Call the plugin's cleanup function
-	lt_ptr_t deinit_func = lt_dlsym(handle, "deinit");
+	void *deinit_func = library->symbol("deinit");
 	if (deinit_func)
 	    ((void (*)())deinit_func)();
-        lt_dlclose(handle);
+	library->unload();
+	library = 0;
     }
 }
 
@@ -54,10 +54,11 @@ void PluginMgr::updatePlugin()
     KConfig *config = KGlobal::config();
     config->reparseConfiguration();
     config->setGroup("Style");
-    QString newPlugin = config->readEntry("PluginLib", defaultPlugin);
-
-    if (newPlugin != pluginStr) 
-         loadPlugin(newPlugin);
+    if ( !loadPlugin( config->readEntry("PluginLib", defaultPlugin )) && library ) {
+	void *reset_func = library->symbol("reset");
+	if (reset_func)
+	    ((void (*)())reset_func)();
+    }
 }
 
 Client* PluginMgr::allocateClient(Workspace *ws, WId w, bool tool)
@@ -71,23 +72,16 @@ Client* PluginMgr::allocateClient(Workspace *ws, WId w, bool tool)
 }
 
 // returns true if plugin was loaded successfully
-void PluginMgr::loadPlugin(QString nameStr)
+bool PluginMgr::loadPlugin(QString nameStr)
 {
-    static bool dlregistered = false;
-    lt_dlhandle oldHandle = handle;
-    handle = 0;
+    KLibrary *oldLibrary = library;
 
-    if(!dlregistered) {
-       dlregistered = true;
-       lt_dlinit();
-    }
-
-    QString path = KLibLoader::findLibrary(nameStr.latin1());
+    QString path = KLibLoader::findLibrary(QFile::encodeName(nameStr));
 
     // If the plugin was not found, try to find the default
     if (path.isEmpty()) {
         nameStr = defaultPlugin;
-        path = KLibLoader::findLibrary(nameStr.latin1());
+        path = KLibLoader::findLibrary(QFile::encodeName(nameStr));
     }
 
     // If no library was found, exit kwin with an error message
@@ -95,35 +89,38 @@ void PluginMgr::loadPlugin(QString nameStr)
         shutdownKWin(i18n("No window decoration plugin library was found!"));
 
     // Check if this library is not already loaded.
-    if(pluginStr == nameStr) 
-	return;
+    if(pluginStr == nameStr)
+	return FALSE;
 
     // Try loading the requested plugin
-    handle = lt_dlopen(path.latin1());
+    library = KLibLoader::self()->library(QFile::encodeName(path));
 
     // If that fails, fall back to the default plugin
-    if (!handle) {
+    if (!library) {
+	kdDebug() << " could not load library, try default plugin again" << endl;
         nameStr = defaultPlugin;
-        path = KLibLoader::findLibrary(nameStr.latin1());
+	if ( pluginStr == nameStr )
+	    return FALSE;
+        path = KLibLoader::findLibrary(QFile::encodeName(nameStr));
 	if (!path.isEmpty())
-            handle = lt_dlopen(path.latin1());
+            library = KLibLoader::self()->library(QFile::encodeName(path));
     }
 
-    if (!handle)
+    if (!library)
         shutdownKWin(i18n("The default decoration plugin is corrupt "
                           "and could not be loaded!"));
 
     // Call the plugin's initialisation function
-    lt_ptr_t init_func = lt_dlsym(handle, "init");
+    void *init_func = library->symbol("init");
     if (init_func)
         ((void (*)())init_func)();
 
-    lt_ptr_t alloc_func = lt_dlsym(handle, "allocate");
+    void *alloc_func = library->symbol("allocate");
     if(alloc_func) {
         alloc_ptr = (Client* (*)(Workspace *ws, WId w, int tool))alloc_func;
     } else {
-        qWarning("KWin: The library %s is not a KWin plugin.", path.latin1());
-        lt_dlclose(handle);
+        kdWarning() << "KWin: The library " << path << " is not a KWin plugin." << endl;
+        library->unload();
         exit(1);
     }
 
@@ -131,24 +128,18 @@ void PluginMgr::loadPlugin(QString nameStr)
     emit resetAllClients();
 
     // Call the old plugin's cleanup function
-    if(oldHandle) {
-	lt_ptr_t deinit_func = lt_dlsym(oldHandle, "deinit");
+    if(oldLibrary) {
+	void *deinit_func = oldLibrary->symbol("deinit");
 	if (deinit_func)
 	    ((void (*)())deinit_func)();
-        lt_dlclose(oldHandle);
+	oldLibrary->unload();
     }
-}
-
-void PluginMgr::resetPlugin()
-{
-    lt_ptr_t reset_func = lt_dlsym(handle, "reset");
-    if (reset_func)
-       ((void (*)())reset_func)();
+    return TRUE;
 }
 
 void PluginMgr::shutdownKWin(const QString &error_msg)
 {
-    qWarning( (i18n("KWin: ") + error_msg + 
+    qWarning( (i18n("KWin: ") + error_msg +
                i18n("\nKWin will now exit...")).latin1() );
     exit(1);
 }
