@@ -8,10 +8,9 @@ Copyright (C) 1999, 2000    Daniel M. Duley <mosfet@kde.org>
 
 #include <qpopupmenu.h>
 #include <qstringlist.h>
-#define LT_NON_POSIX_NAMESPACE
-#include <ltdl.h>
 
 class QFileInfo;
+class KLibrary;
 
 namespace KWinInternal {
 
@@ -25,17 +24,16 @@ public:
     PluginMgr();
     ~PluginMgr();
     Client *allocateClient(Workspace *ws, WId w, bool tool);
-    void loadPlugin(QString name);
+    bool loadPlugin(QString name);
     QString currentPlugin() { return pluginStr; }
 public slots:
     void updatePlugin();
-    void resetPlugin();
 signals:
     void resetAllClients();
 protected:
     void shutdownKWin(const QString& error_msg);
     Client* (*alloc_ptr)(Workspace *ws, WId w, int tool);
-    lt_dlhandle handle;
+    KLibrary *library;
     QString pluginStr;
 };
 
