@@ -10,10 +10,15 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 #include <qpainter.h>
 #include <qlabel.h>
 #include <qdrawutil.h>
+#include <qstyle.h>
 #undef Bool // f**king X11
 #include <kglobal.h>
 #include <kconfig.h>
 #include <klocale.h>
+#include <qapplication.h>
+#include <qdesktopwidget.h>
+#include <qcursor.h>
+#include <kstringhandler.h>
 
 // specify externals before namespace
 
@@ -25,6 +30,7 @@ TabBox::TabBox( Workspace *ws, const char *name )
     : QWidget( 0, name, WStyle_Customize | WStyle_NoBorder )
 {
     no_tasks = i18n("*** No Tasks ***");
+    m = DesktopMode; // init variables
     wspace = ws;
     reconfigure();
     reset();
@@ -88,10 +94,17 @@ void TabBox::reset()
 	desk = workspace()->currentDesktop();
     }
 
-    int w = QMAX( wmax + 20, qApp->desktop()->width()/3 );
-    setGeometry( (qApp->desktop()->width()-w)/2,
-		 qApp->desktop()->height()/2-fontMetrics().height()*2-10,
+
+    QDesktopWidget* desktop = qApp->desktop();
+    int screen =  desktop->screenNumber( QCursor::pos() );
+    QRect r = desktop->screenGeometry(screen);
+
+
+    int w = QMIN( QMAX( wmax + 20, r.width()/3 ), r.width() );
+    setGeometry( (r.width()-w)/2 + r.x(),
+		 r.height()/2-fontMetrics().height()*2-10 + r.y(),
 		 w, fontMetrics().height()*4 + 20 );
+
     wmax = QMIN( wmax, width() - 12 );
 }
 
@@ -203,8 +216,15 @@ void TabBox::paintEvent( QPaintEvent* )
 {
     {
 	QPainter p( this );
+#if QT_VERSION < 300
 	style().drawPanel( &p, 0, 0, width(), height(), colorGroup(), FALSE );
 	style().drawPanel( &p, 4, 4, width()-8, height()-8, colorGroup(), TRUE );
+#else
+	style().drawPrimitive( QStyle::PE_Panel, &p, QRect( 0, 0, width(), height() ),
+                               colorGroup(), QStyle::Style_Default );
+	style().drawPrimitive( QStyle::PE_Panel, &p, QRect( 4, 4, width()-8, height()-8 ),
+                               colorGroup(), QStyle::Style_Sunken );
+#endif
     }
     paintContents();
 }
@@ -222,19 +242,25 @@ void TabBox::paintContents()
     p.fillRect( r, colorGroup().brush( QColorGroup::Background ) );
     if ( mode () == WindowsMode ) {
 	if ( currentClient() ) {
+	    int textw, maxlen = client->caption().length();
+	    int icon = client->icon().isNull() ? 0 : 42;
 	    QString s;
-	    if (!client->isOnDesktop(workspace()->currentDesktop())){
-		s.append(": ");
-	    }
+	    do {
+		s = QString();
+		if (!client->isOnDesktop(workspace()->currentDesktop())){
+		    s.append(": ");
+		}
 
-	    if (client->isIconified())
-		s += QString("(")+client->caption()+")";
-	    else
-		s += client->caption();
-	    int textw = fontMetrics().width( s );
+		if (client->isIconified())
+		    s += QString("(")+KStringHandler::csqueeze(client->caption(), maxlen)+")";
+		else
+		    s += KStringHandler::csqueeze(client->caption(), maxlen);
+		textw = fontMetrics().width( s );
+		maxlen--;
+	    } while (textw > r.width() - icon);
 	    r.setLeft( r.left() + (r.width() - textw)/2);
 
-	    if ( !client->icon().isNull() ) {
+	    if ( icon ) {
 		int py = r.center().y() - 16;
 		r.setLeft( r.left() + 20 );
 		p.drawPixmap( r.left()-42, py, client->icon() );
