@@ -2,15 +2,16 @@
 #include <stdio.h>
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kprocess.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 
 #include "extension.h"
 #include <qwindowdefs.h>
+#include <qglobal.h>
 #include <locale.h>
 
 #include <X11/Xatom.h>
@@ -26,29 +27,29 @@ XKBExtension::XKBExtension(Display *d)
   dpy = d;
 
   qt_input_encoding = XInternAtom( d, "_QT_INPUT_ENCODING", false);
-  
-  // verify the Xlib has matching XKB extension
-  int major = XkbMajorVersion;
-  int minor = XkbMinorVersion;
-  if (!XkbLibraryVersion(&major, &minor))
-    {
-      kdDebug() << "Xlib XKB extension does not match" << endl;
-      return;
-    }
-  kdDebug() << "Xlib XKB extension major=" << major << " minor=" << minor << endl;
 
-  // verify the X server has matching XKB extension
-  // if yes, the XKB extension is initialized
-  int opcode_rtrn;
-  int error_rtrn;
-  if (!XkbQueryExtension(dpy, &opcode_rtrn, &xkb_opcode, &error_rtrn,
-			 &major, &minor))
+    // Verify the Xlib has matching XKB extension.
+
+    int major = XkbMajorVersion;
+    int minor = XkbMinorVersion;
+    if (!XkbLibraryVersion(&major, &minor))
     {
-      kdDebug() << "X server has not matching XKB extension" << endl;
-      return;
+        kdError() << "Xlib XKB extension " << major << '.' << minor <<
+            " != " << XkbMajorVersion << '.' << XkbMinorVersion << endl;
+        return;
     }
 
-  kdDebug() << "X server XKB extension major=" << major << " minor=" << minor << endl;
+    // Verify the X server has matching XKB extension.
+
+    int opcode_rtrn;
+    int error_rtrn;
+    if (!XkbQueryExtension(qt_xdisplay(), &opcode_rtrn, &xkb_opcode, &error_rtrn,
+                         &major, &minor))
+    {
+        kdError() << "X server XKB extension " << major << '.' << minor <<
+            " != " << XkbMajorVersion << '.' << XkbMinorVersion << endl;
+        return;
+    }
 }
 
 XKBExtension::~XKBExtension()
@@ -63,8 +64,11 @@ XKBExtension::~XKBExtension()
 				&after,  &data );
     if( data )
 	delete data;
-}    
-void XKBExtension::setLayout(QString rule, QString model, QString layout, const QString &encoding, unsigned int group)
+}
+
+void XKBExtension::setLayout(const QString& rule, const QString& model, 
+		const QString& layout, const char* variant, const QString& options, 
+		bool resetOld, const QString &encoding, unsigned int group)
 {
   if (rule.isEmpty() || model.isEmpty() || layout.isEmpty())
     return;
@@ -78,16 +82,37 @@ void XKBExtension::setLayout(QString rule, QString model, QString layout, const
   *p << "-rules" << rule;
   *p << "-model" << model;
   *p << "-layout" << layout;
-  
+  if( variant && *variant )
+    *p << "-variant" << variant;
+  if( resetOld )
+    *p << "-option";
+  if( !options.isEmpty() )
+    *p << "-option" << options;
+
   p->start(KProcess::Block);
 
   XkbLockGroup( dpy, XkbUseCoreKbd, group );
 //   XkbStateRec rec;
 //   XkbGetState( dpy, XkbUseCoreKbd, &rec );
 //   qDebug( "keyboard state is: group: %d, lock %d", (int)rec.group, (int)rec.locked_group);
-  
+
+#if QT_VERSION < 230
   const char * enc = encoding.latin1();
-  XChangeProperty( dpy, qt_xrootwin(), qt_input_encoding, XA_STRING, 8, 
+  XChangeProperty( dpy, qt_xrootwin(), qt_input_encoding, XA_STRING, 8,
 		   PropModeReplace, (unsigned char *)enc, strlen(enc) );
+#endif
 }
 
+
+void XKBExtension::setGroup(int group)
+{
+  XkbLockGroup( dpy, XkbUseCoreKbd, group );
+}
+
+int XKBExtension::getGroup()
+{
+    XkbStateRec xkbState;
+    XkbGetState( dpy, XkbUseCoreKbd, &xkbState);
+    
+    return xkbState.group;
+}
