@@ -5,6 +5,7 @@
 #include <X11/Xlib.h>
 #define explicit int_explicit        // avoid compiler name clash in XKBlib.h
 #include <X11/XKBlib.h> 
+#undef explicit
 
 
 class XKBExtension
@@ -15,8 +16,12 @@ public:
   XKBExtension(Display *display=0);
     ~XKBExtension();
     
-  void setLayout(QString rule, QString model, QString layout, const QString &encoding, unsigned int group);
+  void setLayout(const QString& rule, const QString& model, const QString& layout, const char* variant, 
+		    const QString& options, bool resetOldOptions, const QString &encoding, unsigned int group);
 
+  void setGroup(int group);
+  int getGroup();
+  
 private:
 
   Display *dpy;
