@@ -4,7 +4,7 @@
 #include <qpushbutton.h>
 #include <qlineedit.h>
 #include <qinputdialog.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
@@ -12,7 +12,7 @@
 #include <kfiledialog.h>
 #include <ksimpleconfig.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 
 KLegacyImport::KLegacyImport(QWidget *parent, const char *name)
@@ -89,7 +89,7 @@ other than where the pixmaps are located enter it here.</QT>"), secondPage);
 void KLegacyImport::slotBrowsePixClicked()
 {
     QString pixmapStr = KFileDialog::getExistingDirectory(QString::null, this,
-                                                          i18n("GTK theme's folder"));
+                                                          i18n("GTK Themes Folder"));
     if(!pixmapStr.isEmpty()){
         pixDirEdit->setText(pixmapStr);
         if(QFile::exists(pixmapStr + "/gtkrc")){
@@ -121,7 +121,7 @@ void KLegacyImport::slotBrowseGtkrcClicked()
 {
     QString gtkrcStr = KFileDialog::getOpenFileName(QString::null, "gtkrc",
                                                     this,
-                                                    i18n("Gtkrc theme file"));
+                                                    i18n("Gtkrc Theme File"));
     if(!gtkrcStr.isEmpty())
         finished();
 }
@@ -141,7 +141,7 @@ void KLegacyImport::slotGtkrcEdit()
 void KLegacyImport::finished()
 {
 
-    QString themeName = QInputDialog::getText(i18n("Theme title"),
+    QString themeName = QInputDialog::getText(i18n("Theme Title"),
                                               i18n("Please enter a short title for this theme"));
     if(themeName.isEmpty())
         kapp->exit();
@@ -166,7 +166,7 @@ int main(int argc, char **argv)
     KAboutData aboutData("klegacyimport", I18N_NOOP("KLegacyImport"),
                          "v0.1", I18N_NOOP("Importer for legacy themes"),
                          KAboutData::License_BSD,
-                         "(c)2000 KDE project");
+                         I18N_NOOP("(c) 2000 KDE project"));
     aboutData.addAuthor("KDE project", 0, "");
     KCmdLineArgs::init( argc, argv, &aboutData );
     KApplication app(argc, argv);
