@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Malte Starostik <malte.starostik@t-online.de>
+   Copyright (C) 2001 Malte Starostik <malte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,15 +23,13 @@
 #include <qbuffer.h>
 #include <qfile.h>
 #include <qimage.h>
-#include <qmap.h>
 #include <qtimer.h>
 
 #include <kdatastream.h> // DO NOT REMOVE, otherwise bool marshalling breaks
-#include <kglobal.h>
 #include <kicontheme.h>
 #include <kimageio.h>
 #include <ksimpleconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kio/job.h>
 
 #include "favicons.moc"
@@ -49,17 +47,22 @@ struct FaviconsModulePrivate
     QMap<KIO::Job *, DownloadInfo> downloads;
     QStringList failedDownloads;
     KSimpleConfig *config;
-	QList<KIO::Job> killJobs;
+    QPtrList<KIO::Job> killJobs;
+    KIO::MetaData metaData;
+    QString faviconsDir;
 };
 
 FaviconsModule::FaviconsModule(const QCString &obj)
     : KDEDModule(obj)
 {
     // create our favicons folder so that KIconLoader knows about it
-    (void) KGlobal::dirs()->saveLocation( "icon", "favicons" );
     d = new FaviconsModulePrivate;
+    d->faviconsDir = KGlobal::dirs()->saveLocation( "cache", "favicons/" );
+    d->faviconsDir.truncate(d->faviconsDir.length()-9); // Strip off "favicons/"
+    d->metaData.insert("ssl_no_client_cert", "TRUE");
+    d->metaData.insert("ssl_militant", "TRUE");
     d->config = new KSimpleConfig(locateLocal("data", "konqueror/faviconrc"));
-	d->killJobs.setAutoDelete(true);
+    d->killJobs.setAutoDelete(true);
 }
 
 FaviconsModule::~FaviconsModule()
@@ -72,12 +75,15 @@ QString FaviconsModule::iconForURL(const KURL &url)
     if (url.host().isEmpty())
         return QString::null;
 
-    QString iconURL = d->config->readEntry(simplifyURL(url));
-    if (!iconURL.isEmpty())
-        return iconNameFromURL(iconURL);
+    QString icon = d->config->readEntry(simplifyURL(url));
+    if (!icon.isEmpty())
+        icon = iconNameFromURL(icon);
+    else 
+        icon = url.host();
+        
+    icon = "favicons/" + icon;
 
-    QString icon = "favicons/" + url.host();
-    if (!locate("icon", icon + ".png").isEmpty())
+    if (QFile::exists(d->faviconsDir+icon+".png"))
         return icon;
 
     return QString::null;
@@ -96,6 +102,9 @@ QString FaviconsModule::simplifyURL(const KURL &url)
 
 QString FaviconsModule::iconNameFromURL(const KURL &iconURL)
 {
+    if (iconURL.path() == "/favicon.ico")
+       return iconURL.host();
+
     QString result = iconURL.host() + iconURL.path();
     // splat = and / so it can be safely used as a file name
     for (unsigned int i = 0; i < result.length(); ++i)
@@ -106,7 +115,7 @@ QString FaviconsModule::iconNameFromURL(const KURL &iconURL)
     if (ext == ".ico" || ext == ".png" || ext == ".xpm")
         result.remove(result.length() - 4, 4);
 
-    return "favicons/" + result;
+    return result;
 }
 
 bool FaviconsModule::isIconOld(const QString &icon)
@@ -120,12 +129,8 @@ bool FaviconsModule::isIconOld(const QString &icon)
 
 void FaviconsModule::setIconForURL(const KURL &url, const KURL &iconURL)
 {
-    // Ignore pages that explicitly specify /favicon.ico, like kmail.kde.org
-    if (iconURL.host() == url.host() && iconURL.path() == "/favicon.ico")
-        return;
-
-    QString iconFile = locate("icon", iconNameFromURL(iconURL) + ".png");
-    if (!(iconFile.isEmpty() || isIconOld(iconFile)))
+    QString iconFile = d->faviconsDir + "favicons/" + iconNameFromURL(iconURL) + ".png";
+    if (!isIconOld(iconFile))
         return;
 
     startDownload(simplifyURL(url), false, iconURL);
@@ -133,8 +138,8 @@ void FaviconsModule::setIconForURL(const KURL &url, const KURL &iconURL)
 
 void FaviconsModule::downloadHostIcon(const KURL &url)
 {
-    QString iconFile = locate("icon", "favicons/" + url.host() + ".png");
-    if (!(iconFile.isEmpty() || isIconOld(iconFile)))
+    QString iconFile = d->faviconsDir + "favicons/" + url.host() + ".png";
+    if (!isIconOld(iconFile))
         return;
 
     KURL iconURL(url, "/favicon.ico");
@@ -146,11 +151,8 @@ void FaviconsModule::startDownload(const QString &hostOrURL, bool isHost, const
     if (d->failedDownloads.contains(iconURL.url()))
         return;
 
-    KIO::MetaData md;
-    md.insert("ssl_militant", "TRUE");
-    md.insert("ssl_no_client_cert", "TRUE");
-    KIO::TransferJob *job = KIO::get(iconURL, false, false);
-    job->addMetaData(md);
+    KIO::Job *job = KIO::get(iconURL, false, false);
+    job->addMetaData(d->metaData);
     connect(job, SIGNAL(data(KIO::Job *, const QByteArray &)), SLOT(slotData(KIO::Job *, const QByteArray &)));
     connect(job, SIGNAL(result(KIO::Job *)), SLOT(slotResult(KIO::Job *)));
     connect(job, SIGNAL(infoMessage(KIO::Job *, const QString &)), SLOT(slotInfoMessage(KIO::Job *, const QString &)));
@@ -198,12 +200,14 @@ void FaviconsModule::slotResult(KIO::Job *job)
                 io.setImage(io.image().smoothScale(KIcon::SizeSmall, KIcon::SizeSmall));
 
             if (download.isHost)
-                iconName = "favicons/" + download.hostOrURL;
+                iconName = download.hostOrURL;
             else
                 iconName = iconNameFromURL(iconURL);
 
+            iconName = "favicons/" + iconName;
+                
             io.setIODevice(0);
-            io.setFileName(locateLocal("icon", iconName + ".png"));
+            io.setFileName(d->faviconsDir + iconName + ".png");
             io.setFormat("PNG");
             if (!io.write())
                 iconName = QString::null;
@@ -214,20 +218,13 @@ void FaviconsModule::slotResult(KIO::Job *job)
     if (iconName.isEmpty())
         d->failedDownloads.append(iconURL);
 
-    QByteArray data;
-    QDataStream stream( data, IO_WriteOnly );
-    stream << download.isHost << download.hostOrURL << iconName;
-    emitDCOPSignal("iconChanged(bool,QString,QString)", data);
+    emit iconChanged(download.isHost, download.hostOrURL, iconName);
 }
 
 void FaviconsModule::slotInfoMessage(KIO::Job *job, const QString &msg)
 {
-  FaviconsModulePrivate::DownloadInfo download = d->downloads[job];
-  QString iconURL = static_cast<KIO::TransferJob *>(job)->url().url();
-  QByteArray data;
-  QDataStream stream( data, IO_WriteOnly );
-  stream << iconURL << msg;
-  emitDCOPSignal("infoMessage(KURL,QString)", data);
+    QString iconURL = static_cast<KIO::TransferJob *>(job)->url().url();
+    emit infoMessage(iconURL, msg);
 }
 
 void FaviconsModule::slotKill()
