@@ -18,26 +18,21 @@
 */
 
 #include <qdir.h>
-#include <qpopupmenu.h>
 
-#include <kaction.h>
-#include <kapp.h>
 #include <kdebug.h>
 #include <kdesktopfile.h>
 #include <kdirwatch.h>
+#include <kinstance.h>
 #include <klineeditdlg.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <ksimpleconfig.h>
-#include <kstddirs.h>
-#include <kurl.h>
+#include <kstandarddirs.h>
 #include <kprotocolinfo.h>
 #include <kpopupmenu.h>
 
-#include <kio/global.h>
 #include <kio/job.h>
 
-#include <kpropsdlg.h>
+#include <kpropertiesdialog.h>
 //#include <konq_dirwatcher_stub.h>
 #include "konq_undo.h"
 #include "knewmenu.h"
@@ -51,24 +46,24 @@ KNewMenu::KNewMenu( KActionCollection * _collec, const char *name ) :
   KActionMenu( i18n( "Create &New" ), "filenew", _collec, name ), m_actionCollection( _collec ),
   menuItemsVersion( 0 )
 {
-    kdDebug(1203) << "KNewMenu::KNewMenu " << this << endl;
+    //kdDebug(1203) << "KNewMenu::KNewMenu " << this << endl;
   // Don't fill the menu yet
   // We'll do that in slotCheckUpToDate (should be connected to abouttoshow)
 }
 
 KNewMenu::~KNewMenu()
 {
-    kdDebug(1203) << "KNewMenu::~KNewMenu " << this << endl;
+    //kdDebug(1203) << "KNewMenu::~KNewMenu " << this << endl;
 }
 
 void KNewMenu::slotCheckUpToDate( )
 {
-    kdDebug(1203) << "KNewMenu::slotCheckUpToDate() " << this
-                  << " : menuItemsVersion=" << menuItemsVersion
-                  << " s_templatesVersion=" << s_templatesVersion << endl;
+    //kdDebug(1203) << "KNewMenu::slotCheckUpToDate() " << this
+    //              << " : menuItemsVersion=" << menuItemsVersion
+    //              << " s_templatesVersion=" << s_templatesVersion << endl;
     if (menuItemsVersion < s_templatesVersion || s_templatesVersion == 0)
     {
-        kdDebug(1203) << "KNewMenu::slotCheckUpToDate() : recreating actions" << endl;
+        //kdDebug(1203) << "KNewMenu::slotCheckUpToDate() : recreating actions" << endl;
         // We need to clean up the action collection
         // We look for our actions using the group
         QValueList<KAction*> actions = m_actionCollection->actions( "KNewMenu" );
@@ -97,7 +92,7 @@ void KNewMenu::slotCheckUpToDate( )
 
 void KNewMenu::parseFiles()
 {
-    kdDebug(1203) << "KNewMenu::parseFiles()" << endl;
+    //kdDebug(1203) << "KNewMenu::parseFiles()" << endl;
     s_filesParsed = true;
     QValueList<Entry>::Iterator templ = s_templatesList->begin();
     for ( /*++templ*/; templ != s_templatesList->end(); ++templ)
@@ -165,7 +160,7 @@ void KNewMenu::parseFiles()
 
 void KNewMenu::fillMenu()
 {
-    kdDebug(1203) << "KNewMenu::fillMenu()" << endl;
+    //kdDebug(1203) << "KNewMenu::fillMenu()" << endl;
     popupMenu()->clear();
     //KAction * act = new KAction( i18n( "Folder" ), 0, this, SLOT( slotNewFile() ),
     //                              m_actionCollection, QString("newmenu1") );
@@ -193,7 +188,7 @@ void KNewMenu::fillMenu()
             {
                 if ( (*it)->text() == (*templ).text )
                 {
-                    kdDebug(1203) << "skipping " << (*templ).filePath << endl;
+                    kdDebug(1203) << "KNewMenu: skipping " << (*templ).filePath << endl;
                     bSkip = true;
                 }
             }
@@ -206,7 +201,7 @@ void KNewMenu::fillMenu()
                 act->plug( popupMenu() );
             }
         } else { // Separate system from personal templates
-            ASSERT( (*templ).entryType != 0 );
+            Q_ASSERT( (*templ).entryType != 0 );
 
             KActionSeparator * act = new KActionSeparator();
             act->plug( popupMenu() );
@@ -216,20 +211,22 @@ void KNewMenu::fillMenu()
 
 void KNewMenu::slotFillTemplates()
 {
-    kdDebug(1203) << "KNewMenu::slotFillTemplates()" << endl;
+    //kdDebug(1203) << "KNewMenu::slotFillTemplates()" << endl;
     // Ensure any changes in the templates dir will call this
     if ( ! s_pDirWatch )
     {
-        s_pDirWatch = new KDirWatch( 5000 ); // 5 seconds
+        s_pDirWatch = new KDirWatch;
         QStringList dirs = m_actionCollection->instance()->dirs()->resourceDirs("templates");
         for ( QStringList::Iterator it = dirs.begin() ; it != dirs.end() ; ++it )
         {
-            kdDebug(1203) << "Templates resource dir: " << *it << endl;
+            //kdDebug(1203) << "Templates resource dir: " << *it << endl;
             s_pDirWatch->addDir( *it );
         }
         connect ( s_pDirWatch, SIGNAL( dirty( const QString & ) ),
                   this, SLOT ( slotFillTemplates() ) );
-        connect ( s_pDirWatch, SIGNAL( fileDirty( const QString & ) ),
+        connect ( s_pDirWatch, SIGNAL( created( const QString & ) ),
+                  this, SLOT ( slotFillTemplates() ) );
+        connect ( s_pDirWatch, SIGNAL( deleted( const QString & ) ),
                   this, SLOT ( slotFillTemplates() ) );
         // Ok, this doesn't cope with new dirs in KDEDIRS, but that's another story
     }
@@ -243,13 +240,17 @@ void KNewMenu::slotFillTemplates()
     QStringList files = m_actionCollection->instance()->dirs()->findAllResources("templates");
     for ( QStringList::Iterator it = files.begin() ; it != files.end() ; ++it )
     {
-        kdDebug(1203) << *it << endl;
+        //kdDebug(1203) << *it << endl;
         if ( (*it)[0] != '.' )
         {
             Entry e;
             e.filePath = *it;
             e.entryType = 0; // not parsed yet
-            s_templatesList->append( e );
+            // put Directory first in the list (a bit hacky)
+            if ( (*it).endsWith( "Directory.desktop" ) )
+                s_templatesList->prepend( e );
+            else
+                s_templatesList->append( e );
         }
     }
 }
@@ -259,6 +260,8 @@ void KNewMenu::slotNewFile()
     int id = QString( sender()->name() + 7 ).toInt(); // skip "newmenu"
     if (id == 0) return;
 
+    emit activated(); // for KDIconView::slotNewMenuActivated()
+
     Entry entry = *(s_templatesList->at( id - 1 ));
     //kdDebug(1203) << QString("sFile = %1").arg(sFile) << endl;
 
@@ -275,7 +278,7 @@ void KNewMenu::slotNewFile()
     if ( KDesktopFile::isDesktopFile( entry.templatePath ) )
     {
         KDesktopFile df( entry.templatePath );
-        kdDebug(1203) <<  df.readType() << endl;
+        //kdDebug(1203) <<  df.readType() << endl;
         if ( df.readType() == "Link" )
         {
             m_isURLDesktopFile = true;
