@@ -16,18 +16,16 @@
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 */
-#include <qmap.h>
 
 #include "konq_dirpart.h"
 #include "konq_bgnddlg.h"
 #include "konq_propsview.h"
-#include "konq_settings.h"
 
 #include <kaction.h>
 #include <kdatastream.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kdebug.h>
-#include <kfileitem.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <konq_drag.h>
 #include <kparts/browserextension.h>
@@ -41,7 +39,7 @@
 class KonqDirPart::KonqDirPartPrivate
 {
 public:
-    QMap<QString,QString> mimeFilterList;
+    QStringList mimeFilters;
 };
 
 KonqDirPart::KonqDirPart( QObject *parent, const char *name )
@@ -118,25 +116,22 @@ KonqDirPart::~KonqDirPart()
     delete d;
 }
 
-void KonqDirPart::setMimeFilter( const QString& mime )
+void KonqDirPart::setMimeFilter (const QStringList& mime)
 {
     QString u = url().url();
-    if ( !u.isEmpty() )
-    {
-        if ( mime.isEmpty() )
-            d->mimeFilterList.remove( u );
-        else
-            d->mimeFilterList[u] = mime;
-    }
+
+    if ( u.isEmpty () )
+        return;
+
+    if ( mime.isEmpty() )
+        d->mimeFilters.clear();
+    else
+        d->mimeFilters = mime;
 }
 
-QString KonqDirPart::mimeFilter() const
+QStringList KonqDirPart::mimeFilter() const
 {
-    QMapConstIterator<QString,QString> it = d->mimeFilterList.find(url().url());
-    if ( it != d->mimeFilterList.end() )
-        return it.data();
-    else
-        return QString::null;
+    return d->mimeFilters;
 }
 
 QScrollView * KonqDirPart::scrollWidget()
@@ -173,7 +168,7 @@ void KonqDirPart::mmbClicked( KFileItem * fileItem )
     {
         // Optimisation to avoid KRun to call kfmclient that then tells us
         // to open a window :-)
-        KService::Ptr offer = KServiceTypeProfile::preferredService(fileItem->mimetype(), true);
+        KService::Ptr offer = KServiceTypeProfile::preferredService(fileItem->mimetype(), "Application");
         //if (offer) kdDebug(1203) << "KonqDirPart::mmbClicked: got service " << offer->desktopEntryName() << endl;
         if ( offer && offer->desktopEntryName().startsWith("kfmclient") )
         {
@@ -187,12 +182,14 @@ void KonqDirPart::mmbClicked( KFileItem * fileItem )
     else
     {
         // MMB on background, try opening clipboard URL
+        QApplication::clipboard()->setSelectionMode( true );
         QMimeSource *data = QApplication::clipboard()->data();
         if ( data->provides("text/plain") )
         {
             QString url;
             if ( QTextDrag::decode( data, url ) )
             {
+                url = url.stripWhiteSpace();
                 KURL u(url);
                 if ( u.isMalformed() ) {
                     // some half-baked guesses for incomplete urls
@@ -218,7 +215,7 @@ void KonqDirPart::mmbClicked( KFileItem * fileItem )
 
 void KonqDirPart::saveNameFilter( QDataStream &stream )
 {
-    stream << m_nameFilter << d->mimeFilterList;
+    stream << m_nameFilter;
 }
 
 void KonqDirPart::saveState( QDataStream &stream )
@@ -247,7 +244,7 @@ void KonqDirPart::saveState( QDataStream &stream )
 
 void KonqDirPart::restoreNameFilter( QDataStream &stream )
 {
-    stream >> m_nameFilter >> d->mimeFilterList;
+    stream >> m_nameFilter;
     //kdDebug(1203) << "KonqDirPart::restoreNameFilter " << m_nameFilter << endl;
 }
 
@@ -275,6 +272,8 @@ void KonqDirPart::restoreState( QDataStream &stream )
 
 void KonqDirPart::slotClipboardDataChanged()
 {
+    // This is very related to KDIconView::slotClipboardDataChanged
+
     KURL::List lst;
     QMimeSource *data = QApplication::clipboard()->data();
     if ( data->provides( "application/x-kde-cutselection" ) && data->provides( "text/uri-list" ) )
@@ -330,7 +329,7 @@ void KonqDirPart::deleteItem( KFileItem * fileItem )
 void KonqDirPart::emitTotalCount()
 {
     QString summary =
-        KIO::itemsSummaryString64(m_lFileCount + m_lDirCount,
+        KIO::itemsSummaryString(m_lFileCount + m_lDirCount,
                                   m_lFileCount,
                                   m_lDirCount,
                                   m_lDirSize,
@@ -375,7 +374,7 @@ void KonqDirPart::emitCounts( const KFileItemList & lst, bool selectionChanged )
                 fileCount++;
             }
 
-        emit setStatusBarText( KIO::itemsSummaryString64(fileCount + dirCount,
+        emit setStatusBarText( KIO::itemsSummaryString(fileCount + dirCount,
                                                          fileCount,
                                                          dirCount,
                                                          fileSizeSum,
@@ -415,7 +414,7 @@ void KonqDirPart::slotIncIconSize()
     for ( int idx=1; idx < 5 ; ++idx )
         if (s == m_iIconSize[idx])
             sizeIndex = idx;
-    ASSERT( sizeIndex != 0 && sizeIndex < 4 );
+    Q_ASSERT( sizeIndex != 0 && sizeIndex < 4 );
     setIconSize( m_iIconSize[sizeIndex + 1] );
 }
 
@@ -427,7 +426,7 @@ void KonqDirPart::slotDecIconSize()
     for ( int idx=1; idx < 5 ; ++idx )
         if (s == m_iIconSize[idx])
             sizeIndex = idx;
-    ASSERT( sizeIndex > 1 );
+    Q_ASSERT( sizeIndex > 1 );
     setIconSize( m_iIconSize[sizeIndex - 1] );
 }
 
@@ -453,15 +452,26 @@ void KonqDirPart::setIconSize( int size )
     newIconSize( size );
 }
 
-void KonqDirPart::beforeOpenURL()
+bool KonqDirPart::closeURL()
+{
+    // Tell all the childern objects to clean themselves up for dinner :)
+    return doCloseURL();
+}
+
+bool KonqDirPart::openURL(const KURL& url)
 {
     if ( m_findPart )
     {
-        kdDebug(1203) << "KonqDirPart::beforeOpenURL -> emit findClosed " << this << endl;
+        kdDebug(1203) << "KonqDirPart::openURL -> emit findClosed " << this << endl;
         delete m_findPart;
         m_findPart = 0L;
         emit findClosed( this );
     }
+    
+    m_url = url;
+    emit aboutToOpenURL ();
+
+    return doOpenURL(url);
 }
 
 void KonqDirPart::setFindPart( KParts::ReadOnlyPart * part )
@@ -514,5 +524,4 @@ void KonqDirPart::slotStopAnimationSearching()
   completed();
 }
 
-
 #include "konq_dirpart.moc"
