@@ -1,5 +1,6 @@
 /* This file is part of the KDE projects
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
+   Copyright (C) 2000, 2001, 2002 David Faure <david@mandrakesoft.com>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,49 +19,245 @@
 */
 #include "konq_iconviewwidget.h"
 #include "konq_undo.h"
+#include "konq_sound.h"
 
-#include <qapplication.h>
 #include <qclipboard.h>
-#include <qfile.h>
-#include <qdragobject.h>
-#include <qlist.h>
-#include <qregion.h>
 #include <qtimer.h>
+#include <qpainter.h>
+#include <qtooltip.h>
+#include <qlabel.h>
+#include <qmovie.h>
+#include <qregexp.h>
 
-#include <kapp.h>
-#include <kcursor.h>
+#include <kapplication.h>
 #include <kdebug.h>
-#include <kio/job.h>
 #include <kio/previewjob.h>
-#include <klocale.h>
 #include <kfileivi.h>
-#include <konq_fileitem.h>
-#include <kmessagebox.h>
-#include <konq_defaults.h>
 #include <konq_settings.h>
 #include <konq_drag.h>
 #include <konq_operations.h>
-#include <konq_imagepreviewjob.h>
 #include <kglobalsettings.h>
-#include <kstddirs.h>
-#include <kpropsdlg.h>
+#include <kpropertiesdialog.h>
 #include <kipc.h>
+#include <kicontheme.h>
 #include <kiconeffect.h>
 #include <kurldrag.h>
-#include <klibloader.h>
+#include <kstandarddirs.h>
 
 #include <assert.h>
 #include <unistd.h>
 
+class KFileTip: public QLabel
+{
+public:
+    KFileTip( KIconView* parent )
+        : QLabel( 0, 0, WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WStyle_StaysOnTop | WX11BypassWM ),
+          m_view( parent ),
+          m_corner( 0 ),
+          m_filter( false )
+    {
+        setPalette( QToolTip::palette() );
+        setMargin( 1 );
+        setFrameStyle( QFrame::Plain | QFrame::Box );
+        hide();
+    }
+
+    void setOptions( bool on, int num)
+    {
+        m_num = num;
+        m_on = on;
+    }
+
+    void setItem( KFileIVI *ivi );
+
+    virtual bool eventFilter( QObject *, QEvent *e );
+
+protected:
+    virtual void drawContents( QPainter *p );
+    virtual void timerEvent( QTimerEvent * );
+
+private:
+    void setFilter( bool enable );
+
+    KIconView* m_view;
+    int        m_num;
+    bool       m_on;
+    QPixmap    m_corners[4];
+    int        m_corner;
+    bool       m_filter;
+};
+
+void KFileTip::setItem( KFileIVI *ivi )
+{
+    if (!m_on) return;
+
+    QString text = ivi ? ivi->item()->getToolTipText( m_num ) : QString::null;
+    if ( !text.isEmpty() ) {
+        setText( text );
+        adjustSize();
+        QRect rect = ivi->rect();
+        QPoint off = m_view->mapToGlobal( m_view->contentsToViewport( QPoint( 0, 0 ) ) );
+        rect.moveBy( off.x(), off.y() );
+
+        QPoint pos = rect.center();
+        // m_corner:
+        // 0: upperleft
+        // 1: upperright
+        // 2: lowerleft
+        // 3: lowerright
+        m_corner = 0;
+        // should the tooltip be shown to the left or to the right of the ivi ?
+        if ( ( ( rect.center().x() > width() ) && ( rect.center().x() - off.x() > m_view->width() / 2 ) ) ||
+             ( rect.center().x() + width() > QApplication::desktop()->width() ) )
+        {
+            // to the left
+            pos.setX( pos.x() - width() );
+            m_corner = 1;
+        }
+        // should the tooltip be shown above or below the ivi ?
+        if ( ( ( rect.top() > height() ) && ( rect.top() - off.y() > m_view->height() / 2 ) ) ||
+             ( rect.bottom() + height() > QApplication::desktop()->height() ) )
+        {
+            // above
+            pos.setY( rect.top() - height() );
+            m_corner += 2;
+        }
+        else pos.setY( rect.bottom() );
+
+        move( pos );
+        killTimers();
+        setFilter( true );
+        if ( !isVisible() ) startTimer( 700 );
+        else update();
+    }
+    else {
+        killTimers();
+        if ( isVisible() ) startTimer( 500 );
+        else setFilter( false );
+    }
+}
+
+void KFileTip::drawContents( QPainter *p )
+{
+    static const char * const names[] = {
+        "arrow_topleft",
+        "arrow_topright",
+        "arrow_bottomleft",
+        "arrow_bottomright"
+    };
+
+    if ( m_corners[m_corner].isNull() )
+        m_corners[m_corner].load( locate( "data", QString::fromLatin1( "konqueror/pics/%1.png" ).arg( names[m_corner] ) ) );
+
+    QPixmap &pix = m_corners[m_corner];
+    switch ( m_corner )
+    {
+        case 0:
+            p->drawPixmap( 3, 3, pix );
+            break;
+        case 1:
+            p->drawPixmap( width() - pix.width() - 3, 3, pix );
+            break;
+        case 2:
+            p->drawPixmap( 3, height() - pix.height() - 3, pix );
+            break;
+        case 3:
+            p->drawPixmap( width() - pix.width() - 3, height() - pix.height() - 3, pix );
+            break;
+    }
+
+    QLabel::drawContents( p );
+}
+
+void KFileTip::setFilter( bool enable )
+{
+    if ( enable == m_filter ) return;
+
+    if ( enable ) {
+        kapp->installEventFilter( this );
+        QApplication::setGlobalMouseTracking( true );
+    }
+    else {
+        QApplication::setGlobalMouseTracking( false );
+        kapp->removeEventFilter( this );
+    }
+    m_filter = enable;
+}
+
+void KFileTip::timerEvent( QTimerEvent * )
+{
+    killTimers();
+    if ( !isVisible() ) {
+        startTimer( 15000 );
+        show();
+    }
+    else {
+        setFilter( false );
+        hide();
+    }
+}
+
+bool KFileTip::eventFilter( QObject *, QEvent *e )
+{
+    switch ( e->type() )
+    {
+        case QEvent::MouseButtonPress:
+        case QEvent::MouseButtonRelease:
+        case QEvent::KeyPress:
+        case QEvent::KeyRelease:
+        case QEvent::FocusIn:
+        case QEvent::FocusOut:
+            killTimers();
+            setFilter( false );
+            hide();
+        default: break;
+    }
+
+    return false;
+}
+
 struct KonqIconViewWidgetPrivate
 {
+    KonqIconViewWidgetPrivate() {
+        pActiveItem = 0;
+        bSoundPreviews = false;
+        pSoundItem = 0;
+        bSoundItemClicked = false;
+        pSoundPlayer = 0;
+        pSoundTimer = 0;
+        pPreviewJob = 0;
+        updateAfterPreview = false;
+
+        doAnimations = true;
+        m_movie = 0L;
+        m_movieBlocked = 0;
+        pFileTip = 0;
+    }
+    ~KonqIconViewWidgetPrivate() {
+        delete pSoundPlayer;
+        delete pSoundTimer;
+        delete m_movie;
+        delete pFileTip;
+        //delete pPreviewJob; done by stopImagePreview
+    }
     KFileIVI *pActiveItem;
-    bool bSoundPreviews;
-    bool updateAfterPreview;
+    // Sound preview
     KFileIVI *pSoundItem;
-    QObject *pSoundPlayer;
+    KonqSoundPlayer *pSoundPlayer;
     QTimer *pSoundTimer;
+    bool bSoundPreviews;
+    bool bSoundItemClicked;
+
+    bool updateAfterPreview;
+
+    // Animated icons support
+    bool doAnimations;
+    QMovie* m_movie;
+    int m_movieBlocked;
+    QString movieFileName;
+
     KIO::PreviewJob *pPreviewJob;
+    KFileTip* pFileTip;
 };
 
 KonqIconViewWidget::KonqIconViewWidget( QWidget * parent, const char * name, WFlags f, bool kdesktop )
@@ -76,12 +273,6 @@ KonqIconViewWidget::KonqIconViewWidget( QWidget * parent, const char * name, WFl
     connect( this, SIGNAL( selectionChanged() ),
              this, SLOT( slotSelectionChanged() ) );
 
-    connect( horizontalScrollBar(),  SIGNAL(valueChanged(int)),
-             this,                   SIGNAL(viewportAdjusted()));
-
-    connect( verticalScrollBar(),  SIGNAL(valueChanged(int)),
-             this,                 SIGNAL(viewportAdjusted()));
-
     kapp->addKipcEventMask( KIPC::IconChanged );
     connect( kapp, SIGNAL(iconChanged(int)), SLOT(slotIconChanged(int)) );
     connect( this, SIGNAL(onItem(QIconViewItem *)), SLOT(slotOnItem(QIconViewItem *)) );
@@ -92,17 +283,13 @@ KonqIconViewWidget::KonqIconViewWidget( QWidget * parent, const char * name, WFl
     setSelectionMode( QIconView::Extended );
     setItemTextPos( QIconView::Bottom );
 
+    d->pFileTip = new KFileTip(this);
+
     calculateGridX();
     setAutoArrange( true );
     setSorting( true, sortDirection() );
+    readAnimatedIconsConfig();
     m_bSortDirsFirst = true;
-    d->pActiveItem = 0;
-    d->bSoundPreviews = false;
-    d->pSoundItem = 0;
-    d->pSoundPlayer = 0;
-    d->pSoundTimer = 0;
-    d->pPreviewJob = 0;
-    d->updateAfterPreview = false;
     m_bMousePressed = false;
     m_LineupMode = LineupBoth;
     // emit our signals
@@ -115,7 +302,6 @@ KonqIconViewWidget::~KonqIconViewWidget()
 {
     stopImagePreview();
     KonqUndoManager::decRef();
-    delete d->pSoundPlayer;
     delete d;
 }
 
@@ -144,6 +330,13 @@ void KonqIconViewWidget::slotIconChanged( int group )
     if ( m_size == 0 )
       m_size = -1; // little trick to force grid change in setIcons
     setIcons( size ); // force re-determining all icons
+    readAnimatedIconsConfig();
+}
+
+void KonqIconViewWidget::readAnimatedIconsConfig()
+{
+    KConfigGroup cfgGroup( KGlobal::config(), "DesktopIcons" );
+    d->doAnimations = cfgGroup.readBoolEntry( "Animated", true /*default*/ );
 }
 
 void KonqIconViewWidget::slotOnItem( QIconViewItem *item )
@@ -151,106 +344,187 @@ void KonqIconViewWidget::slotOnItem( QIconViewItem *item )
     // Reset icon of previous item
     if( d->pActiveItem != 0L && d->pActiveItem != item )
     {
-	d->pActiveItem->setEffect( KIcon::Desktop, KIcon::DefaultState );
-	d->pActiveItem = 0L;
+        if ( d->m_movie && d->pActiveItem->isAnimated() )
+        {
+            d->m_movie->pause(); // we'll see below what we do with it
+            d->pActiveItem->setAnimated( false );
+            d->pActiveItem->refreshIcon( true );
+        }
+        else {
+            d->pActiveItem->setActive( false );
+        }
+        d->pActiveItem = 0L;
     }
 
     // Stop sound
     if (d->pSoundPlayer != 0 && static_cast<KFileIVI *>(item) != d->pSoundItem)
     {
-	delete d->pSoundPlayer;
-	d->pSoundPlayer = 0;
+        d->pSoundPlayer->stop();
 
-	d->pSoundItem = 0;
-	if (d->pSoundTimer && d->pSoundTimer->isActive())
-    	    d->pSoundTimer->stop();
+        d->pSoundItem = 0;
+        if (d->pSoundTimer && d->pSoundTimer->isActive())
+            d->pSoundTimer->stop();
     }
 
     if ( !m_bMousePressed )
     {
-	if( item != d->pActiveItem )
-	{
-	    d->pActiveItem = static_cast<KFileIVI *>(item);
-	    d->pActiveItem->setEffect( KIcon::Desktop, KIcon::ActiveState );
-
-	    //kdDebug(1203) << "desktop;defaultstate=" <<
-	    //      KGlobal::iconLoader()->iconEffect()->
-	    //      fingerprint(KIcon::Desktop, KIcon::DefaultState) <<
-	    //      endl;
-	    //kdDebug(1203) << "desktop;activestate=" <<
-	    //      KGlobal::iconLoader()->iconEffect()->
-	    //      fingerprint(KIcon::Desktop, KIcon::ActiveState) <<
-	    //      endl;
-	}
-	else
-	{
-	    // No effect. If we want to underline on hover, we should
-	    // force the IVI to repaint here, though!
-	    d->pActiveItem = 0L;
-	}
-    }	// bMousePressed
+        if( item != d->pActiveItem )
+        {
+            d->pActiveItem = static_cast<KFileIVI *>(item);
+            if ( topLevelWidget() == kapp->activeWindow() )
+                d->pFileTip->setItem( d->pActiveItem );
+            if ( d->doAnimations && d->pActiveItem && d->pActiveItem->hasAnimation() )
+            {
+                //kdDebug(1203) << "Playing animation for: " << d->pActiveItem->mouseOverAnimation() << endl;
+                // Check if cached movie can be used
+#if 0 // Qt-mng bug, reusing the movie doesn't work currently.
+                if ( d->m_movie && d->movieFileName == d->pActiveItem->mouseOverAnimation() )
+                {
+                    d->pActiveItem->setAnimated( true );
+                    if (d->m_movieBlocked) {
+                        kdDebug(1203) << "onitem, but blocked" << endl;
+                        d->m_movie->pause();
+                    }
+                    else {
+                        kdDebug(1203) << "we go ahead.." << endl;
+                        d->m_movieBlocked++;
+                        QTimer::singleShot(300, this, SLOT(slotReenableAnimation()));
+                        d->m_movie->restart();
+                        d->m_movie->unpause();
+                    }
+                }
+                else
+#endif
+                {
+                    QMovie movie = KGlobal::iconLoader()->loadMovie( d->pActiveItem->mouseOverAnimation(), KIcon::Desktop, d->pActiveItem->iconSize() );
+                    if ( !movie.isNull() )
+                    {
+                        delete d->m_movie;
+                        d->m_movie = new QMovie( movie ); // shallow copy, don't worry
+                        // Fix alpha-channel - currently only if no background pixmap,
+                        // the bg pixmap case requires to uncomment the code at qmovie.cpp:404
+                        const QPixmap* pm = backgroundPixmap();
+                        bool hasPixmap = pm && !pm->isNull();
+                        if ( !hasPixmap ) {
+                            pm = viewport()->backgroundPixmap();
+                            hasPixmap = pm && !pm->isNull();
+                        }
+                        if (!hasPixmap && backgroundMode() != NoBackground)
+                           d->m_movie->setBackgroundColor( viewport()->backgroundColor() );
+                        d->m_movie->connectUpdate( this, SLOT( slotMovieUpdate(const QRect &) ) );
+                        d->m_movie->connectStatus( this, SLOT( slotMovieStatus(int) ) );
+                        d->movieFileName = d->pActiveItem->mouseOverAnimation();
+                        d->pActiveItem->setAnimated( true );
+                    }
+                    else
+                    {
+                        d->pActiveItem->setAnimated( false );
+                        if (d->m_movie)
+                            d->m_movie->pause();
+                        // No movie available, remember it
+                        d->pActiveItem->setMouseOverAnimation( QString::null );
+                    }
+                }
+            } // animations
+            // Only do the normal "mouseover" effect if no animation is in use
+            if (!d->pActiveItem->isAnimated())
+            {
+                d->pActiveItem->setActive( true );
+            }
+        }
+        else // No change in current item
+        {
+            // No effect. If we want to underline on hover, we should
+            // force the IVI to repaint here, though!
+            d->pActiveItem = 0L;
+            d->pFileTip->setItem( 0L );
+        }
+    } // bMousePressed
     else
     {
-      // All features disabled during mouse clicking, e.g. rectangular
-      // selection
-      d->pActiveItem = 0L;
+        // All features disabled during mouse clicking, e.g. rectangular
+        // selection
+        d->pActiveItem = 0L;
     }
 
-    if (d->bSoundPreviews && static_cast<KFileIVI *>(item)->item()->mimetype().startsWith("audio/"))
+    // ## shouldn't this be disabled during rectangular selection too ?
+    if (d->bSoundPreviews && d->pSoundPlayer &&
+        d->pSoundPlayer->mimeTypes().contains(
+            static_cast<KFileIVI *>(item)->item()->mimetype()))
     {
-      d->pSoundItem = static_cast<KFileIVI *>(item);
-      if (!d->pSoundTimer)
-      {
-        d->pSoundTimer = new QTimer(this);
-        connect(d->pSoundTimer, SIGNAL(timeout()), SLOT(slotStartSoundPreview()));
-      }
-      if (d->pSoundTimer->isActive())
-        d->pSoundTimer->stop();
-      d->pSoundTimer->start(500, true);
+        d->pSoundItem = static_cast<KFileIVI *>(item);
+        d->bSoundItemClicked = false;
+        if (!d->pSoundTimer)
+        {
+            d->pSoundTimer = new QTimer(this);
+            connect(d->pSoundTimer, SIGNAL(timeout()), SLOT(slotStartSoundPreview()));
+        }
+        if (d->pSoundTimer->isActive())
+            d->pSoundTimer->stop();
+        d->pSoundTimer->start(500, true);
     }
     else
     {
-      delete d->pSoundPlayer;
-      d->pSoundPlayer = 0;
-      d->pSoundItem = 0;
-      if (d->pSoundTimer && d->pSoundTimer->isActive())
-        d->pSoundTimer->stop();
+        if (d->pSoundPlayer)
+            d->pSoundPlayer->stop();
+        d->pSoundItem = 0;
+        if (d->pSoundTimer && d->pSoundTimer->isActive())
+            d->pSoundTimer->stop();
     }
 }
 
 void KonqIconViewWidget::slotOnViewport()
 {
-    delete d->pSoundPlayer;
-    d->pSoundPlayer = 0;
+    d->pFileTip->setItem( 0L );
+
+    if (d->pSoundPlayer)
+      d->pSoundPlayer->stop();
     d->pSoundItem = 0;
     if (d->pSoundTimer && d->pSoundTimer->isActive())
       d->pSoundTimer->stop();
 
     if (d->pActiveItem == 0L)
         return;
-				
-    d->pActiveItem->setEffect( KIcon::Desktop, KIcon::DefaultState );
+
+    if ( d->doAnimations && d->m_movie && d->pActiveItem->isAnimated() )
+    {
+        d->pActiveItem->setAnimated( false );
+#if 0
+        // Aborting before the end of the animation ?
+        if (d->m_movie->running()) {
+            d->m_movie->pause();
+            d->m_movieBlocked++;
+            kdDebug(1203) << "on viewport, blocking" << endl;
+            QTimer::singleShot(300, this, SLOT(slotReenableAnimation()));
+        }
+#endif
+        d->pActiveItem->refreshIcon( true );
+        Q_ASSERT( d->pActiveItem->state() == KIcon::DefaultState );
+        //delete d->m_movie;
+        //d->m_movie = 0L;
+        // TODO a timer to delete the movie after some time if unused?
+    }
+    else
+    {
+        d->pActiveItem->setActive( false );
+    }
     d->pActiveItem = 0L;
 }
 
 void KonqIconViewWidget::slotStartSoundPreview()
 {
-  if (!d->pSoundItem)
+  if (!d->pSoundItem || d->bSoundItemClicked)
     return;
-  KLibFactory *factory = KLibLoader::self()->factory("libkonqsound");
-  if (factory)
-  {
-    QStringList args;
-    args << d->pSoundItem->item()->url().url();
-    d->pSoundPlayer = factory->create(this, 0, "KPlayObject", args);
-  }
+
+  d->pSoundPlayer->play(d->pSoundItem->item()->url().url());
 }
 
 void KonqIconViewWidget::slotPreview(const KFileItem *item, const QPixmap &pix)
 {
-    for (QIconViewItem *it = firstItem(); it; it = it->nextItem()) 
+    // ### slow. Idea: move KonqKfmIconView's m_itemDict into this class
+    for (QIconViewItem *it = firstItem(); it; it = it->nextItem())
     {
-        if (static_cast<KFileIVI *>(it)->item() == item) 
+        if (static_cast<KFileIVI *>(it)->item() == item)
         {
             static_cast<KFileIVI *>(it)->setThumbnailPixmap(pix);
             d->updateAfterPreview = true;
@@ -265,10 +539,58 @@ void KonqIconViewWidget::slotPreviewResult()
         arrangeItemsInGrid();
         d->updateAfterPreview = false;
     }
-
     emit imagePreviewFinished();
 }
 
+void KonqIconViewWidget::slotMovieUpdate( const QRect& rect )
+{
+    //kdDebug(1203) << "KonqIconViewWidget::slotMovieUpdate " << rect.x() << "," << rect.y() << " " << rect.width() << "x" << rect.height() << endl;
+    Q_ASSERT( d );
+    Q_ASSERT( d->m_movie );
+    // seems stopAnimation triggers one last update
+    if ( d->pActiveItem && d->m_movie && d->pActiveItem->isAnimated() ) {
+        const QPixmap &frame = d->m_movie->framePixmap();
+        // This can happen if the icon was scaled to the desired size, so KIconLoader
+        // will happily return a movie with different dimensions than the icon
+        int iconSize=d->pActiveItem->iconSize();
+        if (iconSize==0) iconSize = KGlobal::iconLoader()->currentSize( KIcon::Desktop );
+        if ( frame.width() != iconSize || frame.height() != iconSize ) {
+            d->pActiveItem->setAnimated( false );
+            d->m_movie->pause();
+            // No movie available, remember it
+            d->pActiveItem->setMouseOverAnimation( QString::null );
+            d->pActiveItem->setActive( true );
+            return;
+        }
+        d->pActiveItem->setPixmapDirect( frame, false, false /*no redraw*/ );
+        QRect pixRect = d->pActiveItem->pixmapRect(false);
+        repaintContents( pixRect.x() + rect.x(), pixRect.y() + rect.y(), rect.width(), rect.height(), false );
+    }
+}
+
+void KonqIconViewWidget::slotMovieStatus( int status )
+{
+    if ( status < 0 ) {
+        // Error playing the MNG -> forget about it and do normal iconeffect
+        if ( d->pActiveItem && d->pActiveItem->isAnimated() ) {
+            d->pActiveItem->setAnimated( false );
+            d->pActiveItem->setMouseOverAnimation( QString::null );
+            d->pActiveItem->setActive( true );
+        }
+    }
+}
+
+void KonqIconViewWidget::slotReenableAnimation()
+{
+    if (!--d->m_movieBlocked) {
+        if ( d->pActiveItem && d->m_movie && d->m_movie->paused()) {
+            kdDebug(1203) << "reenabled animation" << endl;
+            d->m_movie->restart();
+            d->m_movie->unpause();
+        }
+    }
+}
+
 void KonqIconViewWidget::clear()
 {
     KIconView::clear();
@@ -319,47 +641,86 @@ void KonqIconViewWidget::initConfig( bool bInit )
           setItemTextBackground( NoBrush );
     }
 
+
+    d->pFileTip->setOptions(m_pSettings->showFileTips() && showToolTips(),
+                            m_pSettings->numFileTips());
+
     // Font settings
     QFont font( m_pSettings->standardFont() );
     font.setUnderline( m_pSettings->underlineLink() );
-    setItemFont( font );
-
+    if ( font != KonqIconViewWidget::font() )
+    {
+        setFont( font );
+        if (!bInit)
+        {
+            // QIconView doesn't do it by default... but if the font is made much
+            // bigger, we really need to give more space between the icons
+            arrangeItemsInGrid();
+        }
+    }
     setWordWrapIconText( m_pSettings->wordWrapText() );
 
     if (!bInit)
         updateContents();
+
 }
 
-void KonqIconViewWidget::setIcons( int size, const char * stopImagePreviewFor )
+void KonqIconViewWidget::disableSoundPreviews()
 {
-    kdDebug(1203) << "KonqIconViewWidget::setIcons( " << size << " , " << stopImagePreviewFor << ")" << endl;
+    d->bSoundPreviews = false;
+
+    if (d->pSoundPlayer)
+      d->pSoundPlayer->stop();
+    d->pSoundItem = 0;
+    if (d->pSoundTimer && d->pSoundTimer->isActive())
+      d->pSoundTimer->stop();
+}
+
+void KonqIconViewWidget::setIcons( int size, const QStringList& stopImagePreviewFor )
+{
+    //kdDebug(1203) << "KonqIconViewWidget::setIcons( " << size << " , " << stopImagePreviewFor.join(",") << ")" << endl;
     bool sizeChanged = (m_size != size);
     int oldGridX = gridX();
     m_size = size;
-    if ( sizeChanged || stopImagePreviewFor )
+    if ( sizeChanged || !stopImagePreviewFor.isEmpty() )
     {
         calculateGridX();
     }
+    bool stopAll = !stopImagePreviewFor.isEmpty() && stopImagePreviewFor.first() == "*";
     // Do this even if size didn't change, since this is used by refreshMimeTypes...
     for ( QIconViewItem *it = firstItem(); it; it = it->nextItem() ) {
         KFileIVI * ivi = static_cast<KFileIVI *>( it );
-	if ( !ivi->isThumbnail() ||
-	    ( stopImagePreviewFor && strlen(stopImagePreviewFor) == 0) ||
-	    ( stopImagePreviewFor &&
-	    ivi->thumbnailName() == stopImagePreviewFor ) )
-	{
-            // perhaps we should do one big redraw instead ?
-	    ivi->setIcon( size, ivi->state(), true, true );
-	}
-	else
-	    ivi->invalidateThumb( ivi->state(), true );
+        // Set a normal icon for files that are not thumbnails, and for files
+        // that are thumbnails but for which it should be stopped
+        if ( !ivi->isThumbnail() ||
+             stopAll ||
+             mimeTypeMatch( ivi->item()->mimetype(), stopImagePreviewFor ) )
+        {
+            ivi->setIcon( size, ivi->state(), true, true );
+        }
+        else
+            ivi->invalidateThumb( ivi->state(), true );
     }
-    if ( autoArrange() && (oldGridX != gridX() || stopImagePreviewFor) )
+    if ( autoArrange() && (oldGridX != gridX() || !stopImagePreviewFor.isEmpty()) )
     {
         arrangeItemsInGrid( true ); // take new grid into account
     }
 }
 
+bool KonqIconViewWidget::mimeTypeMatch( const QString& mimeType, const QStringList& mimeList ) const
+{
+    for (QStringList::ConstIterator mt = mimeList.begin(); mt != mimeList.end(); ++mt)
+    {
+        if ( mimeType == *mt )
+            return true;
+        // Support for *mt == "image/*"
+        QString tmp( mimeType );
+        if ( (*mt).endsWith("*") && tmp.replace(QRegExp("/.*"), "/*") == (*mt) )
+            return true;
+    }
+    return false;
+}
+
 void KonqIconViewWidget::setItemTextPos( ItemTextPos pos )
 {
     if ( m_bSetGridX )
@@ -412,6 +773,24 @@ void KonqIconViewWidget::startImagePreview( const QStringList &previewSettings,
 {
     stopImagePreview(); // just in case
 
+    // Check config
+    KConfigGroup group( KGlobal::config(), "PreviewSettings" );
+    if ( !group.readBoolEntry( url().protocol(), true ) ) {
+        kdDebug(1203) << "Previews disabled for protocol " << url().protocol() << endl;
+        emit imagePreviewFinished();
+        return;
+    }
+
+    if ((d->bSoundPreviews = previewSettings.contains( "audio/" )) &&
+        !d->pSoundPlayer)
+    {
+      KLibFactory *factory = KLibLoader::self()->factory("konq_sound");
+      if (factory)
+        d->pSoundPlayer = static_cast<KonqSoundPlayer *>(
+          factory->create(this, 0, "KonqSoundPlayer"));
+      d->bSoundPreviews = (d->pSoundPlayer != 0L);
+    }
+
     KFileItemList items;
     for ( QIconViewItem *it = firstItem(); it; it = it->nextItem() )
         if ( force || !static_cast<KFileIVI *>( it )->isThumbnail() )
@@ -424,20 +803,26 @@ void KonqIconViewWidget::startImagePreview( const QStringList &previewSettings,
         else
             onlyAudio = false;
     }
-    
+
     if ( items.isEmpty() || onlyAudio ) {
         emit imagePreviewFinished();
         return; // don't start the preview job if not really necessary
     }
-    
+
     int iconSize = m_size ? m_size : KGlobal::iconLoader()->currentSize( KIcon::Desktop );
     int size;
     if (iconSize < 28)
         size = 48;
     else if (iconSize < 40)
-        size = 60;
+#if 0 // TMS sizes, enable when KIO::Previewjob uses them
+        size = 64;
+    else if (iconSize < 60)
+        size = 96;
     else
-        size = 90;
+        size = 128;
+#endif
+        size = 60;
+    else size = 90;
 
     d->pPreviewJob = KIO::filePreview( items, size, size, iconSize,
         m_pSettings->textPreviewIconTransparency(), true /* scale */,
@@ -459,6 +844,11 @@ void KonqIconViewWidget::stopImagePreview()
     }
 }
 
+bool KonqIconViewWidget::isPreviewRunning() const
+{
+    return d->pPreviewJob;
+}
+
 KFileItemList KonqIconViewWidget::selectedFileItems()
 {
     KFileItemList lstItems;
@@ -528,7 +918,7 @@ KonqIconDrag * KonqIconViewWidget::konqDragObject( QWidget * dragSource )
     // Append all items to the drag object
     for ( QIconViewItem *it = firstItem(); it; it = it->nextItem() ) {
         if ( it->isSelected() ) {
-          QString itemURL = (static_cast<KFileIVI *>(it))->item()->url().url(0, QFont::Unicode);
+          QString itemURL = (static_cast<KFileIVI *>(it))->item()->url().url(0, 106); // 106 is mib enum for utf8 codec
           kdDebug(1203) << "itemURL=" << itemURL << endl;
           QIconDragItem id;
           id.setData( QCString(itemURL.latin1()) );
@@ -561,11 +951,6 @@ void KonqIconViewWidget::contentsDragEnterEvent( QDragEnterEvent *e )
     KIconView::contentsDragEnterEvent( e );
 }
 
-void KonqIconViewWidget::setItemFont( const QFont &f )
-{
-    setFont( f );
-}
-
 void KonqIconViewWidget::setItemColor( const QColor &c )
 {
     iColor = c;
@@ -645,7 +1030,7 @@ void KonqIconViewWidget::renameSelectedItem()
         }
     if (!item)
     {
-        ASSERT(item);
+        Q_ASSERT(item);
         return;
     }
     item->rename();
@@ -668,17 +1053,7 @@ void KonqIconViewWidget::copySelection()
 
 void KonqIconViewWidget::pasteSelection()
 {
-    KURL::List lst = selectedUrls();
-
-    // nonsense.
-    //assert ( lst.count() <= 1 );
-    /*KURL pasteURL;
-    if ( lst.count() == 1 )
-      pasteURL = lst.first();
-    else
-      pasteURL = url(); */
-
-    KonqOperations::doPaste( this, /*pasteURL*/url() );
+    KonqOperations::doPaste( this, url() );
 }
 
 KURL::List KonqIconViewWidget::selectedUrls()
@@ -721,12 +1096,6 @@ void KonqIconViewWidget::setSortDirectoriesFirst( bool b )
   m_bSortDirsFirst = b;
 }
 
-void KonqIconViewWidget::viewportResizeEvent(QResizeEvent * e)
-{
-  KIconView::viewportResizeEvent(e);
-  emit viewportAdjusted();
-}
-
 void KonqIconViewWidget::contentsDropEvent( QDropEvent * ev )
 {
   QIconViewItem *i = findItem( ev->pos() );
@@ -750,6 +1119,8 @@ void KonqIconViewWidget::contentsDropEvent( QDropEvent * ev )
   }
   // Don't do this here, it's too early !
   // slotSaveIconPositions();
+  // If we want to save after the new file gets listed, though,
+  // we could reimplement contentsDropEvent in KDIconView and set m_bNeedSave. Bah.
 }
 
 void KonqIconViewWidget::contentsMousePressEvent( QMouseEvent *e )
@@ -757,6 +1128,9 @@ void KonqIconViewWidget::contentsMousePressEvent( QMouseEvent *e )
   //kdDebug(1203) << "KonqIconViewWidget::contentsMousePressEvent" << endl;
   m_mousePos = QCursor::pos();
   m_bMousePressed = true;
+  if (d->pSoundPlayer)
+    d->pSoundPlayer->stop();
+  d->bSoundItemClicked = true;
   KIconView::contentsMousePressEvent( e );
 }
 
@@ -772,7 +1146,7 @@ void KonqIconViewWidget::slotSaveIconPositions()
     return;
   if ( !m_bDesktop )
     return; // Currently not available in Konqueror
-  //kdDebug(1203) << "KonqIconViewWidget::slotSaveIconPositions" << endl;
+  kdDebug(1214) << "KonqIconViewWidget::slotSaveIconPositions" << endl;
   KSimpleConfig dotDirectory( m_dotDirectoryPath );
   QIconViewItem *it = firstItem();
   if ( !it )
@@ -780,10 +1154,10 @@ void KonqIconViewWidget::slotSaveIconPositions()
   while ( it )
   {
     KFileIVI *ivi = static_cast<KFileIVI *>( it );
-    KonqFileItem *item = ivi->item();
+    KFileItem *item = ivi->item();
 
     dotDirectory.setGroup( QString( m_iconPositionGroupPrefix ).append( item->url().fileName() ) );
-    //kdDebug(1203) << "KonqIconViewWidget::slotSaveIconPositions " << item->url().fileName() << " " << it->x() << " " << it->y() << endl;
+    kdDebug(1214) << "KonqIconViewWidget::slotSaveIconPositions " << item->url().fileName() << " " << it->x() << " " << it->y() << endl;
     dotDirectory.writeEntry( "X", it->x() );
     dotDirectory.writeEntry( "Y", it->y() );
     dotDirectory.writeEntry( "Exists", true );
@@ -801,7 +1175,10 @@ void KonqIconViewWidget::slotSaveIconPositions()
       if ( dotDirectory.hasKey( "Exists" ) )
         dotDirectory.deleteEntry( "Exists", false );
       else
+      {
+        kdDebug(1214) << "KonqIconViewWidget::slotSaveIconPositions deleting group " << *gIt << endl;
         dotDirectory.deleteGroup( *gIt );
+      }
     }
 
   dotDirectory.sync();
@@ -830,8 +1207,8 @@ void KonqIconViewWidget::insertInGrid(QIconViewItem *item)
         y = QMAX(y, i->y() + i->height());
     }
 
-    QArray<QRect> rects = r.rects();
-    QArray<QRect>::Iterator it = rects.begin();
+    QMemArray<QRect> rects = r.rects();
+    QMemArray<QRect>::Iterator it = rects.begin();
     bool foundPlace = FALSE;
     for (; it != rects.end(); ++it)
     {
@@ -876,7 +1253,7 @@ public:
     QIconViewItem *right();
 
 private:
-    QList<QIconViewItem> mData;
+    QPtrList<QIconViewItem> mData;
 };
 
 QIconViewItem *QIVItemBin::top()
@@ -1082,7 +1459,7 @@ void KonqIconViewWidget::lineupIcons()
         {
             item = *it;
             int mid = item->x() + item->width()/2 - x1;
-            kdDebug() << "matching " << mid << " left " << left << " right " << right << endl;
+            kdDebug(1203) << "matching " << mid << " left " << left << " right " << right << endl;
             if (mid < left || (mid >= left && mid < right)) {
                 it = items.remove(it);
                 j = (item->y() + item->height()/2 - y1) / dy;
@@ -1096,7 +1473,7 @@ void KonqIconViewWidget::lineupIcons()
             } else
                 ++it;
         }
-        kdDebug() << "next round " << items.count() << endl;
+        kdDebug(1203) << "next round " << items.count() << endl;
         i = QMIN(i+1, nx - 1);
         left += max_icon_x + spacing();
     }
@@ -1271,4 +1648,4 @@ void KonqIconViewWidget::backgroundPixmapChange( const QPixmap & )
 
 #include "konq_iconviewwidget.moc"
 
-/* vim: set noet sw=4 ts=8 softtabstop=4: */
+/* vim: set et sw=4 ts=8 softtabstop=4: */
