@@ -1,5 +1,6 @@
 /*  This file is part of the KDE project
     Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
+    Copyright (C) 2000, 2001, 2002 David Faure <david@mandrakesoft.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,19 +23,19 @@
 #include <kiconloader.h>
 #include <kiconview.h>
 #include <kurl.h>
-#include <konq_fileitem.h>
 #include <qguardedptr.h>
+#include <kfileitem.h>
 
 class KonqFMSettings;
 class KFileIVI;
 class KonqIconDrag;
-class KonqImagePreviewJob;
 namespace KIO { class Job; }
 
 /**
  * A file-aware icon view, implementing drag'n'drop, KDE icon sizes,
- * user settings, ...
- * Used by kdesktop and konq_iconview
+ * user settings, animated icons...
+ * Used by kdesktop and konq_iconview.
+ *
  */
 class KonqIconViewWidget : public KIconView
 {
@@ -100,11 +101,14 @@ public:
 
     /**
      * Sets the icons of all items, and stores the @p size
-     * This doesn't touch thumbnails, except @p stopImagePreview is set to true
-     * Takes care of the grid, when changing the size
-     * @param stopImagePreviewFor set to "image/" to make images normal again, etc.
+     * This doesn't touch thumbnails, except if @p stopImagePreviewFor is set.
+     * Takes care of the grid, when changing the size.
+     *
+     * @param stopImagePreviewFor set to a list of mimetypes which should be made normal again.
+     * For instance "text/plain,image/wmf".
+     * Can be set to "*" for "all mimetypes" and to "image/"+"*" for "all images".
      */
-    void setIcons( int size, const char * stopImagePreviewFor = 0 );
+    void setIcons( int size, const QStringList& stopImagePreviewFor = QStringList() );
 
     /**
      * Called on databaseChanged
@@ -120,20 +124,27 @@ public:
      */
     int gridXValue() const;
 
+    /**
+     * Start generating the previews.
+     * @param previewSettings
+     * @param force if true, all files are looked at.
+     *    Otherwise, only those which are not a thumbnail already.
+     */
     void startImagePreview( const QStringList &previewSettings, bool force );
     void stopImagePreview();
+    bool isPreviewRunning() const;
     void setThumbnailPixmap( KFileIVI * item, const QPixmap & pixmap );
+    void disableSoundPreviews();
 
     void setURL ( const KURL & kurl );
     const KURL & url() { return m_url; }
-    void setRootItem ( const KonqFileItem * item ) { m_rootItem = item; }
+    void setRootItem ( const KFileItem * item ) { m_rootItem = item; }
 
     /**
      * Get list of selected KFileItems
      */
     KFileItemList selectedFileItems();
 
-    void setItemFont( const QFont &f );
     void setItemColor( const QColor &c );
     QColor itemColor() const;
 
@@ -184,6 +195,9 @@ public:
 
     void disableIcons( const KURL::List & lst );
 
+    QString iconPositionGroupPrefix() const { return m_iconPositionGroupPrefix; }
+    QString dotDirectoryPath() const { return m_dotDirectoryPath; }
+
 public slots:
     /**
      * Checks the new selection and emits enableAction() signals
@@ -200,7 +214,6 @@ signals:
      */
     void enableAction( const char * name, bool enabled );
 
-    void viewportAdjusted();
     void dropped();
     void imagePreviewFinished();
 
@@ -217,9 +230,13 @@ protected slots:
     void slotPreview(const KFileItem *, const QPixmap &);
     void slotPreviewResult();
 
+    void slotMovieUpdate( const QRect& rect );
+    void slotMovieStatus( int status );
+    void slotReenableAnimation();
 protected:
     virtual QDragObject *dragObject();
     KonqIconDrag *konqDragObject( QWidget * dragSource = 0L );
+    bool mimeTypeMatch( const QString& mimeType, const QStringList& mimeList ) const;
 
     virtual void drawBackground( QPainter *p, const QRect &r );
     /**
@@ -229,22 +246,21 @@ protected:
      */
     virtual void drawBackground( QPainter *p, const QRect &r,
 		 			const QPoint &pt );
-    virtual void viewportResizeEvent(QResizeEvent *);
     virtual void contentsDragEnterEvent( QDragEnterEvent *e );
     virtual void contentsDropEvent( QDropEvent *e );
     virtual void contentsMousePressEvent( QMouseEvent *e );
     virtual void contentsMouseReleaseEvent ( QMouseEvent * e );
     virtual void backgroundPixmapChange( const QPixmap & );
+    void readAnimatedIconsConfig();
 
+private:
     KURL m_url;
-    const KonqFileItem * m_rootItem;
+    const KFileItem * m_rootItem;
 
     KURL::List m_lstDragURLs;
 
     int m_size;
 
-    QGuardedPtr<KonqImagePreviewJob> m_pImagePreviewJob; /// ### KDE 3.0 remove
-
     /** Konqueror settings */
     KonqFMSettings * m_pSettings;
 
