@@ -16,54 +16,52 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include <qwidget.h>
 #include <qclipboard.h>
 #include <konq_operations.h>
-#include <kconfig.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <krun.h>
 
-#include <kdirwatch.h>
-#include <kpropsdlg.h>
 #include <kdirnotify_stub.h>
 
 #include <dcopclient.h>
 #include "konq_undo.h"
 #include "konq_defaults.h"
+#include "konqbookmarkmanager.h"
 
 // For doDrop
 #include <qdir.h>//first
 #include <assert.h>
-#include <kapp.h>
+#include <kapplication.h>
+#include <kipc.h>
 #include <kdebug.h>
+#include <kfileitem.h>
 #include <kdesktopfile.h>
 #include <kurldrag.h>
 #include <kglobalsettings.h>
 #include <kimageio.h>
 #include <kio/job.h>
 #include <kio/paste.h>
-#include <klocale.h>
 #include <konq_drag.h>
-#include <konq_fileitem.h>
 #include <konq_iconviewwidget.h>
 #include <kprotocolinfo.h>
 #include <kprocess.h>
 #include <kstringhandler.h>
-#include <kstddirs.h>
 #include <qpopupmenu.h>
-#include <qtextstream.h>
 #include <unistd.h>
 #include <X11/Xlib.h>
 
+KBookmarkManager * KonqBookmarkManager::s_bookmarkManager;
+
 KonqOperations::KonqOperations( QWidget *parent )
-    : QObject( parent, "KonqOperations" ), m_info(0L)
+    : QObject( parent, "KonqOperations" ), m_info(0L), m_pasteInfo(0L)
 {
 }
 
 KonqOperations::~KonqOperations()
 {
     delete m_info;
+    delete m_pasteInfo;
 }
 
 void KonqOperations::editMimeType( const QString & mimeType )
@@ -111,9 +109,10 @@ void KonqOperations::emptyTrash()
   KonqOperations *op = new KonqOperations( 0L );
 
   QDir trashDir( KGlobalSettings::trashPath() );
-  QStringList files = trashDir.entryList( QDir::Files | QDir::Dirs );
+  QStringList files = trashDir.entryList( QDir::All | QDir::Hidden | QDir::System );
   files.remove(QString("."));
   files.remove(QString(".."));
+  files.remove(QString(".directory"));
 
   QStringList::Iterator it(files.begin());
   for (; it != files.end(); ++it )
@@ -133,6 +132,14 @@ void KonqOperations::emptyTrash()
 
 }
 
+void KonqOperations::mkdir( QWidget *parent, const KURL & url )
+{
+    KIO::Job * job = KIO::mkdir( url );
+    KonqOperations * op = new KonqOperations( parent );
+    op->setOperation( job, MKDIR, KURL::List(), url );
+    (void) new KonqCommandRecorder( KonqCommand::MKDIR, KURL(), url, job ); // no support yet, apparently
+}
+
 void KonqOperations::doPaste( QWidget * parent, const KURL & destURL )
 {
     // move or not move ?
@@ -205,7 +212,7 @@ void KonqOperations::_del( int method, const KURL::List & selectedURLs, int conf
         job = KIO::del( selectedURLs, true );
         break;
       default:
-        ASSERT(0);
+        Q_ASSERT(0);
         delete this;
         return;
     }
@@ -217,15 +224,15 @@ void KonqOperations::_del( int method, const KURL::List & selectedURLs, int conf
 
 bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int confirmation )
 {
+    QString keyName;
     bool ask = ( confirmation == FORCE_CONFIRMATION );
     if ( !ask )
     {
-        KConfig *config = new KConfig("konquerorrc", false, true);
-        config->setGroup( "Trash" );
-        QString groupName = ( m_method == DEL ? "ConfirmDelete" : m_method == SHRED ? "ConfirmShred" : "ConfirmTrash" );
+        KConfig config("konquerorrc", true, false);
+        config.setGroup( "Trash" );
+        keyName = ( m_method == DEL ? "ConfirmDelete" : m_method == SHRED ? "ConfirmShred" : "ConfirmTrash" );
         bool defaultValue = ( m_method == DEL ? DEFAULT_CONFIRMDELETE : m_method == SHRED ? DEFAULT_CONFIRMSHRED : DEFAULT_CONFIRMTRASH );
-        ask = config->readBoolEntry( groupName, defaultValue );
-        delete config;
+        ask = config.readBoolEntry( keyName, defaultValue );
     }
     if ( ask )
     {
@@ -234,33 +241,98 @@ bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int
       for ( ; it != selectedURLs.end(); ++it )
         prettyList.append( (*it).prettyURL() );
 
+      int result;
       if ( prettyList.count() == 1 )
       {
         QString filename = KStringHandler::csqueeze(KIO::decodeFileName(selectedURLs.first().fileName()));
         QString directory = KStringHandler::csqueeze(selectedURLs.first().directory());
-        QString msg = (m_method == DEL ? i18n( "Do you really want to delete <b>%1</b> from '%2'?" ).arg( filename ).arg( directory ) :
-                       m_method == SHRED ? i18n( "Do you really want to shred <b>%1</b>?" ).arg( filename ) :
-                       i18n( "Do you really want to move <b>%1</b> to the trash?" ).arg( filename ));
-        return ( KMessageBox::questionYesNo( 0, msg ) == KMessageBox::Yes );
+        switch(m_method)
+        {
+          case DEL:
+             result = KMessageBox::warningContinueCancel( 0,
+             	i18n( "<p>Do you really want to delete <b>%1</b> from <b>%2</b>?</p>" ).arg( filename ).arg( directory ),
+		i18n( "Delete File" ),
+		i18n( "Delete" ),
+		keyName, false);
+	     break;
+
+	  case SHRED:
+             result = KMessageBox::warningContinueCancel( 0,
+             	i18n( "<p>Do you really want to shred <b>%1</b>?</p>" ).arg( filename ),
+		i18n( "Shred File" ),
+		i18n( "Shred" ),
+		keyName, false);
+	     break;
+
+          case MOVE:
+ 	  default:
+             result = KMessageBox::warningContinueCancel( 0,
+             	i18n( "<p>Do you really want to move <b>%1</b> to the trash?</p>" ).arg( filename ),
+		i18n( "Move to Trash" ),
+		i18n( "Verb", "Trash" ),
+		keyName, false);
+	     break;
+        }
       }
       else
       {
-        QString msg = (m_method == DEL ? i18n( "Do you really want to delete those %1 items?" ) :
-                       m_method == SHRED ? i18n( "Do you really want to shred those %1 items?" ) :
-                       i18n( "Do you really want to move those %1 items to the trashcan?" ));
+        switch(m_method)
+        {
+          case DEL:
+             result = KMessageBox::warningContinueCancelList( 0,
+             	i18n( "Do you really want to delete these %1 items?" ).arg(prettyList.count()),
+             	prettyList,
+		i18n( "Delete Files" ),
+		i18n( "Delete" ),
+		keyName);
+	     break;
 
-        return ( KMessageBox::questionYesNoList( 0, msg.arg(prettyList.count()), prettyList ) == KMessageBox::Yes );
+	  case SHRED:
+             result = KMessageBox::warningContinueCancelList( 0,
+                i18n( "Do you really want to shred these %1 items?" ).arg(prettyList.count()),
+                prettyList,
+                i18n( "Shred Files" ),
+		i18n( "Shred" ),
+		keyName);
+	     break;
+
+          case MOVE:
+ 	  default:
+             result = KMessageBox::warningContinueCancelList( 0,
+                i18n( "Do you really want to move these %1 items to the trashcan?" ).arg(prettyList.count()),
+                prettyList,
+		i18n( "Move to Trash" ),
+		i18n( "Verb", "Trash" ),
+		keyName);
+	     break;
+        }
       }
+      if (!keyName.isEmpty())
+      {
+         // Check kmessagebox setting... erase & copy to konquerorrc.
+         KConfig *config = kapp->config();
+         KConfigGroupSaver saver(config, "Notification Messages");
+         if (!config->readBoolEntry(keyName, true))
+         {
+            config->writeEntry(keyName, true);
+            config->sync();
+            KConfig konq_config("konquerorrc", false);
+            konq_config.setGroup( "Trash" );
+            konq_config.writeEntry( keyName, false );
+         }
+      }
+      return (result == KMessageBox::Continue);
     }
     return true;
 }
 
 //static
-void KonqOperations::doDrop( const KonqFileItem * destItem, const KURL & dest, QDropEvent * ev, QWidget * parent )
+void KonqOperations::doDrop( const KFileItem * destItem, const KURL & dest, QDropEvent * ev, QWidget * parent )
 {
     kdDebug(1203) << "dest : " << dest.url() << endl;
     KURL::List lst;
-    if ( KURLDrag::decode( ev, lst ) ) // Are they urls ?
+    QMap<QString, QString> metaData;
+    if ( KURLDrag::decode( ev, lst, metaData ) ) // Are they urls ?
     {
         if( lst.count() == 0 )
         {
@@ -268,6 +340,12 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, const KURL & dest, Q
             ev->accept(false);
             return;
         }
+        kdDebug() << "KonqOperations::doDrop metaData: " << metaData.count() << " entries." << endl;
+        QMap<QString,QString>::ConstIterator mit;
+        for( mit = metaData.begin(); mit != metaData.end(); ++mit )
+        {
+            kdDebug() << "metaData: key=" << mit.key() << " value=" << mit.data() << endl;
+        }
         // Check if we dropped something on itself
         KURL::List::Iterator it = lst.begin();
         for ( ; it != lst.end() ; it++ )
@@ -278,7 +356,7 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, const KURL & dest, Q
                 // The event source may be the view or an item (icon)
                 // Note: ev->source() can be 0L! (in case of kdesktop) (Simon)
                 if ( !ev->source() || ev->source() != parent && ev->source()->parent() != parent )
-                    KMessageBox::sorry( parent, i18n("You can't drop a directory on itself") );
+                    KMessageBox::sorry( parent, i18n("You can't drop a directory onto itself") );
                 kdDebug(1203) << "Dropped on itself" << endl;
                 ev->accept(false);
                 return; // do nothing instead of displaying kfm's annoying error box
@@ -303,7 +381,7 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, const KURL & dest, Q
         }
 
         KonqOperations * op = new KonqOperations(parent);
-        op->setDropInfo( new DropInfo( keybstate, lst, win_x, win_y, action ) );
+        op->setDropInfo( new DropInfo( keybstate, lst, metaData, win_x, win_y, action ) );
 
         // Ok, now we need destItem.
         if ( destItem )
@@ -341,12 +419,25 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, const KURL & dest, Q
             else
                 data = ev->data( formats.first() );
 
-            KIO::pasteData( dest, data );
+            // Delay the call to asyncDrop so that the event filters can return. See #38688.
+            KonqOperations * op = new KonqOperations(parent);
+            KIOPasteInfo * pi = new KIOPasteInfo;
+            pi->data = data;
+            pi->destURL = dest;
+            op->setPasteInfo( pi );
+            QTimer::singleShot( 0, op, SLOT( slotKIOPaste() ) );
         }
         ev->acceptAction();
     }
 }
 
+void KonqOperations::slotKIOPaste()
+{
+    assert(m_pasteInfo); // setPasteInfo should have been called before
+    KIO::pasteData( m_pasteInfo->destURL, m_pasteInfo->data );
+    delete m_pasteInfo;
+}
+
 void KonqOperations::asyncDrop( const KFileItem * destItem )
 {
     assert(m_info); // setDropInfo should have been called before asyncDrop
@@ -379,13 +470,12 @@ void KonqOperations::asyncDrop( const KFileItem * destItem )
             }
 
             // Check what the source can do
-            QString protocol = lst.first().protocol(); // we'll assume it's the same for all URLs (hack)
-            bool sReading = KProtocolInfo::supportsReading( protocol );
-            bool sDeleting = KProtocolInfo::supportsDeleting( protocol );
-            bool sMoving = KProtocolInfo::supportsMoving( protocol );
+            KURL url = lst.first(); // we'll assume it's the same for all URLs (hack)
+            bool sReading = KProtocolInfo::supportsReading( url );
+            bool sDeleting = KProtocolInfo::supportsDeleting( url );
+            bool sMoving = KProtocolInfo::supportsMoving( url );
             // Check what the destination can do
-            protocol = dest.protocol();
-            bool dWriting = KProtocolInfo::supportsWriting( protocol );
+            bool dWriting = KProtocolInfo::supportsWriting( dest );
             if ( !dWriting )
             {
                 delete this;
@@ -395,12 +485,12 @@ void KonqOperations::asyncDrop( const KFileItem * destItem )
             // Nor control nor shift are pressed => show popup menu
             QPopupMenu popup;
             if ( sReading )
-              popup.insertItem( i18n( "&Copy Here" ), 1 );
+              popup.insertItem(SmallIconSet("editcopy"), i18n( "&Copy Here" ), 1 );
             if ( (sMoving || (sReading && sDeleting)) )
               popup.insertItem( i18n( "&Move Here" ), 2 );
-            popup.insertItem( i18n( "&Link Here" ), 3 );
+            popup.insertItem(SmallIconSet("www"), i18n( "&Link Here" ), 3 );
             if (bSetWallpaper)
-                popup.insertItem( i18n( "Set as &Wallpaper"), 4 );
+                popup.insertItem(SmallIconSet("background"), i18n( "Set as &Wallpaper"), 4 );
 
             int result = popup.exec( m_info->mousePos );
             switch (result) {
@@ -410,7 +500,7 @@ void KonqOperations::asyncDrop( const KFileItem * destItem )
                 case 4 :
                 {
                     kdDebug(1203) << "setWallpaper iconView=" << iconView << " url=" << lst.first().url() << endl;
-                    if (iconView) iconView->setWallpaper(lst.first());
+                    if (iconView && iconView->isDesktop() ) iconView->setWallpaper(lst.first());
                     delete this;
                     return;
                 }
@@ -422,17 +512,20 @@ void KonqOperations::asyncDrop( const KFileItem * destItem )
         switch ( action ) {
             case QDropEvent::Move :
                 job = KIO::move( lst, dest );
+                job->setMetaData( m_info->metaData );
                 setOperation( job, MOVE, lst, dest );
                 (void) new KonqCommandRecorder( KonqCommand::MOVE, lst, dest, job );
                 return; // we still have stuff to do -> don't delete ourselves
             case QDropEvent::Copy :
                 job = KIO::copy( lst, dest );
+                job->setMetaData( m_info->metaData );
                 setOperation( job, COPY, lst, dest );
                 (void) new KonqCommandRecorder( KonqCommand::COPY, lst, dest, job );
                 return;
             case QDropEvent::Link :
                 kdDebug(1203) << "KonqOperations::asyncDrop lst.count=" << lst.count() << endl;
                 job = KIO::link( lst, dest );
+                job->setMetaData( m_info->metaData );
                 setOperation( job, LINK, lst, dest );
                 (void) new KonqCommandRecorder( KonqCommand::LINK, lst, dest, job );
                 return;
@@ -440,7 +533,7 @@ void KonqOperations::asyncDrop( const KFileItem * destItem )
         }
     } else
     {
-        // (If this fails, there is a bug in KonqFileItem::acceptsDrops)
+        // (If this fails, there is a bug in KFileItem::acceptsDrops)
         assert( dest.isLocalFile() );
         if ( destItem->mimetype() == "application/x-desktop")
         {
@@ -462,9 +555,9 @@ void KonqOperations::asyncDrop( const KFileItem * destItem )
         } else
         {
             // Should be a local executable
-            // (If this fails, there is a bug in KonqFileItem::acceptsDrops)
+            // (If this fails, there is a bug in KFileItem::acceptsDrops)
             kdDebug(1203) << "KonqOperations::doDrop " << dest.path() << "should be an executable" << endl;
-            ASSERT ( access( QFile::encodeName(dest.path()), X_OK ) == 0 );
+            Q_ASSERT ( access( QFile::encodeName(dest.path()), X_OK ) == 0 );
             KProcess proc;
             proc << dest.path() ;
             // Launch executable for each of the files
@@ -488,10 +581,19 @@ void KonqOperations::rename( QWidget * parent, const KURL & oldurl, const QStrin
     {
         KURL::List lst;
         lst.append(oldurl);
-        KIO::Job * job = KIO::moveAs( oldurl, newurl );
+        KIO::Job * job = KIO::moveAs( oldurl, newurl, !oldurl.isLocalFile() );
         KonqOperations * op = new KonqOperations( parent );
         op->setOperation( job, MOVE, lst, newurl );
         (void) new KonqCommandRecorder( KonqCommand::MOVE, lst, newurl, job );
+        // if old trash then update config file and emit
+        if(oldurl.isLocalFile() && oldurl.path(1) == KGlobalSettings::trashPath() ) {
+            kdDebug(1203) << "That rename was the Trashcan, updating config files" << endl;
+            KConfig *globalConfig = KGlobal::config();
+            KConfigGroupSaver cgs( globalConfig, "Paths" );
+            globalConfig->writeEntry("Trash" , newurl.path(), true, true );
+            globalConfig->sync();
+            KIPC::sendMessageAll(KIPC::SettingsChanged, KApplication::SETTINGS_PATHS);
+        }
     }
 }
 
