@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 David Faure <faure@kde.org>
+   Copyright (C) 2001 Holger Freyther <freyther@yahoo.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,33 +19,23 @@
 */
 
 #include <qdir.h>
-#include <qclipboard.h>
-#include <qapplication.h>
-#include <qdragobject.h>
 
 #include <klocale.h>
-#include <krun.h>
-#include <kbookmark.h>
 #include <kbookmarkmanager.h>
 #include <kdebug.h>
-#include <kio/job.h>
-#include <kio/paste.h>
-#include <kopenwith.h>
-#include <kmessagebox.h>
+#include <krun.h>
 #include <kprotocolinfo.h>
-#include <kservice.h>
-#include <ktrader.h>
-#include <kurl.h>
-#include <kuserprofile.h>
+#include <kiconloader.h>
+#include <klineeditdlg.h>
 #include <kglobalsettings.h>
-#include <kglobal.h>
-#include <kstddirs.h>
-#include <kxmlgui.h>
+#include <kstandarddirs.h>
+#include <kxmlguifactory.h>
 #include <kxmlguibuilder.h>
+#include <kparts/componentfactory.h>
 
 #include <assert.h>
 
-#include "kpropsdlg.h"
+#include "kpropertiesdialog.h"
 #include "knewmenu.h"
 #include "konq_popupmenu.h"
 #include "konq_operations.h"
@@ -74,14 +65,50 @@ public:
   QPopupMenu *m_menu;
 };
 
-KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
+class KonqPopupMenu::KonqPopupMenuPrivate
+{
+public:
+  QString m_urlTitle;
+};
+
+KonqPopupMenu::ProtocolInfo::ProtocolInfo( )
+{
+  m_Reading = false;
+  m_Writing = false;
+  m_Deleting = false;
+  m_Moving = false;
+  m_TrashIncluded = false;
+}
+bool KonqPopupMenu::ProtocolInfo::supportsReading() const
+{
+  return m_Reading;
+}
+bool KonqPopupMenu::ProtocolInfo::supportsWriting() const
+{
+  return m_Writing;
+}
+bool KonqPopupMenu::ProtocolInfo::supportsDeleting() const
+{
+  return m_Deleting;
+}
+bool KonqPopupMenu::ProtocolInfo::supportsMoving() const
+{
+  return m_Moving;
+}
+bool KonqPopupMenu::ProtocolInfo::trashIncluded() const
+{
+  return m_TrashIncluded;
+}
+
+KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
                               KURL viewURL,
                               KActionCollection & actions,
                               KNewMenu * newMenu,
                   bool showPropertiesAndFileType )
-  : QPopupMenu( 0L, "konq_popupmenu" ), m_actions( actions ), m_pMenuNew( newMenu ),
-    m_sViewURL(viewURL), m_lstItems(items)
+  : QPopupMenu( 0L, "konq_popupmenu" ), m_actions( actions ), m_ownActions( this, "KonqPopupMenu::m_ownActions" ),
+    m_pMenuNew( newMenu ), m_sViewURL(viewURL), m_lstItems(items), m_pManager(mgr)
 {
+  d = new KonqPopupMenuPrivate;
   assert( m_lstItems.count() >= 1 );
 
   bool currentDir     = false;
@@ -96,12 +123,14 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
   int id = 0;
 
   setFont(KGlobalSettings::menuFont());
-
+  m_pluginList.setAutoDelete( true );
   m_ownActions.setHighlightingEnabled( true );
 
   attrName = QString::fromLatin1( "name" );
 
   prepareXMLGUIStuff();
+  m_builder = new KonqPopupMenuGUIBuilder( this );
+  m_factory = new KXMLGUIFactory( m_builder );
 
   KURL url;
   KFileItemListIterator it ( m_lstItems );
@@ -144,11 +173,16 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
       sMoving = false;
       sDeleting = false;
   }
-
   //check if current url is trash
   url = m_sViewURL;
   url.cleanPath();
 
+  m_info.m_Reading = sReading;
+  m_info.m_Writing = sWriting;
+  m_info.m_Deleting = sDeleting;
+  m_info.m_Moving = sMoving;
+  m_info.m_TrashIncluded = bTrashIncluded;
+
   bool isCurrentTrash = ( url.isLocalFile() &&
                           url.path(1) == KGlobalSettings::trashPath() );
 
@@ -170,13 +204,13 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
 
   addMerge( "konqueror" );
 
-  m_paNewView = new KAction( i18n( "New Window" ), "window_new", 0, this, SLOT( slotPopupNewView() ), &m_ownActions, "newview" );
-  m_paNewView->setStatusText( i18n( "Open the document in a new window" ) );
+  KAction *actNewView = new KAction( i18n( "New Window" ), "window_new", 0, this, SLOT( slotPopupNewView() ), &m_ownActions, "newview" );
+  actNewView->setStatusText( i18n( "Open the document in a new window" ) );
 
   if ( ( isCurrentTrash && currentDir ) ||
        ( m_lstItems.count() == 1 && bTrashIncluded ) )
   {
-    addAction( m_paNewView );
+    addAction( actNewView );
     addSeparator();
 
     act = new KAction( i18n( "Empty Trash Bin" ), 0, this, SLOT( slotPopupEmptyTrashBin() ), &m_ownActions, "empytrash" );
@@ -184,14 +218,9 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
   }
   else
   {
-    // hack for khtml pages/frames
-    bool httpPage = (m_sViewURL.protocol().find("http", 0, false) == 0);
-
-    //kdDebug() << "httpPage=" << httpPage << " dir=" << S_ISDIR( mode ) << " currentDir=" << currentDir << endl;
-
-    if ( S_ISDIR( mode ) ) // all URLs are directories (also set for rmb-on-background of html pages)
+    if ( S_ISDIR(mode) && sWriting ) // A dir, and we can create things into it
     {
-      if ( currentDir && sWriting && m_pMenuNew ) // Add the "new" menu
+      if ( currentDir && m_pMenuNew ) // Current dir -> add the "new" menu
       {
         // As requested by KNewMenu :
         m_pMenuNew->slotCheckUpToDate();
@@ -201,31 +230,33 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
 
         addSeparator();
       }
-
-      if ( currentDir || httpPage )
+      else
       {
-        addAction( "up" );
-        addAction( "back" );
-        addAction( "forward" );
-        if ( currentDir )
-            addAction( "reload" );
-        addGroup( "reload" );
+        KAction *actNewDir = new KAction( i18n( "Create Directory" ), "folder_new", 0, this, SLOT( slotPopupNewDir() ), &m_ownActions, "newdir" );
+        addAction( actNewDir );
         addSeparator();
       }
+    }
 
-      addAction( m_paNewView );
+    // hack for khtml pages/frames
+    bool httpPage = (m_sViewURL.protocol().find("http", 0, false) == 0);
+
+    if ( currentDir || httpPage ) // rmb on background or html frame
+    {
+      addAction( "up" );
+      addAction( "back" );
+      addAction( "forward" );
+      if ( currentDir ) // khtml adds a different "reload frame" for frames
+        addAction( "reload" );
+      addGroup( "reload" );
       addSeparator();
     }
-    else // not all URLs are dirs
-    {
-      if ( httpPage ) // HTML link
-      {
-        addAction( m_paNewView );
-        addSeparator();
-      }
-    }
 
-    if ( sReading ) {
+    // "open in new window" always available
+    addAction( actNewView );
+    addSeparator();
+
+    if ( !currentDir && sReading ) {
       if ( sDeleting ) {
         addAction( "undo" );
         addAction( "cut" );
@@ -233,7 +264,7 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
       addAction( "copy" );
     }
 
-    if ( sWriting ) {
+    if ( S_ISDIR(mode) && sWriting ) {
       addAction( "paste" );
     }
 
@@ -260,7 +291,7 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
     }
   }
 
-  act = new KAction( i18n( "Add To Bookmarks" ), "bookmark_add", 0, this, SLOT( slotPopupAddToBookmark() ), &m_ownActions, "addbookmark" );
+  act = new KAction( i18n( "Add to Bookmarks" ), "bookmark_add", 0, this, SLOT( slotPopupAddToBookmark() ), &m_ownActions, "addbookmark" );
   addAction( act );
 
   //////////////////////////////////////////////////////
@@ -307,12 +338,11 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
   }
 
   KTrader::OfferList offers;
-  if ( !m_sMimeType.isNull() ) // common mimetype among all URLs ?
-  {
+      // if check m_sMimeType.isNull (no commom mime type) set it to all/all
       // 3 - Query for applications
-      offers = KTrader::self()->query( m_sMimeType,
+      offers = KTrader::self()->query( m_sMimeType.isNull( ) ? QString::fromLatin1( "all/all" ) : m_sMimeType ,
    "Type == 'Application' and DesktopEntryName != 'kfmclient' and DesktopEntryName != 'kfmclient_dir' and DesktopEntryName != 'kfmclient_html'" );
-  }
+
 
   //// Ok, we have everything, now insert
 
@@ -425,6 +455,7 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
       if ( insertedOffer )
         addSeparator();
   }
+  addPlugins( ); // now it's time to add plugins
 
   if ( !m_sMimeType.isEmpty() && showPropertiesAndFileType )
   {
@@ -451,8 +482,16 @@ KonqPopupMenu::KonqPopupMenu( const KFileItemList &items,
 
 KonqPopupMenu::~KonqPopupMenu()
 {
+  m_pluginList.clear();
   delete m_factory;
   delete m_builder;
+  delete d;
+  kdDebug(1203) << "~KonqPopupMenu leave" << endl;
+}
+
+void KonqPopupMenu::setURLTitle( const QString& urlTitle )
+{
+    d->m_urlTitle = urlTitle;
 }
 
 void KonqPopupMenu::slotPopupNewView()
@@ -462,6 +501,23 @@ void KonqPopupMenu::slotPopupNewView()
     (void) new KRun(*it);
 }
 
+void KonqPopupMenu::slotPopupNewDir()
+{
+    KLineEditDlg l( i18n("New Directory"), i18n("Directory"), 0L );
+    if ( l.exec() )
+    {
+        QString name = KIO::encodeFileName( l.text() );
+        KURL::List::ConstIterator it = m_lstPopupURLs.begin();
+        for ( ; it != m_lstPopupURLs.end(); it++ )
+        {
+            KURL url(*it);
+            url.addPath( name );
+            kdDebug() << "KonqPopupMenu::slotPopupNewDir creating dir " << url.url() << endl;
+            KonqOperations::mkdir( 0L, url );
+        }
+    }
+}
+
 void KonqPopupMenu::slotPopupEmptyTrashBin()
 {
   KonqOperations::emptyTrash();
@@ -469,16 +525,24 @@ void KonqPopupMenu::slotPopupEmptyTrashBin()
 
 void KonqPopupMenu::slotPopupOpenWith()
 {
-  KOpenWithHandler::getOpenWithHandler()->displayOpenWithDialog( m_lstPopupURLs );
+  KRun::displayOpenWithDialog( m_lstPopupURLs );
 }
 
 void KonqPopupMenu::slotPopupAddToBookmark()
 {
-  KBookmarkGroup root = KBookmarkManager::self()->root();
-  KURL::List::ConstIterator it = m_lstPopupURLs.begin();
-  for ( ; it != m_lstPopupURLs.end(); it++ )
-      root.addBookmark( (*it).prettyURL(), (*it).url() );
-  KBookmarkManager::self()->emitChanged( root );
+  KBookmarkGroup root = m_pManager->root();
+  if ( m_lstPopupURLs.count() == 1 ) {
+    KURL url = m_lstPopupURLs.first();
+    QString title = d->m_urlTitle.isEmpty() ? url.prettyURL() : d->m_urlTitle;
+    root.addBookmark( m_pManager, title, url.url() );
+  }
+  else
+  {
+    KURL::List::ConstIterator it = m_lstPopupURLs.begin();
+    for ( ; it != m_lstPopupURLs.end(); it++ )
+      root.addBookmark( m_pManager, (*it).prettyURL(), (*it).url() );
+  }
+  m_pManager->emitChanged( root );
 }
 
 void KonqPopupMenu::slotRunService()
@@ -542,77 +606,67 @@ KAction *KonqPopupMenu::action( const QDomElement &element ) const
 
   return res;
 }
-
-QDomDocument KonqPopupMenu::domDocument() const
-{
-  return m_doc;
-}
-
 KActionCollection *KonqPopupMenu::actionCollection() const
 {
   return const_cast<KActionCollection *>( &m_ownActions );
 }
 
-void KonqPopupMenu::addAction( KAction *act, const QDomElement &menu )
-{
-  addAction( act->name(), menu );
+QString KonqPopupMenu::mimeType( ) const {
+    return m_sMimeType;
 }
-
-void KonqPopupMenu::addAction( const char *name, const QDomElement &menu )
+KonqPopupMenu::ProtocolInfo KonqPopupMenu::protocolInfo() const
 {
-  static QString tagAction = QString::fromLatin1( "action" );
-
-  QDomElement parent = menu;
-  if ( parent.isNull() )
-    parent = m_menuElement;
-
-  QDomElement e = m_doc.createElement( tagAction );
-  parent.appendChild( e );
-  e.setAttribute( attrName, name );
+  return m_info;
 }
+void KonqPopupMenu::addPlugins( ){
+	// search for Konq_PopupMenuPlugins inspired by simons kpropsdlg
+	//search for a plugin with the right protocol
+	KTrader::OfferList plugin_offers;
+        unsigned int pluginCount = 0;
+	plugin_offers = KTrader::self()->query( m_sMimeType.isNull() ? QString::fromLatin1( "all/all" ) : m_sMimeType , "'KonqPopupMenu/Plugin' in ServiceTypes");
+        if ( plugin_offers.isEmpty() )
+	  return; // no plugins installed do not bother about it
 
-void KonqPopupMenu::addSeparator( const QDomElement &menu )
-{
-  static QString tagSeparator = QString::fromLatin1( "separator" );
+	KTrader::OfferList::ConstIterator iterator = plugin_offers.begin( );
+	KTrader::OfferList::ConstIterator end = plugin_offers.end( );
 
-  QDomElement parent = menu;
-  if ( parent.isNull() )
-    parent = m_menuElement;
+	addGroup( "plugins" );
+	// travers the offerlist
+	for(; iterator != end; ++iterator, ++pluginCount ){
+		KonqPopupMenuPlugin *plugin =
+			KParts::ComponentFactory::
+			createInstanceFromLibrary<KonqPopupMenuPlugin>( (*iterator)->library().local8Bit(),
+									this,
+									(*iterator)->name().latin1() );
+		if ( !plugin )
+			continue;
+                QString pluginClientName = QString::fromLatin1( "Plugin%1" ).arg( pluginCount );
+                addMerge( pluginClientName );
+                plugin->domDocument().documentElement().setAttribute( "name", pluginClientName );
+		m_pluginList.append( plugin );
+		insertChildClient( plugin );
+	}
 
-  parent.appendChild( m_doc.createElement( tagSeparator ) );
+	addMerge( "plugins" );
+	addSeparator();
 }
-
-void KonqPopupMenu::addMerge( const char *name )
-{
-  static QString tagMerge = QString::fromLatin1( "merge" );
-  QDomElement merge = m_doc.createElement( tagMerge );
-  m_menuElement.appendChild( merge );
-  if ( name )
-    merge.setAttribute( attrName, name );
+KURL KonqPopupMenu::url( ) const {
+  return m_sViewURL;
 }
-
-void KonqPopupMenu::addGroup( const QString &grp )
-{
-  QDomElement group = m_doc.createElement( "definegroup" );
-  m_menuElement.appendChild( group );
-  group.setAttribute( "name", grp );
+KFileItemList KonqPopupMenu::fileItemList( ) const {
+  return m_lstItems;
 }
-
-void KonqPopupMenu::prepareXMLGUIStuff()
-{
-  m_doc = QDomDocument( "kpartgui" );
-
-  QDomElement root = m_doc.createElement( "kpartgui" );
-  m_doc.appendChild( root );
-  root.setAttribute( attrName, "popupmenu" );
-
-  m_menuElement = m_doc.createElement( "Menu" );
-  root.appendChild( m_menuElement );
-  m_menuElement.setAttribute( attrName, "popupmenu" );
-
-  m_builder = new KonqPopupMenuGUIBuilder( this );
-  m_factory = new KXMLGUIFactory( m_builder );
+KURL::List KonqPopupMenu::popupURLList( ) const {
+  return m_lstPopupURLs;
 }
+/**
+	Plugin
+*/
 
+KonqPopupMenuPlugin::KonqPopupMenuPlugin( KonqPopupMenu *parent, const char *name )
+    : QObject( parent, name ) {
+}
+KonqPopupMenuPlugin::~KonqPopupMenuPlugin( ){
 
+}
 #include "konq_popupmenu.moc"
