@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 David Faure <faure@kde.org>
+   Copyright (C) 2001 Holger Freyther <freyther@yahoo.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,22 +26,25 @@
 #include <qpopupmenu.h>
 #include <qmap.h>
 #include <kaction.h>
-#include <kxmlguiclient.h>
+
 #include <qstringlist.h>
 
 #include <kfileitem.h>
 #include <kmimetype.h> // for KDEDesktopMimeType
 
+#include "konq_xmlguiclient.h"
+
 class KNewMenu;
 class KService;
-
+class KonqPopupMenuPlugin;
+class KBookmarkManager;
 /**
  * This class implements the popup menu for URLs in konqueror and kdesktop
  * It's usage is very simple : on right click, create the KonqPopupMenu instance
  * with the correct arguments, then exec() to make it appear, then destroy it.
  *
  */
-class KonqPopupMenu : public QPopupMenu, public KXMLGUIClient
+class KonqPopupMenu : public QPopupMenu, public KonqXMLGUIClient
 {
   Q_OBJECT
 public:
@@ -59,7 +63,8 @@ public:
    * The others items are automatically inserted.
    *
    */
-  KonqPopupMenu( const KFileItemList &items,
+  KonqPopupMenu( KBookmarkManager* manager,
+                 const KFileItemList &items,
                  KURL viewURL,
                  KActionCollection & actions,
                  KNewMenu * newMenu, bool showPropertiesAndFileType = true );
@@ -68,19 +73,43 @@ public:
    */
   ~KonqPopupMenu();
 
+  /**
+   * Set the title of the URL, when the popupmenu is opened for a single URL.
+   * This is used if the user chooses to add a bookmark for this URL.
+   */
+  void setURLTitle( const QString& urlTitle );
+
+  class ProtocolInfo {
+   public:
+    ProtocolInfo();
+    bool supportsReading()  const;
+    bool supportsWriting()  const;
+    bool supportsDeleting() const;
+    bool supportsMoving()   const;
+    bool trashIncluded()    const;
+   private:
+    friend class KonqPopupMenu;
+    bool m_Reading:1;
+    bool m_Writing:1;
+    bool m_Deleting:1;
+    bool m_Moving:1;
+    bool m_TrashIncluded:1;
+  };
   /**
    * Reimplemented for internal purpose
    */
   virtual KAction *action( const QDomElement &element ) const;
 
-  /**
-   * Reimplemented for internal purpose
-   */
-  virtual QDomDocument domDocument() const;
 
   virtual KActionCollection *actionCollection() const;
+  QString mimeType( ) const;
+  KURL url( ) const;
+  KFileItemList fileItemList() const;
+  KURL::List popupURLList( ) const;
+  ProtocolInfo protocolInfo() const;
 
 public slots:
+  void slotPopupNewDir();
   void slotPopupNewView();
   void slotPopupEmptyTrashBin();
   void slotPopupOpenWith();
@@ -90,18 +119,13 @@ public slots:
   void slotPopupProperties();
 
 protected:
-  void prepareXMLGUIStuff();
-  void addAction( KAction *action, const QDomElement &menu = QDomElement() );
-  void addAction( const char *name, const QDomElement &menu = QDomElement() );
-  void addSeparator( const QDomElement &menu = QDomElement() );
-  void addMerge( const char *name );
-  void addGroup( const QString &grp );
-
   KActionCollection &m_actions;
   KActionCollection m_ownActions;
 
 private:
-  KAction *m_paNewView;
+  void addPlugins( );
+  class KonqPopupMenuPrivate;
+  KonqPopupMenuPrivate *d;
   KNewMenu *m_pMenuNew;
   KURL m_sViewURL;
   QString m_sMimeType;
@@ -110,11 +134,27 @@ private:
   QMap<int,KService::Ptr> m_mapPopup;
   QMap<int,KDEDesktopMimeType::Service> m_mapPopupServices;
   bool m_bHandleEditOperations;
-  QDomDocument m_doc;
-  QDomElement m_menuElement;
   KXMLGUIFactory *m_factory;
   KXMLGUIBuilder *m_builder;
   QString attrName;
+  ProtocolInfo m_info;
+  QPtrList<KonqPopupMenuPlugin> m_pluginList;
+  KBookmarkManager* m_pManager;
+};
+
+class KonqPopupMenuPlugin : public QObject, public KonqXMLGUIClient {
+	Q_OBJECT
+public:
+  /**
+  * Constructor
+  * If you want to insert a dynamic item or menu to konqpopupmenu
+  * this class is the right choice.
+  * Create a KAction and use _popup->addAction(new KAction );
+  * If you want to create a submenu use _popup->addGroup( );
+  */
+  KonqPopupMenuPlugin( KonqPopupMenu *_popup, const char *name ); // this should also be the parent
+  virtual ~KonqPopupMenuPlugin ( );
 };
 
 #endif
+
