@@ -20,7 +20,6 @@
 #include "konq_settings.h"
 #include "konq_defaults.h"
 #include "kglobalsettings.h"
-#include <kconfig.h>
 #include <kglobal.h>
 #include <kservicetype.h>
 #include <kdesktopfile.h>
@@ -79,6 +78,9 @@ void KonqFMSettings::init( KConfig * config )
   m_alwaysNewWin = config->readBoolEntry( "AlwaysNewWin", FALSE );
 
   m_homeURL = config->readEntry("HomeURL", "~");
+  
+  m_showFileTips = config->readBoolEntry("ShowFileTips", true);
+  m_numFileTips = config->readNumEntry("FileTipsItems", 6);
 
   m_embedMap = config->entryMap( "EmbedSettings" );
 }
