@@ -26,11 +26,11 @@
 #include <qdir.h>
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kprocess.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kconfig.h>
 #include <dcopclient.h>
 #include <dcopstub.h>
