@@ -1,4 +1,4 @@
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kdebug.h>
@@ -85,13 +85,12 @@ PluginFactory::~PluginFactory()
    s_instance = 0;
 }
 
-KParts::Part * PluginFactory::createPart(QWidget *parentWidget, const char *widgetName,
+KParts::Part * PluginFactory::createPartObject(QWidget *parentWidget, const char *widgetName,
                                          QObject *parent, const char *name,
                                          const char */*classname*/, const QStringList &args)
 {
     kdDebug(1432) << "PluginFactory::create" << endl;
     KParts::Part *obj = new PluginPart(parentWidget, widgetName, parent, name, args);
-    emit objectCreated(obj);
     return obj;
 }
 
@@ -200,21 +199,23 @@ bool PluginPart::openURL(const KURL &url)
     emit setStatusBarText( i18n("Loading Netscape plugin for %1").arg(url.prettyURL()) );
 
     // create plugin widget
-    NSPluginInstance *inst = _loader->newInstance( _canvas, surl, smime, embed, argn, argv,
-                                                   kapp->dcopClient()->appId(), _callback->objId() );
+    NSPluginInstance *inst = _loader->newInstance( _canvas, surl, smime, embed,
+                                                   argn, argv,
+                                                   kapp->dcopClient()->appId(),
+                                                   _callback->objId());
+
     if ( inst ) {
-        inst->resize( _canvas->width(), _canvas->height() );
-        inst->show();
         _widget = inst;
     } else {
-        QLabel *label = new QLabel( i18n("Unable to load Netscape plugin for ") +
-                                    url.url(), _canvas );
+        QLabel *label = new QLabel( i18n("Unable to load Netscape plugin for ")
+                                    +url.url(), _canvas );
         label->setAlignment( AlignCenter | WordBreak );
-        label->resize( _canvas->width(), _canvas->height() );
-        label->show();
         _widget = label;
     }
 
+    _widget->resize( _canvas->width(), _canvas->height() );
+    _widget->show();
+
     kdDebug(1432) << "<- PluginPart::openURL = " << (inst!=0) << endl;
     return inst!=0;
 }
