@@ -21,7 +21,7 @@
 */
 
 /****************************************************************************
-** $Id: kxt.cpp,v 1.14 2001/03/08 13:25:52 mueller Exp $
+** $Id: kxt.cpp,v 1.16 2001/12/29 17:33:05 mueller Exp $
 **
 ** Implementation of Qt extension classes for Xt/Motif support.
 **
@@ -45,7 +45,7 @@
 **
 *****************************************************************************/
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <qwidget.h>
 #include <qobjectlist.h>
 #include <qwidgetlist.h>
@@ -345,7 +345,7 @@ KXtApplication::KXtApplication(Display* dpy, int& argc, char** argv,
 */
 KXtApplication::~KXtApplication()
 {
-    ASSERT(qxtapp==this);
+    Q_ASSERT(qxtapp==this);
     removeXtEventFilters();
     qxtapp = 0;
 
@@ -358,7 +358,7 @@ KXtApplication::~KXtApplication()
 
 void KXtApplication::init()
 {
-    ASSERT(qxtapp==0);
+    Q_ASSERT(qxtapp==0);
     qxtapp = this;
     installXtEventFilters();
     qt_np_add_timeoutcb(np_do_timers);
@@ -390,7 +390,7 @@ void KXtWidget::init(const char* name, WidgetClass widget_class,
     need_reroot=FALSE;
     xtparent = 0;
     if (parent ) {
-        ASSERT(!qparent);
+        Q_ASSERT(!qparent);
         xtw = XtCreateWidget(name, widget_class, parent, args, num_args);
         if ( widget_class == qWidgetClass )
             ((QWidgetRec*)xtw)->qwidget.qxtwidget = this;
@@ -398,7 +398,7 @@ void KXtWidget::init(const char* name, WidgetClass widget_class,
         if (managed)
             XtManageChild(xtw);
     } else {
-        ASSERT(!managed);
+        Q_ASSERT(!managed);
 
         String n, c;
         XtGetApplicationNameAndClass(qt_xdisplay(), &n, &c);
