@@ -34,7 +34,7 @@
 #include <qobject.h>
 #include <qstring.h>
 #include <qstringlist.h>
-#include <qqueue.h>
+#include <qptrqueue.h>
 #include <qdict.h>
 #include <qintdict.h>
 #include <qguardedptr.h>
@@ -117,7 +117,7 @@ public:
 
 protected slots:
   void data(KIO::Job *job, const QByteArray &data);
-  void totalSize(KIO::Job *job, unsigned long size);
+  void totalSize(KIO::Job *job, KIO::filesize_t size);
   void mimetype(KIO::Job * job, const QString &mimeType);
   void result(KIO::Job *job);
   void resume();
@@ -156,7 +156,7 @@ public:
   // constructor, destructor
   NSPluginInstance( NPP privateData, NPPluginFuncs *pluginFuncs, KLibrary *handle,
 		    int width, int height, QString src, QString mime,
-                    QString appId, QString callbackId,
+                    QString appId, QString callbackId, bool embed,
 		    QObject *parent, const char* name=0 );
   ~NSPluginInstance();
 
@@ -204,9 +204,9 @@ private:
 
   bool _destroyed;
   void addTempFile(KTempFile *tmpFile);
-  QList<KTempFile> _tempFiles;
+  QPtrList<KTempFile> _tempFiles;
   NSPluginCallbackIface_stub *_callback;
-  QList<NSPluginStreamBase> _streams;
+  QPtrList<NSPluginStreamBase> _streams;
   KLibrary *_handle;
   QTimer *_timer;
 
@@ -229,7 +229,9 @@ private:
       void *notify;
   };
 
-  QQueue<Request> _waitingRequests;
+  NPWindow _win;
+  NPSetWindowCallbackStruct _win_info;
+  QPtrQueue<Request> _waitingRequests;
 };
 
 
@@ -268,8 +270,8 @@ private:
   NPPluginFuncs _pluginFuncs;
   NPNetscapeFuncs _nsFuncs;
 
-  QList<NSPluginInstance> _instances;
-  QList<NSPluginInstance> _trash;
+  QPtrList<NSPluginInstance> _instances;
+  QPtrList<NSPluginInstance> _trash;
 };
 
 
