@@ -25,13 +25,13 @@
 
 #include "nsplugin.h"
 
-#include <qmessagebox.h>
+#include <kmessagebox.h>
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <dcopclient.h>
 #include <klocale.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qsocketnotifier.h>
 #include <stdlib.h>
 #include "../../config.h"
@@ -101,7 +101,7 @@ struct SocketNot
   XtInputId id;
 };
 
-QList<SocketNot> _notifiers[3];
+QPtrList<SocketNot> _notifiers[3];
 
 /**
  * socketCallback - send event to the socket notifier
@@ -129,8 +129,6 @@ void socketCallback(void *client_data, int */*source*/, XtInputId */*id*/)
 extern bool qt_set_socket_handler( int, int, QObject *, bool );
 bool qt_set_socket_handler( int sockfd, int type, QObject *obj, bool enable )
 {
-  kdDebug(1430) << "-> qt_set_socket_handler( sockfd=" << sockfd << ", type=" << type << ", obj=" << obj << ", enable=" << enable << " )" << endl;
-
   if ( sockfd < 0 || type < 0 || type > 2 || obj == 0 ) {
 #if defined(CHECK_RANGE)
       qWarning( "QSocketNotifier: Internal error" );
@@ -183,9 +181,9 @@ bool qt_set_socket_handler( int sockfd, int type, QObject *obj, bool enable )
           return FALSE;
 
       XtRemoveInput( sn->id );
+      _notifiers[type].remove();
   }
 
-  kdDebug(1430) << "<- qt_set_socket_handler" << endl;
   return TRUE;
 }
 
@@ -222,12 +220,12 @@ int main(int argc, char** argv)
    DCOPClient *dcop = app.dcopClient();
    if (!dcop->attach())
    {
-      QMessageBox::critical(NULL,
-                            i18n("Error connecting to DCOP server"),
-                            i18n("There was an error connecting to the Desktop\n"
-                                 "communications server.  Please make sure that\n"
-                                 "the 'dcopserver' process has been started, and\n"
-                                 "then try again.\n"));
+      KMessageBox::error(NULL,
+                            i18n("There was an error connecting to the Desktop "
+                                 "communications server. Please make sure that "
+                                 "the 'dcopserver' process has been started, and "
+                                 "then try again."),
+                            i18n("Error connecting to DCOP server"));
       exit(1);
    }
 
@@ -242,13 +240,9 @@ int main(int argc, char** argv)
    NSPluginViewer *viewer = new NSPluginViewer( "viewer", 0 );
 
    // start main loop
-   kdDebug(1430) << "8 - XtAppNextEvent" << endl;
-   XEvent xe;
+   kdDebug(1430) << "8 - XtAppProcessEvent" << endl;
    while (!g_quit)
-   {
-      XtAppNextEvent( g_appcon, &xe );
-      XtDispatchEvent( &xe );
-   }
+     XtAppProcessEvent( g_appcon, XtIMAll);
 
    // delete viewer
    delete viewer;
